(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    228421,       5547]
NotebookOptionsPosition[    158925,       3967]
NotebookOutlinePosition[    223595,       5403]
CellTagsIndexPosition[    223391,       5393]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"\[Copyright]", "  ", "Markus", " ", "van", " ", "Almsick"}], ",", 
   " ", 
   RowBox[{"1999", "         ", 
    RowBox[{"(", 
     RowBox[{"for", " ", "academic", " ", "use", " ", 
      RowBox[{"only", "!"}]}], ")"}]}]}], "Text",
  FontWeight->"Plain",
  FontColor->RGBColor[1, 0, 0]], "\n", 
 RowBox[{"     ", 
  StyleBox[
   RowBox[{"m", ".", "van", ".", 
    RowBox[{"almsick", "@", "arcor"}], ".", "de"}],
   FontWeight->"Plain",
   FontColor->RGBColor[1, 0, 0]]}]}], "Input",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellMargins->{{8, Inherited}, {Inherited, Inherited}},
 Evaluatable->False],

Cell[TextData[{
 "Isomers",
 StyleBox["`", "MB"],
 "Isomers",
 StyleBox["`", "MB"]
}], "Subsection",
 CellTags->{"S5.93.1", "1.1"}],

Cell[TextData[{
 "The ",
 StyleBox["Mathematica", "TI"],
 " package ",
 StyleBox["Isomers.m", "MR"],
 " enumerates substitutional isomers, enantiomers, achiral isomers, and \
diastereoisomers with P\[OAcute]lyas group theoretical enumeration scheme. A \
set of automatically loaded panels allows the user to implement a permutation \
group reflecting the point group symmetry and conformational transformations \
of a chemical compound. One can also load a database of previously \
implemented molecules. Thereafter one can calculate the number of isomers, \
enantiomers, achiral isomers, and diastereoisomers for arbitrary many \
substituents or for a given substituent distribution. Furthermore, one can \
determine the name of the point group, the equivalence class structure of the \
symmetry group, the P\[OAcute]lya polynomial, and the P\[OAcute]lya cycle \
index."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell["\<\
This loads the package, the 'Isomer Control Panel', and the 'Parent Compound \
Database'. \
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell["<<Isomers`Isomers`", "Input",
 CellTags->"S5.93.1",
 CellLabel->"In[2]:="],

Cell[TextData[{
 "Most ",
 StyleBox["Mathematica", "TI"],
 " commands, implemented in the Chemistry",
 StyleBox["`", "MB"],
 "Isomers",
 StyleBox["`", "MB"],
 "-package, are available as paste buttons on the 'Isomer Control Panel' \
palette that appears on the right side of your screen."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Editable->False,
 Selectable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellMargins->{{Inherited, Inherited}, {Inherited, 8}},
 Evaluatable->False,
 Copyable->False,
 ImageSize->{253, 222},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"ImageCacheDepth"->4}],

Cell["Isomer Control Panel", "Caption",
 CellTags->"NumberOfIsomers"],

Cell["\<\
The Isomer`-commands are divided into four groups. The first group consists \
of commands that facilitate the implementation of parent compounds. One can \
either install a new parent compound or one can load previously defined \
molecules from a database. \
\>", "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        StyleBox["ParentCompounds", "MR"], 
        RowBox[{
         RowBox[{
          StyleBox["ParentCompounds", "MR"], " ", "is", 
          StyleBox[" ",
           FontSlant->"Italic"], 
          StyleBox["a",
           FontSlant->"Plain"], 
          StyleBox[" ",
           FontSlant->"Italic"], "list", " ", "of", " ", "chemical", " ", 
          "molecule", " ", "symbols", " ", "representing", " ", "skeletons", 
          " ", "of", " ", "substitutional", " ", 
          RowBox[{"isomers", ".", "The"}], " ", "point", " ", "group", " ", 
          "symmetries", " ", "and", "  ", "conformational", " ", "properties",
           " ", "of", " ", "these", " ", "parent", " ", "compounds", " ", 
          "are", " ", "stored", " ", "in", "  ", 
          RowBox[{"Chemistry`IsomersData", ".", "m"}], " ", "and", " ", 
          "other", " ", "database", " ", "files"}], ",", " ", 
         RowBox[{
         "or", " ", "may", " ", "be", " ", "added", " ", "with", " ", 
          RowBox[{
           StyleBox["DefineParentCompound", "MR"], "."}]}]}]},
       {
        RowBox[{
         StyleBox["GetParentCompounds", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["filename", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["GetParentCompounds", "MR"], " ", "provides", 
          StyleBox[" ",
           FontSlant->"Italic"], 
          StyleBox["a",
           FontSlant->"Plain"], 
          StyleBox[" ",
           FontSlant->"Italic"], "mechanism", " ", "to", " ", "load", " ", 
          "a", "  ", "database", " ", "of", " ", "parent", " ", 
          RowBox[{"compounds", ".", " ", "One"}], " ", "loads", " ", "the", 
          " ", "default", " ", "database", "  ", 
          RowBox[{"Chemistry`IsomersData", ".", 
           StyleBox["m",
            FontSlant->"Plain"]}]}], ",", " ", 
         RowBox[{"if", " ", "one", " ", "omits", " ", "the", " ", 
          RowBox[{"filename", "."}]}]}]},
       {
        RowBox[{
         StyleBox["SaveParentCompounds", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["filename", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["SaveParentCompounds", "MR"], " ", "saves", " ", "the", 
          " ", "database", " ", "of", " ", "parent", " ", "compounds", " ", 
          "as", " ", "listed", " ", "in", " ", 
          StyleBox["ParentCompounds", "MR"], " ", "in", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", "file", " ", "specified", " ", "by", " ", 
          RowBox[{"filename", ".", " ", "One"}], " ", "saves", " ", "the", 
          " ", "database", " ", "in", " ", "the", " ", "default", " ", "file",
           " ", 
          RowBox[{"Chemistry`IsomersData", ".", 
           StyleBox["m",
            FontSlant->"Plain"]}]}], ",", " ", 
         RowBox[{"if", " ", "one", " ", "omits", " ", "the", " ", 
          RowBox[{
           StyleBox["filename", "TI"], "."}]}]}]},
       {
        RowBox[{
         StyleBox["ParentCompoundQ", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["ParentCompoundQ", "MR"], "  ", "is", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "boolean", " ", "function", " ", "that", 
         " ", "verifies", " ", "if", " ", "the", "  ", "parent", " ", 
         "compound", " ", "represented", " ", "by", "  ", 
         StyleBox["mol", "TI"], "  ", "can", " ", "be", " ", "found", " ", 
         "in", " ", "one", " ", "of", " ", "the", " ", "active", "  ", 
         "databases", " ", "such", " ", "as", " ", 
         RowBox[{"Chemistry`IsomersData", ".", 
          StyleBox["m",
           FontSlant->"Plain"], "."}]}]},
       {
        RowBox[{
         StyleBox["DefineParentCompound", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          RowBox[{
           StyleBox["{", "MR"], 
           StyleBox["gens", "TI"], 
           StyleBox["}", "MR"]}]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["DefineParentCompound", "MR"], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "provides", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "mechanism", " ", "to", " ", "extend", "  ",
          "the", " ", "database", " ", "of", " ", "parent", " ", 
         RowBox[{"compounds", ".", " ", "The"}], " ", "command", " ", 
         "installs", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "new", " ", "molecule", " ", "symbol", "  ", 
         StyleBox["mol", "IT"], "  ", "and", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "new", " ", "set", " ", "of", " ", 
         "point", " ", "group", " ", "generators", " ", 
         RowBox[{
          StyleBox["gens", "IT"], "."}]}]},
       {
        RowBox[{
         StyleBox["DeleteParentCompound", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["DeleteParentCompound", "MR"], " ", 
         StyleBox["removes",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", "the", " ", 
         "parent", " ", "compound", " ", "represented", " ", "by", "  ", 
         StyleBox["mol", "TI"], "  ", "from", " ", "the", " ", "active", " ", 
         "database", " ", "and", " ", "list", " ", "of", " ", 
         RowBox[{
          StyleBox["ParentCompounds", "MR"], "."}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["Parent compound commands", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[TextData[{
 "The Chemistry",
 StyleBox["`", "MB"],
 "Isomers",
 StyleBox["`", "MB"],
 "-package comes with a small database of parent compounds. This database \
('IsomersData.m') automatically loads with the package. Thus, a 'Parent \
Compound Database' palette appears beneath the 'Isomer Control Panel'. "
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Editable->False,
 Selectable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellMargins->{{Inherited, Inherited}, {Inherited, 8}},
 Evaluatable->False,
 Copyable->False,
 ImageSize->{253, 399},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"ImageCacheDepth"->4}],

Cell["Parent Compound Database palette ", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[TextData[{
 "To retrieve a parent compound from the database, click open one of the \
subsections for compounds 'with ",
 StyleBox["n", "TI"],
 " substituent sites', and select a molecule by pressing its button. A \
paste-button of the selected compound appears at the top of the database \
palette. The figure above shows the selection of ",
 StyleBox["Benzene", "MR"],
 "."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[TextData[{
 "To enter a new parent compound, press the ",
 Cell[BoxData[
  FormBox[
   ButtonBox[
    RowBox[{"Parent", " ", "Compound", " ", "Input", " ", "Panel"}],
    BaseStyle->None], TraditionalForm]]],
 " button at the top of the control panel to evoke a parent compound \
definition procedure. A panel, as shown below, will guide you through the \
necessary steps."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Editable->False,
 Selectable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellMargins->{{Inherited, Inherited}, {Inherited, 8}},
 Evaluatable->False,
 Copyable->False,
 ImageSize->{443, 355},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"ImageCacheDepth"->4}],

Cell["Parent Compound Definition Panel ", "Caption",
 CellTags->"NumberOfIsomers"],

Cell["\<\
Once you master the details of parent compound definitions you can circumvent \
the above panel and enter the parent compound definition directly. \
\>", "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[TextData[{
 "The definition of methane, for example, consists of a symbol, in this case ",
 StyleBox["Methane", "MR"],
 ", and a list of substituent site permutations that describe the equivalence \
of mesomorphic substituent configurations. The site permutations are entered \
as a list of ",
 StyleBox["PointGroupElement[{", "MR"],
 StyleBox["perm", "TI"],
 StyleBox["},", "MR"],
 StyleBox["refl", "TI"],
 StyleBox[",", "MR"],
 StyleBox["conf", "TI"],
 StyleBox["]", "MR"],
 ". The ",
 StyleBox["PointGroupElement", "MR"],
 "-list structure joins the site permutations with information about the \
nature of the symmetry transformations. ",
 StyleBox["refl", "TI"],
 " and ",
 StyleBox["conf", "TI"],
 " are boolean flags that are set to ",
 StyleBox["True", "MR"],
 ", if the transformation contains a reflection, or if it is \
conformational.",
 StyleBox["PointGroupElement", "MR"],
 "s may be entered and are displayed as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalR]", "[", 
    StyleBox["perm", "TI"], "]"}], TraditionalForm]]],
 ",  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    StyleBox["perm", "TI"], "]"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "c"], "[", 
    StyleBox["perm", "TI"], "]"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "c\[Sigma]"], "[", 
    StyleBox["perm", "TI"], "]"}], TraditionalForm]]],
 ". "
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[BoxData[
 RowBox[{"DefineParentCompound", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[ScriptCapitalR]", "[", 
      RowBox[{"1", ",", "3", ",", "4", ",", "2"}], "]"}], ",", 
     RowBox[{"\[ScriptCapitalR]", "[", 
      RowBox[{"2", ",", "1", ",", "4", ",", "3"}], "]"}], ",", 
     RowBox[{
      SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
      RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->"In[2]:="],

Cell["\<\
As soon as a parent compound is implemented, one can retrieve information \
about it. One should start with a few checks that verify the symmetry of the \
new molecule. For this purpose turn to the second group Isomers` commands, \
the point group commands.\
\>", "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["PointGroupGenerators", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["PointGroupGenerators", "MR"], " ", "renders", " ", "the", 
         " ", "list", " ", "of", " ", "point", " ", "group", " ", 
         "generators", " ", "that", " ", "were", " ", "implemented", " ", 
         StyleBox[
          RowBox[{"fo", 
           StyleBox["r",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "the", " ", "parent",
          " ", "compound", " ", "with", " ", "symbol", "  ", 
         RowBox[{
          StyleBox["mol", "IT"], "."}]}]},
       {
        RowBox[{
         StyleBox["PointGroupElement", "MR"], 
         StyleBox[",", "MR"], "\[ScriptCapitalR]", ",", 
         SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], ",", 
         SubscriptBox["\[ScriptCapitalR]", "c"], ",", 
         SubscriptBox["\[ScriptCapitalR]", "c\[Sigma]"]}], 
        RowBox[{
         RowBox[{
          StyleBox["PointGroupElement", "MR"], " ", "is", " ", "the", " ", 
          "head", " ", "of", " ", "the", " ", "Mathematica", " ", "data", " ",
           "structure", " ", "that", " ", "describes", " ", 
          StyleBox[
           RowBox[{
            StyleBox["p",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "oint"}]], " ", 
          "group", " ", "and", " ", "conformational", " ", "symmetry", " ", 
          "transformations", " ", "of", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", "parent", " ", 
          RowBox[{"compound", ".", "The"}], " ", "first", " ", "argument", 
          " ", "consist", " ", "of", " ", "an", " ", "integer", " ", "list", 
          " ", "depicting", " ", "the", " ", "site", " ", "permutation", " ", 
          "of", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", 
          RowBox[{"transformation", ".", " ", "The"}], " ", "second", " ", 
          "and", " ", "third", " ", "arguments", " ", "are", " ", "boolean", 
          " ", "flags", " ", "indicating", " ", "the", " ", "transformation", 
          " ", 
          RowBox[{"type", ".", "The"}], " ", "standard", " ", "in", " ", 
          "and", " ", "output", " ", "form", " ", "of", " ", 
          StyleBox[
           RowBox[{"th", 
            StyleBox["ese",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["Mathematica",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["list",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", "structures", 
          " ", "begins", " ", "with", " ", "\[ScriptCapitalR]"}], ",", 
         SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], ",", 
         SubscriptBox["\[ScriptCapitalR]", "c"], ",", 
         RowBox[{"or", "  ", 
          RowBox[{
           SubscriptBox["\[ScriptCapitalR]", "c\[Sigma]"], "."}]}]}]},
       {
        RowBox[{
         StyleBox["PointGroupElementQ", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["expr", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["PointGroupElementQ", "MR"], " ", "verifies"}], ",", " ", 
         RowBox[{
         "if", " ", "the", " ", "syntax", " ", "of", " ", "argument", "  ", 
          StyleBox["expr", "IT"], "  ", "is", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", "properly", " ", "defined", " ", 
          StyleBox["PointGroupElement", "MR"], " ", "data", " ", 
          RowBox[{"structure", 
           StyleBox[".",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]}]}]},
       {
        RowBox[{
         StyleBox["GeneratePointGroupElements", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["GeneratePointGroupElements", "MR"], "  ", 
         StyleBox["determines",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["all",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["point",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["group",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["elements",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["that",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["can",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["be",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["formed",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["with",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["the",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["generator",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["set",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          RowBox[{
           StyleBox["PointGroupGenerators", "MR"], 
           StyleBox["[", "MR"], 
           StyleBox["mol", "TI"], 
           StyleBox["]", "MR"]}], 
          StyleBox[".", "MR"]}]}]},
       {
        RowBox[{
         StyleBox["PointGroup", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["PointGroup", "MR"], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "identifies", " ", 
         "in", " ", "Schoenflies", " ", "notation", " ", "all", " ", 
         "possible", "  ", "point", " ", "groups", " ", "that", " ", "are", 
         " ", "compatible", " ", "with", " ", 
         StyleBox["the",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", "given", " ", 
         "set", " ", "of", " ", "generators", " ", 
         RowBox[{
          RowBox[{
           StyleBox["PointGroupGenerators", "MR"], 
           StyleBox["[", "MR"], 
           StyleBox["mol", "TI"], 
           StyleBox["]", "MR"]}], "."}]}]},
       {
        RowBox[{
         StyleBox["PointGroupCycleStructure", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["PointGroupCycleStructure", "MR"], " ", 
          StyleBox["renders",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["all",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["equivalence",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["classes",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["of",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["symmetry",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["group",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["generated",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["by",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["  ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          RowBox[{
           RowBox[{
            StyleBox["PointGroupGenerators", "MR"], 
            StyleBox["[", "MR"], 
            StyleBox["mol", "TI"], 
            StyleBox["]", "MR"]}], 
           StyleBox[".",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", "The"}], " ", 
          "number", " ", "of", " ", "elements"}], ",", " ", 
         RowBox[{
          RowBox[{"their", " ", "cycle", " ", "length", "  ", "is", " ", 
           RowBox[{"displayed", ".", " ", "\[Sigma]"}], " ", "identifies", 
           " ", "reflection"}], "\[Dash]", 
          RowBox[{"rotations", " ", "and", " ", 
           RowBox[{"inversions", "."}]}]}]}]},
       {
        RowBox[{
         StyleBox["PointGroupReport", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["PointGroupReport", "MR"], 
         StyleBox[" ", "MR"], "prints", " ", "out", " ", "the", " ", "point", 
         " ", "group", " ", "cycle", " ", "structure", 
         StyleBox[" ", "MR"], "and", " ", "point", " ", "group", " ", "of", 
         " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "parent", " ", "compound", " ", 
         RowBox[{
          StyleBox["mol", "IT"], "."}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["Point group commands", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[TextData[{
 "One can recall the point group generators of any implemented parent \
compound.(For convenience, click on the paste button of the selected compound \
in database panel and select the ",
 StyleBox["PointGroupGenerators", "MR"],
 "-command from the control panel.)"
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PointGroupGenerators", "[", "Methane", "]"}]], "Input",
 CellLabel->"In[15]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"1", ",", "3", ",", "4", ",", "2"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"2", ",", "1", ",", "4", ",", "3"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "]"}]}], "}"}]], "Output",
 CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
 "The command ",
 StyleBox["GeneratePointGroupElements", "MR"],
 " displays all symmetry transformations that one can form with the given set \
of generators."
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GeneratePointGroupElements", "[", "Methane", "]"}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"1", ",", "3", ",", "4", ",", "2"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"1", ",", "4", ",", "2", ",", "3"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"1", ",", "4", ",", "3", ",", "2"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"2", ",", "1", ",", "4", ",", "3"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"2", ",", "3", ",", "1", ",", "4"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"2", ",", "4", ",", "1", ",", "3"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"2", ",", "4", ",", "3", ",", "1"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"3", ",", "1", ",", "2", ",", "4"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"3", ",", "2", ",", "1", ",", "4"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"3", ",", "2", ",", "4", ",", "1"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"3", ",", "4", ",", "1", ",", "2"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"3", ",", "4", ",", "2", ",", "1"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"4", ",", "1", ",", "2", ",", "3"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"4", ",", "1", ",", "3", ",", "2"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"4", ",", "2", ",", "1", ",", "3"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"4", ",", "2", ",", "3", ",", "1"}], "]"}], ",", 
   RowBox[{
    SubscriptBox["\[ScriptCapitalR]", "\[Sigma]"], "[", 
    RowBox[{"4", ",", "3", ",", "1", ",", "2"}], "]"}], ",", 
   RowBox[{"\[ScriptCapitalR]", "[", 
    RowBox[{"4", ",", "3", ",", "2", ",", "1"}], "]"}]}], "}"}]], "Output",
 CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["PointGroup", "MR"],
 " command renders the point group of a molecule in Schoenflies notation."
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PointGroup", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"Conformations", "->", " ", "False"}]}], "]"}]], "Input",
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{"{", 
  SubscriptBox["\<\"T\"\>", "\<\"d\"\>"], "}"}]], "Output",
 CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["PointGroupCycleStructure", "MR"],
 " function returns the structure (number and size) of symmetry group \
equivalence classes. It also informs about the group cycle length ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["\[ScriptCapitalC]", "n"], ")"}], TraditionalForm]]],
 " and the existence of a reflection (\[Sigma]) within these equivalence \
classes."
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PointGroupCycleStructure", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"Conformations", "->", " ", "False"}]}], "]"}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{"(", "\[ScriptCapitalE]", ")"}],
   DisplayForm], 
  RowBox[{
   RowBox[{",", " "}], 
   TagBox[
    RowBox[{"(", 
     RowBox[{"6", " ", "\[Sigma]"}], ")"}],
    DisplayForm]}], 
  RowBox[{
   RowBox[{",", " "}], 
   TagBox[
    RowBox[{"(", 
     RowBox[{"3", " ", 
      SubsuperscriptBox["\[ScriptCapitalC]", "4", "2"]}], ")"}],
    DisplayForm]}], 
  RowBox[{
   RowBox[{",", " "}], 
   TagBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["\[ScriptCapitalC]", "3"]}], 
      RowBox[{
       RowBox[{",", " "}], 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[ScriptCapitalC]", "3", "2"]}]}]}], ")"}],
    DisplayForm]}], 
  RowBox[{
   RowBox[{",", " "}], 
   TagBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SubscriptBox["\[Sigma]\[ScriptCapitalC]", "4"]}], 
      RowBox[{
       RowBox[{",", " "}], 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Sigma]\[ScriptCapitalC]", "4", "3"]}]}]}], ")"}],
    
    DisplayForm]}]}]], "Output",
 CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["PointGroupReport", "MR"],
 " combines the two functions ",
 StyleBox["PointGroupCycleStructure", "MR"],
 " and ",
 StyleBox["PointGroup", "MR"],
 "."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell["\<\
Finally, after implementing a parent compound and verifying it's symmetry, \
one can proceed and enumerate the substitutional isomers.\
\>", "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["NumberOfSubstituentSites", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["NumberOfSubstituentSites", "MR"], " ", "renders", " ", 
         "the", " ", "number", " ", "of", " ", 
         StyleBox["substituent",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["sites",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], " ", "that", " ", "were", " ", 
         "implemented", " ", 
         StyleBox[
          RowBox[{"fo", 
           StyleBox["r",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "the", " ", "parent",
          " ", "compound", " ", "with", " ", "symbol", "  ", 
         RowBox[{
          StyleBox["mol", "IT"], "."}]}]},
       {
        RowBox[{
         StyleBox["CycleIndex", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["mol", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["CycleIndex", "MR"], " ", "returns", " ", 
         RowBox[{"P\[OAcute]lya", "'"}], "s", " ", "cycle", " ", "index", " ", 
         StyleBox["for",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["parent",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["compound",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[
          RowBox[{
           StyleBox["mol", "IT"], "."}],
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}]}]},
       {
        RowBox[{
         StyleBox["PolyaPolynomial", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], ",", 
          RowBox[{
           StyleBox["{", "MR"], 
           StyleBox["vars", "IT"], 
           StyleBox["}", "MR"]}]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["PolyaPolynomial", "MR"], " ", "determines", "  ", 
         RowBox[{"P\[OAcute]lya", "'"}], 
         StyleBox["s",
          FontSlant->"Plain"], " ", "polynomial", "  ", 
         StyleBox["for",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["parent",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["compound",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         RowBox[{
          StyleBox["mol", "IT",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          StyleBox[".",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          RowBox[{"P\[OAcute]lya", "'"}]}], "s", " ", "polynomial", " ", "is",
          " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "generating", " ", "function", " ", "for",
          " ", "the", " ", "enumeration", " ", "of", " ", 
         RowBox[{"isomers", ".", " ", "The"}], " ", "substituents", " ", 
         "are", " ", "represented", " ", "by", " ", "the", " ", 
         StyleBox["vars", "IT"], " ", "of", " ", "the", " ", 
         RowBox[{"polynomial", "."}]}]},
       {
        StyleBox["Reflections", "MR"], 
        RowBox[{
         RowBox[{
          StyleBox["Reflections", "MR"], " ", "is", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", "boolean", " ", "Mathematica", " ", 
          "option", " ", "for", " ", "Isomers`"}], "-", 
         RowBox[{
          RowBox[{"commands", ".", " ", "Setting"}], " ", "this", "  ", 
          "option", " ", "to", " ", 
          StyleBox["True", "MR"], " ", "includes", " ", "reflections", " ", 
          "in", " ", "the", " ", "group", " ", "of", " ", "symmetry", " ", 
          RowBox[{"transformations", ".", " ", "Isomers"}], " ", "being", " ",
           "mirror", " ", "images", " ", "of", " ", "each", " ", "other", " ",
           "are", " ", "then", " ", "considered", " ", 
          RowBox[{"mesomeres", ".", " "}]}]}]},
       {
        StyleBox["Conformations", "MR"], 
        RowBox[{
         RowBox[{
          StyleBox["Conformations", "MR"], " ", "is", " ", 
          StyleBox["a",
           FontSlant->"Plain"], " ", "boolean", " ", "Mathematica", " ", 
          "option", " ", "for", " ", "Isomers`"}], "-", 
         RowBox[{
          RowBox[{"commands", ".", " ", "Setting"}], " ", "this", "  ", 
          "option", " ", "to", " ", 
          StyleBox["True", "MR"], " ", "includes", " ", "conformational", " ",
           "transformation", " ", "in", " ", "the", " ", "group", " ", "of", 
          " ", "symmetry", " ", 
          RowBox[{"transformations", "."}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{"Columns" -> {{
          Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["\<\
Commands related toP\[OAcute]lya's enumeration scheme\
\>", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["NumberOfIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", "isomers", " ",
           "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", " ", 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["same",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", " ", 
          StyleBox["some",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["other",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          RowBox[{"etc", ".."}], " ", 
          StyleBox[
           RowBox[{"A", 
            StyleBox["ll",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["substituents",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["are",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["taken",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["from",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["a",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["pool",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["of",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
          StyleBox["k", "TI"], " ", "different", " ", 
          RowBox[{"types", "."}]}]}]},
       {
        RowBox[{
         StyleBox["NumberOfEnantiomericPairs", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", "enantiomeric",
           " ", "pairs", " ", "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", " ", 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["same",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", " ", 
          StyleBox["some",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["other",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          RowBox[{"etc", ".."}], " ", 
          StyleBox[
           RowBox[{"A", 
            StyleBox["ll",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["substituents",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["are",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["taken",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["from",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["a",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["pool",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["of",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
          StyleBox["k", "TI"], " ", "different", " ", 
          RowBox[{"types", "."}]}]}]},
       {
        RowBox[{
         StyleBox["NumberOfAchiralIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", "achiral", " ",
           "isomers", " ", "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", " ", 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["same",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", " ", 
          StyleBox["some",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["other",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          RowBox[{"etc", ".."}], " ", 
          StyleBox[
           RowBox[{"A", 
            StyleBox["ll",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["substituents",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["are",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["taken",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["from",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["a",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["pool",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["of",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
          StyleBox["k", "TI"], " ", "different", " ", 
          RowBox[{"types", "."}]}]}]},
       {
        RowBox[{
         StyleBox["NumberOfDiastereoisomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", 
          "diastereoisomers", " ", "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", " ", 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["same",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", " ", 
          StyleBox["some",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["other",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          RowBox[{"etc", ".."}], " ", 
          StyleBox[
           RowBox[{"A", 
            StyleBox["ll",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["substituents",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["are",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["taken",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["from",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["a",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["pool",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["of",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
          StyleBox["k", "TI"], " ", "different", " ", 
          RowBox[{"types", "."}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{"Columns" -> {{
          Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["All isomer enumeration commands", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[TextData[{
 "The isomer enumeration commands above except their arguments in four \
different ways as shown for ",
 StyleBox["NumberOfIsomers", "MR"],
 " below."
}], "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["NumberOfIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", "isomers", " ",
           "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["one",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["two",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[
          RowBox[{"and", " ", "so", " ", 
           RowBox[{"on", "."}]}],
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]},
       {
        RowBox[{
         StyleBox["NumberOfIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], "s"}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
        "renders", " ", "the", " ", "number", " ", "of", " ", "isomers", " ", 
         "exhibiting", " ", "s", " ", "occupied", " ", "substituent", " ", 
         RowBox[{"sites", 
          StyleBox[".",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          StyleBox["The",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}]}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["substituents",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["may",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["be",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["of",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["the",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["same",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["or",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["of",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["different",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[
          RowBox[{"type", "."}],
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}]}]},
       {
        RowBox[{
         StyleBox["NumberOfIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "renders", " ", "the", " ", "number", " ", "of", " ", "isomers", " ",
           "exhibiting", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            StyleBox[
             SubscriptBox["s", "i"], "TI"]}], ")"}], " ", "occupied", " ", 
          "substituent", " ", "sites", " ", "with", " ", 
          SubscriptBox[
           StyleBox["s", "TI"], "1"], " ", "sites", " ", "occupied", " ", 
          "by", " ", "substituents", " ", "of", " ", 
          StyleBox["the",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["one",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", " ", 
         RowBox[{
          SubscriptBox["s", "2"], " ", "sites", " ", "occupied", " ", "by", 
          " ", "substituents", " ", "of", " ", 
          StyleBox["some",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["other",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
         StyleBox[",",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         RowBox[{
          StyleBox["and",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["so",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          RowBox[{
           StyleBox["on",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], ".", " ", 
           StyleBox[
            RowBox[{"A", 
             StyleBox["ll",
              GridBoxOptions->{
              GridBoxDividers->{
               "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]]}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["substituents",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["are",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["taken",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["from",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["a",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["pool",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox[" ",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
          StyleBox["with",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
          StyleBox["k", "TI"], " ", "different", " ", "substituent", " ", 
          RowBox[{"types", "."}]}]}]},
       {
        RowBox[{
         StyleBox["NumberOfIsomers", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["mol", "TI"], 
          StyleBox[",", "TI"], 
          StyleBox[" ", "MR"], "s", 
          StyleBox[",", "MR"], 
          StyleBox["k", "TI"]}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
        "renders", " ", "the", " ", "number", " ", "of", " ", "isomers", " ", 
         "exhibiting", " ", "s", " ", "occupied", " ", "substituent", " ", 
         RowBox[{"sites", ".", " ", 
          StyleBox["The",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}]}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["substituents",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["may",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["be",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["of",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["the",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["same",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["or",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["of",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox["different",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}},
          GridBoxItemSize->{"Columns" -> {{
               Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
            "RowsIndexed" -> {}}}], 
         RowBox[{
          StyleBox["type",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          StyleBox[".",
           GridBoxOptions->{
           GridBoxDividers->{
            "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{False}}, "RowsIndexed" -> {}},
           GridBoxItemSize->{"Columns" -> {{
                Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
             "RowsIndexed" -> {}}}], 
          StyleBox[
           RowBox[{"A", 
            StyleBox["ll",
             GridBoxOptions->{
             GridBoxDividers->{
              "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]]}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["substituents",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["are",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["taken",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["from",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["a",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["pool",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox[" ",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
         StyleBox["with",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}], " ", 
         StyleBox["k", "TI"], " ", "different", " ", "substituent", " ", 
         RowBox[{"types", "."}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{"Columns" -> {{
          Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["Enumerating substitutional isomers", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["SubstituentsMultiplicity", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox[" ", "MR"], 
         RowBox[{
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            StyleBox[
             SubscriptBox[
              StyleBox["s", "TI",
               GridBoxOptions->{
               GridBoxDividers->{
                "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], "TI"], 
            ",", 
            SubscriptBox["s", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["s", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], ",", "n"}], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["SubstituentsMultiplicity", "MR"], " ", "returns", " ", 
          "the", " ", "number", " ", "of", "  ", "possibilities", " ", "to", 
          " ", "distribute", " ", "substituents", " ", "of", " ", "n", " ", 
          "different", " ", "types", " ", "into", " ", 
          StyleBox["a",
           FontSlant->"Plain"], "  ", 
          RowBox[{"{", 
           RowBox[{"s1", ",", "s2", ",", "s3", ",", "..."}], "}"}], 
          RowBox[{"partition", ".", " ", "Each"}], " ", "slot", " ", "of", 
          " ", "the", " ", "partition", " ", "may", " ", "only", " ", "be", 
          " ", "filled", " ", "with", " ", "substituents", " ", "of", " ", 
          "the", " ", "same", " ", 
          RowBox[{"type", "."}]}], " "}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{"Columns" -> {{
          Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["Multiplicity factor in isomer enumerations", "Caption",
 CellTags->"NumberOfIsomers"],

Cell["\<\
One can attach on methane three different substituents in two ways.\
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfIsomers", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[24]:="],

Cell[BoxData["2"], "Output",
 CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
Considering mirror images as mesomeres, one can create wit methane and three \
different substituents only one isomer.\
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfIsomers", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"Reflections", " ", "->", " ", "True"}]}], "]"}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
There is only one methane isomer with three identical substituents.\
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfIsomers", "[", 
  RowBox[{"Methane", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input",
 CellLabel->"In[25]:="],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
 "The number of molecules that one can form by replacing three methane \
hydrogens with substituents taken from a pool of ",
 StyleBox["n", "IT"],
 " different substituent types is:"
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfIsomers", "[", 
  RowBox[{"Methane", ",", "3", ",", "n"}], "]"}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", "n", " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    SuperscriptBox["n", "2"]}], ")"}]}]], "Output",
 CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
The number of enantiomeric pairs in the above enumeration is:\
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfEnantiomericPairs", "[", 
  RowBox[{"Methane", ",", "3", ",", "n"}], "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", "n", " ", 
  RowBox[{"(", 
   RowBox[{"2", "-", 
    RowBox[{"3", " ", "n"}], "+", 
    SuperscriptBox["n", "2"]}], ")"}]}]], "Output",
 CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
Substituting all four methane hydrogens one can generate five \
diastereoisomers.\
\>", "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfDiastereoisomers", "[", 
  RowBox[{"Methane", ",", "4"}], "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[BoxData["5"], "Output",
 CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[{
 "The calculations can be arbitrarily complex. The enumeration of isomers \
formed by substituting twenty-four carbons with ",
 StyleBox["n", "IT"],
 " different substituents may however take a few seconds. "
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfIsomers", "[", 
  RowBox[{"C60Fullerene", ",", "24", ",", "n"}], "]"}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{
  FractionBox["1235", "4"], " ", 
  SuperscriptBox["n", "8"], " ", 
  RowBox[{"(", 
   RowBox[{"136", "+", 
    RowBox[{"70035", " ", 
     SuperscriptBox["n", "4"]}], "+", 
    RowBox[{"1946147772317", " ", 
     SuperscriptBox["n", "16"]}]}], ")"}]}]], "Output",
 CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
The fourth group of Isomers`-commands contains utility functions that help to \
enter site permutations and to create isomer enumeration tables.\
\>", "Text",
 CellTags->{"S5.93.1", "1.2"}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[
    StyleBox[GridBox[{
       {
        RowBox[{
         StyleBox["Partitions", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox[
          RowBox[{"n", ",", "m", ",", "l"}], "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
          StyleBox["Partitions", "MR"], 
          StyleBox["[", "MR"], "n", 
          StyleBox["]", "MR"]}], " ", 
         StyleBox[
          RowBox[{
           StyleBox["co",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "nstructs"}]], " ",
          "all", " ", "partitions", " ", "of", " ", "integer", "  ", "n", "  ",
          "in", " ", "reverse", "  ", "lexicographic", " ", 
         RowBox[{"order", ".", " ", 
          RowBox[{
           StyleBox["Partitions", "MR"], 
           StyleBox["[", "MR"], 
           RowBox[{"n", ",", "m"}], 
           StyleBox["]", "MR"]}]}], " ", "constructs", " ", "all", " ", 
         "partitions", " ", "of", " ", "integer", "  ", "n", " ", "with", " ",
          "all", " ", "summands", " ", "being", " ", "smaller", " ", "or", 
         " ", "equal", "  ", 
         RowBox[{"m", ".", " ", 
          RowBox[{
           StyleBox["Partitions", "MR"], 
           StyleBox["[", "MR"], 
           RowBox[{"n", ",", "m", ",", "l"}], "]"}]}], 
         StyleBox[" ", "MR"], "constructs", "  ", "partitions", " ", "with", 
         " ", "no", " ", "more", " ", "than", "  ", "l", "  ", "parts", " ", 
         "or", " ", "summands"}]},
       {
        RowBox[{
         StyleBox["LimitedPartitions", "MR"], 
         StyleBox["[", "MR"], 
         RowBox[{
          StyleBox["n", "IT"], ",", 
          RowBox[{
           StyleBox["{",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}], 
           RowBox[{
            SubscriptBox[
             StyleBox["l", "TI",
              GridBoxOptions->{
              GridBoxDividers->{
               "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{False}}, "RowsIndexed" -> {}}}], "1"], ",", 
            SubscriptBox["l", "2"], ",", "\[TripleDot]", ",", 
            SubscriptBox["l", "n"]}], 
           StyleBox["}",
            GridBoxOptions->{
            GridBoxDividers->{
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}]}], 
         StyleBox["]", "MR",
          GridBoxOptions->{
          GridBoxDividers->{
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{False}}, "RowsIndexed" -> {}}}]}], 
        RowBox[{
         RowBox[{
          StyleBox["LimitedPartitions", "MR"], " ", "constructs", " ", "all", 
          " ", "limited", " ", "partitions", " ", "of", "  ", "integer", " ", 
          
          RowBox[{
           StyleBox["n", "IT"], ".", " ", "The"}], " ", "limitations", " ", 
          "are", " ", "upper", " ", "limits", " ", 
          RowBox[{
           StyleBox["{", "MR"], 
           RowBox[{
            StyleBox["l1", "IT"], 
            StyleBox[",", "IT"], 
            StyleBox["l2", "IT"], 
            StyleBox[",", "IT"], "..."}], 
           StyleBox["}", "MR"]}], " ", "for", " ", "each", " ", "partition", "  ", 
          RowBox[{"summand", ".", " ", "The"}], " ", "upper", " ", "limits", 
          " ", "are", " ", "provided", " ", "by", " ", "the", " ", "integer", 
          " ", "list", " ", "in", " ", "the", " ", "second", "  ", 
          RowBox[{"argument", ".", " ", "Note"}]}], ",", " ", "that", " ", 
         "limited", " ", "partitions", " ", "are", " ", "not", " ", 
         RowBox[{"orderless", "!"}]}]},
       {
        RowBox[{
         StyleBox["InversePermutation", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["p", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["InversePermutation", "MR"], "  ", "renders", " ", "the", 
         " ", "inverse", " ", "permutation", " ", "of", " ", "permutation", 
         " ", 
         RowBox[{
          StyleBox["p", "IT"], "."}]}]},
       {
        RowBox[{
         StyleBox["ToCycles", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["p", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["ToCycles", "MR"], " ", "yields", " ", "the", " ", "cycle", 
         " ", "structure", " ", "of", " ", "permutation", " ", 
         RowBox[{"p", "."}]}]},
       {
        RowBox[{
         StyleBox["FromCycles", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["c", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["FromCycles", "MR"], " ", "renders", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "permutation", " ", "in", " ", "cycle", 
         " ", "structure", "  ", "c", "  ", "as", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "regular", " ", "permutation", " ", 
         RowBox[{"list", "."}]}]},
       {
        RowBox[{
         StyleBox["PermutationQ", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["expr", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         StyleBox["PermutationQ", "MR"], " ", "is", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "boolean", " ", "function", " ", "that", 
         " ", "verifies", " ", "if", " ", 
         StyleBox["expr", "IT"], " ", "is", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "well", " ", "defined", " ", 
         "permutation", " ", 
         RowBox[{"list", "."}]}]},
       {
        RowBox[{
         StyleBox["CyclesQ", "MR"], 
         StyleBox["[", "MR"], 
         StyleBox["expr", "TI"], 
         StyleBox["]", "MR"]}], 
        RowBox[{
         RowBox[{
         "CyclesQ", " ", "is", " ", "a", " ", "boolean", " ", "function", " ",
           "that", " ", "verifies", " ", "if", " "}], 
         StyleBox["expr", "IT"], " ", "is", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", "well", "  ", "defined", " ", "list", " ",
          "of", " ", "cycles", " ", "representing", " ", 
         StyleBox["a",
          FontSlant->"Plain"], " ", 
         RowBox[{"permutation", "."}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}],
     GridBoxOptions->{
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}}}]], "2ColumnBox"], TraditionalForm]], "Text",
 CellTags->{"S5.93.1", "1.3"}],

Cell["Utility commands", "Caption",
 CellTags->"NumberOfIsomers"],

Cell[TextData[{
 "The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code below generates a list of isomer, enantiomeric pair, and achiral \
isomer enumeration for ",
 StyleBox["Triptycene", "MR"],
 ". Only substituent schemes with up to three different substituent types are \
considered. Theses are determined with ",
 StyleBox["Partitions[14,14,3]", "MR"],
 "."
}], "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "\n", "\t", 
  RowBox[{
   RowBox[{"Map", "[", "\n", "\t\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "#", "}"}], ",", "\n", "\t\t  ", 
        RowBox[{"NumberOfIsomers", "[", 
         RowBox[{"Triptycene", ",", "#"}], "]"}], ",", "\n", "\t\t  ", 
        RowBox[{"NumberOfEnantiomericPairs", "[", 
         RowBox[{"Triptycene", ",", "#"}], "]"}], ",", "\n", "\t\t  ", 
        RowBox[{"NumberOfAchiralIsomers", "[", 
         RowBox[{"Triptycene", ",", "#"}], "]"}]}], "\n", "\t\t", "}"}], 
      "&"}], ",", "\n", "\t\t", 
     RowBox[{"Partitions", "[", 
      RowBox[{"14", ",", "14", ",", "3"}], "]"}]}], "\n", "\t", "]"}], ",", 
   "\n", "\t", 
   RowBox[{"TableHeadings", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Partition\>\"", ",", "\"\<Isomers\>\"", ",", 
        "\"\<Enantiomeric Pairs\>\"", ",", "\"\<Achiral Isomers\>\""}], 
       "}"}]}], "}"}]}]}], "\n", "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"\"\>", "\<\"Partition\"\>", "\<\"Isomers\"\>", "\<\"Enantiomeric \
Pairs\"\>", "\<\"Achiral Isomers\"\>"},
    {"\<\"\"\>", GridBox[{
       {"5", "5", "4"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "42042", "20538", "966"},
    {"\<\"\"\>", GridBox[{
       {"6", "4", "4"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "35148", "17120", "908"},
    {"\<\"\"\>", GridBox[{
       {"6", "5", "3"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "28032", "13630", "772"},
    {"\<\"\"\>", GridBox[{
       {"6", "6", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "14086", "6774", "538"},
    {"\<\"\"\>", GridBox[{
       {"7", "4", "3"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "20028", "9696", "636"},
    {"\<\"\"\>", GridBox[{
       {"7", "5", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "12012", "5772", "468"},
    {"\<\"\"\>", GridBox[{
       {"7", "6", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "4008", "1878", "252"},
    {"\<\"\"\>", GridBox[{
       {"7", "7"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "576", "246", "84"},
    {"\<\"\"\>", GridBox[{
       {"8", "3", "3"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "10014", "4792", "430"},
    {"\<\"\"\>", GridBox[{
       {"8", "4", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "7560", "3592", "376"},
    {"\<\"\"\>", GridBox[{
       {"8", "5", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "3003", "1395", "213"},
    {"\<\"\"\>", GridBox[{
       {"8", "6"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "520", "218", "84"},
    {"\<\"\"\>", GridBox[{
       {"9", "3", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "3338", "1556", "226"},
    {"\<\"\"\>", GridBox[{
       {"9", "4", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "1671", "759", "153"},
    {"\<\"\"\>", GridBox[{
       {"9", "5"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "335", "137", "61"},
    {"\<\"\"\>", GridBox[{
       {"10", "2", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "1022", "452", "118"},
    {"\<\"\"\>", GridBox[{
       {"10", "3", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "670", "290", "90"},
    {"\<\"\"\>", GridBox[{
       {"10", "4"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "180", "68", "44"},
    {"\<\"\"\>", GridBox[{
       {"11", "2", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "182", "70", "42"},
    {"\<\"\"\>", GridBox[{
       {"11", "3"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "62", "20", "22"},
    {"\<\"\"\>", GridBox[{
       {"12", "1", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "31", "8", "15"},
    {"\<\"\"\>", GridBox[{
       {"12", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "19", "4", "11"},
    {"\<\"\"\>", GridBox[{
       {"13", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "3", "0", "3"},
    {"\<\"\"\>", "14", "1", "0", "1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{{{5, 5, 4}}, 42042, 20538, 966}, {{{6, 4, 4}}, 35148, 17120, 
     908}, {{{6, 5, 3}}, 28032, 13630, 772}, {{{6, 6, 2}}, 14086, 6774, 
     538}, {{{7, 4, 3}}, 20028, 9696, 636}, {{{7, 5, 2}}, 12012, 5772, 
     468}, {{{7, 6, 1}}, 4008, 1878, 252}, {{{7, 7}}, 576, 246, 84}, {{{8, 3, 
     3}}, 10014, 4792, 430}, {{{8, 4, 2}}, 7560, 3592, 376}, {{{8, 5, 1}}, 
     3003, 1395, 213}, {{{8, 6}}, 520, 218, 84}, {{{9, 3, 2}}, 3338, 1556, 
     226}, {{{9, 4, 1}}, 1671, 759, 153}, {{{9, 5}}, 335, 137, 61}, {{{10, 2, 
     2}}, 1022, 452, 118}, {{{10, 3, 1}}, 670, 290, 90}, {{{10, 4}}, 180, 68, 
     44}, {{{11, 2, 1}}, 182, 70, 42}, {{{11, 3}}, 62, 20, 22}, {{{12, 1, 1}},
      31, 8, 15}, {{{12, 2}}, 19, 4, 11}, {{{13, 1}}, 3, 0, 3}, {{{14}}, 1, 0,
      1}}, TableHeadings -> {{}, {
     "Partition", "Isomers", "Enantiomeric Pairs", 
      "Achiral Isomers"}}]]], "Output",
 CellLabel->"Out[52]//TableForm="]
}, Open  ]]
},
WindowSize->{1298, 1340},
WindowMargins->{{Automatic, 626}, {Automatic, 3}},
Visible->True,
PageFooters->{{Inherited, 
   Cell[
    TextData[{"\[Copyright]1999 Markus van Almsick,  All rights reserved."}], 
    "PageFooter"], Inherited}, {Inherited, 
   Cell[
    TextData[{"\[Copyright]1999 Markus van Almsick,  All rights reserved."}], 
    "PageFooter"], Inherited}},
PageFooterLines->{True, Inherited},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 7, \
2012)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions for Online Help", "Subtitle"], 
      Cell[
      "These styles are carefully tuned for all aspects of the online help. \
It's recommended that they remain unchanged.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Subsubsection"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          5, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Subsubsection"], 
         Cell[
         "  The options defined for the style below will be used at the \
Notebook level.  ", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{"Printed from the ", 
                StyleBox["Mathematica", FontSlant -> "Italic"], 
                " Help Browser"}], "PageHeader"]}, {
             Cell[
              TextData[{"Printed from the ", 
                StyleBox["Mathematica", FontSlant -> "Italic"], 
                " Help Browser"}], "PageHeader"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageFooters -> {{None, 
             Cell[
              
              TextData[{
               "\[Copyright]1996 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, 
             Cell[
              
              TextData[{
               "\[Copyright]1996 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}}, PageHeaderLines -> {True, True}, 
          PageFooterLines -> {True, True}, 
          PrintingOptions -> {"FacingPages" -> True}, CellLabelAutoDelete -> 
          False, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Headings", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {4, 24}}, FontFamily -> "Helvetica", 
             FontSize -> 24, FontWeight -> "Bold"], 
            Cell[
             StyleData["Chapter", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 22]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {12, 18}}, FontFamily -> "Helvetica", 
             FontSize -> 20, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSquare]", 
             ShowCellBracket -> False, CellMargins -> {{24, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             CellFrameLabelMargins -> 6, FontFamily -> "Helvetica", FontSize -> 
             16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{16, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionColor"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.297993, 0, 0.454994]], 
            Cell[
             StyleData["SubsubsectionColor", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionIcon"], ShowCellBracket -> False, 
             ShowGroupOpener -> True, CellMargins -> {{24, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 8}, 
             CellGroupingRules -> {"SectionGrouping", 50}, CounterIncrements -> 
             "Section", FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsectionIcon", "Printout"], CellDingbat -> 
             "\[FilledSquare]", ShowGroupOpener -> False, 
             CellMargins -> {{16, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionIcon"], ShowCellBracket -> False, 
             ShowGroupOpener -> True, CellMargins -> {{24, 4}, {0, 8}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 4}, 
             CellGroupingRules -> {"SectionGrouping", 60}, CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["SubsubsectionIcon", "Printout"], ShowGroupOpener -> 
             False, CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False,
              FontSize -> 10]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Text", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, ShowSpecialCharacters -> Automatic, 
             ParagraphSpacing -> {0, 8}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 0}, {0, 8}}]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CompactText"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, ShowSpecialCharacters -> 
             Automatic, ParagraphSpacing -> {0, 0}, StyleMenuListing -> None, 
             FontSize -> 10], 
            Cell[
             StyleData["CompactText", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Compact12Text"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, ShowSpecialCharacters -> 
             Automatic, ParagraphSpacing -> {0, 0}, StyleMenuListing -> None], 
            Cell[
             StyleData["Compact12Text", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TextSans"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, ShowSpecialCharacters -> Automatic, 
             ParagraphSpacing -> {0, 8}, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["TextSans", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedText"], ShowCellBracket -> False, 
             CellMargins -> {{20, 4}, {0, 8}}, ShowSpecialCharacters -> 
             Automatic, ParagraphSpacing -> {0, 8}, ParagraphIndent -> -15, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedText", "Printout"], 
             CellMargins -> {{12, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedTextNote"], ShowCellBracket -> False, 
             CellMargins -> {{35, 4}, {0, 4}}, ShowSpecialCharacters -> 
             Automatic, ParagraphSpacing -> {0, 8}, StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedTextNote", "Printout"], 
             CellMargins -> {{27, 0}, {0, 4}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndentedText"], ShowCellBracket -> False, 
             CellMargins -> {{20, 4}, {0, 6}}, ShowSpecialCharacters -> 
             Automatic, ParagraphSpacing -> {0, 8}, StyleMenuListing -> None], 
            Cell[
             StyleData["IndentedText", "Printout"], 
             CellMargins -> {{12, 0}, {0, 6}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], CellDingbat -> "\[FilledSmallSquare]", 
             ShowCellBracket -> False, CellMargins -> {{19, 62}, {0, 14}}, 
             CellFrameLabelMargins -> 4, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 8}, FontColor -> RGBColor[0, 0, 0.4]], 
            Cell[
             StyleData["MathCaption", "Printout"], 
             CellMargins -> {{9, 0}, {0, 14}}, FontSize -> 9, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Input/Output", "Subsubsection"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{46, 4}, {3, 8}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             ShowSpecialCharacters -> Automatic, FormatType -> StandardForm, 
             ShowStringCharacters -> True, NumberMarks -> True, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["Input", "Printout"], ShowCellBracket -> False, 
             FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 4}, {4, 2}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             StandardForm], 
            Cell[
             StyleData["Output", "Printout"], ShowCellBracket -> False, 
             FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellMargins -> {{47, 4}, {4, 2}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, StyleMenuListing -> None, FontColor -> 
             RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Printout"], ShowCellBracket -> False, 
             FontSize -> 9.5, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], CellMargins -> {{47, 4}, {4, 2}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, StyleMenuListing -> None], 
            Cell[
             StyleData["Print", "Printout"], ShowCellBracket -> False, 
             FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], CellMargins -> {{47, 4}, {4, 2}}, 
             CellGroupingRules -> "GraphicsGrouping", PageBreakWithin -> 
             False, GeneratedCell -> True, CellAutoOverwrite -> True, 
             ShowCellLabel -> False, DefaultFormatType -> 
             DefaultFormatTypeForOutput, FormatType -> InputForm, 
             StyleMenuListing -> None, FontWeight -> "Plain"], 
            Cell[
             StyleData["Graphics", "Printout"], ShowCellBracket -> False, 
             FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontWeight -> "Plain", FontColor -> 
             RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 7, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Name"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
             "Italic", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Name", "Printout"], FontSize -> 7, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlinks", "Subsubsection"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, FontFamily -> 
             "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, FontFamily -> 
             "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Subsubsection"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["BF"], StyleMenuListing -> None, FontWeight -> "Bold", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["IT"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["BI"], StyleMenuListing -> None, FontWeight -> "Bold", 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["TB"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["TBI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["MR"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["MO"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["MB"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["MBO"], StyleMenuListing -> None, FontFamily -> "Courier",
           FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["SR"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["SO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["SB"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["SBO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["M4"], ShowCellBracket -> True, StyleMenuListing -> None, 
          FontFamily -> "Math4", CharacterEncoding -> "Math4"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["C1"], StyleMenuListing -> None, FontColor -> 
             RGBColor[0.4, 0, 1]], 
            Cell[
             StyleData["C1", "Printout"], FontColor -> GrayLevel[0]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["C1MR"], StyleMenuListing -> None, FontFamily -> 
             "Courier", FontColor -> RGBColor[0.4, 0, 1]], 
            Cell[
             StyleData["C1MR", "Printout"], FontColor -> GrayLevel[0]]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Emphasis Boxes and Pictures", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Box"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Box", "Printout"], CellMargins -> {{2, 0}, {0, 8}}, 
             Background -> GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DoubleBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Top}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DoubleBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["1ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["1ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnEvenBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnEvenBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnSmallBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.35]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.0499999999999998`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnSmallBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.31]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnSmallBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.24]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.0499999999999998`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnSmallBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["4ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.13], 
                   Scaled[0.33], 
                   Scaled[0.13], {
                    Scaled[0.33]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["4ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["5ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.194]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
                  "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["5ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["6ColumnBox"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.12], 
                   Scaled[0.22], 
                   Scaled[0.12], 
                   Scaled[0.12], 
                   Scaled[0.22], {
                    Scaled[0.12]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["6ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedNoteBox"], CellFrame -> 0.5, ShowCellBracket -> 
             False, CellMargins -> {{37, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, Background -> 
             RGBColor[1, 0.8, 0.6], 
             FrameBoxOptions -> {
              FrameMargins -> {{13.870898437500001`, 13.870898437500001`}, {
                10.48125, 10.48125}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["ItemizedNoteBox", "Printout"], FontSize -> 10, 
             Background -> GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], ShowCellBracket -> False, 
             CellMargins -> {{10, Inherited}, {0, 8}}, 
             CellHorizontalScrolling -> True, StyleMenuListing -> None], 
            Cell[
             StyleData["Picture", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedPicture"], ShowCellBracket -> False, 
             CellMargins -> {{35, 4}, {0, 4}}, CellGroupingRules -> 
             "GraphicsGrouping", CellHorizontalScrolling -> True, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedPicture", "Printout"], 
             CellMargins -> {{27, 0}, {0, 4}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PictureGroup"], 
             CellMargins -> {{10, Inherited}, {0, 8}}, CellGroupingRules -> 
             "GraphicsGrouping", CellHorizontalScrolling -> True, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Sound"], CellMargins -> {{10, Inherited}, {0, 8}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Sound", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Caption"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 3}}, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["Caption", "Printout"], 
             CellMargins -> {{2, 0}, {0, 3}}, FontSize -> 7]}, Closed]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell["Tables", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnTable"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.34], {
                    Scaled[0.64]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnEvenTable"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.49]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnEvenTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnTable"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, LineIndent -> 0, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.28], 
                   Scaled[0.28], {
                    Scaled[0.43]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, ScriptLevel -> 1, SingleLetterItalics -> True, SpanMaxSize -> 
             Infinity, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineOutput"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, StyleMenuListing -> None, FontFamily -> "Courier"], 
            Cell[
             StyleData["InlineOutput", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], ShowCellBracket -> False, 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, SpanMaxSize -> Infinity, 
             StyleMenuListing -> None, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{34, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], ShowCellBracket -> False, 
             CellMargins -> {{16, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, StyleMenuListing -> None, 
             FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{8, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 9.5]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Help Browser Styles", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ObjectName"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {1, 10}}, StyleMenuListing -> None, 
             FontFamily -> "Courier", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["ObjectName", "Printout"], 
             CellMargins -> {{2, 0}, {1, 10}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Command"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 14}}, CounterIncrements -> 
             "Section", StyleMenuListing -> None, FontFamily -> "Helvetica", 
             FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Command", "Printout"], 
             CellMargins -> {{2, 0}, {0, 14}}, PageBreakBelow -> False, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CharacterName"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {0, 4}}, 
             CellFrameMargins -> 4, StyleMenuListing -> None], 
            Cell[
             StyleData["CharacterName", "Printout"], 
             CellMargins -> {{2, 0}, {0, 4}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Usage"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {0, 4}}, 
             CellFrameMargins -> 5, ParagraphSpacing -> {0, 6}, 
             ParagraphIndent -> -10, StyleMenuListing -> None], 
            Cell[
             StyleData["Usage", "Printout"], CellMargins -> {{2, 0}, {0, 4}}, 
             FontWeight -> "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Notes"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
             StyleMenuListing -> None, FontFamily -> "Times"], 
            Cell[
             StyleData["Notes", "Printout"], CellMargins -> {{2, 0}, {0, 8}}, 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NotesList"], ShowCellBracket -> False, 
             CellMargins -> {{20, 4}, {2, 8}}, CellHorizontalScrolling -> 
             True, ScriptLevel -> 1, SingleLetterItalics -> True, 
             StyleMenuListing -> None, FontFamily -> "Times"], 
            Cell[
             StyleData["NotesList", "Printout"], 
             CellMargins -> {{12, 0}, {2, 8}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExampleSection"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             ShowCellBracket -> False, ShowGroupOpener -> True, 
             CellMargins -> {{11, 4}, {0, 10}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, CellFrameMargins -> 
             12, StyleMenuListing -> None, FontSize -> 13, FontWeight -> 
             "Bold", FontSlant -> "Italic", FontColor -> RGBColor[0, 0, 0.4]], 
            Cell[
             StyleData["ExampleSection", "Printout"], 
             CellMargins -> {{3, 0}, {0, 10}}, PageBreakBelow -> False, 
             FontSize -> 9, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExampleText"], ShowCellBracket -> True, 
             CellMargins -> {{20, 40}, {0, 18}}, ParagraphSpacing -> {0, 6}, 
             StyleMenuListing -> None, FontColor -> RGBColor[0, 0, 0.4]], 
            Cell[
             StyleData["ExampleText", "Printout"], 
             CellMargins -> {{2, 80}, {0, 8}}, PageBreakBelow -> False, 
             FontSize -> 8, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExampleSubsection"], ShowCellBracket -> True, 
             CellMargins -> {{20, 4}, {0, 16}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ExampleSubsection", "Printout"], 
             CellMargins -> {{12, 0}, {0, 16}}, PageBreakBelow -> False, 
             FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LineHead"], CellFrame -> {{0, 0}, {0.5, 0}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {8, 18}}, 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubection", 0}}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["LineHead", "Printout"], 
             CellMargins -> {{2, 0}, {8, 18}}, PageBreakBelow -> False]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["FlushInput"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {1, 4}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             ShowSpecialCharacters -> Automatic, FormatType -> StandardForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             StyleMenuListing -> None, FontWeight -> "Bold"], 
            Cell[
             StyleData["FlushInput", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{2, 0}, {1, 4}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["FlushOutput"], ShowCellBracket -> False, 
             CellMargins -> {{10, Inherited}, {Inherited, Inherited}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             StandardForm, StyleMenuListing -> None], 
            Cell[
             StyleData["FlushOutput", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{2, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DialogItem"], CellDingbat -> "\[EmptyDiamond]", 
             ShowCellBracket -> False, CellMargins -> {{20, 4}, {0, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["DialogItem", "Printout"], 
             CellMargins -> {{12, 0}, {0, 12}}, PageBreakBelow -> False, 
             FontSize -> 8]}, Closed]], 
         Cell[
          StyleData["GroupDivider"], ShowCellBracket -> False, 
          CellMargins -> {{10, Inherited}, {Inherited, Inherited}}, 
          CellEditDuplicate -> True, 
          CellGroupingRules -> {"TitleGrouping", 0}, StyleMenuListing -> 
          None], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Highlight"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 18}}, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 12, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["Highlight", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, LineSpacing -> {1, 3}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["UserNotes"], CellFrame -> {{2, 0}, {0, 0.25}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {0, 4}}, 
             ParagraphIndent -> -7, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["UserNotes", "Printout"], 
             CellMargins -> {{2, 0}, {0, 4}}, LineSpacing -> {1, 3}, FontSize -> 
             8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MoreInfo"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 4}}, ParagraphIndent -> -7, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             10, FontColor -> GrayLevel[1], Background -> GrayLevel[0.2]], 
            Cell[
             StyleData["MoreInfo", "Printout"], 
             CellMargins -> {{2, 0}, {0, 4}}, LineSpacing -> {1, 3}, FontSize -> 
             8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["UserTips"], CellFrame -> {{2, 0}, {0, 0.25}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {0, 4}}, 
             ParagraphIndent -> -7, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontColor -> GrayLevel[1], 
             Background -> RGBColor[0.2, 0.500008, 0.700008]], 
            Cell[
             StyleData["UserTips", "Printout"], 
             CellMargins -> {{2, 0}, {0, 4}}, LineSpacing -> {1, 3}, FontSize -> 
             8, Background -> GrayLevel[0.700008]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Contents and Index", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsTitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {0, 18}}, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold"], 
            Cell[
             StyleData["ContentsTitle", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsSection"], CellDingbat -> "\[FilledSquare]", 
             ShowCellBracket -> False, CellMargins -> {{20, 4}, {3, 18}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold"], 
            Cell[
             StyleData["ContentsSection", "Printout"], 
             CellMargins -> {{12, 0}, {3, 18}}, PageBreakBelow -> False]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSection"], CellDingbat -> "\[FilledSquare]", 
             ShowCellBracket -> False, CellMargins -> {{20, 4}, {5, 20}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold"], 
            Cell[
             StyleData["IndexSection", "Printout"], 
             CellMargins -> {{12, 0}, {5, 20}}, PageBreakBelow -> False]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Contents"], ShowCellBracket -> False, 
             CellMargins -> {{21, 4}, {0, 8}}, StyleMenuListing -> None], 
            Cell[
             StyleData["Contents", "Printout"], 
             CellMargins -> {{13, 0}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Index"], ShowCellBracket -> False, 
             CellMargins -> {{21, 4}, {0, 0}}, ParagraphIndent -> -48, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Index", "Printout"], CellMargins -> {{13, 0}, {0, 0}},
              FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSubentry"], ShowCellBracket -> False, 
             CellMargins -> {{36, 4}, {0, 0}}, ParagraphIndent -> -48, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["IndexSubentry", "Printout"], 
             CellMargins -> {{24, 0}, {0, 0}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Horizontal Lines", "Subsubsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Line1"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {-16, 9}}, 
             StyleMenuListing -> None, FontSize -> 2], 
            Cell[
             StyleData["Line1", "Printout"], 
             CellMargins -> {{2, 0}, {-16, 9}}]}, Closed]], 
         Cell["\nThe item above is horizontal 0.5 pt line", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ProgramTop"], CellFrame -> {{0.5, 0.5}, {0, 0.5}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {-18, 18}}, 
             LineSpacing -> {1, -4}, StyleMenuListing -> None, FontSize -> 4], 
            Cell[
             StyleData["ProgramTop", "Printout"], 
             CellMargins -> {{2, 0}, {-18, 18}}]}, Closed]], 
         Cell["\nThe item above is a ProgramTop line\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ProgramBottom"], CellFrame -> {{0.5, 0.5}, {0.5, 0}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {-10, -2}}, 
             LineSpacing -> {1, -4}, StyleMenuListing -> None, FontSize -> 4], 
            Cell[
             StyleData["ProgramBottom", "Printout"], 
             CellMargins -> {{2, 0}, {-10, -2}}]}, Closed]], 
         Cell["\nThe item above is a ProgramBottom line\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SessionLabel"], CellFrame -> {{0.5, 0}, {0, 0.5}}, 
             ShowCellBracket -> False, CellMargins -> {{10, 4}, {-4, 18}}, 
             LineSpacing -> {1, -3}, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["SessionLabel", "Printout"], 
             CellMargins -> {{2, 0}, {-4, 18}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Page Headers and Footers", "Subsubsection"], 
         Cell[
          StyleData["PageHeader"], CellMargins -> {{0, 0}, {2, 0}}, 
          StyleMenuListing -> None, FontSize -> 8, FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {2, 0}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 8, 
          FontWeight -> "Bold"], 
         Cell[
          StyleData["PageFooter"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontSize -> 6]}, Closed]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 7, 2012)", 
  StyleDefinitions -> "Default.nb"],
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@00000000000000040801T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "S5.93.1"->{
  Cell[1230, 43, 131, 6, 34, "Subsection",
   CellTags->{"S5.93.1", "1.1"}],
  Cell[1364, 51, 914, 17, 46, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[2281, 70, 152, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[2436, 76, 80, 2, 23, "Input",
   CellTags->"S5.93.1"],
  Cell[2519, 80, 331, 10, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[6153, 156, 312, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[6468, 164, 6266, 150, 205, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[12813, 319, 355, 9, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[18558, 428, 423, 10, 33, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[18984, 440, 421, 11, 29, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[28805, 617, 202, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[29010, 623, 1579, 50, 52, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[31097, 690, 312, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[31412, 698, 18017, 443, 207, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[49504, 1146, 331, 7, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[50389, 1174, 225, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[53613, 1254, 180, 5, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[54108, 1275, 459, 12, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[55867, 1343, 228, 9, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[56098, 1354, 189, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[56290, 1360, 10857, 254, 188, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[67263, 1621, 30481, 760, 232, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[97830, 2386, 209, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[98042, 2394, 33126, 796, 179, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[131257, 3195, 2446, 60, 60, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[133800, 3260, 129, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[134204, 3278, 180, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[134717, 3298, 129, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[135086, 3315, 248, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[135686, 3339, 123, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[136206, 3361, 143, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[136574, 3378, 274, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[137340, 3406, 199, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[137542, 3412, 6785, 173, 177, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[144398, 3590, 422, 12, 39, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}]},
 "1.1"->{
  Cell[1230, 43, 131, 6, 34, "Subsection",
   CellTags->{"S5.93.1", "1.1"}]},
 "1.2"->{
  Cell[1364, 51, 914, 17, 46, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[2519, 80, 331, 10, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[6153, 156, 312, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[12813, 319, 355, 9, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[18558, 428, 423, 10, 33, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[18984, 440, 421, 11, 29, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[28805, 617, 202, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[31097, 690, 312, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[55867, 1343, 228, 9, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[56098, 1354, 189, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[97830, 2386, 209, 6, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}],
  Cell[137340, 3406, 199, 4, 20, "Text",
   CellTags->{"S5.93.1", "1.2"}]},
 "1.5"->{
  Cell[2281, 70, 152, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[29010, 623, 1579, 50, 52, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[49504, 1146, 331, 7, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[50389, 1174, 225, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[53613, 1254, 180, 5, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[54108, 1275, 459, 12, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[133800, 3260, 129, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[134204, 3278, 180, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[134717, 3298, 129, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[135086, 3315, 248, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[135686, 3339, 123, 3, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[136206, 3361, 143, 4, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[136574, 3378, 274, 6, 26, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}],
  Cell[144398, 3590, 422, 12, 39, "MathCaption",
   CellTags->{"S5.93.1", "1.5"}]},
 "NumberOfIsomers"->{
  Cell[6081, 153, 69, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[12737, 316, 73, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[18473, 425, 82, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[28720, 614, 82, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[49432, 1143, 69, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[67150, 1616, 110, 3, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[97747, 2383, 80, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[131171, 3192, 83, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[133706, 3257, 91, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"],
  Cell[144330, 3587, 65, 1, 15, "Caption",
   CellTags->"NumberOfIsomers"]},
 "1.3"->{
  Cell[6468, 164, 6266, 150, 205, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[31412, 698, 18017, 443, 207, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[56290, 1360, 10857, 254, 188, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[67263, 1621, 30481, 760, 232, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[98042, 2394, 33126, 796, 179, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[131257, 3195, 2446, 60, 60, "Text",
   CellTags->{"S5.93.1", "1.3"}],
  Cell[137542, 3412, 6785, 173, 177, "Text",
   CellTags->{"S5.93.1", "1.3"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"S5.93.1", 217197, 5226},
 {"1.1", 219916, 5297},
 {"1.2", 220004, 5300},
 {"1.5", 220895, 5325},
 {"NumberOfIsomers", 222060, 5354},
 {"1.3", 222820, 5375}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 670, 21, 39, "Input",
 Evaluatable->False],
Cell[1230, 43, 131, 6, 34, "Subsection",
 CellTags->{"S5.93.1", "1.1"}],
Cell[1364, 51, 914, 17, 46, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[2281, 70, 152, 4, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[2436, 76, 80, 2, 23, "Input",
 CellTags->"S5.93.1"],
Cell[2519, 80, 331, 10, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[2853, 92, 3225, 59, 234, "Graphics",
 Evaluatable->False],
Cell[6081, 153, 69, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[6153, 156, 312, 6, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[6468, 164, 6266, 150, 205, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[12737, 316, 73, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[12813, 319, 355, 9, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[13171, 330, 5299, 93, 411, "Graphics",
 Evaluatable->False],
Cell[18473, 425, 82, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[18558, 428, 423, 10, 33, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[18984, 440, 421, 11, 29, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[19408, 453, 9309, 159, 367, "Graphics",
 Evaluatable->False],
Cell[28720, 614, 82, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[28805, 617, 202, 4, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[29010, 623, 1579, 50, 52, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[30592, 675, 502, 13, 23, "Input"],
Cell[31097, 690, 312, 6, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[31412, 698, 18017, 443, 207, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[49432, 1143, 69, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[49504, 1146, 331, 7, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[49860, 1157, 103, 2, 23, "Input"],
Cell[49966, 1161, 408, 10, 18, "Output"]
}, Open  ]],
Cell[50389, 1174, 225, 6, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[50639, 1184, 108, 2, 23, "Input"],
Cell[50750, 1188, 2848, 63, 34, "Output"]
}, Open  ]],
Cell[53613, 1254, 180, 5, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[53818, 1263, 161, 4, 23, "Input"],
Cell[53982, 1269, 111, 3, 18, "Output"]
}, Open  ]],
Cell[54108, 1275, 459, 12, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[54592, 1291, 175, 4, 23, "Input"],
Cell[54770, 1297, 1082, 43, 24, "Output"]
}, Open  ]],
Cell[55867, 1343, 228, 9, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[56098, 1354, 189, 4, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[56290, 1360, 10857, 254, 188, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[67150, 1616, 110, 3, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[67263, 1621, 30481, 760, 232, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[97747, 2383, 80, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[97830, 2386, 209, 6, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[98042, 2394, 33126, 796, 179, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[131171, 3192, 83, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[131257, 3195, 2446, 60, 60, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[133706, 3257, 91, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[133800, 3260, 129, 3, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[133954, 3267, 180, 5, 23, "Input"],
Cell[134137, 3274, 52, 1, 18, "Output"]
}, Open  ]],
Cell[134204, 3278, 180, 4, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[134409, 3286, 238, 6, 23, "Input"],
Cell[134650, 3294, 52, 1, 18, "Output"]
}, Open  ]],
Cell[134717, 3298, 129, 3, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[134871, 3305, 145, 4, 23, "Input"],
Cell[135019, 3311, 52, 1, 18, "Output"]
}, Open  ]],
Cell[135086, 3315, 248, 6, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[135359, 3325, 131, 3, 23, "Input"],
Cell[135493, 3330, 178, 6, 38, "Output"]
}, Open  ]],
Cell[135686, 3339, 123, 3, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[135834, 3346, 141, 3, 23, "Input"],
Cell[135978, 3351, 213, 7, 38, "Output"]
}, Open  ]],
Cell[136206, 3361, 143, 4, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[136374, 3369, 130, 3, 23, "Input"],
Cell[136507, 3374, 52, 1, 18, "Output"]
}, Open  ]],
Cell[136574, 3378, 274, 6, 26, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[136873, 3388, 137, 3, 23, "Input"],
Cell[137013, 3393, 312, 10, 37, "Output"]
}, Open  ]],
Cell[137340, 3406, 199, 4, 20, "Text",
 CellTags->{"S5.93.1", "1.2"}],
Cell[137542, 3412, 6785, 173, 177, "Text",
 CellTags->{"S5.93.1", "1.3"}],
Cell[144330, 3587, 65, 1, 15, "Caption",
 CellTags->"NumberOfIsomers"],
Cell[144398, 3590, 422, 12, 39, "MathCaption",
 CellTags->{"S5.93.1", "1.5"}],
Cell[CellGroupData[{
Cell[144845, 3606, 1087, 28, 174, "Input"],
Cell[145935, 3636, 12974, 328, 438, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

