(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    953368,      22309]*)
(*NotebookOutlinePosition[    955739,      22383]*)
(*  CellTagsIndexPosition[    955466,      22373]*)
(*WindowFrame->Palette*)



Notebook[{
Cell["Parent Compound Definition Panel", NotebookDefault,
  Editable->False,
  Selectable->False,
  Deletable->False,
  CellFrame->True,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  Copyable->False,
  TextAlignment->Center,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  Background->GrayLevel[0.900008]],

Cell["\<\
The definition of a new parent compound is an error prone task. We, \
therefore, ask the user to read this input panel carefully and to proceed \
diligently.\
\>", NotebookDefault,
  Editable->False,
  Selectable->False,
  Deletable->False,
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{Inherited, 0}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[CellGroupData[{

Cell["Parent Compound Reference Symbol", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  Copyable->False,
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[TextData[{
  "To define a parent compound in the Isomer-package, you have to provide a \
symbol that identifies the compound (e.g. ",
  StyleBox["Methane", "Input"],
  "). The symbol has to start with a letter and may consist of as many \
letters and numerals as you like. The symbol may end in a pair of square \
brackets ('[' and ']') encompassing a list of symbolic- or numeric-arguments \
(e.g. ",
  StyleBox["Methane[1,2]", "Input"],
  "). No special characters should be used. Furthermore, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " distinguishes between small and capital letters."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Example:",
    FontVariations->{"Underline"->True}],
  " the graphic below shows a model of Methane, a molecule with tetrahedral \
symmetry and four potential substituent sites."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  CellOpen->True,
  FontFamily->"Times",
  FontSize->12],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000hb000`400?l00000o`00003oUP3oool0
0`2e]KD0oooo0?ooo`150?ooo`00SP3oool90;Fe]@P0[Jf]?`3oool008X0oooo1@2e]KD?06][J`D0
[Jf]>`3oool008L0oooo102e]KDG06][J`@0[Jf]>03oool008D0oooo0`2e]KDB06][J`T0Lg=c0P1[
Jf/30:f][CH0oooo00230?ooo`<0]KFe401[Jf/A07=cL`<0[Jf]=03oool00840oooo0`2e]KD>06][
J`P0Lg=c2`1kNg/407=cL`<0[Jf]<P3oool00800oooo0P2e]KD=06][J`L0Lg=c201kNg/308B4Q0P0
Ng]k0P1cLg<20:f][C40oooo001n0?ooo`<0]KFe301[Jf/507=cL`H0Ng]k4024Q8@407]kN`<0[Jf]
;`3oool007d0oooo0P2e]KD<06][J`@0Lg=c1@1kNg/708B4Q0`0S8b<1024Q8@307]kN`80[Jf];P3o
ool007`0oooo0P2e]KD;06][J`@0Lg=c1@1kNg/508B4Q0P0S8b<1@2DU9@708b<S0<0Q8B400<0Ng]k
0;Fe]@2e]KD0;@3oool007X0oooo0`2e]KD:06][J`@0Lg=c101kNg/508B4Q0H0S8b<402DU9@408b<
S080Q8B40`2e]KD[0?ooo`00N@3oool20;Fe]@/0Jf][0`1cLg<407]kN`@0Q8B41@2<S8`709BDU0/0
W9bL1P2DU9@208b<S080Q8B400<0[Jf]0;Fe]@3oool0:@3oool007P0oooo0P2e]KD;06][J`<0Lg=c
0`1kNg/408B4Q0D0S8b<1P2DU9@A09bLW0@0U9BD0`2<S8`00`24Q8@0[Jf]0;Fe]@0Y0?ooo`00N03o
ool00`2e]KD0Jf][06][J`0906][J`<0Lg=c0`1kNg/308B4Q0@0S8b<1`2DU9@709bLW0T0YJFU1P2L
W9`309BDU00408b<S024Q8@0Q8B40;Fe]BT0oooo001g0?ooo`80]KFe2P1[Jf/207=cL`@0Ng]k0`24
Q8@308b<S0H0U9BD1P2LW9`@0:FUY@D0W9bL0P2DU9@0102<S8`0Q8B40:f][@2e]KDX0?ooo`00MP3o
ool20;Fe]@T0Jf][0`1cLg<307]kN`<0Q8B4102<S8`409BDU0H0W9bL2`2UYJD30:f][@T0YJFU0`2L
W9`209BDU00308b<S02e]KD0]KFe02L0oooo001e0?ooo`80]KFe2@1[Jf/307=cL`80Ng]k0`24Q8@4
08b<S0@0U9BD1@2LW9`60:FUYA40[Jf]1@2UYJD209bLW080U9BD00<0S8b<0;Fe]@2e]KD09P3oool0
07@0oooo0P2e]KD906][J`<0Lg=c0P1kNg/308B4Q0<0S8b<1@2DU9@409bLW0H0YJFU5P2][Jd40:FU
Y@80W9bL00@0U9BD08b<S02e]KD0]KFe9@3oool007@0oooo00<0]KFe06][J`1[Jf/0201[Jf/207=c
L`80Ng]k0`24Q8@308b<S0@0U9BD102LW9`60:FUY@H0[Jf]3`2e]KD60:f][@80YJFU0P2LW9`00`2D
U9@0S8b<0;Fe]@0U0?ooo`00L`3oool20;Fe]@P0Jf][0`1cLg<207]kN`<0Q8B40`2<S8`309BDU0@0
W9bL1P2UYJD60:f][A<0]KFe1@2][Jd20:FUY@80W9bL00<0U9BD0;Fe]@2e]KD0903oool007<0oooo
00<0]KFe06][J`1[Jf/01`1[Jf/207=cL`80Ng]k0`24Q8@308b<S0<0U9BD102LW9`50:FUY@H0[Jf]
1`2e]KD:0;fm_@P0]KFe0P2][Jd20:FUY@80W9bL00<0U9BD0;fm_@3oool08`3oool00780oooo0P2e
]KD806][J`80Lg=c0P1kNg/308B4Q0<0S8b<0`2DU9@409bLW0@0YJFU1P2][Jd50;Fe]A40_Kfm1P2e
]KD20:f][@80YJFU00@0W9bL09BDU02e]KD0]KFe8`3oool00780oooo00<0]KFe06][J`1[Jf/01P1[
Jf/207=cL`<0Ng]k0P24Q8@308b<S0<0U9BD0`2LW9`40:FUY@H0[Jf]1@2e]KDG0;fm_@<0]KFe0P2]
[Jd20:FUY@0309bLW02DU9@0_Kfm02<0oooo000H0?ooo`<000000`3oool300000080oooo0P000004
0?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?ooo`00000000000080000000@0
oooo000000000000oooo0P00000c0?ooo`80]KFe1`1[Jf/307=cL`80Ng]k0P24Q8@308b<S0<0U9BD
0`2LW9`40:FUY@D0[Jf]1@2e]KD=0;fm_@<0a/K62P2m_Kd30;Fe]@80[Jf]0P2UYJD00`2LW9`0_Kfm
0;Fe]@0R0?ooo`006@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0300oooo00<0
]KFe06][J`1[Jf/01P1[Jf/207=cL`80Ng]k0P24Q8@308b<S0<0U9BD0`2LW9`40:FUY@@0[Jf]1@2e
]KD70;fm_A80a/K61@2m_Kd20;Fe]@80[Jf]0P2UYJD00`2LW9`0_Kfm0?ooo`0Q0?ooo`006@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`000000=03oool20;Fe]@L0Jf][0P1cLg<207]kN`<0Q8B40P2<S8`309BDU0<0W9bL102UYJD30:f]
[@D0]KFe1`2m_KdF0<K6aP@0_Kfm0P2e]KD20:f][@80YJFU0P2m_KdQ0?ooo`006@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00@000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<000000P3oool01@000000oooo0?ooo`000000oooo00@00000<@3o
ool00`2e]KD0Jf][06][J`0506][J`<0Lg=c00@0Ng]k08B4Q024Q8@0Q8B40P2<S8`309BDU0<0W9bL
102UYJD30:f][@@0]KFe1`2m_Kd60<K6aPl0c/k>1@36a/H40;fm_@060;Fe]@2][Jd0[Jf]0:FUY@2L
W9`0_Kfm8@3oool001T0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo02h0
oooo0P2e]KD606][J`<0Lg=c0P1kNg/208B4Q080S8b<0`2DU9@309bLW0<0YJFU102][Jd40;Fe]@H0
_Kfm1P36a/HC0<k>cPD0a/K60`2m_Kd20;Fe]@040:f][@2UYJD0_Kfm0;fm_B00oooo000I0?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`8000000P3oool3000000040?ooo`000000
0000000000<0oooo0P0000020?ooo`040000003oool00000000000<0oooo0P00000a0?ooo`030;Fe
]@1[Jf/0Jf][00D0Jf][0P1cLg<207]kN`80Q8B40`2<S8`209BDU0<0W9bL0`2UYJD40:f][@@0]KFe
1P2m_Kd40<K6aPT0c/k>2@3Fe]H70<k>cP<0a/K60P2m_Kd20;Fe]@040:f][@2UYJD0W9bL0;fm_B00
oooo000I0?ooo`8000000`3oool2000000P0oooo00@000000?ooo`3oool00000@`3oool00`2e]KD0
Jf][06][J`0406][J`<0Lg=c0P1kNg/208B4Q080S8b<0`2DU9@309bLW080YJFU102][Jd40;Fe]@80
_Kfm0P0000000`24Q8@0a/K60<K6aP030<K6aP<0c/k>00@061PH0000001BDU80c/k>3`3Fe]H50<k>
cP<0a/K60P2m_Kd20;Fe]@030:f][@2UYJD0_Kfm0200oooo000H0?ooo`<000000`3oool3000000T0
oooo0P0000130?ooo`030;Fe]@1[Jf/0Jf][00@0Jf][0P1cLg<207]kN`80Q8B40P2<S8`309BDU0<0
W9bL0`2UYJD30:f][@@0]KFe0`2m_Kd20000000308b<S036a/H0a/K60080a/K6103>c/h00`0H61P0
000005YJFP0A0=KFePD0c/k>0P36a/H30;fm_@040;Fe]@2][Jd0YJFU0<K6aR00oooo001^0?ooo`80
]KFe1P1[Jf/207=cL`0307]kN`24Q8@0Q8B400<0S8b<0P2DU9@309bLW0<0YJFU0`2][Jd40;Fe]@@0
_Kfm0P000000102<S8`0a/K60<K6aP36a/H30<k>cP80e]KF00<061PH0000001JFUX0503Fe]H30<k>
cP80a/K60`2m_Kd0102e]KD0[Jf]0<K6aP2m_KdO0?ooo`00KP3oool00`2e]KD0Jf][06][J`0406][
J`80Lg=c0P1kNg/208B4Q080S8b<0P2DU9@309bLW0<0YJFU0`2][Jd30;Fe]@D0_Kfm00@0a/K60000
00000000S8b<1@3>c/h30=KFeP0301PH60000000FUYJ0080e]KF3@3Ng]h60=KFeP<0c/k>0P36a/H2
0;fm_@040;Fe]@2][Jd0YJFU0<K6aQl0oooo001^0?ooo`030;Fe]@1[Jf/0Jf][00@0Jf][0P1cLg<2
07]kN`0408B4Q02<S8`0S8b<08b<S080U9BD0P2LW9`40:FUY@<0[Jf]0`2e]KD40;fm_@80a/K60P00
00000`2<S8`0c/k>0<k>cP020<k>cP@0e]KF00@061PH0000001JFUX0e]KF3`3Ng]h60=KFeP<0c/k>
0P36a/H01@2m_Kd0]KFe0:f][@2UYJD0a/K601l0oooo001^0?ooo`030;Fe]@1[Jf/0Jf][00@0Jf][
0P1cLg<00`1kNg/0Q8B408B4Q00208b<S0<0U9BD0P2LW9`30:FUY@<0[Jf]0`2e]KD40;fm_@<0a/K6
0P000000102<S8`0c/k>0<k>cP3>c/h50=KFeP0301PH60000000FUYJ0140g]kN1P3Fe]H20<k>cP80
a/K60P2m_Kd00`2e]KD0YJFU0<K6aP0O0?ooo`00KP3oool00`2e]KD0Jf][06][J`0306][J`80Lg=c
0P1kNg/208B4Q080S8b<0P2DU9@309bLW0<0YJFU0`2][Jd20;Fe]@@0_Kfm1036a/H20000000308b<
S03>c/h0c/k>00H0e]KF00<061PH0000001JFUX0503Ng]h30=KFeP<0c/k>00H0a/K60;fm_@2m_Kd0
]KFe0:f][@36a/HO0?ooo`00KP3oool00`2e]KD0Jf][06][J`0306][J`80Lg=c0P1kNg/208B4Q080
S8b<0P2DU9@209bLW0<0YJFU0`2][Jd30;Fe]@@0_Kfm0`36a/H01@3>c/h000000000002DU9@0c/k>
00H0e]KF00@0g]kN01PH60000000FUYJ5@3Ng]h30=KFeP80c/k>0P36a/H0102m_Kd0]KFe0:f][@36
a/HO0?ooo`00KP3oool00`2e]KD0Jf][06][J`0306][J`80Lg=c00<0Ng]k08B4Q024Q8@00P2<S8`3
09BDU080W9bL0`2UYJD30:f][@<0]KFe0`2m_Kd40<K6aP030<k>cP000000000000/0000000<0FUYJ
0=kNgP3Ng]h04`3Ng]h30=KFeP80c/k>0P36a/H0102m_Kd0]KFe0:f][@36a/HO0?ooo`00KP3oool0
0`2e]KD0Jf][06][J`0206][J`<0Lg=c00<0Ng]k08B4Q024Q8@00P2<S8`209BDU080W9bL0`2UYJD3
0:f][@<0]KFe0`2m_Kd40<K6aP80c/k>3@0000000`1JFUX0g]kN0=kNgP0=0>OWi`L0g]kN0`3Fe]H2
0<k>cP050<K6aP2m_Kd0]KFe0:f][@36a/H07`3oool006h0oooo00<0]KFe06][J`1[Jf/00P1[Jf/2
07=cL`80Ng]k0P24Q8@0102<S8`0U9BD09BDU02DU9@209bLW0<0YJFU0`2][Jd20;Fe]@@0_Kfm1036
a/H20<k>cP80000000<0U9BD0=KFeP3Fe]H00P3Fe]H40=kNgP0401PH60000000FUYJ0=kNgPl0inOW
1P3Ng]h30=KFeP80c/k>0P36a/H00`2m_Kd0[Jf]0<K6aP0O0?ooo`00KP3oool00`2e]KD0Jf][06][
J`0206][J`80Lg=c0P1kNg/00`24Q8@0S8b<08b<S00309BDU080W9bL0P2UYJD30:f][@<0]KFe0`2m
_Kd40<K6aP<0c/k>0P000000102DU9@0e]KF0=KFeP3Fe]H50=kNgP0301PH60000000Hf=S0140inOW
1P3Ng]h30=KFeP060<k>cP36a/H0a/K60;fm_@2][Jd0a/K67`3oool006h0oooo00<0]KFe06][J`1[
Jf/00P1[Jf/207=cL`0307]kN`24Q8@0Q8B40080S8b<0P2DU9@209bLW0<0YJFU0`2][Jd30;Fe]@<0
_Kfm0`36a/H30<k>cP040=KFeP000000000009BDU080e]KF1P3Ng]h00`0H61P0000006=SH`0D0>OW
i`@0g]kN0P3Fe]H20<k>cP040<K6aP2m_Kd0]KFe0<K6aQl0oooo001^0?ooo`030;Fe]@1[Jf/0Jf][
0080Jf][0P1cLg<00`1kNg/0Q8B408B4Q00208b<S080U9BD0P2LW9`20:FUY@<0[Jf]0`2e]KD30;fm
_@<0a/K60`3>c/h20=KFeP80000000<0U9BD0=KFeP3Ng]h01@3Ng]h0103WinL08B4Q0000001SHf<E
0>OWi`<0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@2e]KD0a/K601l0oooo001^0?ooo`040;Fe]@1[Jf/0
Jf][06][J`80Lg=c0P1kNg/208B4Q00308b<S02DU9@0U9BD00<0W9bL0P2UYJD30:f][@80]KFe102m
_Kd30<K6aP80c/k>0`3Fe]H20000000309bLW03Ng]h0g]kN00@0g]kN0P3WinL00`0Q8B40000006=S
H`0E0>OWi`<0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@2e]KD0c/k>01l0oooo001^0?ooo`040;Fe]@1[
Jf/0Jf][06][J`80Lg=c0P1kNg/00`24Q8@0S8b<08b<S00209BDU080W9bL0P2UYJD30:f][@<0]KFe
0`2m_Kd30<K6aP<0c/k>0`3Fe]H20000000309bLW03Ng]h0g]kN00<0g]kN0`3WinL00`0Q8B400000
06=SH`0F0>OWi`<0g]kN0P3Fe]H01@3>c/h0a/K60;fm_@2e]KD0c/k>01l0oooo001^0?ooo`040;Fe
]@1[Jf/0Jf][06][J`80Lg=c00<0Ng]k08B4Q024Q8@00P2<S8`0102DU9@0W9bL09bLW02LW9`20:FU
Y@<0[Jf]0`2e]KD30;fm_@<0a/K60`3>c/h30=KFeP80000000<0W9bL0=kNgP3Ng]h00P3Ng]h40>OW
i`03024Q8@000000Hf=S0080inOW3@3_knl70>OWi`<0g]kN0P3Fe]H01@3>c/h0a/K60<K6aP2e]KD0
c/k>01l0oooo001^0?ooo`040;Fe]@1[Jf/0Jf][06][J`80Lg=c00@0Ng]k08B4Q024Q8@0S8b<0P2D
U9@309bLW080YJFU0P2][Jd30;Fe]@<0_Kfm0`36a/H30<k>cP@0e]KF0P2LW9`0103>c/h0g]kN0=kN
gP3Ng]h50>OWi`040;Fe]@2UYJD0a/K60>OWi`l0kno_1`3WinL30=kNgP80e]KF00@0c/k>0<K6aP2e
]KD0c/k>7`3oool006h0oooo0P2e]KD206][J`80Lg=c00@0Ng]k08B4Q024Q8@0S8b<0P2DU9@209bL
W0<0YJFU0P2][Jd20;Fe]@@0_Kfm0`36a/H30<k>cP@0e]KF1P3Ng]h70>OWia40kno_1`3WinL30=kN
gP040=KFeP3>c/h0c/k>0;fm_@80c/k>7`3oool006l0oooo00<0]KFe06][J`1[Jf/00P1cLg<0101k
Ng/0Q8B408B4Q02<S8`209BDU080W9bL0`2UYJD20:f][@80]KFe102m_Kd20<K6aP<0c/k>1@3Fe]H6
0=kNgPL0inOW4@3_knl70>OWi`80g]kN0P3Fe]H0103>c/h0a/K60;fm_@3>c/hP0?ooo`00K`3oool0
0`2e]KD0Jf][06][J`0207=cL`0407]kN`24Q8@0Q8B408b<S080U9BD0P2LW9`20:FUY@<0[Jf]0P2e
]KD40;fm_@80a/K60`3>c/h40=KFePH0g]kN1`3WinLC0>o_k`H0inOW0`3Ng]h01@3Fe]H0c/k>0<K6
aP2m_Kd0c/k>0200oooo001_0?ooo`030;Fe]@1[Jf/0Jf][0080Lg=c00@0Ng]k08B4Q024Q8@0S8b<
0P2DU9@209bLW080YJFU0`2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OWiaD0kno_
1@3WinL30=kNgP050=KFeP3>c/h0a/K60;fm_@3>c/h0803oool006l0oooo0P2e]KD0101[Jf/0Lg=c
07=cL`1kNg/208B4Q00308b<S02DU9@0U9BD0080W9bL0P2UYJD30:f][@80]KFe0`2m_Kd30<K6aP80
c/k>103Fe]H60=kNgPL0inOW5@3_knl50>OWi`<0g]kN00D0e]KF0<k>cP36a/H0e]KF0<k>cP0P0?oo
o`00L03oool01@2e]KD0Jf][07=cL`1cLg<0Ng]k0080Q8B400<0S8b<09BDU02DU9@00P2LW9`20:FU
Y@<0[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLE0>o_k`D0inOW0P3Ng]h20=KF
eP030<k>cP36a/H0e]KF0240oooo001`0?ooo`80]KFe00H0Jf][07=cL`1kNg/0Ng]k08B4Q02<S8`2
09BDU080W9bL0P2UYJD30:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW5@3_knl5
0>OWi`80g]kN00D0e]KF0<k>cP36a/H0e]KF0<k>cP0Q0?ooo`00L@3oool01P2e]KD0Jf][07=cL`1c
Lg<0Ng]k08B4Q080S8b<00<0U9BD09bLW02LW9`00`2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>
103Fe]H60=kNgPL0inOW4`3_knl60>OWi`<0g]kN00@0e]KF0<k>cP36a/H0e]KF8P3oool00740oooo
0P2e]KD207=cL`0507]kN`24Q8@0Q8B408b<S02DU9@00P2LW9`30:FUY@80[Jf]0P2e]KD30;fm_@<0
a/K60P3>c/h40=KFePH0g]kN1`3WinLC0>o_k`H0inOW0P3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>
0280oooo001b0?ooo`040;Fe]@1[Jf/0Lg=c07]kN`80Q8B400@0S8b<09BDU02DU9@0W9bL0`2UYJD2
0:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW4`3_knl50>OWi`<0g]kN00@0e]KF
0<k>cP36a/H0e]KF8`3oool00780oooo0P2e]KD01@1cLg<0Ng]k07]kN`24Q8@0S8b<0080U9BD0P2L
W9`20:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLC0>o_k`D0inOW0P3N
g]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>02<0oooo000X0?ooo`030;Fe]@3oool0oooo04P0oooo00H0
]KFe07=cL`1cLg<0Ng]k08B4Q02<S8`209BDU080W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80
c/k>103Fe]H60=kNgPL0inOW4`3_knl50>OWi`80g]kN00@0e]KF0<k>cP36a/H0e]KF903oool00200
oooo4@2e]KE20?ooo`80]KFe00<0Lg=c07]kN`24Q8@00P2<S8`00`2DU9@0W9bL09bLW0020:FUY@80
[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLB0>o_k`D0inOW0`3Ng]h0103Fe]H0
c/k>0=KFeP3Fe]HT0?ooo`00703oool50;Fe]@l0Jf][1@2e]KDo0?ooo`030;Fe]@1cLg<0Ng]k0080
Q8B400@0S8b<09BDU02DU9@0W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kN
gPL0inOW4@3_knl60>OWi`80g]kN00@0e]KF0<k>cP36a/H0e]KF9@3oool001T0oooo102e]KDG06][
J`@0]KFe?03oool20;Fe]@0407=cL`1kNg/0Q8B408b<S080U9BD00<0W9bL0:FUY@2UYJD00P2][Jd3
0;Fe]@<0_Kfm0P36a/H30<k>cP<0e]KF1P3Ng]h70>OWia40kno_1@3WinL30=kNgP040=KFeP3>c/h0
e]KF0=KFeRD0oooo000G0?ooo`<0]KFe4P1[Jf/907=cL`80Jf][0`2e]KDk0?ooo`80]KFe00D0Ng]k
08B4Q02<S8`0S8b<09BDU00209bLW0040:FUY@2][Jd0[Jf]0:f][@80]KFe0`2m_Kd30<K6aP80c/k>
0`3Fe]H60=kNgPL0inOW403_knl50>OWi`80g]kN0P3Fe]H00`3>c/h0g]kN0=KFeP0V0?ooo`005@3o
ool30;Fe]A00Jf][4@1cLg<30;Fe]CX0oooo0P2e]KD00`1kNg/0Q8B408b<S00209BDU00309bLW02U
YJD0YJFU0080[Jf]0`2e]KD30;fm_@80a/K60P3>c/h40=KFePH0g]kN2@3WinL:0>o_k`L0inOW0P3N
g]h20=KFeP030<k>cP3Ng]h0e]KF02L0oooo000C0?ooo`<0]KFe3P1[Jf/807=cL`/0Ng]k101cLg<3
0;Fe]CT0oooo0P2e]KD0101kNg/0Q8B408b<S02DU9@209bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36
a/H20<k>cP@0e]KF1P3Ng]hH0>OWi`80g]kN0P3Fe]H00`3>c/h0g]kN0=KFeP0X0?ooo`004P3oool2
0;Fe]@d0Jf][1`1cLg<807]kN`<0Q8B4201kNg/207=cL`80]KFe>@3oool0102e]KD0Ng]k08B4Q02<
S8`209BDU00409bLW02UYJD0YJFU0:FUY@80[Jf]0P2e]KD30;fm_@80a/K60P3>c/h50=KFePH0g]kN
5P3WinL30=kNgP040=KFeP3>c/h0a/K60=KFeRT0oooo000@0?ooo`<0]KFe301[Jf/507=cL`H0Ng]k
4024Q8@407]kN`<0]KFe=`3oool20;Fe]@0407]kN`24Q8@0S8b<09BDU080W9bL0P2UYJD20:f][@80
]KFe0`2m_Kd20<K6aP<0c/k>103Fe]H60=kNgQD0inOW0`3Ng]h20=KFeP030<k>cP3Ng]h0e]KF02T0
oooo000?0?ooo`80]KFe301[Jf/407=cL`D0Ng]k1`24Q8@<08b<S0@0Q8B40`1kNg/20;Fe]CL0oooo
0P2e]KD01@24Q8@0S8b<09BDU02DU9@0W9bL0080YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0
e]KF1P3Ng]hD0>OWi`<0g]kN0P3Fe]H00`3>c/h0g]kN0=kNgP0Z0?ooo`003P3oool20;Fe]@/0Jf][
101cLg<507]kN`D0Q8B4202<S8`509BDU0L0S8b<0`24Q8@00`1kNg/0]KFe0;Fe]@0g0?ooo`<0]KFe
00@0S8b<09BDU02LW9`0W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgQ80
inOW0`3Ng]h00`3Fe]H0c/k>0>OWi`020=kNgR/0oooo000<0?ooo`<0]KFe2P1[Jf/407=cL`@0Ng]k
1@24Q8@608b<S100U9BD102<S8`208B4Q0<0]KFe=`3oool00`2m_Kd0]KFe08b<S00209BDU00309bL
W02UYJD0YJFU0080[Jf]0P2e]KD30;fm_@80a/K60`3>c/h50=KFePH0g]kN303WinL50=kNgP80e]KF
00<0c/k>0=kNgP3Ng]h0;@3oool000/0oooo0P2e]KD;06][J`<0Lg=c101kNg/408B4Q0D0S8b<1`2D
U9@;09bLW0H0U9BD0P2<S8`208B4Q080]KFe=`3oool00`2e]KD0Q8B408b<S00209BDU00309bLW02U
YJD0YJFU0080[Jf]0P2e]KD30;fm_@80a/K60`3>c/h60=KFeQ<0g]kN0P3Fe]H0103>c/h0a/K60=kN
gP3Fe]H^0?ooo`002P3oool20;Fe]@/0Jf][0`1cLg<307]kN`@0Q8B41@2<S8`609BDU140W9bL102D
U9@308b<S00308B4Q02e]KD0]KFe03D0oooo00D0[Jf]0;Fe]@1kNg/0Q8B408b<S00209BDU00309bL
W02UYJD0YJFU0080[Jf]0P2e]KD30;fm_@<0a/K60`3>c/h50=KFeQ00g]kN0P3Fe]H20<k>cP80g]kN
00<0e]KF0?ooo`3oool0;@3oool000X0oooo00<0]KFe06][J`1[Jf/02@1[Jf/307=cL`<0Ng]k0`24
Q8@408b<S0L0U9BD1`2LW9`90:FUY@H0W9bL0`2DU9@0102<S8`0Q8B408B4Q02e]KDe0?ooo`060:FU
Y@1SHf<0Jf][07]kN`24Q8@0S8b<0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80]KFe0`2m_Kd30<K6
aP@0c/k>1@3Fe]H:0=kNgP@0e]KF0P3>c/h00`36a/H0g]kN0=kNgP0a0?ooo`002@3oool20;Fe]@X0
Jf][0P1cLg<407]kN`<0Q8B40`2<S8`609BDU0H0W9bL402UYJD509bLW080U9BD00@0S8b<08B4Q02e
]KD0_Kfm;03oool80:f][@080;Fe]@1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S02DU9@209bLW080YJFU
0P2][Jd20;Fe]@<0_Kfm1036a/H40<k>cPl0e]KF0P3>c/h01036a/H0g]kN0=KFeP3Fe]Hb0?ooo`00
203oool20;Fe]@T0Jf][0`1cLg<307]kN`<0Q8B4102<S8`409BDU0H0W9bL2`2UYJD30:f][@T0YJFU
0`2LW9`209BDU00308b<S02e]KD0]KFe02L0oooo1@2][Jd70492@P0604Y:BP1BDU80Hf=S07=cL`24
Q8@0S8b<0P2DU9@309bLW080YJFU0P2][Jd20;Fe]@@0_Kfm1036a/H40<k>cPT0e]KF103>c/h01036
a/H0g]kN0=kNgP3Fe]Hd0?ooo`001`3oool20;Fe]@T0Jf][0`1cLg<207]kN`<0Q8B4102<S8`409BD
U0D0W9bL1P2UYJDA0:f][@D0YJFU0P2LW9`209BDU00308b<S02e]KD0_Kfm02<0oooo102][Jd;0492
@P0804Y:BP1BDU80Hf=S07]kN`24Q8@0S8b<09BDU02LW9`60:FUY@80[Jf]0`2e]KD40;fm_@D0a/K6
2P3>c/h30<K6aP030=kNgP3Fe]H0e]KF03H0oooo00060?ooo`80]KFe2@1[Jf/307=cL`80Ng]k0`24
Q8@308b<S0D0U9BD102LW9`60:FUYAH0[Jf]102UYJD209bLW00409BDU02<S8`0]KFe0;fm_B00oooo
0`2][Jd>0492@P0804Y:BP1BDU80Jf][07]kN`2<S8`0U9BD09bLW02UYJD90:f][@@0]KFe1@2m_Kd<
0<K6aP80g]kN0P3Fe]Hh0?ooo`001P3oool00`2e]KD0Jf][06][J`0806][J`80Lg=c0P1kNg/308B4
Q0<0S8b<102DU9@409bLW0H0YJFU1P2][Jd?0;Fe]@H0[Jf]0P2UYJD209bLW00309BDU02<S8`0_Kfm
01h0oooo0`2][Jd@0492@P0904Y:BP1JFUX0Jf][08B4Q02<S8`0U9BD0:FUY@2][Jd0]KFe00D0_Kfm
202e]KD80;fm_@040<K6aP2m_Kd0_Kfm0;fm_@D0e]KF>`3oool000D0oooo0P2e]KD806][J`<0Lg=c
0P1kNg/308B4Q0<0S8b<0`2DU9@409bLW0H0YJFU1P2][JdC0;Fe]@D0[Jf]0P2UYJD209bLW00309BD
U02m_Kd0_Kfm01/0oooo0`2][JdB0492@P0904Y:BP1JFUX0Lg=c08B4Q02DU9@0W9bL0:FUY@2e]KD0
_Kfm00<0a/K60P3>c/h20<K6aP030<k>cP36a/H0_Kfm00<0_Kfm0P36a/H20;fm_@030=KFeP3>c/h0
e]KF00@0e]KF00<0c/k>0=KFeP3oool0?P3oool000D0oooo00<0]KFe06][J`1[Jf/01`1[Jf/207=c
L`80Ng]k0`24Q8@308b<S0<0U9BD102LW9`50:FUY@H0[Jf]1`2e]KD:0;fm_@P0]KFe0P2][Jd20:FU
Y@80W9bL00<0U9BD0;fm_@3oool06@3oool20:f][@h0@T921`1:BTX02@1JFUX0Lg=c08B4Q02DU9@0
W9bL0:FUY@2e]KD0_Kfm0<K6aP020<k>cP<0e]KF0`3Ng]h50=KFeP040<k>cP36a/H0_Kfm0=KFeTL0
oooo00040?ooo`80]KFe201[Jf/207=cL`80Ng]k0`24Q8@308b<S0<0U9BD102LW9`40:FUY@H0[Jf]
1@2e]KDA0;fm_@H0]KFe0P2][Jd20:FUY@0409bLW02DU9@0_Kfm0;fm_AL0oooo0`2][Jd=0492@PT0
BTY:00T0FUYJ07=cL`24Q8@0S8b<09bLW02UYJD0]KFe0;fm_@36a/H00P3>c/h20=KFeP80g]kN1P3W
inL20=kNgP030<k>cP3Fe]H0c/k>04L0oooo00040?ooo`030;Fe]@1[Jf/0Jf][00H0Jf][0P1cLg<3
07]kN`80Q8B40`2<S8`309BDU0<0W9bL102UYJD60:f][@D0]KFe5`2m_Kd30;Fe]@80[Jf]0P2UYJD0
0`2LW9`0U9BD0;fm_@0F0?ooo`80[Jf]3@12@T8504Y:BP@0DU9B00/0BTY:059BDP1JFUX0Hf=S07=c
L`24Q8@0U9BD0:FUY@2][Jd0_Kfm0<K6aP020<k>cP030=KFeP3Ng]h0g]kN00L0inOW00@0g]kN0=KF
eP36a/H0c/k>B03oool000<0oooo0P2e]KD706][J`<0Lg=c0P1kNg/208B4Q0<0S8b<0`2DU9@309bL
W0@0YJFU1@2][Jd50;Fe]@d0_Kfm0`36a/H:0;fm_@<0]KFe0P2][Jd20:FUY@0309bLW02m_Kd0_Kfm
01@0oooo0P2][Jd<0492@PD0BTY:201BDU802P1JFUX0Hf=S07=cL`1kNg/0S8b<09bLW02][Jd0]KFe
0;fm_@3>c/h20=KFeP80g]kN1`3WinL01@3Ng]h0a/K60;Fe]@2e]KD0a/K604L0oooo00030?ooo`03
0;Fe]@1[Jf/0Jf][00H0Jf][0P1cLg<207]kN`80Q8B40`2<S8`309BDU0<0W9bL102UYJD40:f][@D0
]KFe1`2m_KdB0<K6aPD0_Kfm0P2e]KD20:f][@80YJFU00<0W9bL0<K6aP3oool04@3oool30:f][@/0
@T921@1:BTX5059BDPH0FUYJ00/0Hf=S06][J`1kNg/0Q8B409BDU02LW9`0YJFU0;Fe]@36a/H0c/k>
0=KFeP020=kNgPH0inOW00D0g]kN0<k>cP2e]KD0W9bL07]kN`020;Fe]@030:f][@3oool0oooo04<0
oooo00020?ooo`80]KFe1`1[Jf/207=cL`80Ng]k0`24Q8@208b<S0<0U9BD0`2LW9`40:FUY@<0[Jf]
1@2e]KD70;fm_AH0a/K6102m_Kd20;Fe]@80[Jf]0P2UYJD20;fm_A00oooo0P2][Jd;0492@PD0BTY:
101BDU8605YJFP@0Hf=S00/0Jf][07=cL`24Q8@0S8b<09BDU02LW9`0[Jf]0;fm_@36a/H0c/k>0=KF
eP020=kNgP<0inOW0P3Ng]h02@3>c/h0_Kfm0:FUY@24Q8@0Jf][05YJFP1BDU80YJFU0:f][@0K0?oo
o`030:f][@3oool0oooo02H0oooo00020?ooo`030;Fe]@1[Jf/0Jf][00D0Jf][0`1cLg<0101kNg/0
Q8B408B4Q024Q8@208b<S0<0U9BD0`2LW9`40:FUY@<0[Jf]102e]KD70;fm_@H0a/K63`3>c/h50<K6
aP@0_Kfm00H0]KFe0:f][@2][Jd0YJFU09bLW036a/H?0?ooo`80[Jf]2`12@T8404Y:BPD0DU9B1@1J
FUX606=SH`0<06][J`1cLg<0Ng]k08B4Q02<S8`0U9BD0:FUY@2][Jd0]KFe0;fm_@36a/H0e]KF103N
g]h0303Fe]H0c/k>0;fm_@2][Jd0U9BD07]kN`1[Jf/0Hf=S05YJFP1BDU80YJFU0:f][A80oooo4@2]
[JdP0?ooo`0000<0oooo0;Fe]@2e]KD01P1[Jf/307=cL`80Ng]k0P24Q8@208b<S0<0U9BD0`2LW9`3
0:FUY@@0[Jf]102e]KD60;fm_@H0a/K64`3>c/h50<K6aP<0_Kfm0P2e]KD0102][Jd0YJFU0<K6aP2m
_Kd>0?ooo`030:f][@12@T80@T9200T0@T92101:BTX4059BDP@0FUYJ2@1SHf<03P1[Jf/0Lg=c07]k
N`24Q8@0S8b<09BDU02LW9`0YJFU0:f][@2e]KD0_Kfm0<K6aP3Fe]H0g]kN0P3Fe]H01P3>c/h0_Kfm
0:f][@2LW9`0S8b<07=cL`80Hf=S0P1JFUX00`1BDU80[Jf]0?ooo`0=0?ooo`D0[Jf]3`1[Jf/50:f]
[A`0oooo00000`3oool0]KFe06][J`0606][J`80Lg=c0P1kNg/208B4Q0<0S8b<0P2DU9@309bLW0<0
YJFU102][Jd40;Fe]@H0_Kfm1036a/H90<k>cPT0e]KF1`3>c/h30<K6aP80_Kfm0P2e]KD0102][Jd0
YJFU09bLW036a/H=0?ooo`80[Jf]2P12@T8404Y:BP@0DU9B0`1JFUX906=SH`<0Jf][00@0Lg=c07]k
N`24Q8@0S8b<0P2DU9@01@2LW9`0YJFU0:f][@2m_Kd0a/K600<0e]KF00P0c/k>0;fm_@2e]KD0YJFU
09BDU01kNg/0Lg=c06][J`<0Hf=S00<0FUYJ0:FUY@2][Jd02P3oool40:f][AL0Jf][102][JdI0?oo
o`0000<0oooo0;Fe]@1[Jf/01@1[Jf/307=cL`80Ng]k0P24Q8@208b<S0<0U9BD0`2LW9`20:FUY@@0
[Jf]102e]KD50;fm_@D0a/K61`3>c/h?0=KFePD0c/k>0`36a/H20;fm_@80]KFe00<0[Jf]0:FUY@36
a/H0303oool20:f][@X0@T920`1:BTX4059BDP@0FUYJ1`1SHf<606][J`80Lg=c00<0Ng]k08B4Q02<
S8`00P2DU9@03@2LW9`0YJFU0;Fe]@36a/H0c/k>0=KFeP3>c/h0a/K60;fm_@2UYJD0U9BD08B4Q01k
Ng/00`1[Jf/306=SH`0305YJFP2UYJD0[Jf]00L0oooo0`2][JdB06][J`T0Lg=c0P1[Jf/30:f][AL0
oooo00000`3oool0]KFe06][J`0506][J`80Lg=c0P1kNg/208B4Q080S8b<0`2DU9@309bLW0<0YJFU
0`2][Jd40;Fe]@D0_Kfm1@36a/H50<k>cQ<0e]KF1@3>c/h20<K6aP<0_Kfm00@0]KFe0:f][@2UYJD0
a/K62`3oool20:f][@T0@T92101:BTX3059BDP@0FUYJ1P1SHf<806][J`@0Lg=c0P1kNg/208B4Q004
08b<S02DU9@0W9bL0:f][@80_Kfm0P2e]KD0102UYJD0U9BD08B4Q01kNg/207=cL`@0Jf][0P1SHf<0
0`1JFUX0YJFU0:f][@040?ooo`<0[Jf]401[Jf/A07=cL`<0[Jf]5@3oool00080]KFe1P1[Jf/207=c
L`0307]kN`24Q8@0Q8B400<0S8b<0P2DU9@309bLW0<0YJFU0`2][Jd40;Fe]@@0_Kfm1P36a/H30<k>
cQT0e]KF0`3>c/h20<K6aP80_Kfm00<0]KFe0:f][@2UYJD00P2m_Kd90?ooo`80[Jf]2@12@T8404Y:
BP<0DU9B101JFUX606=SH`H0Jf][1P1cLg<607]kN`80Q8B41@2DU9@0102<S8`0Q8B407]kN`1kNg/4
07=cL`<0Jf][0`1SHf<00`2UYJD0]KFe0?ooo`030:f][@h0Jf][201cLg<;07]kN`@0Lg=c0`2][JdC
0?ooo`0000<0YJFU06][J`1[Jf/0101[Jf/207=cL`80Ng]k0P24Q8@208b<S080U9BD0`2LW9`30:FU
Y@<0[Jf]0`2e]KD50;fm_@@0a/K61@3>c/h80=KFePd0g]kN1P3Fe]H30<k>cP080<K6aP2m_Kd0]KFe
0:FUY@2LW9`0U9BD08b<S02e]KD90?ooo`030:f][@12@T80@T9200P0@T920`1:BTX3059BDP<0FUYJ
1P1SHf<706][J`H0Lg=c2@1kNg/608B4Q0@0Ng]k1@1cLg<206][J`<0Hf=S00<0]KFe0:FUY@2][Jd0
3@1[Jf/707=cL`P0Ng]k0`24Q8@807]kN`80Lg=c0P2][JdB0?ooo`0000<0YJFU06][J`1[Jf/0101[
Jf/207=cL`80Ng]k00@0Q8B408b<S02<S8`0S8b<0P2DU9@209bLW0@0YJFU0`2][Jd30;Fe]@<0_Kfm
0P0000000`2<S8`0a/K60<K6aP050<k>cP040=KFeP0H61P0000005YJFP@0e]KF3`3Ng]h60=KFeP80
c/k>00`0a/K60;fm_@2UYJD0U9BD08B4Q01kNg/0Lg=c0;Fe]@2][Jd0YJFU0;Fe]@2][Jd40?ooo`80
[Jf]2012@T8404Y:BP<0DU9B0`1JFUX506=SH`H0Jf][1`1cLg<=07]kN`0308B4Q01kNg/0Ng]k00P0
Ng]k0`1cLg<206][J`D0Hf=S2`1[Jf/507=cL`H0Ng]k4024Q8@407]kN`<0[Jf]403oool000030:FU
Y@1[Jf/0Jf][00@0Jf][0P1cLg<00`1kNg/0Q8B408B4Q00208b<S0<0U9BD0P2LW9`30:FUY@<0[Jf]
0`2e]KD40;fm_@80000000<0S8b<0<K6aP3>c/h0103>c/h20=KFeP0401PH60000000FUYJ0=KFeQ<0
g]kN1P3Fe]H02P3>c/h0_Kfm0:f][@2DU9@0Ng]k07=cL`1[Jf/0Hf=S05YJFP1BDU8204Y:BPH0[Jf]
2@12@T8304Y:BP<0DU9B0`1JFUX506=SH`H0Jf][1P1cLg<707]kN`h0Q8B41`1kNg/207=cL`80Jf][
101SHf<906][J`@0Lg=c1@1kNg/708B4Q0`0S8b<1024Q8@307]kN`80[Jf]3`3oool000030:FUY@1[
Jf/0Jf][00<0Jf][0P1cLg<207]kN`80Q8B40P2<S8`209BDU0<0W9bL0`2UYJD30:f][@80]KFe102m
_Kd01036a/H000000000002<S8`50<k>cP<0e]KF00<061PH0000001JFUX05`3Ng]h30=KFeP090<K6
aP2e]KD0W9bL08B4Q01cLg<0Jf][06=SH`1JFUX0DU9B00H0BTY:2`12@T8304Y:BP<0DU9B0`1JFUX5
06=SH`H0Jf][1@1cLg<707]kNa<0Q8B41@1kNg/207=cL`80Jf][101SHf<606][J`@0Lg=c1@1kNg/5
08B4Q0P0S8b<1@2DU9@708b<S0<0Q8B400<0Ng]k0;Fe]@2e]KD03P3oool000030:FUY@1[Jf/0Jf][
00<0Jf][0P1cLg<207]kN`80Q8B40P2<S8`209BDU080W9bL0`2UYJD30:f][@<0]KFe102m_Kd01036
a/H000000000002<S8`40<k>cP@0e]KF00<061PH0000001JFUX0603Ng]h02P3Fe]H0c/k>0;fm_@2U
YJD0S8b<07]kN`1cLg<0Jf][06=SH`1BDU8704Y:BPX0@T920`1:BTX3059BDP<0FUYJ1@1SHf<506][
J`D0Lg=c1P1kNg/I08B4Q0<0Ng]k0P1cLg<206][J`<0Hf=S101[Jf/407=cL`@0Ng]k1@24Q8@608b<
S100U9BD102<S8`208B4Q0<0]KFe303oool000030:FUY@1[Jf/0Jf][00<0Jf][0P1cLg<00`1kNg/0
Q8B408B4Q00208b<S0<0U9BD0P2LW9`30:FUY@<0[Jf]0`2e]KD30;fm_@80a/K60P000000102<S8`0
c/k>0<k>cP3>c/h50=KFeP0301PH60000000FUYJ01P0g]kN00X0e]KF0<k>cP2e]KD0W9bL08b<S024
Q8@0Lg=c06][J`1SHf<0FUYJ0`1BDU8404Y:BPT0@T92101:BTX2059BDP<0FUYJ1@1SHf<406][J`D0
Lg=c1P1kNg/;08B4Q0P0S8b<2@24Q8@307]kN`80Lg=c0P1[Jf/206=SH`<0Jf][0`1cLg<407]kN`@0
Q8B41@2<S8`709BDU0/0W9bL1P2DU9@208b<S080Q8B400<0[Jf]0;Fe]@3oool02P3oool000030:FU
Y@1[Jf/0Jf][0080Jf][0`1cLg<00`1kNg/0Q8B408B4Q00208b<S080U9BD0P2LW9`30:FUY@<0[Jf]
0`2e]KD30;fm_@<0a/K60P0000000`2<S8`0c/k>0<k>cP060=KFeP0301PH60000000FUYJ00D0g]kN
3@3WinL60=kNgP090=KFeP36a/H0]KFe09bLW02DU9@0Q8B407]kN`1[Jf/0Hf=S00@0FUYJ00@0DU9B
04Y:BP1:BTX0BTY:2@12@T8304Y:BP<0DU9B0P1JFUX506=SH`@0Jf][101cLg<607]kN`L0Q8B44`2<
S8`508B4Q0<0Ng]k0P1cLg<01@1[Jf/0Hf=S06=SH`1SHf<0Jf][00<0Lg=c0`1kNg/408B4Q0D0S8b<
1P2DU9@A09bLW0@0U9BD0`2<S8`00`24Q8@0[Jf]0;Fe]@0:0?ooo`0000<0YJFU06][J`1[Jf/00P1[
Jf/207=cL`80Ng]k0P24Q8@0102<S8`0U9BD09BDU02DU9@209bLW0<0YJFU0`2][Jd20;Fe]@@0_Kfm
0`36a/H20000000309BDU03>c/h0e]KF00D0e]KF00@0g]kN01PH60000000FUYJ103Ng]h?0>OWi`D0
g]kN00P0e]KF0<K6aP2][Jd0W9bL09BDU02<S8`0Ng]k07=cL`@0Hf=S0P1JFUX00`1BDU80BTY:04Y:
BP080492@P<0BTY:0`1BDU8205YJFPD0Hf=S101[Jf/407=cL`D0Ng]k2024Q8@608b<S0`0U9BD102<
S8`508B4Q080Ng]k0P1cLg<0101[Jf/0Hf=S06=SH`1[Jf/207=cL`<0Ng]k0`24Q8@408b<S0L0U9BD
1`2LW9`90:FUY@H0W9bL0`2DU9@0102<S8`0Q8B408B4Q02e]KD:0?ooo`0000<0YJFU06][J`1[Jf/0
0P1[Jf/207=cL`80Ng]k00<0Q8B408b<S02<S8`00`2DU9@209bLW080YJFU0`2][Jd30;Fe]@<0_Kfm
1036a/H20000000309BDU03Fe]H0e]KF00@0e]KF0P3Ng]h0100H61P0000005YJFP3Ng]hC0>OWi`@0
g]kN00T0e]KF0;fm_@2][Jd0W9bL09BDU024Q8@0Ng]k07=cL`1[Jf/0101SHf<205YJFP80BTY:2012
@T8204Y:BP<0DU9B0P1JFUX506=SH`@0Jf][101cLg<407]kN`L0Q8B41@2<S8`B09BDU0@0S8b<1024
Q8@207]kN`80Lg=c0`1[Jf/0101cLg<0Ng]k07]kN`1kNg/308B4Q0<0S8b<1P2DU9@609bLW100YJFU
1@2LW9`209BDU00408b<S024Q8@0[Jf]0;Fe]@T0oooo00000`2UYJD0Jf][06][J`0206][J`80Lg=c
00<0Ng]k08B4Q024Q8@00P2<S8`209BDU080W9bL0`2UYJD30:f][@<0]KFe0`2m_Kd30<K6aP030<k>
cP000000000000/0000000<0FUYJ0>OWi`3WinL05@3WinL02P3Ng]h0c/k>0;fm_@2][Jd0W9bL09BD
U024Q8@0Ng]k07=cL`1[Jf/506=SH`0305YJFP1BDU80BTY:00H0@T92101:BTX2059BDP<0FUYJ101S
Hf<406][J`@0Lg=c101kNg/708B4Q0@0S8b<202DU9@909bLW0H0U9BD0`2<S8`308B4Q080Ng]k00H0
Lg=c06][J`1[Jf/0Jf][07=cL`1kNg/308B4Q0@0S8b<102DU9@609bLW0/0YJFU0`2][Jd90:FUY@<0
W9bL0P2DU9@00`2<S8`0]KFe0;Fe]@080?ooo`0000<0YJFU06][J`1[Jf/00P1[Jf/207=cL`0307]k
N`24Q8@0Q8B40080S8b<0P2DU9@209bLW080YJFU0`2][Jd30;Fe]@<0_Kfm0`36a/H20<k>cPd00000
00<0Hf=S0>OWi`3WinL05@3WinL02@3Ng]h0c/k>0;fm_@2][Jd0YJFU09BDU02<S8`0Q8B407=cL`04
06][J`80Hf=S00<0FUYJ04Y:BP1:BTX01P12@T8304Y:BP<0DU9B0P1JFUX406=SH`@0Jf][101cLg<4
07]kN`H0Q8B4102<S8`709BDU0l0W9bL102DU9@308b<S0<0Q8B40P1kNg/0101cLg<0Jf][06][J`1k
Ng/208B4Q0@0S8b<102DU9@509bLW0H0YJFU4@2][Jd50:FUY@80W9bL0P2DU9@00`2<S8`0]KFe0;Fe
]@070?ooo`0000@0YJFU06][J`1[Jf/0Jf][0P1cLg<207]kN`80Q8B400<0S8b<09BDU02DU9@00`2L
W9`20:FUY@<0[Jf]0P2e]KD40;fm_@<0a/K60P3>c/h20000000409BDU03Fe]H0e]KF0=KFePD0g]kN
00<061PH0000001SHf<05`3WinL02P3Ng]h0c/k>0;fm_@2][Jd0YJFU09BDU02<S8`0Q8B407]kN`1c
Lg<306][J`80Hf=S00<0FUYJ059BDP1:BTX01@12@T8404Y:BP80DU9B0P1JFUX506=SH`@0Jf][0`1c
Lg<407]kN`H0Q8B4102<S8`509BDU0H0W9bL2@2UYJD409bLW0D0U9BD0P2<S8`308B4Q00607]kN`1c
Lg<0Jf][07=cL`1kNg/0Q8B40`2<S8`509BDU0@0W9bL1P2UYJDF0:f][@@0YJFU0P2LW9`0102DU9@0
S8b<0;Fe]@2e]KD60?ooo`0000@0YJFU06][J`1[Jf/0Jf][0P1cLg<207]kN`0308B4Q02<S8`0S8b<
0080U9BD0P2LW9`20:FUY@<0[Jf]0`2e]KD30;fm_@<0a/K60`3>c/h20000000309BDU03Fe]H0e]KF
00H0g]kN00<061PH0000001SHf<05`3WinL02@3Ng]h0c/k>0;fm_@2][Jd0YJFU09BDU02<S8`0Q8B4
07]kN`0207=cL`80Jf][0P1SHf<00`1JFUX0BTY:0492@P050492@P<0BTY:0P1BDU8305YJFP@0Hf=S
101[Jf/307=cL`@0Ng]k1@24Q8@208b<S00706][J`12@T80<C4a034a<@1JFUX0S8b<09BDU00509bL
W0h0YJFU102LW9`409BDU080S8b<0P24Q8@207]kN`80Lg=c00@0Ng]k08B4Q02<S8`0S8b<102DU9@4
09bLW0H0YJFU1P2][Jd?0;Fe]@H0[Jf]0P2UYJD209bLW00309BDU02<S8`0]KFe00H0oooo0000102U
YJD0Jf][06][J`1[Jf/207=cL`0307]kN`24Q8@0Q8B40080S8b<00@0U9BD09bLW02LW9`0W9bL0P2U
YJD30:f][@<0]KFe0`2m_Kd30<K6aP<0c/k>0P0000000`2DU9@0e]KF0=kNgP050=kNgP040>OWi`0Q
8B40000006=SH`D0inOW3@3_knl60>OWi`080=KFeP2m_Kd0]KFe0:FUY@2LW9`0U9BD08B4Q01kNg/3
07=cL`80Jf][00@0Hf=S059BDP1:BTX0BTY:1@12@T8204Y:BP<0DU9B0P1JFUX406=SH`@0Jf][0`1c
Lg<407]kN`D0Q8B400<0S8b<059BDP0000001P0000000`0Q8B40U9BD09bLW00C0:FUY@@0W9bL0P2D
U9@308b<S080Q8B400H0Ng]k07=cL`1cLg<0Ng]k08B4Q02<S8`309BDU0@0W9bL1P2UYJD60:f][A<0
]KFe1@2][Jd20:FUY@80W9bL00<0U9BD0;Fe]@2e]KD01@3oool000040:FUY@1[Jf/0Jf][06][J`80
Lg=c00@0Ng]k08B4Q024Q8@0S8b<0P2DU9@309bLW080YJFU0P2][Jd30;Fe]@<0_Kfm0`36a/H30<k>
cP040=KFeP000000000009BDU0H0g]kN0P3WinL00`0Q8B40000006=SH`040>OWi`l0kno_103WinL0
2P3Ng]h0e]KF0<K6aP2m_Kd0[Jf]0:FUY@2DU9@0S8b<08B4Q01kNg/207=cL`0506][J`1SHf<0Hf=S
059BDP1:BTX01@12@T8304Y:BP80DU9B0P1JFUX406=SH`@0Jf][0`1cLg<407]kN`@0Q8B40P2<S8`0
1@1:BTX000000000000000008B4Q0080>CTi00D061PH000000000000000007]kN`050:FUY@/0[Jf]
1P2UYJD209bLW080U9BD0P2<S8`208B4Q080Ng]k00@0Lg=c07]kN`24Q8@0S8b<0P2DU9@409bLW0D0
YJFU1P2][Jd70;Fe]@X0_Kfm202e]KD20:f][@80YJFU0P2LW9`00`2DU9@0_Kfm0?ooo`040?ooo`00
0P2][Jd206][J`80Lg=c00@0Ng]k08B4Q024Q8@0S8b<0P2DU9@209bLW0<0YJFU0P2][Jd20;Fe]@@0
_Kfm0`36a/H30<k>cP040=KFeP000000000009bLW0H0g]kN0P3WinL00`0Q8B40000006=SH`020>OW
ia40kno_103WinL02@3Ng]h0c/k>0<K6aP2m_Kd0]KFe0:FUY@2LW9`0U9BD08B4Q00207]kN`80Lg=c
00<0Jf][06=SH`1BDU800P1:BTX40492@P<0BTY:0P1BDU8205YJFP@0Hf=S101[Jf/307=cL`<0Ng]k
1@24Q8@01P2<S8`0DU9B0000000000008B4Q08b<S080U9BD0P2LW9`0101kNg/00000000000000003
0:FUY@l0[Jf]1@2UYJD209bLW080U9BD0P2<S8`208B4Q00407]kN`1cLg<0Ng]k08B4Q080U9BD102L
W9`40:FUY@H0[Jf]1@2e]KDA0;fm_@H0]KFe0P2][Jd20:FUY@0409bLW02DU9@0]KFe0;Fe]@@0oooo
0000103oool0[Jf]06][J`1[Jf/207=cL`0407]kN`24Q8@0Q8B408b<S080U9BD0P2LW9`30:FUY@80
[Jf]0P2e]KD40;fm_@80a/K60`3>c/h20=KFeP80000000<0W9bL0=kNgP3Ng]h0103Ng]h20>OWi`03
024Q8@000000Hf=S0080inOW4@3_knl40>OWi`0:0=kNgP3>c/h0a/K60;fm_@2e]KD0[Jf]0:FUY@2D
U9@0S8b<08B4Q0<0Ng]k00@0Jf][06=SH`1BDU80BTY:1@12@T8304Y:BP80DU9B0P1JFUX406=SH`<0
Jf][0`1cLg<307]kN`D0Q8B40P2<S8`200000004024Q8@2DU9@0U9BD09BDU0<0W9bL00D0YJFU08b<
S000000000000492@P030:f][@d0]KFe0P2][Jd40:FUY@<0W9bL0P2DU9@0202<S8`0Q8B408B4Q01k
Ng/0Lg=c07]kN`24Q8@0U9BD0`2LW9`40:FUY@H0[Jf]1@2e]KDG0;fm_@<0]KFe0P2][Jd20:FUY@03
09bLW02DU9@0_Kfm00@0oooo0000103oool0[Jf]06][J`1[Jf/207=cL`0407]kN`24Q8@0Q8B408b<
S080U9BD0P2LW9`20:FUY@<0[Jf]0P2e]KD40;fm_@80a/K60`3>c/h20=KFeP80000000<0W9bL0=kN
gP3Ng]h00`3Ng]h30>OWi`04024Q8@000000Hf=S0>OWia<0kno_0`3WinL02@3Ng]h0c/k>0<K6aP2m
_Kd0]KFe0:f][@2UYJD0W9bL09BDU00208B4Q080Ng]k00@0Lg=c06=SH`1BDU80BTY:1@12@T8204Y:
BP80DU9B0`1JFUX306=SH`@0Jf][0`1cLg<307]kN`@0Q8B40P2<S8`0101:BTX000000000002<S8`2
09BDU0<0W9bL0`2UYJD00`0a<C400000000000020:f][@l0]KFe0`2][Jd30:FUY@80W9bL0P2DU9@2
08b<S00608B4Q01kNg/0Ng]k07]kN`2<S8`0U9BD0P2LW9`40:FUY@D0[Jf]1@2e]KD=0;fm_@<0a/K6
2P2m_Kd30;Fe]@80[Jf]0P2UYJD00`2LW9`0_Kfm0;Fe]@030?ooo`0000@0oooo0:f][@1[Jf/0Jf][
0P1cLg<0101kNg/0Q8B408B4Q02<S8`209BDU080W9bL0P2UYJD30:f][@80]KFe0`2m_Kd30<K6aP80
c/k>0`3Fe]H00`2DU9@0W9bL0<k>cP040=kNgP@0inOW00<0]KFe0:FUY@36a/H05@3_knl20>OWi`05
0=kNgP3>c/h0a/K60;fm_@2e]KD00P2][Jd00`2LW9`0U9BD08b<S00208B4Q00507]kN`1cLg<0Jf][
05YJFP1:BTX01012@T8304Y:BP80DU9B0P1JFUX406=SH`<0Jf][0`1cLg<307]kN`@0Q8B40`2<S8`0
0`0Q8B400000024Q8@0209BDU0<0W9bL102UYJD01024Q8@000000000002DU9@A0;Fe]@<0[Jf]0`2U
YJD00`2LW9`0U9BD09BDU00208b<S00508B4Q01kNg/0Ng]k07]kN`2<S8`00P2LW9`40:FUY@@0[Jf]
1@2e]KD70;fm_A80a/K61@2m_Kd20;Fe]@80[Jf]0P2UYJD00`2LW9`0_Kfm0?ooo`020?ooo`0000@0
oooo0:f][@2][Jd0Jf][0P1cLg<0101kNg/0Q8B408B4Q02<S8`209BDU080W9bL0P2UYJD30:f][@80
]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW5@3_knl20>OWi`040=kNgP3Fe]H0a/K60;fm
_@80]KFe00<0[Jf]0:FUY@2DU9@00P2<S8`208B4Q00407]kN`1[Jf/0FUYJ04Y:BP@0@T920`1:BTX2
059BDP80FUYJ0`1SHf<406][J`<0Lg=c0`1kNg/408B4Q0<0S8b<0P0000000`12@T80U9BD09bLW002
09bLW0@0YJFU0P2][Jd207]kN`030:FUY@2e]KD0]KFe0080]KFe2@2m_Kd60;Fe]@80[Jf]0P2UYJD2
09bLW080U9BD00<0S8b<08B4Q024Q8@00P1kNg/00`2<S8`0W9bL0:FUY@030:FUY@<0[Jf]1@2e]KD7
0;fm_AH0a/K6102m_Kd20;Fe]@80[Jf]0P2UYJD20;fm_@80oooo00020?ooo`050:f][@1[Jf/0Lg=c
07=cL`1kNg/00P24Q8@00`2<S8`0U9BD09BDU00209bLW080YJFU0`2][Jd20;Fe]@<0_Kfm0`36a/H2
0<k>cP@0e]KF1P3Ng]h70>OWiaD0kno_0P3WinL00`3Ng]h0c/k>0;fm_@030;Fe]@040:f][@2UYJD0
U9BD08b<S0<0Q8B400@0Ng]k07=cL`1JFUX0BTY:1012@T8204Y:BP80DU9B0P1JFUX406=SH`<0Jf][
0`1cLg<307]kN`@0Q8B40`2<S8`0102DU9@000000000001SHf<309bLW0@0YJFU0P2][Jd60;Fe]@d0
_Kfm1@2e]KD01@2][Jd0YJFU0:FUY@2UYJD0W9bL0080U9BD00L0S8b<08B4Q024Q8@0Ng]k08B4Q02D
U9@0W9bL00<0YJFU0`2][Jd40;Fe]@L0_Kfm1P36a/H?0<k>cPD0a/K6102m_Kd01P2e]KD0[Jf]0:f]
[@2UYJD0W9bL0;fm_@80oooo00020?ooo`80[Jf]00H0Jf][07=cL`1kNg/0Ng]k08B4Q02<S8`209BD
U080W9bL0P2UYJD30:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW5@3_knl20>OW
i`0:0=kNgP3>c/h0_Kfm0;Fe]@2][Jd0]KFe0:f][@2UYJD0U9BD08b<S0<0Q8B400@0Ng]k06][J`1J
FUX0BTY:0`12@T8304Y:BP80DU9B0P1JFUX406=SH`<0Jf][0`1cLg<307]kN`@0Q8B40`2<S8`0102D
U9@000000000001[Jf/209bLW0@0YJFU0P2][Jd50;Fe]@80_Kfm3@36a/H00`2m_Kd0]KFe0;Fe]@02
0;Fe]@80[Jf]0P2UYJD209bLW00709BDU02<S8`0S8b<08B4Q01kNg/0Q8B409BDU0020:FUY@@0[Jf]
102e]KD60;fm_@H0a/K64`3>c/h50<K6aP<0_Kfm0P2e]KD0102][Jd0YJFU0;fm_@2m_Kd10?ooo`00
0`3oool01P2][Jd0Jf][07=cL`1cLg<0Ng]k08B4Q080S8b<00<0U9BD09bLW02LW9`00`2UYJD20:f]
[@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW4`3_knl40>OWi`030=kNgP3>c/h0_Kfm
00@0[Jf]00<0YJFU09BDU02<S8`00`24Q8@00`1kNg/0Jf][05YJFP0204Y:BP80@T920`1:BTX2059B
DP80FUYJ0`1SHf<306][J`<0Lg=c0`1kNg/408B4Q0<0S8b<0P2DU9@20000000306][J`2LW9`0YJFU
00<0YJFU0P2][Jd40;Fe]@<0_Kfm3`36a/H20;fm_@<0]KFe0P2][Jd20:FUY@0909bLW02DU9@0U9BD
08b<S024Q8@0Ng]k08B4Q02LW9`0YJFU00@0[Jf]102e]KD60;fm_@@0a/K62@3>c/h90=KFePL0c/k>
0`36a/H20;fm_@80]KFe00@0[Jf]0:FUY@2LW9`0_Kfm0@3oool000<0oooo0P2][Jd207=cL`0507]k
N`24Q8@0Q8B408b<S02DU9@00P2LW9`30:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0
g]kN1`3WinLC0>o_k`@0inOW00@0g]kN0=KFeP36a/H0]KFe0`2][Jd0102UYJD0W9bL08b<S024Q8@3
07]kN`0406][J`1JFUX0BTY:04Y:BP80@T920`1:BTX2059BDP80FUYJ0`1SHf<306][J`<0Lg=c0`1k
Ng/408B4Q080S8b<0`2DU9@20000000304Y:BP2UYJD0YJFU0080YJFU0P2][Jd40;Fe]@030;fm_@36
a/H0a/K600<0a/K62`3>c/h30<K6aP<0_Kfm0P2e]KD00`2][Jd0YJFU0:FUY@0209bLW00609BDU02<
S8`0Q8B408B4Q02<S8`0W9bL102][Jd40;Fe]@D0_Kfm1@36a/H70<k>cPl0e]KF1@3>c/h30<K6aP80
_Kfm0P2e]KD00`2][Jd0YJFU0;fm_@010?ooo`00103oool0102][Jd0Jf][07=cL`1kNg/208B4Q004
08b<S02DU9@0U9BD09bLW0<0YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OW
ia<0kno_103WinL0103Ng]h0e]KF0<K6aP2e]KD20:f][@040;Fe]@2][Jd0YJFU09BDU080Q8B400D0
Ng]k07=cL`1[Jf/0FUYJ04Y:BP030492@P80BTY:0P1BDU8205YJFP@0Hf=S0`1[Jf/207=cL`<0Ng]k
1024Q8@208b<S0<0U9BD00@0W9bL01PH600000008B4Q0`2UYJD20:f][@@0]KFe00<0_Kfm0<K6aP36
a/H00P36a/H>0<k>cPD0a/K600@0_Kfm0;Fe]@2e]KD0[Jf]0P2UYJD00`2LW9`0U9BD08b<S00208B4
Q00308b<S02UYJD0]KFe00H0]KFe1@2m_Kd50<K6aPD0c/k>4`3Fe]H50<k>cP80a/K60`2m_Kd0102e
]KD0[Jf]0:FUY@36a/H10?ooo`00103oool20:f][@0507=cL`1kNg/0Ng]k08B4Q02<S8`00P2DU9@2
09bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OWia<0kno_1@3WinL0
0`3Ng]h0c/k>0;fm_@040:f][@030:FUY@2DU9@0Q8B40080Ng]k00@0Lg=c06][J`1BDU80BTY:0`12
@T8204Y:BP80DU9B0P1JFUX306=SH`<0Jf][0`1cLg<307]kN`@0Q8B40P2<S8`309BDU00409bLW01B
DU80000000000080YJFU0P2][Jd40;Fe]@040;fm_@1[Jf/0000000000180c/k>0`36a/H20;fm_@05
0;Fe]@2][Jd0YJFU0:FUY@2LW9`00P2DU9@0102<S8`0Q8B408b<S02UYJD60;Fe]@@0_Kfm1P36a/H3
0<k>cQT0e]KF0`3>c/h20<K6aP<0_Kfm00<0]KFe0:f][@36a/H00@2m_Kd000D0oooo00H0[Jf]07=c
L`1cLg<0Ng]k08B4Q02<S8`209BDU080W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103F
e]H60=kNgPL0inOW4`3_knl50>OWi`050=kNgP3Fe]H0a/K60;Fe]@2][Jd00P3>c/h01036a/H0]KFe
09BDU01kNg/207=cL`0306][J`1JFUX0BTY:0080@T920`1:BTX2059BDP80FUYJ0`1SHf<306][J`80
Lg=c0`1kNg/408B4Q080S8b<102DU9@01@2LW9`0U9BD000000000000@T920080[Jf]102e]KD01@2m
_Kd0a/K601PH60000000<C4a00<0c/k>00<0e]KF0=kNgP3Ng]h02@3Ng]h00`3Fe]H0c/k>0<k>cP02
0<k>cP80a/K600D0_Kfm0;Fe]@2][Jd0[Jf]0:FUY@0209bLW00509BDU02<S8`0Q8B409BDU02][Jd0
102e]KD50;fm_@@0a/K60`3>c/h20000000309BDU03Fe]H0e]KF00D0e]KF00@0g]kN01PH60000000
FUYJ2@3Ng]h60=KFeP<0c/k>0P36a/H20;fm_@030;Fe]@2][Jd0YJFU0040]KFe00050?ooo`80[Jf]
00<0Lg=c07]kN`24Q8@00P2<S8`00`2DU9@0W9bL09bLW0020:FUY@80[Jf]0P2e]KD30;fm_@<0a/K6
0P3>c/h40=KFePH0g]kN1`3WinLB0>o_k`D0inOW0P3Ng]h01@3Fe]H0c/k>0;fm_@3>c/h0g]kN0080
oooo00P0inOW0;fm_@2m_Kd0]KFe0:f][@2UYJD0[Jf]04Y:BP80@T920`1:BTX2059BDP0405YJFP1S
Hf<0Hf=S06=SH`<0Jf][0`1cLg<307]kN`@0Q8B40P2<S8`309BDU080W9bL00D0YJFU04Y:BP000000
0000059BDP040;Fe]@030;fm_@36a/H0<C4a0080000000D0YJFU0<k>cP3Fe]H0e]KF0=kNgP0;0>OW
i`030=kNgP3Fe]H0c/k>00<0c/k>00D0a/K60;fm_@2e]KD0]KFe0:f][@020:FUY@0609bLW02DU9@0
S8b<08B4Q02DU9@0[Jf]0P2m_Kd20;Fe]@@0_Kfm1036a/H40<k>cP80000000<0U9BD0=KFeP3Fe]H0
103Fe]H20=kNgP0301PH60000000FUYJ00X0g]kN1P3Fe]H30<k>cP80a/K600@0_Kfm0;Fe]@2][Jd0
YJFU0@2e]KD000H0oooo00<0[Jf]07=cL`1kNg/00P24Q8@0102<S8`0U9BD09BDU02LW9`20:FUY@80
[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLA0>o_k`H0inOW0P3Ng]h0103Fe]H0
c/k>0<K6aP3Ng]h80?ooo`030?Ogm`2][Jd0BTY:0080@T920`1:BTX00`1BDU80FUYJ05YJFP0306=S
H`<0Jf][0P1cLg<307]kN`@0Q8B40P2<S8`309BDU080W9bL0`2UYJD01@0Y:BT000000000000@4100
DU9B0080Q8B400D0FUYJ01PH60000000000007=cL`020=KFeP80g]kN0P3WinL90>o_k`80inOW00<0
g]kN0=KFeP3>c/h00P3>c/h20<K6aP0;0;fm_@2e]KD0[Jf]0:f][@2UYJD0W9bL09BDU02<S8`0Q8B4
09BDU02][Jd01`2m_Kd40<K6aPD0c/k>0P000000102DU9@0e]KF0=KFeP3Fe]H50=kNgP0301PH6000
0000FUYJ00/0g]kN1P3Fe]H20<k>cP80a/K60P2m_Kd10;Fe]@40YJFU0@2e]KD000H0oooo0P2][Jd0
101cLg<0Ng]k08B4Q02<S8`209BDU00309bLW02UYJD0YJFU0080[Jf]0`2e]KD30;fm_@80a/K60`3>
c/h30=KFePH0g]kN1`3WinLA0>o_k`D0inOW0`3Ng]h0103Fe]H0c/k>0=KFeP3Fe]H90?ooo`80[Jf]
0P12@T8204Y:BP80DU9B0P1JFUX306=SH`<0Jf][0P1cLg<307]kN`@0Q8B40P2<S8`309BDU080W9bL
0`2UYJD00`2][Jd0@T92000000070000000407=cL`3>c/h0g]kN0=kNgP<0inOW2`3_knl20>OWi`03
0=kNgP3Fe]H0c/k>0080c/k>00<0a/K60;fm_@2e]KD00P2][Jd00`2UYJD0W9bL09BDU00208b<S003
09bLW02e]KD0a/K600D0_Kfm1036a/H50<k>cP040=KFeP000000000009BDU080e]KF1P3Ng]h00`0H
61P0000005YJFP0>0=kNgP<0e]KF0`3>c/h01@36a/H0_Kfm0;fm_@2e]KD0[Jf]0040]KFe00070?oo
o`80[Jf]00D0Ng]k08B4Q02<S8`0S8b<09BDU00209bLW0040:FUY@2][Jd0[Jf]0:f][@80]KFe0`2m
_Kd30<K6aP80c/k>0`3Fe]H60=kNgPL0inOW403_knl50>OWi`80g]kN0P3Fe]H00`3>c/h0g]kN0=KF
eP0;0?ooo`030:f][@12@T80@T9200<0BTY:00<0DU9B05YJFP1JFUX00`1SHf<306][J`80Lg=c0`1k
Ng/408B4Q080S8b<0`2DU9@209bLW0<0YJFU0P2][Jd00`2UYJD0DU9B02TY:@02010@4006034a<@1S
Hf<0_Kfm0<k>cP3Fe]H0g]kN0`3WinL=0>o_k`030>OWi`3Ng]h0e]KF00<0c/k>00@0a/K60;fm_@2e
]KD0[Jf]0P2UYJD01P2LW9`0U9BD08b<S02<S8`0W9bL0;fm_@80a/K6102m_Kd30<K6aPD0c/k>0P3F
e]H20000000309BDU03Fe]H0g]kN00H0g]kN00<061PH0000001JFUX03`3Ng]h30=KFeP80c/k>0P36
a/H00`2m_Kd0]KFe0:f][@010;Fe]@00203oool20;Fe]@0307]kN`24Q8@0S8b<0080U9BD00<0W9bL
0:FUY@2UYJD00P2][Jd30;Fe]@<0_Kfm0P36a/H20<k>cP@0e]KF1P3Ng]h90>OWi`X0kno_1`3WinL2
0=kNgP80e]KF00<0c/k>0=kNgP3Fe]H0303oool00`2][Jd0@T920492@P0304Y:BP03059BDP1JFUX0
FUYJ00<0Hf=S0P1[Jf/307=cL`<0Ng]k1024Q8@208b<S080U9BD0P2LW9`30:FUY@80[Jf]102e]KD0
0`2m_Kd0a/K60<K6aP030<k>cP030=KFeP3Ng]h0inOW0080inOW3@3_knl00`3WinL0g]kN0=KFeP03
0<k>cP030<K6aP2m_Kd0]KFe0080[Jf]00T0YJFU09bLW02DU9@0S8b<09BDU02][Jd0a/K60<k>cP36
a/H00`2m_Kd40<K6aP@0c/k>0`3Fe]H20000000309bLW03Ng]h0g]kN00H0g]kN00<061PH0000001J
FUX03`3Ng]h30=KFeP80c/k>0P36a/H00`2m_Kd0]KFe0:f][@010;Fe]@002@3oool20;Fe]@0407]k
N`24Q8@0S8b<09BDU080W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgQP0
inOW0P3Ng]h20=KFeP030<k>cP3Ng]h0e]KF00d0oooo00<0[Jf]0492@P12@T800`1:BTX00`1BDU80
FUYJ05YJFP0306=SH`80Jf][0`1cLg<307]kN`<0Q8B40P2<S8`309BDU080W9bL0`2UYJD00`2][Jd0
]KFe0;Fe]@020;Fe]@040;fm_@36a/H0a/K60<K6aP80c/k>00@0e]KF0=kNgP3WinL0inOW403_knl0
0`3WinL0g]kN0=KFeP020<k>cP80a/K600T0_Kfm0;Fe]@2][Jd0YJFU09bLW02DU9@0S8b<09bLW02m
_Kd00P3>c/h00`36a/H0_Kfm0;fm_@040<K6aP@0c/k>103Fe]H20000000309bLW03Ng]h0g]kN00D0
g]kN00@0inOW01PH60000000Hf=S2@3WinL70=kNgP<0e]KF0P3>c/h01036a/H0_Kfm0;Fe]@2][Jd1
0;Fe]@002P3oool0102e]KD0Ng]k08B4Q02<S8`209BDU00409bLW02UYJD0YJFU0:FUY@80[Jf]0P2e
]KD30;fm_@80a/K60P3>c/h50=KFePH0g]kN5P3WinL30=kNgP040=KFeP3>c/h0a/K60=KFePh0oooo
0P2][Jd01@12@T80BTY:04Y:BP1:BTX0DU9B0080FUYJ0`1SHf<206][J`<0Lg=c0P1kNg/408B4Q080
S8b<0`2DU9@0102LW9`0YJFU0:FUY@2UYJD20:f][@@0]KFe00<0_Kfm0<K6aP36a/H00`3>c/h00`3N
g]h0inOW0>OWi`0A0>o_k`80inOW00H0g]kN0<k>cP3>c/h0a/K60;fm_@2e]KD20:f][@090:FUY@2L
W9`0U9BD09BDU02][Jd0a/K60=KFeP3>c/h0a/K60080_Kfm1036a/H30<k>cPD0e]KF0P0000000`2L
W9`0g]kN0=kNgP040=kNgP80inOW00<08B4Q0000001SHf<02P3WinL60=kNgP<0e]KF0P3>c/h20<K6
aP40_Kfm0@2][Jd10;Fe]@002P3oool01P2][Jd0]KFe07]kN`24Q8@0S8b<09BDU080W9bL0P2UYJD2
0:f][@80]KFe0`2m_Kd20<K6aP<0c/k>103Fe]H60=kNgQD0inOW0`3Ng]h20=KFeP030<k>cP3Ng]h0
e]KF00l0oooo00<0[Jf]0492@P12@T800P1:BTX00`1BDU80FUYJ05YJFP0306=SH`<0Jf][0P1cLg<2
07]kN`@0Q8B40P2<S8`309BDU00409bLW02UYJD0YJFU0:FUY@80[Jf]102e]KD00`2m_Kd0a/K60<K6
aP030<k>cP030=kNgP3WinL0kno_0140kno_0P3WinL02@3Ng]h0c/k>0<k>cP36a/H0_Kfm0;Fe]@2]
[Jd0YJFU09bLW00209BDU00409bLW02m_Kd0c/k>0=KFeP80a/K600<0_Kfm0<K6aP36a/H00P36a/H3
0<k>cPH0e]KF3@0000000`1SHf<0inOW0>OWi`090>OWi`H0g]kN0`3Fe]H01@3>c/h0a/K60<K6aP2m
_Kd0[Jf]0040]KFe000;0?ooo`80]KFe00D0Q8B408b<S02DU9@0U9BD09bLW0020:FUY@80[Jf]0P2e
]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN503WinL30=kNgP80e]KF00<0c/k>0=kNgP3Ng]h0403o
ool20:f][@040492@P1:BTX0BTY:059BDP80FUYJ0`1SHf<306][J`80Lg=c0P1kNg/408B4Q080S8b<
0`2DU9@0102LW9`0YJFU0:FUY@2UYJD20:f][@<0]KFe0P2m_Kd00`36a/H0c/k>0<k>cP020<k>cP03
0=kNgP3WinL0kno_0100kno_0P3WinL00`3Ng]h0e]KF0<k>cP020<K6aP050;fm_@2e]KD0[Jf]0:FU
Y@2LW9`00P2DU9@01P2UYJD0a/K60<k>cP3>c/h0a/K60;fm_@@0a/K60`3>c/h60=KFeP030=kNgP00
0000000000/0000000<0Hf=S0>OWi`3WinL0303WinL40=kNgP80e]KF0P3>c/h00`36a/H0_Kfm0;Fe
]@010;Fe]@00303oool30;Fe]@0408b<S02DU9@0W9bL09bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36
a/H20<k>cP@0e]KF1P3Ng]hB0>OWi`<0g]kN00<0e]KF0<k>cP3WinL00P3Ng]hB0?ooo`040:f][@12
@T80BTY:04Y:BP80DU9B00@0FUYJ06=SH`1SHf<0Hf=S0`1[Jf/207=cL`80Ng]k1024Q8@208b<S0<0
U9BD00@0W9bL0:FUY@2UYJD0YJFU0P2][Jd40;Fe]@030;fm_@36a/H0a/K600<0c/k>00<0g]kN0>OW
i`3_knl0403_knl02`3WinL0g]kN0=KFeP3Fe]H0c/k>0<K6aP2m_Kd0]KFe0:f][@2UYJD0W9bL0080
U9BD00D0W9bL0;Fe]@36a/H0c/k>0<K6aP020;fm_@<0a/K60`3>c/h60=KFeP80g]kN0P0000000`2L
W9`0g]kN0>OWi`060>OWi`03024Q8@000000Hf=S00l0inOW0`3Ng]h30=KFeP030<k>cP36a/H0_Kfm
0080]KFe000>0?ooo`030;fm_@2e]KD0S8b<0080U9BD00<0W9bL0:FUY@2UYJD00P2][Jd20;Fe]@<0
_Kfm0P36a/H30<k>cPD0e]KF1P3Ng]h<0>OWi`D0g]kN0P3Fe]H00`3>c/h0g]kN0=kNgP0D0?ooo`80
[Jf]0P1:BTX2059BDP80FUYJ0P1SHf<306][J`80Lg=c0P1kNg/408B4Q0<0S8b<0P2DU9@0102LW9`0
YJFU0:FUY@2UYJD20:f][@<0]KFe0P2m_Kd00`36a/H0c/k>0<k>cP020<k>cP030=kNgP3WinL0kno_
0100kno_00@0inOW0=kNgP3Fe]H0c/k>0P36a/H01@2m_Kd0]KFe0:f][@2UYJD0W9bL0080U9BD00@0
YJFU0;fm_@36a/H0a/K60`2m_Kd30<K6aP80c/k>1P3Fe]H30=kNgP80000000<0W9bL0>OWi`3WinL0
1P3WinL00`0Q8B40000006=SH`0?0>OWi`<0g]kN0`3Fe]H0103>c/h0a/K60;fm_@2e]KD10;fm_@00
3`3oool20;Fe]@0408b<S02DU9@0U9BD09bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0P36a/H30<k>cPH0
e]KF4`3Ng]h20=KFeP040<k>cP36a/H0g]kN0=KFeQH0oooo00D0[Jf]0492@P1:BTX0BTY:059BDP02
05YJFP80Hf=S0`1[Jf/207=cL`<0Ng]k0`24Q8@308b<S080U9BD00@0W9bL0:FUY@2UYJD0YJFU0P2]
[Jd40;Fe]@030;fm_@36a/H0a/K600<0c/k>00<0g]kN0>OWi`3_knl03`3_knl20>OWi`070=kNgP3>
c/h0c/k>0<K6aP2m_Kd0]KFe0:f][@020:FUY@<0U9BD00<0[Jf]0;fm_@2m_Kd00`2m_Kd30<K6aP<0
c/k>1@3Fe]H40=kNgP80000000<0YJFU0>OWi`3WinL01P3WinL00`0Q8B40000006=SH`0@0>OWi`<0
g]kN0P3Fe]H0103>c/h0a/K60;fm_@2e]KD10;fm_@00403oool30;Fe]@80U9BD00<0W9bL0:FUY@2U
YJD00P2][Jd20;Fe]@<0_Kfm0`36a/H30<k>cPD0e]KF403Ng]h20=KFeP80c/k>0P3Ng]h00`3Fe]H0
oooo0?ooo`0E0?ooo`80[Jf]0P1:BTX00`1BDU80FUYJ05YJFP0306=SH`80Jf][0P1cLg<307]kN`<0
Q8B40`2<S8`209BDU00409bLW02UYJD0YJFU0:FUY@80[Jf]0`2e]KD20;fm_@030<K6aP3>c/h0c/k>
0080c/k>00<0g]kN0>OWi`3_knl03P3_knl30>OWi`090=kNgP3>c/h0c/k>0<K6aP2m_Kd0]KFe0:f]
[@2UYJD0W9bL0080U9BD00<0W9bL0:f][@2m_Kd0102m_Kd30<K6aP<0c/k>103Fe]H50=kNgP800000
00<0YJFU0>OWi`3WinL01@3WinL0103_knl08B4Q0000001SHf<90>o_k`L0inOW0`3Ng]h20=KFeP04
0<k>cP36a/H0a/K60;Fe]@40_Kfm000B0?ooo`80_Kfm0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80
]KFe0`2m_Kd30<K6aP@0c/k>1@3Fe]H:0=kNgP@0e]KF0P3>c/h00`36a/H0g]kN0=kNgP0J0?ooo`03
0:f][@1:BTX0BTY:0080DU9B00@0FUYJ06=SH`1SHf<0Hf=S0P1[Jf/207=cL`<0Ng]k0`24Q8@308b<
S080U9BD00@0W9bL0:FUY@2UYJD0YJFU0P2][Jd40;Fe]@030;fm_@36a/H0a/K600<0c/k>00<0g]kN
0>OWi`3_knl03P3_knl20>OWi`030=kNgP3Fe]H0c/k>0080a/K600@0_Kfm0;Fe]@2][Jd0YJFU0`2D
U9@00`2UYJD0[Jf]0;fm_@030;fm_@<0a/K60`3>c/h40=KFePH0g]kN0P0000000`2UYJD0inOW0>OW
i`040>OWi`80kno_00<08B4Q0000001SHf<02P3_knl70>OWi`<0g]kN0P3Fe]H00`3>c/h0a/K60;Fe
]@010;fm_@004`3oool01@2m_Kd0]KFe0;fm_@2DU9@0W9bL0080YJFU0P2][Jd20;Fe]@<0_Kfm1036
a/H40<k>cPl0e]KF0P3>c/h01036a/H0g]kN0=KFeP3Fe]HK0?ooo`80[Jf]00@0BTY:059BDP1BDU80
FUYJ0`1SHf<206][J`80Lg=c0`1kNg/308B4Q0<0S8b<0P2DU9@0102LW9`0YJFU0:FUY@2UYJD20:f]
[@<0]KFe0P2m_Kd00`36a/H0c/k>0<k>cP020<k>cP030=kNgP3WinL0kno_00h0kno_00H0inOW0=kN
gP3Ng]h0e]KF0<k>cP36a/H20;fm_@030;Fe]@2][Jd0W9bL00<0U9BD00<0YJFU0;Fe]@2e]KD00`2m
_Kd30<K6aP<0c/k>103Fe]H60=kNgP80000000<0YJFU0>OWi`3WinL00P3WinL40>o_k`03024Q8@00
0000Hf=S00X0kno_1`3WinL30=kNgP050=KFeP3>c/h0c/k>0;fm_@3>c/h00@36a/H001D0oooo0`2m
_Kd00`2LW9`0YJFU0:FUY@020:f][@80]KFe102m_Kd40<K6aP@0c/k>2@3Fe]H40<k>cP040<K6aP3N
g]h0g]kN0=KFeQh0oooo00@0[Jf]04Y:BP1:BTX0DU9B0P1JFUX206=SH`80Jf][0P1cLg<307]kN`<0
Q8B40`2<S8`209BDU00409bLW02UYJD0YJFU0:FUY@80[Jf]102e]KD0102m_Kd0a/K60<K6aP36a/H2
0<k>cP030=kNgP3WinL0kno_00h0kno_00<0inOW0=kNgP3Fe]H00P3>c/h01P36a/H0_Kfm0;Fe]@2]
[Jd0YJFU09bLW080U9BD00<0W9bL0:f][@2e]KD0102m_Kd20<K6aP<0c/k>1@3Fe]H60=kNgP800000
00<0YJFU0>OWi`3WinL00P3WinL40>o_k`03024Q8@000000Hf=S00X0kno_1`3WinL20=kNgP80e]KF
00@0c/k>0<K6aP2m_Kd0c/k>0@3oool001L0oooo0`2m_Kd00`2LW9`0YJFU0:FUY@020:f][@80]KFe
102m_Kd50<K6aPX0c/k>0`36a/H00`3Ng]h0e]KF0=KFeP0P0?ooo`80[Jf]00@0BTY:059BDP1JFUX0
FUYJ0P1SHf<206][J`80Lg=c0`1kNg/408B4Q080S8b<0P2DU9@209bLW0<0YJFU102][Jd00`2e]KD0
_Kfm0;fm_@030<K6aP030<k>cP3Fe]H0g]kN0080inOW2`3_knl30>OWi`060=kNgP3>c/h0c/k>0<K6
aP2m_Kd0]KFe0P2][Jd01`2UYJD0W9bL09BDU02LW9`0YJFU0:f][@2e]KD0102m_Kd20<K6aP<0c/k>
103Fe]H60=kNgP040>OWi`2UYJD0YJFU0=KFeP<0inOW1@3_knl00`2m_Kd0YJFU0<K6aP0;0>o_k`H0
inOW0`3Ng]h01@3Fe]H0c/k>0<K6aP2m_Kd0c/k>0040oooo000I0?ooo`80_Kfm0P36a/H00`2UYJD0
[Jf]0:f][@040;Fe]@@0_Kfm3036a/H20=kNgP80e]KF8`3oool20:f][@0304Y:BP1BDU80FUYJ00<0
Hf=S0P1[Jf/207=cL`<0Ng]k0`24Q8@208b<S0<0U9BD2@2LW9`0102UYJD0[Jf]0:f][@2][Jd20;Fe
]@040;fm_@3>c/h0g]kN0=kNgP<0inOW1@3_knl40>OWi`80g]kN00<0e]KF0<k>cP36a/H00P2m_Kd2
0:f][@060:FUY@2LW9`0U9BD09BDU02UYJD0[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN
1`3WinLE0>o_k`D0inOW0`3Ng]h01@3Fe]H0c/k>0<K6aP2m_Kd0c/k>0040oooo000L0?ooo`@0a/K6
00<0c/k>0:f][@2][Jd00`2e]KD60;fm_@040<K6aP2m_Kd0_Kfm0;fm_@D0e]KF9`3oool20:f][@80
DU9B00<0FUYJ06=SH`1SHf<00P1[Jf/307=cL`80Ng]k1024Q8@208b<S080U9BD0P2<S8`208B4Q0@0
Ng]k0P24Q8@208b<S0<0U9BD00D0W9bL0:f][@2m_Kd0a/K60<k>cP020=kNgPH0inOW0P3Ng]h20=KF
eP80c/k>0P36a/H00`2m_Kd0[Jf]0:FUY@0209bLW080U9BD00<0W9bL0:FUY@2][Jd00P2e]KD30;fm
_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLE0>o_k`D0inOW0`3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0
c/k>0040oooo000P0?ooo`80a/K61`3>c/h80=KFeR`0oooo0P2][Jd00`1BDU80FUYJ05YJFP0206=S
H`80Jf][0P1cLg<307]kN`<0Q8B40`2<S8`00`24Q8@0Ng]k06][J`0406=SH`<0Jf][0P1cLg<207]k
N`<0Q8B40P2DU9@01@2LW9`0[Jf]0;fm_@36a/H0e]KF00D0g]kN0P3Fe]H20<k>cP80a/K60P2m_Kd0
0`2e]KD0YJFU09bLW00309BDU00409bLW02UYJD0[Jf]0:f][@80]KFe0`2m_Kd30<K6aP80c/k>103F
e]H60=kNgPL0inOW5@3_knl50>OWi`80g]kN0P3Fe]H00`3>c/h0a/K60=KFeP020?ooo`00:03oool0
0`3>c/h0oooo0?ooo`0c0?ooo`040:f][@1:BTX0DU9B05YJFP80Hf=S0`1[Jf/207=cL`80Ng]k1@24
Q8@00`1kNg/0Jf][05YJFP03059BDP0405YJFP1SHf<0Hf=S06=SH`<0Jf][0P1cLg<307]kN`<0Q8B4
00D0S8b<09bLW02][Jd0a/K60<k>cP030=KFeP@0c/k>0P36a/H20;fm_@090;Fe]@2][Jd0YJFU09bL
W02DU9@0S8b<09BDU02LW9`0YJFU0080[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3W
inLE0>o_k`D0inOW0P3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>0080oooo001N0?ooo`80[Jf]00<0
DU9B05YJFP1SHf<00P1SHf<206][J`80Lg=c0P1kNg/508B4Q00307=cL`1JFUX0BTY:0080BTY:00<0
DU9B05YJFP1SHf<00P1SHf<206][J`<0Lg=c0`1kNg/02P24Q8@0Ng]k07]kN`1kNg/0S8b<09bLW02e
]KD0a/K60<k>cP3Fe]H40<k>cP80a/K600H0_Kfm0;Fe]@2e]KD0[Jf]0:FUY@2LW9`309BDU00309bL
W02UYJD0YJFU0080[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLC0>o_k`H0inOW
0`3Ng]h0103Fe]H0c/k>0<K6aP3Fe]H30?ooo`00G`3oool20:f][@04059BDP1JFUX0Hf=S06=SH`80
Jf][0P1cLg<307]kN`<0Q8B400<0Lg=c06=SH`1BDU800`1:BTX0101BDU80FUYJ06=SH`1[Jf/207=c
L`<0Ng]k1P24Q8@207]kN`0508B4Q02<S8`0YJFU0;Fe]@36a/H00`3>c/h30<K6aP80_Kfm00<0]KFe
0:f][@2UYJD00P2LW9`309BDU00309bLW02UYJD0YJFU0080[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h4
0=KFePH0g]kN1`3WinLC0>o_k`H0inOW0P3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>00<0oooo001P
0?ooo`<0[Jf]00<0FUYJ06=SH`1SHf<00P1[Jf/207=cL`D0Ng]k00<0Jf][05YJFP1:BTX00P1:BTX0
1P1BDU80FUYJ06=SH`1[Jf/0Lg=c07]kN`80Q8B40`2<S8`309BDU080S8b<1024Q8@00`2DU9@0YJFU
0;fm_@050<K6aP060;fm_@2e]KD0[Jf]0:f][@2UYJD0W9bL102DU9@209bLW080YJFU0P2][Jd20;Fe
]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OWia<0kno_1@3WinL30=kNgP040=KFeP3>c/h0a/K6
0=KFeP@0oooo001R0?ooo`030;Fe]@2UYJD0FUYJ0080Hf=S0P1[Jf/207=cL`<0Ng]k00@0Lg=c06=S
H`1BDU80BTY:0P1BDU801@1SHf<0Jf][07=cL`1kNg/0Q8B40080S8b<0P2DU9@209bLW080YJFU0`2L
W9`209BDU00608b<S024Q8@0Q8B409BDU02UYJD0]KFe0`2m_Kd01P2e]KD0[Jf]0:f][@2UYJD0W9bL
09BDU0<0S8b<0P2DU9@209bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h7
0>OWia<0kno_1@3WinL20=kNgP050=KFeP3>c/h0a/K60=KFeP3>c/h0103oool006<0oooo00<0[Jf]
0:FUY@1JFUX00P1SHf<206][J`80Lg=c0P1kNg/02`1[Jf/0FUYJ059BDP1BDU80FUYJ06=SH`1[Jf/0
Lg=c07]kN`24Q8@0S8b<0080U9BD0P2LW9`20:FUY@D0[Jf]0P2UYJD01P2DU9@0S8b<08B4Q02<S8`0
W9bL0:f][@80]KFe0P2][Jd01@2UYJD0W9bL09BDU02DU9@0S8b<0080Q8B40P2<S8`00`2DU9@0W9bL
09bLW0020:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLC0>o_k`D0inOW
0P3Ng]h0103Fe]H0c/k>0<K6aP3Fe]H50?ooo`00I03oool20:f][@030:FUY@1SHf<0Hf=S0080Jf][
0`1cLg<02P1[Jf/0Hf=S05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`309BDU080W9bL0P2U
YJD70:f][@050:FUY@2DU9@0S8b<08b<S02LW9`00`2][Jd01@2UYJD0W9bL09bLW02DU9@0S8b<0080
Q8B400D0Ng]k08B4Q02<S8`0S8b<09BDU00209bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>
cP@0e]KF1P3Ng]h70>OWia80kno_1@3WinL30=kNgP040=KFeP3>c/h0e]KF0<k>cPD0oooo001V0?oo
o`040;Fe]@2][Jd0Hf=S06=SH`80Jf][0`1cLg<00`1[Jf/0Hf=S06=SH`0206][J`0307=cL`1kNg/0
Ng]k0080Q8B41@2<S8`00`2DU9@0W9bL09bLW00309bLW080YJFU00D0[Jf]0:FUY@2DU9@0U9BD09bL
W0030:FUY@0309bLW02DU9@0U9BD00<0]KFe0P1kNg/208B4Q00408b<S02DU9@0U9BD09bLW080YJFU
0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OWia40kno_1P3WinL20=kNgP040=KF
eP3>c/h0a/K60=KFePH0oooo001W0?ooo`<0[Jf]00<0Hf=S06][J`1[Jf/00P1cLg<606][J`<0Lg=c
1`1kNg/508B4Q00408b<S02DU9@0W9bL09bLW0<0U9BD0P2LW9`209BDU0040;Fe]@2][Jd0]KFe0?oo
o`80[Jf]00@0Lg=c07]kN`24Q8@0S8b<0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@<0]KFe0`2m_Kd2
0<K6aP<0c/k>0`3Fe]H60=kNgPL0inOW4@3_knl50>OWi`<0g]kN00@0e]KF0<k>cP3Fe]H0e]KF1P3o
ool006T0oooo00<0]KFe0:f][@2][Jd02`1[Jf/=07=cL`80Ng]k1024Q8@308b<S0030;Fe]@2][Jd0
]KFe00@0oooo0P2][Jd01@1kNg/0Q8B408b<S02<S8`0U9BD0080W9bL00@0YJFU0:f][@2][Jd0[Jf]
0P2e]KD30;fm_@<0a/K60P3>c/h30=KFePH0g]kN1`3WinL@0>o_k`D0inOW0P3Ng]h20=KFeP030<k>
cP3Fe]H0e]KF00L0oooo001[0?ooo`030;Fe]@1SHf<0Jf][01H0Jf][1@1cLg<407]kN`030:f][@3o
ool0oooo00D0oooo0P2][Jd00`1kNg/0Q8B408b<S00209BDU00309bLW02UYJD0YJFU0080[Jf]0`2e
]KD30;fm_@80a/K60P3>c/h40=KFePH0g]kN2@3WinL:0>o_k`L0inOW0P3Ng]h20=KFeP030<k>cP3N
g]h0e]KF00P0oooo001[0?ooo`030:f][@1[Jf/0Jf][0180Jf][3@1cLg<00`2][Jd0oooo0?ooo`06
0?ooo`80[Jf]00@0Ng]k08B4Q02<S8`0U9BD0P2LW9`20:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>
c/h40=KFePH0g]kN603WinL20=kNgP80e]KF00<0c/k>0=KFeP3Fe]H02@3oool006T0oooo0`2][Jd@
06][Ja40Lg=c0`2][Jd70?ooo`040:f][@1kNg/0Q8B408b<S080U9BD00@0W9bL0:FUY@2UYJD0YJFU
0P2][Jd20;Fe]@<0_Kfm0P36a/H20<k>cPD0e]KF1P3Ng]hF0>OWi`<0g]kN00@0e]KF0<k>cP36a/H0
e]KF2P3oool006L0oooo0`2][Jd>06][J`P0Lg=c2`1kNg/407=cL`80[Jf]00<0YJFU0?ooo`3oool0
0`3oool20:f][@0407]kN`24Q8@0S8b<09BDU080W9bL0P2UYJD20:f][@80]KFe0`2m_Kd20<K6aP<0
c/k>103Fe]H60=kNgQD0inOW0`3Ng]h20=KFeP030<k>cP3Fe]H0e]KF00X0oooo001V0?ooo`80[Jf]
3@1[Jf/707=cL`P0Ng]k0`24Q8@807]kN`80Lg=c0P2][Jd50?ooo`80[Jf]00D0Q8B408b<S02DU9@0
U9BD09bLW0020:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN503WinL30=kNgP80
e]KF00<0c/k>0=kNgP3Fe]H02`3oool006@0oooo0`2][Jd<06][J`D0Lg=c1P1kNg/@08B4Q0@0Ng]k
0`2][Jd40?ooo`<0[Jf]00@0S8b<09BDU02LW9`0W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80
c/k>103Fe]H60=kNgQ80inOW0`3Ng]h00`3Fe]H0c/k>0=kNgP020=kNgP`0oooo001S0?ooo`80[Jf]
301[Jf/407=cL`D0Ng]k1`24Q8@<08b<S0@0Q8B40`1kNg/20:f][@D0oooo00<0]KFe0:f][@2<S8`0
0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80]KFe0`2m_Kd20<K6aP<0c/k>1@3Fe]H60=kNgP`0inOW
1@3Ng]h20=KFeP030<k>cP3Ng]h0g]kN00h0oooo001R0?ooo`80[Jf]2`1[Jf/407=cL`D0Ng]k1@24
Q8@808b<S0D0U9BD1`2<S8`308B4Q00307]kN`2][Jd0[Jf]00D0oooo00<0]KFe0:f][@2<S8`00P2D
U9@00`2LW9`0YJFU0:FUY@020:f][@80]KFe0`2m_Kd20<K6aP<0c/k>1P3Fe]HC0=kNgP80e]KF00@0
c/k>0<K6aP3Fe]H0e]KF3`3oool00600oooo0`2][Jd:06][J`@0Lg=c101kNg/508B4Q0H0S8b<402D
U9@408b<S080Q8B40`2][Jd40?ooo`80[Jf]00@0]KFe09BDU02DU9@0W9bL0P2UYJD20:f][@80]KFe
0`2m_Kd30<K6aP<0c/k>1@3Fe]H@0=kNgP80e]KF0P3>c/h00`3Ng]h0e]KF0=KFeP0@0?ooo`00G`3o
ool20:f][@/0Jf][0`1cLg<407]kN`@0Q8B41@2<S8`709BDU0/0W9bL1P2DU9@208b<S080Q8B40P2]
[Jd50?ooo`80]KFe0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80]KFe0`2m_Kd30<K6aP@0c/k>1@3F
e]H:0=kNgP@0e]KF0P3>c/h00`36a/H0e]KF0=KFeP0B0?ooo`00GP3oool20:f][@/0Jf][0`1cLg<3
07]kN`@0Q8B41@2<S8`609BDU140W9bL102DU9@308b<S00308B4Q02][Jd0[Jf]00D0oooo0`2e]KD0
102DU9@0W9bL0:FUY@2UYJD20:f][@80]KFe0`2m_Kd40<K6aP@0c/k>3`3Fe]H20<k>cP040<K6aP3N
g]h0e]KF0=KFeQ<0oooo001N0?ooo`030:f][@1[Jf/0Jf][00T0Jf][0`1cLg<307]kN`<0Q8B4102<
S8`709BDU0L0W9bL2@2UYJD609bLW0<0U9BD00@0S8b<08B4Q024Q8@0[Jf]1`3oool30;Fe]@0309bL
W02UYJD0YJFU0080[Jf]0P2e]KD40;fm_@@0a/K6103>c/h90=KFeP@0c/k>00@0a/K60=kNgP3Fe]H0
e]KF5@3oool005d0oooo0P2][Jd:06][J`80Lg=c101kNg/308B4Q0<0S8b<1P2DU9@609bLW100YJFU
1@2LW9`209BDU00408b<S024Q8@0[Jf]0;Fe]@P0oooo0P2e]KD0102m_Kd0W9bL0:FUY@2UYJD20:f]
[@80]KFe102m_Kd50<K6aPX0c/k>0`36a/H30=KFeQL0oooo001L0?ooo`80[Jf]2@1[Jf/307=cL`<0
Ng]k0`24Q8@408b<S0@0U9BD1P2LW9`;0:FUY@<0[Jf]2@2UYJD309bLW080U9BD00<0S8b<0:f][@2]
[Jd02@3oool30;fm_@040<K6aP2UYJD0[Jf]0:f][@@0]KFe102m_Kd<0<K6aP@0e]KF6@3oool005/0
oooo0P2][Jd906][J`<0Lg=c0P1kNg/308B4Q0@0S8b<102DU9@509bLW0H0YJFU4@2][Jd50:FUY@80
W9bL0P2DU9@00`2<S8`0[Jf]0;Fe]@0;0?ooo`80_Kfm0`36a/H20:f][@<0]KFe1P2m_Kd01036a/H0
_Kfm0;fm_@2m_Kd50=KFeQ`0oooo001J0?ooo`80[Jf]2@1[Jf/307=cL`80Ng]k0`24Q8@308b<S0D0
U9BD102LW9`60:FUYAH0[Jf]102UYJD209bLW00409BDU02<S8`0[Jf]0;Fe]@h0oooo1036a/H60<k>
cP@0e]KF0P3>c/h00`3Fe]H0oooo0?ooo`0N0?ooo`00FP3oool00`2][Jd0Jf][06][J`0806][J`80
Lg=c0P1kNg/308B4Q0<0S8b<102DU9@409bLW0H0YJFU1P2][Jd?0;Fe]@H0[Jf]0P2UYJD209bLW003
09BDU02<S8`0]KFe01H0oooo00<0c/k>0?ooo`3oool09P3oool005T0oooo0P2][Jd806][J`<0Lg=c
0P1kNg/308B4Q0<0S8b<0`2DU9@409bLW0H0YJFU1P2][JdC0;Fe]@D0[Jf]0P2UYJD209bLW00309BD
U02e]KD0]KFe03h0oooo001I0?ooo`030:f][@1[Jf/0Jf][00L0Jf][0P1cLg<207]kN`<0Q8B40`2<
S8`309BDU0@0W9bL1@2UYJD60:f][@L0]KFe2P2m_Kd80;Fe]@80[Jf]0P2UYJD209bLW00309BDU02e
]KD0oooo03d0oooo001H0?ooo`80[Jf]201[Jf/207=cL`80Ng]k0`24Q8@308b<S0<0U9BD102LW9`4
0:FUY@H0[Jf]1@2e]KDA0;fm_@H0]KFe0P2][Jd20:FUY@0409bLW02DU9@0]KFe0;Fe]Cd0oooo001H
0?ooo`030:f][@1[Jf/0Jf][00H0Jf][0P1cLg<307]kN`80Q8B40`2<S8`309BDU0<0W9bL102UYJD6
0:f][@D0]KFe5`2m_Kd30;Fe]@80[Jf]0P2UYJD00`2LW9`0U9BD0;Fe]@0m0?ooo`00E`3oool20:f]
[@L0Jf][0`1cLg<207]kN`80Q8B40`2<S8`309BDU0<0W9bL102UYJD50:f][@D0]KFe3@2m_Kd30<K6
aPX0_Kfm0`2e]KD20:f][@80YJFU00<0W9bL0;Fe]@2e]KD0?03oool005L0oooo00<0[Jf]06][J`1[
Jf/01P1[Jf/207=cL`80Ng]k0P24Q8@308b<S0<0U9BD0`2LW9`40:FUY@@0[Jf]1@2e]KD70;fm_A80
a/K61@2m_Kd20;Fe]@80[Jf]0P2UYJD00`2LW9`0_Kfm0?ooo`0k0?ooo`00EP3oool20:f][@L0Jf][
0P1cLg<207]kN`<0Q8B40P2<S8`309BDU0<0W9bL102UYJD30:f][@D0]KFe1`2m_KdF0<K6aP@0_Kfm
0P2e]KD20:f][@80YJFU0P2e]KDk0?ooo`00EP3oool00`2][Jd0Jf][06][J`0506][J`<0Lg=c00@0
Ng]k08B4Q024Q8@0Q8B40P2<S8`309BDU0<0W9bL102UYJD30:f][@@0]KFe1`2m_Kd60<K6aPl0c/k>
1@36a/H40;fm_@060;Fe]@2][Jd0[Jf]0:FUY@2LW9`0_Kfm>`3oool005D0oooo0P2][Jd606][J`<0
Lg=c0P1kNg/208B4Q080S8b<0`2DU9@309bLW0<0YJFU102][Jd40;Fe]@H0_Kfm1P36a/HC0<k>cPD0
a/K60`2m_Kd20;Fe]@040:f][@2UYJD0_Kfm0;Fe]CX0oooo001E0?ooo`030:f][@1[Jf/0Jf][00D0
Jf][0P1cLg<207]kN`80Q8B40`2<S8`209BDU0<0W9bL0`2UYJD40:f][@@0]KFe1P2m_Kd40<K6aPT0
c/k>2@3Fe]H70<k>cP<0a/K60P2m_Kd20;Fe]@040:f][@2UYJD0W9bL0;fm_CX0oooo001E0?ooo`03
0:f][@1[Jf/0Jf][00@0Jf][0`1cLg<207]kN`80Q8B40P2<S8`309BDU0<0W9bL0P2UYJD40:f][@@0
]KFe1@2m_Kd50<K6aPL0c/k>3`3Fe]H50<k>cP<0a/K60P2m_Kd20;Fe]@030:f][@2UYJD0_Kfm03X0
oooo001E0?ooo`030:f][@1[Jf/0Jf][00@0Jf][0P1cLg<207]kN`80Q8B40P2<S8`309BDU0<0W9bL
0`2UYJD30:f][@@0]KFe1@2m_Kd50<K6aPD0c/k>4`3Fe]H50<k>cP80a/K60`2m_Kd0102e]KD0[Jf]
0:FUY@36a/Hj0?ooo`00E03oool20:f][@H0Jf][0P1cLg<00`1kNg/0Q8B408B4Q00308b<S080U9BD
0`2LW9`30:FUY@<0[Jf]102e]KD40;fm_@H0a/K60`3>c/hI0=KFeP<0c/k>0P36a/H30;fm_@040;Fe
]@2][Jd0_Kfm0;fm_CT0oooo001D0?ooo`030:f][@1[Jf/0Jf][00@0Jf][0P1cLg<207]kN`80Q8B4
0P2<S8`209BDU0<0W9bL0`2UYJD30:f][@<0]KFe1@2m_Kd40<K6aPD0c/k>203Fe]H=0=kNgPH0e]KF
0`3>c/h20<K6aP80_Kfm00@0]KFe0:f][@2UYJD0_Kfm>@3oool005@0oooo00<0[Jf]06][J`1[Jf/0
101[Jf/207=cL`80Ng]k00@0Q8B408b<S02<S8`0S8b<0P2DU9@209bLW0@0YJFU0`2][Jd30;Fe]@@0
_Kfm1036a/H50<k>cPP0e]KF3`3Ng]h60=KFeP<0c/k>0P36a/H01@2m_Kd0]KFe0:f][@2UYJD0_Kfm
03T0oooo001D0?ooo`030:f][@1[Jf/0Jf][00@0Jf][0P1cLg<00`1kNg/0Q8B408B4Q00208b<S0<0
U9BD0P2LW9`30:FUY@<0[Jf]0`2e]KD40;fm_@@0a/K61@3>c/h60=KFeQ<0g]kN1P3Fe]H20<k>cP80
a/K60P2m_Kd00`2e]KD0YJFU0;fm_@0i0?ooo`00E03oool00`2][Jd0Jf][06][J`0306][J`80Lg=c
0P1kNg/208B4Q080S8b<0P2DU9@309bLW0<0YJFU0`2][Jd20;Fe]@@0_Kfm1036a/H50<k>cPH0e]KF
5`3Ng]h30=KFeP<0c/k>00H0a/K60;fm_@2m_Kd0]KFe0:f][@36a/Hi0?ooo`00E03oool00`2][Jd0
Jf][06][J`0306][J`80Lg=c0P1kNg/208B4Q080S8b<0P2DU9@209bLW0<0YJFU0`2][Jd30;Fe]@@0
_Kfm0`36a/H01@3>c/h000000000002DU9@0c/k>00H0e]KF00@0g]kN01PH60000000FUYJ5@3Ng]h3
0=KFeP80c/k>0P36a/H0102m_Kd0]KFe0:f][@36a/Hi0?ooo`00E03oool00`2][Jd0Jf][06][J`03
06][J`80Lg=c00<0Ng]k08B4Q024Q8@00P2<S8`309BDU080W9bL0`2UYJD30:f][@<0]KFe0`2m_Kd4
0<K6aP040<k>cP000000000009BDU0H0e]KF0P3Ng]h00`0H61P0000005YJFP0E0=kNgP<0e]KF0P3>
c/h20<K6aP040;fm_@2e]KD0[Jf]0<K6aST0oooo001D0?ooo`030:f][@1[Jf/0Jf][0080Jf][0`1c
Lg<00`1kNg/0Q8B408B4Q00208b<S080U9BD0P2LW9`30:FUY@<0[Jf]0`2e]KD30;fm_@@0a/K60P3>
c/h20000000309BDU03Fe]H0e]KF00<0e]KF0`3Ng]h00`0H61P0000005YJFP020=kNgPd0inOW1`3N
g]h30=KFeP80c/k>00D0a/K60;fm_@2e]KD0[Jf]0<K6aP0i0?ooo`00E03oool00`2][Jd0Jf][06][
J`0206][J`80Lg=c0P1kNg/208B4Q00408b<S02DU9@0U9BD09BDU080W9bL0`2UYJD30:f][@80]KFe
102m_Kd40<K6aP80c/k>0P0000000`2DU9@0e]KF0=KFeP020=KFeP@0g]kN00@061PH0000001JFUX0
g]kN3`3WinL60=kNgP<0e]KF0P3>c/h20<K6aP030;fm_@2][Jd0a/K603T0oooo001D0?ooo`030:f]
[@1[Jf/0Jf][0080Jf][0P1cLg<207]kN`0308B4Q02<S8`0S8b<00<0U9BD0P2LW9`20:FUY@<0[Jf]
0`2e]KD30;fm_@@0a/K60`3>c/h20000000409BDU03Fe]H0e]KF0=KFePD0g]kN00<061PH0000001S
Hf<04@3WinL60=kNgP<0e]KF00H0c/k>0<K6aP36a/H0_Kfm0:f][@36a/Hi0?ooo`00E03oool00`2]
[Jd0Jf][06][J`0206][J`80Lg=c00<0Ng]k08B4Q024Q8@00P2<S8`209BDU080W9bL0`2UYJD30:f]
[@<0]KFe0`2m_Kd30<K6aP<0c/k>00@0e]KF000000000000U9BD0P3Fe]H60=kNgP0301PH60000000
Hf=S01@0inOW103Ng]h20=KFeP80c/k>00@0a/K60;fm_@2e]KD0a/K6>@3oool005@0oooo00<0[Jf]
06][J`1[Jf/00P1[Jf/207=cL`0307]kN`24Q8@0Q8B40080S8b<0P2DU9@209bLW080YJFU0`2][Jd3
0;Fe]@<0_Kfm0`36a/H30<k>cP80e]KF0P0000000`2DU9@0e]KF0=kNgP050=kNgP040>OWi`0Q8B40
000006=SHaD0inOW0`3Ng]h30=KFeP050<k>cP36a/H0_Kfm0;Fe]@36a/H0>@3oool005@0oooo00@0
[Jf]06][J`1[Jf/0Jf][0P1cLg<207]kN`80Q8B400<0S8b<09BDU02DU9@00`2LW9`20:FUY@<0[Jf]
0P2e]KD40;fm_@<0a/K60P3>c/h30=KFeP80000000<0W9bL0=kNgP3Ng]h0103Ng]h20>OWi`03024Q
8@000000Hf=S01D0inOW0`3Ng]h30=KFeP050<k>cP36a/H0_Kfm0;Fe]@36a/H0>@3oool005@0oooo
00@0[Jf]06][J`1[Jf/0Jf][0P1cLg<207]kN`0308B4Q02<S8`0S8b<0080U9BD0P2LW9`20:FUY@<0
[Jf]0`2e]KD30;fm_@<0a/K60`3>c/h30=KFePd0000000<0Hf=S0>OWi`3WinL0503WinL30=kNgP80
e]KF00D0c/k>0<K6aP2m_Kd0]KFe0<K6aP0i0?ooo`00E03oool0102][Jd0Jf][06][J`1[Jf/207=c
L`0307]kN`24Q8@0Q8B40080S8b<00@0U9BD09bLW02LW9`0W9bL0P2UYJD30:f][@<0]KFe0`2m_Kd3
0<K6aP<0c/k>0`3Fe]H=0000000306=SH`3WinL0inOW00d0kno_1`3WinL30=kNgP80e]KF00D0c/k>
0<K6aP36a/H0]KFe0<k>cP0i0?ooo`00E03oool0102][Jd0Jf][06][J`1[Jf/207=cL`0407]kN`24
Q8@0Q8B408b<S080U9BD0`2LW9`20:FUY@80[Jf]0`2e]KD30;fm_@<0a/K60`3>c/h40=KFeP800000
00@0W9bL0=kNgP3Ng]h0g]kN1@3WinL0100Q8B40000006=SH`3WinL?0>o_k`L0inOW0`3Ng]h20=KF
eP040<k>cP36a/H0]KFe0<k>cST0oooo001D0?ooo`80[Jf]0P1[Jf/207=cL`0407]kN`24Q8@0Q8B4
08b<S080U9BD0P2LW9`30:FUY@80[Jf]0P2e]KD40;fm_@<0a/K60`3>c/h40=KFeP80000000@0W9bL
0=kNgP3Ng]h0g]kN1@3WinL00`0Q8B40000006=SH`0@0>o_k`L0inOW0`3Ng]h01P3Fe]H0c/k>0<k>
cP2m_Kd0c/k>0<K6aST0oooo001E0?ooo`030:f][@1[Jf/0Jf][0080Lg=c00@0Ng]k08B4Q024Q8@0
S8b<0P2DU9@209bLW0<0YJFU0P2][Jd20;Fe]@@0_Kfm0P36a/H30<k>cPD0e]KF0P000000102LW9`0
g]kN0=kNgP3Ng]h50>OWi`03024Q8@000000Hf=S0100kno_1`3WinL20=kNgP80e]KF00@0c/k>0<K6
aP2m_Kd0c/k>>P3oool005D0oooo00<0[Jf]06][J`1[Jf/00P1cLg<0101kNg/0Q8B408B4Q02<S8`2
09BDU080W9bL0P2UYJD30:f][@80]KFe102m_Kd20<K6aP<0c/k>103Fe]H0103Ng]h000000000002L
W9`20=kNgPH0inOW00<08B4Q0000001SHf<04@3_knl60>OWi`<0g]kN00D0e]KF0<k>cP36a/H0_Kfm
0<k>cP0j0?ooo`00E@3oool00`2][Jd0Jf][06][J`0207=cL`0407]kN`24Q8@0Q8B408b<S080U9BD
0P2LW9`20:FUY@<0[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFeP80g]kN0P0000000`2LW9`0g]kN
0>OWi`060>OWi`03024Q8@000000Hf=S0180kno_1@3WinL30=kNgP050=KFeP3>c/h0a/K60;fm_@3>
c/h0>P3oool005D0oooo0P2][Jd0101[Jf/0Lg=c07=cL`1kNg/208B4Q00308b<S02DU9@0U9BD0080
W9bL0P2UYJD30:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H20=kNgP80000000<0W9bL0=kNgP3W
inL01P3WinL00`0Q8B40000006=SH`0B0>o_k`D0inOW0`3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>
03X0oooo001F0?ooo`050:f][@1[Jf/0Lg=c07=cL`1kNg/00P24Q8@00`2<S8`0U9BD09BDU00209bL
W080YJFU0`2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF0P3Ng]h20000000309bLW03Ng]h0inOW
00H0inOW00<08B4Q0000001SHf<04P3_knl50>OWi`80g]kN0P3Fe]H00`3>c/h0a/K60=KFeP0k0?oo
o`00EP3oool20:f][@0606][J`1cLg<0Ng]k07]kN`24Q8@0S8b<0P2DU9@209bLW080YJFU0`2][Jd2
0;Fe]@<0_Kfm0`36a/H20<k>cP@0e]KF0P3Ng]h209bLW0030<k>cP3Ng]h0inOW00H0inOW00<0_Kfm
0:FUY@36a/H04P3_knl50>OWi`80g]kN00D0e]KF0<k>cP36a/H0e]KF0<k>cP0k0?ooo`00E`3oool0
1P2][Jd0Jf][07=cL`1cLg<0Ng]k08B4Q080S8b<00<0U9BD09bLW02LW9`00`2UYJD20:f][@80]KFe
0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW4`3_knl60>OWi`<0g]kN00@0e]KF0<k>cP36a/H0
e]KF?03oool005L0oooo0P2][Jd207=cL`0507]kN`24Q8@0Q8B408b<S02DU9@00P2LW9`30:FUY@80
[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3WinLC0>o_k`H0inOW0P3Ng]h01@3Fe]H0
c/k>0<K6aP3Fe]H0c/k>03`0oooo001H0?ooo`040:f][@1[Jf/0Lg=c07]kN`80Q8B400@0S8b<09BD
U02DU9@0W9bL0`2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgPL0inOW4`3_knl5
0>OWi`<0g]kN00@0e]KF0<k>cP36a/H0e]KF?@3oool005P0oooo0P2][Jd01@1cLg<0Ng]k07]kN`24
Q8@0S8b<0080U9BD0P2LW9`20:FUY@80[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h40=KFePH0g]kN1`3W
inLC0>o_k`D0inOW0P3Ng]h01@3Fe]H0c/k>0<K6aP3Fe]H0c/k>03d0oooo001I0?ooo`060:f][@1c
Lg<0Lg=c07]kN`24Q8@0S8b<0P2DU9@209bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0`36a/H20<k>cP@0
e]KF1P3Ng]h70>OWia<0kno_1@3WinL20=kNgP040=KFeP3>c/h0a/K60=KFeSh0oooo001I0?ooo`80
[Jf]00<0Lg=c07]kN`24Q8@00P2<S8`00`2DU9@0W9bL09bLW0020:FUY@80[Jf]0P2e]KD30;fm_@<0
a/K60P3>c/h40=KFePH0g]kN1`3WinLB0>o_k`D0inOW0`3Ng]h0103Fe]H0c/k>0=KFeP3>c/hn0?oo
o`00FP3oool00`2][Jd0Lg=c07]kN`0208B4Q00408b<S02DU9@0U9BD09bLW080YJFU0P2][Jd20;Fe
]@<0_Kfm0`36a/H20<k>cP@0e]KF1P3Ng]h70>OWia40kno_1P3WinL20=kNgP040=KFeP3>c/h0a/K6
0=KFeSl0oooo001J0?ooo`80[Jf]00@0Lg=c07]kN`24Q8@0S8b<0P2DU9@00`2LW9`0YJFU0:FUY@02
0:f][@<0]KFe0`2m_Kd20<K6aP<0c/k>0`3Fe]H60=kNgPL0inOW4@3_knl50>OWi`<0g]kN00@0e]KF
0<k>cP3Fe]H0e]KF?`3oool005/0oooo0P2][Jd01@1kNg/0Q8B408b<S02<S8`0U9BD0080W9bL00@0
YJFU0:f][@2][Jd0[Jf]0P2e]KD30;fm_@<0a/K60P3>c/h30=KFePH0g]kN1`3WinL@0>o_k`D0inOW
0P3Ng]h20=KFeP030<k>cP3Fe]H0e]KF0400oooo001L0?ooo`80]KFe00<0Ng]k08B4Q02<S8`00P2D
U9@00`2LW9`0YJFU0:FUY@020:f][@<0]KFe0`2m_Kd20<K6aP80c/k>103Fe]H60=kNgPT0inOW2P3_
knl70>OWi`80g]kN0P3Fe]H00`3>c/h0g]kN0=KFeP110?ooo`00G@3oool20;Fe]@0407]kN`24Q8@0
S8b<09BDU080W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgQP0inOW0P3N
g]h20=KFeP030<k>cP3Fe]H0e]KF0480oooo001N0?ooo`040;Fe]@1kNg/0Q8B408b<S080U9BD00@0
W9bL0:FUY@2UYJD0YJFU0P2][Jd20;Fe]@<0_Kfm0P36a/H20<k>cPD0e]KF1P3Ng]hF0>OWi`<0g]kN
00@0e]KF0<k>cP36a/H0e]KF@`3oool005h0oooo00H0[Jf]0;Fe]@1kNg/0Q8B408b<S02DU9@209bL
W080YJFU0P2][Jd20;Fe]@<0_Kfm0P36a/H30<k>cP@0e]KF1P3Ng]hE0>OWi`<0g]kN0P3Fe]H00`3>
c/h0e]KF0=KFeP130?ooo`00G`3oool20;Fe]@0508B4Q02<S8`0U9BD09BDU02LW9`00P2UYJD20:f]
[@80]KFe0`2m_Kd30<K6aP80c/k>103Fe]H60=kNgQ@0inOW0`3Ng]h20=KFeP030<k>cP3Ng]h0e]KF
04@0oooo001P0?ooo`<0]KFe00@0S8b<09BDU02LW9`0W9bL0P2UYJD20:f][@80]KFe0`2m_Kd30<K6
aP80c/k>103Fe]H60=kNgQ80inOW0`3Ng]h00`3Fe]H0c/k>0=kNgP020=kNgTD0oooo001R0?ooo`03
0;fm_@2e]KD0S8b<0080U9BD00<0W9bL0:FUY@2UYJD00P2][Jd20;Fe]@<0_Kfm0P36a/H30<k>cPD0
e]KF1P3Ng]h<0>OWi`D0g]kN0P3Fe]H00`3>c/h0g]kN0=kNgP170?ooo`00H`3oool20;Fe]@0408b<
S02DU9@0U9BD09bLW080YJFU0P2][Jd20;Fe]@<0_Kfm0P36a/H30<k>cPH0e]KF4`3Ng]h20=KFeP04
0<k>cP36a/H0e]KF0=KFeTP0oooo001T0?ooo`<0]KFe0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80
]KFe0`2m_Kd30<K6aP<0c/k>1@3Fe]H@0=kNgP80e]KF0P3>c/h00`3Ng]h0e]KF0=KFeP190?ooo`00
IP3oool20;fm_@80U9BD00<0W9bL0:FUY@2UYJD00P2][Jd20;Fe]@<0_Kfm0`36a/H40<k>cPD0e]KF
2P3Ng]h40=KFeP80c/k>00<0a/K60=KFeP3Fe]H0B`3oool006L0oooo00D0_Kfm0;Fe]@2m_Kd0U9BD
09bLW0020:FUY@80[Jf]0P2e]KD30;fm_@@0a/K6103>c/h?0=KFeP80c/k>00@0a/K60=kNgP3Fe]H0
e]KFC03oool006T0oooo0`2m_Kd00`2LW9`0YJFU0:FUY@020:f][@80]KFe102m_Kd40<K6aP@0c/k>
2@3Fe]H40<k>cP040<K6aP3Ng]h0e]KF0=KFeTh0oooo001[0?ooo`<0_Kfm00<0W9bL0:FUY@2UYJD0
0P2][Jd20;Fe]@@0_Kfm1@36a/H:0<k>cP<0a/K60`3Fe]I@0?ooo`00K@3oool20;fm_@80a/K600<0
YJFU0:f][@2][Jd0102e]KD40;fm_@`0a/K6103Fe]IB0?ooo`00L03oool40<K6aP030<k>cP2][Jd0
[Jf]00<0]KFe1P2m_Kd01036a/H0_Kfm0;fm_@2m_Kd50=KFeUD0oooo001d0?ooo`80a/K61P3>c/h0
0`3Fe]H0c/k>0=KFeP030=KFeP80c/k>00<0e]KF0?ooo`3oool0E`3oool007`0oooo00<0e]KF0?oo
o`3oool0G`3oool00001\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{Inherited, Inherited}, {8, Inherited}},
  Evaluatable->False,
  Copyable->False,
  ImageSize->{222, 227},
  ImageMargins->{{65, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"ImageCacheDepth"->8}],

Cell["\<\
Please, insert your compound symbol in the box below and continue \
with the next section.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->True,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->True,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[""], "Input",
  Editable->True,
  Selectable->True,
  Deletable->False,
  CellFrame->True,
  CellMargins->{{24, 24}, {20, 1}},
  Active->False,
  Evaluatable->False,
  CellFrameLabels->{{
    Inherited, Inherited}, {
      StyleBox[ 
        "Parent Compound Symbol", FontWeight -> "Plain", FontFamily -> 
          "Helvetica", FontSize -> 9], Inherited}},
  CellFrameLabelMargins->2,
  CellTags->"ParentCompoundSymbol"]
}, Closed]],

Cell[CellGroupData[{

Cell["Number of Substituent Sites", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  Copyable->False,
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[TextData[{
  "In a second step you have to enter the number of substituent sites that \
you want to consider in your isomer enumeration. Substituent sites can be the \
hydrogen atoms in an organic compound, if these are to be replaced by \
halogens. They can also be the carbon atoms in a ",
  Cell[BoxData[
      \(TraditionalForm\`C\_60\)]],
  "-Fulleren, if one wants to replace some of these carbons with silicon \
atoms. Caution: chiral substituents may not be processed correctly!"
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
Please, insert the number of substituent sites in the box below and \
continue with the next section.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[""], "Input",
  Editable->True,
  Selectable->True,
  Deletable->False,
  CellFrame->True,
  CellMargins->{{24, 280}, {20, 1}},
  Active->False,
  Evaluatable->False,
  CellFrameMargins->6,
  CellFrameLabels->{{
    Inherited, Inherited}, {
      StyleBox[ 
        "Number of Substituent Sites", FontWeight -> "Plain", FontFamily -> 
          "Helvetica", FontSize -> 9], Inherited}},
  CellFrameLabelMargins->2,
  CellTags->"NumberOfSubstituentSites"]
}, Closed]],

Cell[CellGroupData[{

Cell["Point Group Permutations", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  Copyable->False,
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[TextData[{
  "In a third step you have to identify the symmetries of the parent \
compound. This is done by specifying the point group and conformational \
symmetry trans-formations that leave the parent compound invariant. It is \
sufficient to enter only those symmetry transformations, with which all the \
others can be generated \n(e.g. a ",
  Cell[BoxData[
      \(TraditionalForm\`90\^0\)]],
  "rotation applied repeatedly results in a ",
  Cell[BoxData[
      \(TraditionalForm\`180\^0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`270\^0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`0\^0\)]],
  "rotation). Selecting these generators carefully, one needs at most two \
rotations, one so-called rotation-reflection, and may be a few conformational \
transformations."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Rotations",
    FontVariations->{"Underline"->True}],
  "  are symmetry transformations that rotate the parent compound in three \
dimensional Euclidean space around a fix-point called the 'point group \
origin'. ",
  StyleBox["Rotation-reflections ",
    FontVariations->{"Underline"->True}],
  " are either a combination of a rotation and a reflection, simply a \
reflection across a plane, or an inversion. An inversion is performed by \
flipping every (atom-)position vector across the point group origin into the \
opposite direction.\n",
  StyleBox["Conformational transformations",
    FontVariations->{"Underline"->True}],
  "  are symmetry transformations that affect the chemical bonds of a \
compound by bending, twisting, or rotating them."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
To distinguish and to enumerate different kinds of isomerism, you \
have to enter and label the symmetry transformations of a parent compound \
according to these three catagories: rotations, rotation-reflections, and \
conformational transformantions.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[CellGroupData[{

Cell["Rotations", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {8, Inherited}},
  Copyable->False,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  ScriptMinSize->9,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetic",
  FontSize->12],

Cell["\<\
We commence with rotations containing no reflections. Take your \
parent compound and label all substituent sites with integers from 1 to n. \
Consider a single rotation. This rotation, being a symmetry transformation, \
should map every substituent site onto itself or onto another substituent \
site. Hence, one obtains a rearrangement of substituent sites and thereby a \
permutation of their labels. Of course, all this only applies, if the parent \
compound exhibits some kind of rotational symmetry. If not, proceed to the \
next section about rotation-reflection.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Example:",
    FontVariations->{"Underline"->True}],
  " double click to the right of the graphic below to see the rotation \
generator for a tetrahedral compound around the red ",
  Cell[BoxData[
      \(TraditionalForm\`C\_3\)]],
  "-axis."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.31108 .53898 Mdot
.5 Mabswid
[ ] 0 setdash
.31108 .53898 m
.32445 .26809 L
s
.84584 .42928 m
.31108 .53898 L
s
.4958 .947 m
.31108 .53898 L
s
15 Mabswid
.84584 .42928 Mdot
.5 Mabswid
.84584 .42928 m
.32445 .26809 L
s
.4958 .947 m
.84584 .42928 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.32445 .26809 L
s
15 Mabswid
.32445 .26809 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.94719 .37406 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26817 .1518 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26285 .51761 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00@@3oool01P2YZJT08B4Q000000000000EEEE0>k^k[X0oooo00110?oo
o`06010@402j^[X0oooo0?ooo`2YZJT0<S8b^P3oool004H0oooo00<000000?ooo`3oool0^03oool0
04D0oooo00<0MgMg024Q8@3oool0^@3oool004<0oooo00@08B4Q000000000000^[Zj^P3oool004@0
oooo00<0k^k^07MgM`0b<S80^P3oool004H0oooo00<000000?ooo`3oool0^03oool00440oooo00H0
8B4Q0:VYZ@3oool0oooo06IVIP0b<S:j0?ooo`00@@3oool01P2j^[X0A4A4000000000000A4A40>k^
k[X0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo001A0?ooo`D00000Z`3oool004l0oooo2@00002Y0?ooo`00CP3oool;
00000:P0oooo001=0?ooo`d00000Y`3oool004d0oooo3@00002W0?ooo`00C03oool?00000:H0oooo
001<0?ooo`l00000YP3oool004`0oooo3`00002V0?ooo`00C03oool?00000:H0oooo001<0?oooa00
0000Y@3oool004d0oooo3@0000020?ooo`<00000XP3oool004d0oooo3@0000050?ooo`<00000W`3o
ool004h0oooo2`0000090?ooo`@00000V`3oool004l0oooo2@00000>0?ooo`<00000V03oool00540
oooo1@00000C0?ooo`<00000U@3oool005<0oooo00<000000?ooo`0000005P3oool300000980oooo
001C0?ooo`030000003oool0000001T0oooo0`00002?0?ooo`00DP3oool010000000oooo0?ooo`00
000L0?ooo`@00000R`3oool00580oooo00D000000?ooo`3oool0oooo0000000O0?ooo`<00000R03o
ool00580oooo00D000000?ooo`3oool0oooo0000000R0?ooo`<00000Q@3oool00580oooo00D00000
0?ooo`3oool0oooo0000000U0?ooo`<00000PP3oool00580oooo00D000000?ooo`3oool0oooo0000
000X0?ooo`<00000O`3oool00580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X
0?ooo`<00000O03oool00580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?oo
o`@00000N03oool00580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`<0
0000M@3oool00580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`<00000
LP3oool00580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`<00000K`3o
ool00580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`<00000K03oool0
0580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`@00000J03oool00580
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?ooo`<00000I@3oool00580oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`<00000HP3oool00580oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`130?ooo`<00000G`3oool00580oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`160?ooo`<00000B`3oool6000000/0oooo001B0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool4000004L0oooo00<0V9RH0000
003<c<`00P3oool00`0@4100oooo0?ooo`090?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04`0oooo0`0000150?ooo`0309RHV0000000c<c<00d0oooo001A0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0C`3oool3000004<0oooo00<0ZJVY010@403<c<`0
303oool00540oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`<00000@@3o
ool00`3<c<`0410@0<c<c00;0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo05D0oooo0`00000o0?ooo`030:VYZ@0b<S80oooo00X0oooo001A0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0E`3oool4000003`0oooo00<000000?ooo`3oool02@3oool00540
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1K0?ooo`<00000=03oool01P000000
QhN70>k^kP3oool0MgMg038b<P/0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0j0?ooo`<00000<@3oool01P2YZJT0<S8b000000000000
EEEE0>k^kP/0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0m0?ooo`<00000?`3oool00540oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0400oooo0`00000B0?ooo`D000009@3oool00540
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo04<0
oooo0`00000=0?ooo`T000008`3oool00540oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0P0?ooo`030?l0003oool0oooo04H0oooo100000080?ooo`/000008P3oool00540oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo04X0oooo0`00
00040?ooo`d000008@3oool00540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo04d0oooo0`0000000`3oool000000000000;00000240oooo001A0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`1@0?oo
o`l00000803oool00540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo0500oooo3`00000P0?ooo`00D@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01l0oooo00<0o`000?ooo`3oool0D03oool?00000200oooo001A0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`1@0?ooo`l00000803o
ool00540oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo04/0oooo5000000P0?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01h0oooo00<0o`000?ooo`3oool0AP3oool5000000H0oooo3@00000Q0?ooo`00D03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0@@3oool5000000/0
oooo3@00000Q0?ooo`00D03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo
00<0o`000?ooo`3oool0?03oool500000140oooo2`00000R0?ooo`00D03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0=`3oool5000001L0oooo2@00
000S0?ooo`00D03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<0o`00
0?ooo`3oool0<P3oool5000001`0oooo00<000000?ooo`0000001000000U0?ooo`00D03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0;@3oool50000
0200oooo00<000000?ooo`3oool0:P3oool00500oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0L0?ooo`030?l0003oool0oooo02P0oooo1@00000T0?ooo`030000003oool0oooo02/0
oooo001@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`3o0000oooo
0?ooo`0S0?ooo`D00000:@3oool00`000000oooo0?ooo`0[0?ooo`00D03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool07P3oool5000002d0oooo00<0
00000?ooo`3oool0;03oool00500oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L
0?ooo`030?l0003oool0oooo01T0oooo1@00000a0?ooo`030000003oool0oooo02d0oooo001@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0D0?oo
o`D00000=P3oool00`000000oooo0?ooo`0]0?ooo`00D03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01/0oooo00<0o`000?ooo`3oool0403oool4000003X0oooo00<000000?ooo`3o
ool0;P3oool00500oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`030?l0
003oool0oooo00/0oooo1@00000m0?ooo`030000003oool0oooo02l0oooo001@0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`060?ooo`D00000@P3o
ool00`000000oooo0?ooo`0_0?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01X0oooo00@0o`000?ooo`3oool0oooo1@0000160?ooo`030000003oool0oooo0300oooo001@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`000000o`0000000002
000004X0oooo00<000000?ooo`3oool0<@3oool00500oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`D0000000<0oooo0?l0003oool0B`3oool00`000000oooo0?ooo`0b0?oo
o`00@`3oool200000003010@403oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`D000001P3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo0380
oooo00140?ooo`030000003oool0oooo00H0oooo1@00000A0?ooo`030000003oool0oooo00T0oooo
1@00000;0?ooo`030?l0003oool0oooo04T0oooo00<000000?ooo`3oool0<`3oool00400oooo1P00
00050?ooo`T000003`3oool00`000000oooo0?ooo`040?ooo`D00000403oool00`3o0000oooo0?oo
o`180?ooo`030000003oool0oooo03@0oooo00100?ooo`0507MgM`2YZJT0oooo0?ooo`0000001@3o
ool;000000h0oooo00<000000?ooo`0000001000000E0?ooo`030?l0003oool0oooo04P0oooo00<0
00000?ooo`3oool0=03oool00400oooo00D0k^k^038b<P3^k^h0oooo000000040?ooo`d000002P3o
ool5000001X0oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`0e0?ooo`00@@3oool0
102YZJT0IVIV0?ooo`0000040?ooo`d000001@3oool5000000@0oooo00<000000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo03H0oooo00120?ooo`0304A4A03<c<`0
000000<0oooo4`0000090?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0f0?ooo`00@P3oool00`3MgMd0A4A4000000030?ooo`l000003@3oool00`00
0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0=`3oool004<0
oooo00<0MgMg010@403oool00P3oool?000000d0oooo00<000000?ooo`3oool0603oool00`3o0000
oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00180?ooo`l000003P3oool00`000000oooo
0?ooo`0G0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool004P0oooo3`00
000>0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0i0?ooo`00B@3oool=000000l0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`12
0?ooo`030000003oool0oooo03X0oooo00190?ooo`d000003`3oool00`000000oooo0?ooo`0G0?oo
o`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0>P3oool004X0oooo2`00000A0?ooo`03
0000003oool0oooo01H0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0k0?ooo`00
B`3oool900000180oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`100?ooo`030000
003oool0oooo03`0oooo001=0?ooo`H000004`3oool00`000000oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo0400oooo00<000000?ooo`3oool0?03oool00580oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool0
05<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo
03h0oooo00<000000?ooo`3oool0?P3oool005<0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0E0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0?P3oool005@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo03d0oooo
00<000000?ooo`3oool0?`3oool005@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0E0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0@03oool005D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo03`0oooo00<00000
0?ooo`3oool0@03oool005D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0@@3oool005H0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3o
ool0@P3oool005H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool005L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0@`3o
ool005L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0
oooo03P0oooo00<000000?ooo`3oool0A03oool005L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0A03oool005P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo03L0
oooo00<000000?ooo`3oool0A@3oool005P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0AP3oool005T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo03H0oooo00<0
00000?ooo`3oool0AP3oool005T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool0A`3oool005X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo03@0oooo00<000000?oo
o`3oool0B03oool005X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo03<0oooo00<000000?ooo`3oool0B@3oool005/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0
B@3oool005/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0380oooo00<000000?ooo`3oool0BP3oool005`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0340oooo00<000000?ooo`3oool0B`3oool0
05`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo
0340oooo00<000000?ooo`3oool0B`3oool005`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool0C03oool005d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02l0oooo
00<000000?ooo`3oool0C@3oool005d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0C@3oool005h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo02h0oooo00<00000
0?ooo`3oool0CP3oool005h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?oo
o`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool0C`3oool005l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo02d0oooo00<000000?ooo`3o
ool0C`3oool005l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo02`0oooo00<000000?ooo`3oool0D03oool00600oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0D@3o
ool00600oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo02/0oooo00<000000?ooo`3oool0D@3oool00640oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0DP3oool00640
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02T0
oooo00<000000?ooo`3oool0D`3oool00680oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0D`3oool00680oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo02P0oooo00<0
00000?ooo`3oool0E03oool00680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0E@3oool006<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02L0oooo00<000000?oo
o`3oool0E@3oool006<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02H0oooo00<000000?ooo`3oool0EP3oool006@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0
E`3oool006@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02D0oooo00<000000?ooo`3oool0E`3oool006D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0F03oool0
06D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
02<0oooo00<000000?ooo`3oool0F@3oool006H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0F@3oool006H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0280oooo
00<000000?ooo`3oool0FP3oool006L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0F`3oool006L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0240oooo00<00000
0?ooo`3oool0F`3oool006L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo0200oooo00<000000?ooo`3oool0G03oool006P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3o
ool0G@3oool006P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030?l0
003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool006T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0GP3o
ool006T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0
oooo01d0oooo00<000000?ooo`3oool0G`3oool006X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool0H03oool006X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo01`0
oooo00<000000?ooo`3oool0H03oool006/0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0H@3oool006/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo01X0oooo00<0
00000?ooo`3oool0HP3oool006`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0HP3oool006`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo01T0oooo00<000000?oo
o`3oool0H`3oool006`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0?l0003oool0oooo01P0oooo00<000000?ooo`3oool0I03oool006d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0
I03oool006d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030?l0003o
ool0oooo01L0oooo00<000000?ooo`3oool0I@3oool006h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0IP3oool0
06h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo
01H0oooo00<000000?ooo`3oool0IP3oool006l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool0I`3oool006l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo01@0oooo
00<000000?ooo`3oool0J03oool00700oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0J03oool00700oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01<0oooo00<00000
0?ooo`3oool0J@3oool00740oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0JP3oool00740oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3o
ool0JP3oool00780oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo0140oooo00<000000?ooo`3oool0J`3oool00780oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0100oooo00<000000?ooo`3oool0K03o
ool00780oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0
oooo0100oooo00<000000?ooo`3oool0K03oool007<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool0K@3oool007<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0
oooo00<000000?ooo`3oool0KP3oool007@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0KP3oool007@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00<0
00000?ooo`3oool0K`3oool007D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030?l0003o
ool0oooo00`0oooo00<000000?ooo`3oool0L03oool007D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0L03oool0
07H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030?l0003oool0oooo00/0oooo00<00000
0?ooo`3oool0L@3oool007H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030?l0003oool0
oooo00X0oooo00<000000?ooo`3oool0LP3oool007L0oooo00@000000?ooo`3oool00000103oool0
0`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo0780oooo001g0?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo07<0oooo001g0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0
oooo07@0oooo001h0?ooo`040000003oool0oooo000000<0oooo00<0o`000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1e0?ooo`00N03oool010000000oooo0?ooo`0000030?ooo`030?l0003oool0
oooo00L0oooo00<000000?ooo`3oool0M@3oool007T0oooo00@000000?ooo`3oool000000P3oool0
0`3o0000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo001i0?ooo`040000003oool0oooo
00000080oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`00NP3oool00`00
0000oooo000000020?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool007X0
oooo00<000000?ooo`0000000P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo07P0
oooo001k0?ooo`050000003oool000000?ooo`3o00001@3oool00`000000oooo0?ooo`1i0?ooo`00
N`3oool01@000000oooo0000003oool0o`0000D0oooo00<000000?ooo`3oool0N@3oool007`0oooo
1P0000020?ooo`030000003oool0oooo07X0oooo001k0?ooo`T00000O@3oool007X0oooo2`00001l
0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007P0oooo3`00001j0?ooo`00N03o
ool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0
oooo001i0?ooo`d00000N`3oool007T0oooo3@00001k0?ooo`00NP3oool;000007`0oooo001k0?oo
o`T00000O@3oool007d0oooo1@00001o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o
0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo
0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o
0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
O@3oool400000003010@403oool0oooo07d0oooo001o0?ooo`030000003oool0oooo07l0oooo001o
0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`03
0000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003o
ool0oooo07l0oooo001m0?ooo`0300000014A4@000000840oooo001m0?ooo`030<c<c01EEED00000
0840oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.2826 .53078 Mdot
.5 Mabswid
[ ] 0 setdash
.2826 .53078 m
.36145 .26022 L
s
.83762 .44499 m
.2826 .53078 L
s
.4958 .947 m
.2826 .53078 L
s
15 Mabswid
.83762 .44499 Mdot
.5 Mabswid
.83762 .44499 m
.36145 .26022 L
s
.4958 .947 m
.83762 .44499 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.36145 .26022 L
s
15 Mabswid
.36145 .26022 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.93527 .39499 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.3171 .14058 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.22648 .50709 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00CP3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kZd0oooo001>0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8b[@3oool005<0
oooo00<000000?ooo`3oool0Z`3oool00580oooo00<0MgMg024Q8@3oool0[03oool00500oooo00@0
8B4Q000000000000^[Zj[@3oool00540oooo00<0k^k^07MgM`0b<S80[@3oool005<0oooo00<00000
0?ooo`3oool0Z`3oool004h0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S:]0?ooo`00CP3oool0
1P2j^[X0A4A4000000000000A4A40>k^kZd0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001J0?oo
o`D00000XP3oool005P0oooo2@00002P0?ooo`00E`3oool;000009l0oooo001F0?ooo`d00000WP3o
ool005H0oooo3@00002N0?ooo`00E@3oool?000009d0oooo001E0?ooo`l00000W@3oool005D0oooo
3`00002M0?ooo`00E@3oool?000009d0oooo001E0?ooo`l00000W@3oool005H0oooo4000002K0?oo
o`00EP3oool=000000<0oooo0`00002H0?ooo`00E`3oool;000000L0oooo0P00002F0?ooo`00F03o
ool9000000X0oooo0`00002C0?ooo`00FP3oool5000000l0oooo0P00002A0?ooo`00FP3oool01000
0000oooo0?ooo`00000B0?ooo`<00000SP3oool005X0oooo00D000000?ooo`3oool0oooo0000000D
0?ooo`800000S03oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?oo
o`<00000R@3oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`80
0000Q`3oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`<00000
Q03oool005P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`<00000P@3o
ool005P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`800000O`3oool0
05P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`<00000O03oool005P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`800000NP3oool005L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`<00000M`3oool005L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`800000M@3oool005L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`<00000LP3oool005H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0/0?ooo`<00000K`3oool005H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0_0?ooo`800000K@3oool005H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0a0?ooo`<00000JP3oool005H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0d0?ooo`800000J03oool005D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0e0?ooo`<00000I@3oool005D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0h0?ooo`800000H`3oool005D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0j0?ooo`<00000H03oool005@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0m0?ooo`800000GP3oool005@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`<00000F`3oool005@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`11
0?ooo`<00000F03oool005@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`140?oo
o`800000EP3oool005<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`160?ooo`<0
0000D`3oool005<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`190?ooo`800000
?@3oool6000000h0oooo001C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B`3o
ool3000003X0oooo00<0V9RH0000003<c<`00P3oool00`0@4100oooo0?ooo`0<0?ooo`00DP3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04d0oooo0P00000i0?ooo`0309RHV0000000
c<c<0100oooo001B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0c0?ooo`<00000=`3oool00`2YZJT0410@0<c<c00?0?ooo`00DP3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0=P3oool3000003D0
oooo00<0c<c<010@403<c<`03P3oool00580oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0I0?ooo`030?l0003oool0oooo03T0oooo0P00000d0?ooo`030:VYZ@0b<S80oooo00d0oooo
001A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0k0?ooo`<00000<P3oool00`000000oooo0?ooo`0<0?ooo`00D@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0?P3oool2000002/0oooo00H00000
08N7Q`3^k^h0oooo07MgM`0b<S8>0?ooo`00D@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01P0oooo00<0o`000?ooo`3oool0@03oool3000002P0oooo00H0ZJVY038b<P0000000000
05EEE@3^k^h>0?ooo`00D03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0@`3oool2000000h0oooo1@00000W0?ooo`00D03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0A@3oool3000000T0oooo2@00
000U0?ooo`00D03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<0o`00
0?ooo`3oool0B03oool2000000H0oooo2`00000T0?ooo`00D03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0BP3oool300000080oooo3@00000S0?oo
o`00C`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3o
ool0C@3oool?000002<0oooo001?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`1>0?ooo`l000008P3oool004l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo04h0oooo3`00000R0?ooo`00CP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0CP3oool?
00000280oooo001>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`1;0?oooa8000008P3oool004h0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo04D0oooo1P0000030?ooo`l000008P3oool004h0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo03h0oooo
1`00000:0?ooo`d000008`3oool004d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo03P0oooo1P00000A0?ooo`d000008`3oool004d0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0340oooo1`00000H
0?ooo`/00000903oool004d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo02/0oooo1P00000P0?ooo`T000009@3oool004`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02@0oooo1`00000V0?ooo`03
0000003oool0000000@000009`3oool004`0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo01h0oooo1P00000/0?ooo`030000003oool0oooo02`0oooo
001<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0G0?ooo`L00000<@3oool00`000000oooo0?ooo`0]0?ooo`00C03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool04@3oool6000003P0oooo00<00000
0?ooo`3oool0;@3oool004/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00X0oooo1`00000m0?ooo`030000003oool0oooo02h0oooo001;0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`040?ooo`H0
0000@`3oool00`000000oooo0?ooo`0_0?ooo`00>P3oool200000003010@403oool0oooo00`0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`030?l000000000000000@00000
B03oool00`000000oooo0?ooo`0`0?ooo`00>`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool03P3oool6000000030?l0003oool0oooo04`0oooo00<0
00000?ooo`3oool0<03oool003L0oooo1P0000090?ooo`D000007@3oool00`000000oooo0?ooo`07
0?ooo`L000001P3oool00`3o0000oooo0?ooo`1;0?ooo`030000003oool0oooo0340oooo000g0?oo
o`0507MgM`2YZJT0oooo0?ooo`000000203oool9000001`0oooo00<000000?ooo`3oool01P00000=
0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool0<P3oool003L0oooo00D0k^k^038b
<P3^k^h0oooo000000070?ooo`/000005`3oool7000001<0oooo00<0o`000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0b0?ooo`00>03oool0102YZJT0IVIV0?ooo`0000060?ooo`d00000403oool6
000000@0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0
oooo03<0oooo000i0?ooo`0304A4A03<c<`0000000H0oooo3@0000090?ooo`L000002P3oool00`00
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0=03oool003T0
oooo00<0gMgM04A4A00000001@3oool?00000080oooo1P00000A0?ooo`030000003oool0oooo01<0
oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0d0?ooo`00>P3oool00`1gMgL0410@
0?ooo`040?oooa400000603oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04L0oooo
00<000000?ooo`3oool0=@3oool00440oooo3`00000J0?ooo`030000003oool0oooo0180oooo00<0
o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0f0?ooo`00@@3oool?000001X0oooo00<00000
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo03H0oooo00110?oo
o`l000006P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04D0oooo00<000000?oo
o`3oool0=`3oool00480oooo3@00000K0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0h0?ooo`00@P3oool=000001`0oooo00<000000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00130?ooo`/000007@3o
ool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0>@3o
ool004@0oooo2@00000N0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0j0?ooo`00AP3oool6000001l0oooo00<000000?ooo`3oool04@3oool00`3o
0000oooo0?ooo`120?ooo`030000003oool0oooo03X0oooo001<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo03/0
oooo001<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`3o0000oooo
0?ooo`100?ooo`030000003oool0oooo03`0oooo001=0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0403oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo03`0oooo001=
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0o
0?ooo`030000003oool0oooo03d0oooo001>0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0403oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo001>0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0m0?ooo`03
0000003oool0oooo03l0oooo001?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo03l0oooo001?0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0400oooo001@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo001@0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo
0440oooo001A0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo001B0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04<0oooo
001B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0i0?ooo`030000003oool0oooo04<0oooo001C0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo04@0oooo001C0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0g0?oo
o`030000003oool0oooo04D0oooo001D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0g0?ooo`030000003oool0oooo04D0oooo001D0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0f0?ooo`030000
003oool0oooo04H0oooo001E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo04L0oooo001E0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0
oooo04L0oooo001F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0d0?ooo`030000003oool0oooo04P0oooo001F0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo04T0
oooo001G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0c0?ooo`030000003oool0oooo04T0oooo001G0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0303oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo04X0oooo001H
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0a
0?ooo`030000003oool0oooo04/0oooo001H0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0303oool00`3o0000oooo0?ooo`0a0?ooo`030000003oool0oooo04/0oooo001I0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0`0?ooo`03
0000003oool0oooo04`0oooo001I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
303oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo04d0oooo001J0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0^0?ooo`030000003o
ool0oooo04h0oooo001J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo04h0oooo001K0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo
04l0oooo001K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo001L0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo
001L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0[0?ooo`030000003oool0oooo0540oooo001M0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo001M0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0580oooo001N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo05<0oooo001N0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0X0?ooo`030000
003oool0oooo05@0oooo001O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0
oooo05D0oooo001P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0V0?ooo`030000003oool0oooo05H0oooo001P0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo05H0
oooo001Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0U0?ooo`030000003oool0oooo05L0oooo001Q0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo001R
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0T
0?ooo`030000003oool0oooo05P0oooo001R0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001S0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`03
0000003oool0oooo05X0oooo001T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo05/0oooo001T0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo05/0oooo001U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo05`0oooo001U0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo
05d0oooo001V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo001V0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo
001W0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0M0?ooo`030000003oool0oooo05l0oooo001W0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo05l0oooo001X0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0L0?oo
o`030000003oool0oooo0600oooo001X0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo001Y0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`030000
003oool0oooo0640oooo001Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0680oooo001Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0
oooo06<0oooo001Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo001[0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo06@0
oooo001[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0G0?ooo`030000003oool0oooo06D0oooo001/0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo06D0oooo001/
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0F
0?ooo`030000003oool0oooo06H0oooo001]0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo001]0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0E0?ooo`03
0000003oool0oooo06L0oooo001^0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo001^0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030000003o
ool0oooo06T0oooo001_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo
06X0oooo001`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001`0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0oooo
001a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0oooo001b0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?oo
o`030000003oool0oooo06h0oooo001b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0oooo001c0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`030000
003oool0oooo06l0oooo001c0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
0?l0000>0?ooo`030000003oool0oooo0700oooo001d0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0?l0000>0?ooo`030000003oool0oooo0700oooo001d0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0?l0000=0?ooo`030000003oool0oooo0740oooo
001e0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0?l0000<0?ooo`030000
003oool0oooo0780oooo001e0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
0?l0000<0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0o`002`3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?l000X0oooo00<000000?ooo`3oool0M03oool007L0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3o000:0?ooo`030000003oool0oooo07@0oooo
001h0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo07D0oooo001h0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`3o0000oooo
0?ooo`060?ooo`030000003oool0oooo07H0oooo001i0?ooo`070000003oool0oooo0?ooo`000000
oooo0?l000080?ooo`030000003oool0oooo07H0oooo001i0?ooo`070000003oool0oooo0?ooo`00
0000oooo0?l000070?ooo`030000003oool0oooo07L0oooo001j0?ooo`060000003oool0oooo0000
003oool0o`001P3oool00`000000oooo0?ooo`1h0?ooo`00NP3oool01P000000oooo0?ooo`000000
oooo0?l000D0oooo00<000000?ooo`3oool0N@3oool007/0oooo00D000000?ooo`000000oooo0?l0
00050?ooo`030000003oool0oooo07T0oooo001k0?ooo`030000003oool0000000@000000P3oool0
0`000000oooo0?ooo`1j0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo
3@00001k0?ooo`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?oo
o`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=
000007/0oooo001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo
001m0?ooo`D00000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?oo
o`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0
O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool0
07l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo10000000
0`0@4100oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000
oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?oo
o`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?oo
o`00O@3oool00`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.25592 .52134 Mdot
.5 Mabswid
[ ] 0 setdash
.25592 .52134 m
.40038 .25422 L
s
.82591 .46012 m
.25592 .52134 L
s
.4958 .947 m
.25592 .52134 L
s
15 Mabswid
.82591 .46012 Mdot
.5 Mabswid
.82591 .46012 m
.40038 .25422 L
s
.4958 .947 m
.82591 .46012 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.40038 .25422 L
s
15 Mabswid
.40038 .25422 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.919 .41502 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.36881 .13201 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.19222 .49494 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00F`3oool01P2YZJT08B4Q000000000000EEEE0>k^kZ00oooo001K0?oo
o`06010@402j^[X0oooo0?ooo`2YZJT0<S8bX03oool00600oooo00<000000?ooo`3oool0WP3oool0
05l0oooo00<0MgMg024Q8@3oool0W`3oool005d0oooo00@08B4Q000000000000^[ZjX03oool005h0
oooo00<0k^k^07MgM`0b<S80X03oool00600oooo00<000000?ooo`3oool0WP3oool005/0oooo00H0
8B4Q0:VYZ@3oool0oooo06IVIP0b<S:P0?ooo`00F`3oool01P2j^[X0A4A4000000000000A4A40>k^
kZ00oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001T0?ooo`D00000V03oool0
0680oooo2@00002F0?ooo`00H@3oool;000009D0oooo001P0?ooo`d00000U03oool00600oooo3@00
002D0?ooo`00G`3oool?000009<0oooo001O0?ooo`l00000T`3oool005l0oooo3`00002C0?ooo`00
G`3oool?000009<0oooo001O0?ooo`l00000T`3oool00600oooo3P00002C0?ooo`00H03oool=0000
00030?ooo`00000000000940oooo001Q0?ooo`/00000103oool2000008l0oooo001R0?ooo`T00000
1`3oool2000008d0oooo001S0?ooo`H000002`3oool3000008X0oooo001R0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool2000008P0oooo001Q0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03`3oool2000008H0oooo001Q0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool2000008@0oooo001P0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04`3oool200000880oooo001P0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0503oool200000800oooo001O0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05P3oool2000007h0oooo001O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0603oool2000007`0oooo001N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06P3oool2000007X0oooo001N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
703oool2000007P0oooo001M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3o
ool2000007H0oooo001M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool2
000007@0oooo001L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool20000
0780oooo001L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool3000006l0
oooo001K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool2000006d0oooo
001J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:03oool2000006/0oooo001J
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool2000006T0oooo001I0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;03oool2000006L0oooo001I0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0;P3oool2000006D0oooo001H0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool2000006<0oooo001H0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<@3oool200000640oooo001G0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0<`3oool2000005l0oooo001G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0=@3oool2000005d0oooo001F0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0=`3oool2000005/0oooo001F0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0>@3oool2000005T0oooo001E0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0>`3oool2000005L0oooo001E0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?03oool3000005@0oooo001D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0?`3oool200000580oooo001C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0@@3oool200000500oooo001C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0_0?ooo`800000CP3oool00580oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0340oooo0P00001<0?ooo`00DP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0<`3oool2
00000380oooo1P00000B0?ooo`00D@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0140oooo00<0o`000?ooo`3oool0=@3oool200000300oooo00<0V9RH0000003<c<`00P3oool00`0@
4100oooo0?ooo`0@0?ooo`00D@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0100
oooo00<0o`000?ooo`3oool0=`3oool2000002l0oooo00<0V9RH0000003<c<`0503oool00500oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo03T0oooo
0P00000^0?ooo`030:VYZ@0@4100c<c<01<0oooo001@0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0403oool00`3o0000oooo0?ooo`0k0?ooo`800000;@3oool00`3<c<`0410@0<c<
c00B0?ooo`00C`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo00<0o`00
0?ooo`3oool0?@3oool2000002`0oooo00<0ZJVY038b<P3oool04@3oool004l0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo03l0oooo0P00000[0?oo
o`030000003oool0oooo0100oooo001>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0403oool00`3o0000oooo0?ooo`110?ooo`800000903oool01P000000QhN70>k^kP3oool0MgMg
038b<Q80oooo001>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`3o
0000oooo0?ooo`130?ooo`<000002P3oool500000180oooo00H0ZJVY038b<P000000000005EEE@3^
k^hB0?ooo`00C@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0o`00
0?ooo`3oool0AP3oool2000000H0oooo2@00000X0?ooo`00C@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0B03oool2000000<0oooo2`00000W0?oo
o`00C03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3o
ool0BP3oool?000002H0oooo001;0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`1<0?ooo`d000009P3oool004/0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo04/0oooo3`00000U0?ooo`00BP3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0B`3oool?
000002D0oooo001:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`1;0?ooo`l000009@3oool004T0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo04@0oooo5P00000U0?ooo`00B@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0>`3oool9000000L0oooo
3`00000U0?ooo`00B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo00<0
o`000?ooo`3oool0<P3oool900000140oooo3@00000V0?ooo`00B03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0:@3oool9000001X0oooo3@00000V
0?ooo`00A`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<0o`000?oo
o`3oool07`3oool:000002@0oooo2`00000W0?ooo`00<@3oool200000003010@403oool0oooo0140
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01H0
oooo2@00000_0?ooo`T00000:03oool00380oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool9000003P0oooo
00<000000?ooo`0000001000000Z0?ooo`00;P3oool600000180oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo2@0000100?ooo`030000003o
ool0oooo02l0oooo000^0?ooo`0507MgM`2YZJT0oooo0?ooo`000000303oool5000000030?ooo`00
0000oooo02P0oooo00<000000?ooo`3oool02`3oool2000000030?l000000000000000@00000B03o
ool00`000000oooo0?ooo`0`0?ooo`00;P3oool01@3^k^h0<S8b0>k^kP3oool0000000X0oooo2@00
000Y0?ooo`030000003oool0oooo0080oooo2@0000020?ooo`030?l0003oool0oooo04`0oooo00<0
00000?ooo`3oool0<03oool002l0oooo00@0ZJVY06IVIP3oool000002@3oool;000002<0oooo2P00
000;0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0<@3oool00300oooo00<0A4A4
0<c<c0000000203oool=000001T0oooo2@0000050?ooo`030000003oool0oooo00d0oooo00<0o`00
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0b0?ooo`00<03oool00`3MgMd0A4A4000000080?oo
o`d00000403oool9000000h0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`190?oo
o`030000003oool0oooo03<0oooo000a0?ooo`0307MgM`0@4100oooo00H0oooo3`0000060?ooo`T0
00005`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo04T0oooo00<000000?ooo`3o
ool0<`3oool003X0oooo5@00000P0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0
B03oool00`000000oooo0?ooo`0d0?ooo`00>P3oool?000002L0oooo00<000000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo03D0oooo000j0?ooo`l000009`3oool0
0`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool0=@3oool0
03X0oooo3`00000W0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0f0?ooo`00>`3oool=000002P0oooo00<000000?ooo`3oool0303oool00`3o0000
oooo0?ooo`150?ooo`030000003oool0oooo03L0oooo000k0?ooo`d00000:03oool00`000000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0=`3oool003`0oooo2`00
000Y0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?oo
o`0h0?ooo`00?@3oool9000002X0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`13
0?ooo`030000003oool0oooo03T0oooo000o0?ooo`D0000000<0oooo0000003oool0:P3oool00`00
0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0>@3oool004D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0480
oooo00<000000?ooo`3oool0>P3oool004H0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0;0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0>`3oool004H0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0440oooo00<0
00000?ooo`3oool0>`3oool004L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0?03oool004P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo03l0oooo00<000000?oo
o`3oool0?@3oool004P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool004T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0
?P3oool004T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo03d0oooo00<000000?ooo`3oool0?`3oool004X0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0?`3oool0
04X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
03`0oooo00<000000?ooo`3oool0@03oool004/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0@@3oool004`0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo03/0oooo
00<000000?ooo`3oool0@@3oool004`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool004d0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo03T0oooo00<00000
0?ooo`3oool0@`3oool004d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?oo
o`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0A03oool004h0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3o
ool0A03oool004h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?ooo`030?l0
003oool0oooo03L0oooo00<000000?ooo`3oool0A@3oool004l0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0AP3o
ool00500oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`090?ooo`030?l0003oool0
oooo03H0oooo00<000000?ooo`3oool0AP3oool00500oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool0A`3oool00540
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo03@0
oooo00<000000?ooo`3oool0B03oool00540oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`080?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0B03oool00580oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo03<0oooo00<0
00000?ooo`3oool0B@3oool00580oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0BP3oool005<0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0380oooo00<000000?oo
o`3oool0BP3oool005<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0340oooo00<000000?ooo`3oool0B`3oool005@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool0
C03oool005D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`030?l0003o
ool0oooo0300oooo00<000000?ooo`3oool0C03oool005D0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0C@3oool0
05H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo
02h0oooo00<000000?ooo`3oool0CP3oool005H0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`070?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0CP3oool005L0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02d0oooo
00<000000?ooo`3oool0C`3oool005L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`070?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0D03oool005P0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02`0oooo00<00000
0?ooo`3oool0D03oool005T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?oo
o`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0D@3oool005T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3o
ool0DP3oool005X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030?l0
003oool0oooo02X0oooo00<000000?ooo`3oool0DP3oool005X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0D`3o
ool005/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030?l0003oool0
oooo02P0oooo00<000000?ooo`3oool0E03oool005/0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`060?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0E@3oool005`0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo02L0
oooo00<000000?ooo`3oool0E@3oool005d0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0EP3oool005d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo02D0oooo00<0
00000?ooo`3oool0E`3oool005h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0E`3oool005h0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<000000?oo
o`3oool0F03oool005l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`03
0?l0003oool0oooo02<0oooo00<000000?ooo`3oool0F@3oool005l0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0
F@3oool00600oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0280oooo00<000000?ooo`3oool0FP3oool00640oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0F`3oool0
0640oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo
0240oooo00<000000?ooo`3oool0F`3oool00680oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool0G03oool00680oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01l0oooo
00<000000?ooo`3oool0G@3oool006<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0G@3oool006<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01h0oooo00<00000
0?ooo`3oool0GP3oool006@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo01d0oooo00<000000?ooo`3oool0G`3oool006D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01d0oooo00<000000?ooo`3o
ool0G`3oool006D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo01`0oooo00<000000?ooo`3oool0H03oool006H0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0H@3o
ool006H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo01/0oooo00<000000?ooo`3oool0H@3oool006L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`030?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0HP3oool006L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01T0
oooo00<000000?ooo`3oool0H`3oool006P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`030?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0H`3oool006T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01P0oooo00<0
00000?ooo`3oool0I03oool006T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0I@3oool006X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo01H0oooo00<000000?oo
o`3oool0IP3oool006X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`03
0?l0003oool0oooo01H0oooo00<000000?ooo`3oool0IP3oool006/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool0
I`3oool006/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo01@0oooo00<000000?ooo`3oool0J03oool006`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0J03oool0
06d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo
01<0oooo00<000000?ooo`3oool0J@3oool006d0oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool0o`0001@0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool0o`0001@0oooo00<000000?ooo`3oool0JP3oool006h0
oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0o`0001<0oooo00<000000?oo
o`3oool0J`3oool006l0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0o`00
0180oooo00<000000?ooo`3oool0K03oool006l0oooo00<000000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool0o`000180oooo00<000000?ooo`3oool0K03oool00700oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool0o`000140oooo00<000000?ooo`3oool0K@3oool00700
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0o`000100oooo00<000000?oo
o`3oool0KP3oool00740oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3o000@0?oo
o`030000003oool0oooo06h0oooo001b0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool0o`003`3oool00`000000oooo0?ooo`1_0?ooo`00LP3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo0?l000h0oooo00<000000?ooo`3oool0L03oool007<0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`3o000>0?ooo`030000003oool0oooo0700oooo001c0?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool0o`003@3oool00`000000oooo0?ooo`1a0?oo
o`00M03oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?l000`0oooo00<000000?oo
o`3oool0LP3oool007@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3o000<0?oo
o`030000003oool0oooo0780oooo001e0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
00002`3oool00`000000oooo0?ooo`1c0?ooo`00MP3oool00`000000oooo0?ooo`040?ooo`030000
003oool0o`0000X0oooo00<000000?ooo`3oool0M03oool007H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?l0000:0?ooo`030000003oool0oooo07@0oooo001g0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3o00002@3oool00`000000oooo0?ooo`1e0?ooo`00M`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0o`0000P0oooo00<000000?ooo`3oool0MP3oool007P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?l000070?ooo`030000003oool0oooo07L0
oooo001h0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o00001`3oool00`000000oooo
0?ooo`1g0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000003o0000oooo00D0oooo00<0
00000?ooo`3oool0N03oool007X0oooo00H000000?ooo`3oool0oooo0000003o00050?ooo`030000
003oool0oooo07T0oooo001j0?ooo`060000003oool0oooo0?ooo`000000o`001@3oool00`000000
oooo0?ooo`1i0?ooo`00N`3oool00`000000oooo0000000400000080oooo00<000000?ooo`3oool0
NP3oool007/0oooo2@00001m0?ooo`00NP3oool;000007`0oooo001i0?ooo`d00000N`3oool007T0
oooo3@00001k0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j
0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007T0oooo3@00001k0?ooo`00N@3o
ool=000007/0oooo001j0?ooo`/00000O03oool007/0oooo2@00001m0?ooo`00O@3oool5000007l0
oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o
0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`03
0?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003o
ool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo
07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001m0?ooo`@0000000<0410@0?ooo`3oool0
O@3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool0
07l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo
00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007d0oooo00<00000
04A4A0000000P@3oool007d0oooo00<0c<c<05EEE@000000P@3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00001\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.23132 .51073 Mdot
.5 Mabswid
[ ] 0 setdash
.23132 .51073 m
.44068 .25021 L
s
.81093 .47452 m
.23132 .51073 L
s
.4958 .947 m
.23132 .51073 L
s
15 Mabswid
.81093 .47452 Mdot
.5 Mabswid
.81093 .47452 m
.44068 .25021 L
s
.4958 .947 m
.81093 .47452 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.44068 .25021 L
s
15 Mabswid
.44068 .25021 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.8987 .43399 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.4225 .12627 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.16039 .48122 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00J@3oool0
1P2YZJT08B4Q000000000000EEEE0>k^kY80oooo001Y0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8bTP3oool006h0oooo00<000000?ooo`3oool0T03oool006d0oooo00<0MgMg024Q8@3oool0T@3o
ool006/0oooo00@08B4Q000000000000^[ZjTP3oool006`0oooo00<0k^k^07MgM`0b<S80TP3oool0
06h0oooo00<000000?ooo`3oool0T03oool006T0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S:B
0?ooo`00J@3oool01P2j^[X0A4A4000000000000A4A40>k^kY80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001_0?ooo`D00000S@3oool006d0oooo2@00002;
0?ooo`00K03oool;000008X0oooo001[0?ooo`d00000R@3oool006/0oooo3@0000290?ooo`00JP3o
ool?000008P0oooo001Z0?ooo`l00000R03oool006X0oooo3`0000280?ooo`00JP3oool?000008P0
oooo001Z0?ooo`l00000R03oool006/0oooo3@0000290?ooo`00J`3oool>000008P0oooo001/0?oo
o`/000000P3oool2000008H0oooo001]0?ooo`T000001@3oool2000008@0oooo001/0?ooo`030000
003oool0oooo00D000002@3oool00`000000oooo0?ooo`210?ooo`00J`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo0P0000210?ooo`00JP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo0P00001o0?ooo`00J@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool006T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0>0?ooo`800000O03oool006P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001W0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool2000007T0oooo001V0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04`3oool2000007L0oooo001U0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1d0?ooo`00I@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo0P00001d0?ooo`00I03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01P0oooo0P00001b0?ooo`00H`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K`3oool00680oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`800000K`3oool00640oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`800000K@3oool00600oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06X0oooo001P0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool07`3oool2000006X0oooo001O0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1W0?ooo`00GP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo0P00001W0?ooo`00G@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo0P00001U0?ooo`00G03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0HP3oool005`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0W0?ooo`800000HP3oool005/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`800000H03oool005X0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05d0oooo001I0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;03oool2000005d0oooo001H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0;P3oool2000005/0oooo001H0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1H0?ooo`00E`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0300oooo0P00001H0?ooo`00EP3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0380oooo0P00001F0?ooo`00E@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0D`3oool005@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`800000D`3oool005@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo02`0oooo
00<000000?ooo`3oool0D03oool005<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`080?ooo`030?l0003oool0oooo02d0oooo0P00001@0?ooo`00DP3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0;`3oool2000004h0oooo001A0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0a0?oo
o`030000003oool0oooo04/0oooo001@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0b0?ooo`800000B`3oool00500oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo03@0oooo0P0000190?ooo`00C`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`160?ooo`00CP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00P0oooo00<0o`000?ooo`3oool0=`3oool2000002P0oooo1P00000H0?ooo`00C@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0>@3oool20000
02H0oooo00<0V9RH0000003<c<`00P3oool00`0@4100oooo0?ooo`0F0?ooo`00C03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0T0?ooo`0309RHV0000000c<c<01X0oooo001<0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0l0?ooo`8000009@3oool00`2YZJT0410@
0<c<c00I0?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<0
o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0S0?ooo`030<c<c00@4100c<c<01P0oooo001:
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0o
0?ooo`800000903oool00`2YZJT0<S8b0?ooo`0G0?ooo`00B@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0@@3oool2000002<0oooo00<000000?oo
o`3oool05P3oool004P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`03
0?l0003oool0oooo04<0oooo00<000000?ooo`3oool01P3oool500000100oooo00H0000008N7Q`3^
k^h0oooo07MgM`0b<S8H0?ooo`00A`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00L0oooo00<0o`000?ooo`3oool0A03oool2000000@0oooo2@00000>0?ooo`060:VYZ@0b<S800000
0000001EEED0k^k^603oool004L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`07
0?ooo`030?l0003oool0oooo04H0oooo0P0000000`3oool0000000000009000002/0oooo00160?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`180?oo
o`d00000:P3oool004D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`03
0?l0003oool0oooo04P0oooo3@00000Z0?ooo`00:@3oool200000003010@403oool0oooo01H0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo04L0oooo
3`00000Y0?ooo`00:P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool01`3oool00`3o0000oooo0?ooo`170?ooo`l00000:@3oool002H0oooo1P00000G
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`16
0?oooa000000:@3oool002H0oooo00D0MgMg0:VYZ@3oool0oooo0000000G0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0e0?oooa40000000<0oooo
0000000000003@00000Y0?ooo`009P3oool01@3^k^h0<S8b0>k^kP3oool0000000h0oooo1@000003
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0U
0?oooa0000004P3oool?000002T0oooo000W0?ooo`040:VYZ@1VIVH0oooo000000`0oooo2P00000e
0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0503ooolA000002<0oooo3@00000Z
0?ooo`00:03oool00`14A4@0c<c<0000000;0?ooo`/00000=@3oool00`000000oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo4@00000d0?ooo`d00000:P3oool002P0oooo00<0gMgM04A4A000
00002P3oool=000003<0oooo2P0000000`3o0000000000000003000004H0oooo2`00000[0?ooo`00
:@3oool00`1gMgL0410@0?ooo`090?ooo`d000008P3ooolA000000030?ooo`000000oooo00L0oooo
00<0o`000?ooo`3oool0BP3oool9000002`0oooo000d0?ooo`l000004@3oool@00000180oooo00<0
00000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0000000@00000;P3o
ool003@0oooo8000000R0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0c0?ooo`00=03oool?000003<0oooo00<000000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`180?ooo`030000003oool0oooo03@0oooo000d0?ooo`l00000<`3oool00`000000
oooo0?ooo`060?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0=03oool003@0oooo
3`00000c0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo
0?ooo`0e0?ooo`00=@3oool=000003@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`160?ooo`030000003oool0oooo03H0oooo000e0?ooo`d00000=@3oool00`000000oooo0?ooo`05
0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool0=P3oool003H0oooo2`00000f0?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0g0?oo
o`00=`3oool9000003L0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`140?ooo`03
0000003oool0oooo03P0oooo000i0?ooo`D0000000<0oooo0000003oool0=P3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool00400oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo04<0oooo00<0
00000?ooo`3oool0>@3oool00400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`05
0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0>P3oool00440oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0480oooo00<000000?oo
o`3oool0>P3oool00440oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`050?ooo`03
0?l0003oool0oooo0440oooo00<000000?ooo`3oool0>`3oool00480oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0
?03oool004<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0400oooo00<000000?ooo`3oool0?03oool004<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`050?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool0
04@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo
03h0oooo00<000000?ooo`3oool0?P3oool004@0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`050?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0?P3oool004D0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03d0oooo
00<000000?ooo`3oool0?`3oool004H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0@03oool004H0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03`0oooo00<00000
0?ooo`3oool0@03oool004L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0@@3oool004L0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3o
ool0@P3oool004P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool004T0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0@`3o
ool004T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`030?l0003oool0
oooo03P0oooo00<000000?ooo`3oool0A03oool004X0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0A03oool004X0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03L0
oooo00<000000?ooo`3oool0A@3oool004/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0AP3oool004`0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo03H0oooo00<0
00000?ooo`3oool0AP3oool004`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`04
0?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool0A`3oool004d0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo03@0oooo00<000000?oo
o`3oool0B03oool004h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`03
0?l0003oool0oooo03@0oooo00<000000?ooo`3oool0B03oool004h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0
B@3oool004l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0380oooo00<000000?ooo`3oool0BP3oool004l0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0BP3oool0
0500oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
0340oooo00<000000?ooo`3oool0B`3oool00540oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`030?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool0C03oool00540oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0300oooo
00<000000?ooo`3oool0C03oool00580oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`030?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0C@3oool00580oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo02h0oooo00<00000
0?ooo`3oool0CP3oool005<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?oo
o`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0CP3oool005@0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo02d0oooo00<000000?ooo`3o
ool0C`3oool005@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo02`0oooo00<000000?ooo`3oool0D03oool005D0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0D03o
ool005D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0
oooo02/0oooo00<000000?ooo`3oool0D@3oool005H0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`020?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0DP3oool005L0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02X0
oooo00<000000?ooo`3oool0DP3oool005L0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0D`3oool005P0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02P0oooo00<0
00000?ooo`3oool0E03oool005P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`3oool0E03oool005T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02L0oooo00<000000?oo
o`3oool0E@3oool005X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`03
0?l0003oool0oooo02H0oooo00<000000?ooo`3oool0EP3oool005X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0
E`3oool005/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo02D0oooo00<000000?ooo`3oool0E`3oool005/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0F03oool0
05`0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0o`0002D0oooo00<00000
0?ooo`3oool0F@3oool005d0oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0
o`0002D0oooo00<000000?ooo`3oool0F@3oool005d0oooo00<000000?ooo`3oool06`3oool01@00
0000oooo0?ooo`3oool0o`0002@0oooo00<000000?ooo`3oool0FP3oool005h0oooo00<000000?oo
o`3oool06P3oool01@000000oooo0?ooo`3oool0o`0002<0oooo00<000000?ooo`3oool0F`3oool0
05l0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0o`0002<0oooo00<00000
0?ooo`3oool0F`3oool005l0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0
o`000280oooo00<000000?ooo`3oool0G03oool00600oooo00<000000?ooo`3oool0603oool01@00
0000oooo0?ooo`3oool0o`000240oooo00<000000?ooo`3oool0G@3oool00600oooo00<000000?oo
o`3oool0603oool01@000000oooo0?ooo`3oool0o`000240oooo00<000000?ooo`3oool0G@3oool0
0640oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0o`000200oooo00<00000
0?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0
o`0001l0oooo00<000000?ooo`3oool0G`3oool00680oooo00<000000?ooo`3oool05P3oool01@00
0000oooo0?ooo`3oool0o`0001l0oooo00<000000?ooo`3oool0G`3oool006<0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool0o`0001h0oooo00<000000?ooo`3oool0H03oool0
06<0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0o`0001d0oooo00<00000
0?ooo`3oool0H@3oool006@0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`3o000M
0?ooo`030000003oool0oooo0640oooo001U0?ooo`030000003oool0oooo01@0oooo00@000000?oo
o`3oool0o`00703oool00`000000oooo0?ooo`1R0?ooo`00I@3oool00`000000oooo0?ooo`0D0?oo
o`040000003oool0oooo0?l001/0oooo00<000000?ooo`3oool0H`3oool006H0oooo00<000000?oo
o`3oool04`3oool010000000oooo0?ooo`3o000K0?ooo`030000003oool0oooo06<0oooo001V0?oo
o`030000003oool0oooo01<0oooo00@000000?ooo`3oool0o`006P3oool00`000000oooo0?ooo`1T
0?ooo`00I`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?l001T0oooo00<00000
0?ooo`3oool0I@3oool006P0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`3o000I
0?ooo`030000003oool0oooo06D0oooo001X0?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool0o`00603oool00`000000oooo0?ooo`1V0?ooo`00J@3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo0?l001L0oooo00<000000?ooo`3oool0I`3oool006T0oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`3o000G0?ooo`030000003oool0oooo06L0oooo001Z0?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool0o`005P3oool00`000000oooo0?ooo`1X
0?ooo`00J`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?l001D0oooo00<00000
0?ooo`3oool0J@3oool006/0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3o000E
0?ooo`030000003oool0oooo06T0oooo001/0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3o0000503oool00`000000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0o`0001<0oooo00<000000?ooo`3oool0J`3oool006d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?l0000C0?ooo`030000003oool0oooo06/0oooo001^0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3o00004P3oool00`000000oooo0?ooo`1/0?ooo`00KP3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0o`000140oooo00<000000?ooo`3oool0K@3oool0
06l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?l0000A0?ooo`030000003oool0oooo
06d0oooo001`0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o0000403oool00`000000
oooo0?ooo`1^0?ooo`00L03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0o`0000l0oooo
00<000000?ooo`3oool0K`3oool00740oooo00<000000?ooo`3oool02@3oool00`000000oooo0?l0
000?0?ooo`030000003oool0oooo06l0oooo001a0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3o00003P3oool00`000000oooo0?ooo`1`0?ooo`00LP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0o`0000d0oooo00<000000?ooo`3oool0L@3oool007<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?l0000=0?ooo`030000003oool0oooo0740oooo001c0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3o0000303oool00`000000oooo0?ooo`1b0?ooo`00M03o
ool00`000000oooo0?ooo`070?ooo`030000003o0000oooo00X0oooo00<000000?ooo`3oool0L`3o
ool007@0oooo00<000000?ooo`3oool01`3oool00`000000o`000?ooo`0:0?ooo`030000003oool0
oooo07<0oooo001e0?ooo`030000003oool0oooo00H0oooo00<000000?l0003oool02@3oool00`00
0000oooo0?ooo`1d0?ooo`00MP3oool00`000000oooo0?ooo`050?ooo`030000003o0000oooo00P0
oooo00<000000?ooo`3oool0M@3oool007H0oooo00<000000?ooo`3oool01@3oool00`000000o`00
0?ooo`080?ooo`030000003oool0oooo07D0oooo001g0?ooo`030000003oool0oooo00@0oooo00<0
00000?l0003oool01`3oool00`000000oooo0?ooo`1f0?ooo`00M`3oool00`000000oooo0?ooo`04
0?ooo`030000003o0000oooo00H0oooo00<000000?ooo`3oool0M`3oool007P0oooo00<000000?oo
o`3oool00`3oool00`000000o`000?ooo`060?ooo`030000003oool0oooo07L0oooo001i0?ooo`03
0000003oool0oooo0080oooo00<000000?l0003oool01@3oool00`000000oooo0?ooo`1h0?ooo`00
N@3oool00`000000oooo0?ooo`020?ooo`030000003o0000oooo00@0oooo00<000000?ooo`3oool0
N@3oool007X0oooo00H000000?ooo`3oool0oooo0000003o00050?ooo`030000003oool0oooo07T0
oooo001j0?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`1j0?ooo`00N`3o
ool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?ooo`00N@3oool=000007/0
oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?oo
o`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3o
ool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D00000O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0
oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo0?ooo`1m0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`00
0000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo
0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool00`000000A4A400000021
0?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.20906 .49901 Mdot
.5 Mabswid
[ ] 0 setdash
.20906 .49901 m
.48179 .24826 L
s
.79293 .48808 m
.20906 .49901 L
s
.4958 .947 m
.20906 .49901 L
s
15 Mabswid
.79293 .48808 Mdot
.5 Mabswid
.79293 .48808 m
.48179 .24826 L
s
.4958 .947 m
.79293 .48808 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.48179 .24826 L
s
15 Mabswid
.48179 .24826 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.87471 .45175 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47736 .12348 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.13134 .46601 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00M`3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kX@0oooo001g0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8bQ03oool007`0
oooo00<000000?ooo`3oool0PP3oool007/0oooo00<0MgMg024Q8@3oool0P`3oool007T0oooo00@0
8B4Q000000000000^[ZjQ03oool007X0oooo00<0k^k^07MgM`0b<S80Q03oool007`0oooo00<00000
0?ooo`3oool0PP3oool007L0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S:40?ooo`00M`3oool0
1P2j^[X0A4A4000000000000A4A40>k^kX@0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo001i0?ooo`D00000P`3oool007L0oooo2@0000210?ooo`00MP3oool;
00000800oooo001e0?ooo`d00000O`3oool007D0oooo3@00001o0?ooo`00M03oool?000007h0oooo
001d0?ooo`l00000OP3oool007@0oooo3`00001n0?ooo`00M03oool?000007h0oooo001d0?ooo`l0
0000OP3oool007D0oooo3@00001o0?ooo`00M@3oool=000007l0oooo001e0?ooo``0000000<0oooo
0000003oool0O@3oool007@0oooo00<000000?ooo`3oool02@0000030?ooo`030000003oool0oooo
07/0oooo001c0?ooo`030000003oool0oooo00<0oooo1@0000060?ooo`800000N`3oool00780oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07P0oooo
001a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1g0?ooo`00L03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo0P00001g
0?ooo`00K`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0M03oool006h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo07<0oooo001/0?ooo`8000003@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0780oooo001[0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool200000780oooo001Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1_0?ooo`00J@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0KP3oool006P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0C0?ooo`800000KP3oool006L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo06/0oooo001V0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1Z0?ooo`00I@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0J@3oool006@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0H0?ooo`800000J@3oool006<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06H0oooo001R0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1U0?ooo`00H@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo0P00001U0?ooo`00H03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0HP3oool0
05h0oooo0P00000L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0H@3oool005d0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0600
oooo001L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool200000600oooo
001K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1M0?ooo`00FP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0G03oool005T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0T0?oo
o`800000G03oool005P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo05T0oooo001G0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1H0?ooo`00EP3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02P0oooo0P00001H0?ooo`00E@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0E@3oool005@0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo05@0oooo001C0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1C0?ooo`00DP3oool00`000000oooo
0?ooo`0W0?ooo`040000003oool0oooo0?l002`0oooo0P00001C0?ooo`00D03oool2000002X0oooo
00@000000?ooo`3oool0o`00;P3oool00`000000oooo0?ooo`1@0?ooo`00C`3oool00`000000oooo
0?ooo`0Z0?ooo`040000003oool0oooo0?l002l0oooo00<000000?ooo`3oool0C`3oool004h0oooo
00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`3o000`0?ooo`800000C`3oool004d0oooo
00<000000?ooo`3oool0;03oool010000000oooo0?ooo`3o000b0?ooo`030000003oool0oooo04`0
oooo001<0?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool0o`00<`3oool00`000000
oooo0?ooo`1;0?ooo`00B`3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo0?l003@0
oooo00<000000?ooo`3oool0BP3oool004X0oooo00<000000?ooo`3oool0;`3oool010000000oooo
0?ooo`3o000e0?ooo`800000BP3oool004T0oooo00<000000?ooo`3oool0<03oool010000000oooo
0?ooo`3o000g0?ooo`030000003oool0oooo04L0oooo00180?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool0o`00>03oool00`000000oooo0?ooo`160?ooo`00A`3oool00`000000oooo
0?ooo`0b0?ooo`040000003oool0oooo0?l003T0oooo0P0000160?ooo`00AP3oool00`000000oooo
0?ooo`0c0?ooo`040000003oool0oooo0?l003/0oooo00<000000?ooo`3oool0@`3oool004D0oooo
00<000000?ooo`3oool0=03oool010000000oooo0?ooo`3o000l0?ooo`030000003oool0oooo01h0
oooo1P00000N0?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`040000003oool0oooo0?l003d0
oooo00<000000?ooo`3oool07@3oool00`2HV9P000000<c<c0020?ooo`03010@403oool0oooo01`0
oooo00120?ooo`800000>03oool010000000oooo0?ooo`3o000n0?ooo`8000007P3oool00`2HV9P0
00000<c<c00P0?ooo`008@3oool200000003010@403oool0oooo01/0oooo00<000000?ooo`3oool0
>03oool010000000oooo0?ooo`3o00100?ooo`030000003oool0oooo01`0oooo00<0ZJVY010@403<
c<`07`3oool00280oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0i0?ooo`040000
003oool0oooo0?l00440oooo00<000000?ooo`3oool0703oool00`3<c<`0410@0<c<c00N0?ooo`00
7P3oool6000001/0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`3o00120?ooo`80
00001@3oool5000001<0oooo00<0ZJVY038b<P3oool07@3oool001h0oooo00D0MgMg0:VYZ@3oool0
oooo0000000K0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool0o`00A03oool00`00
0000oooo0?ooo`0900000180oooo00<000000?ooo`3oool0703oool001h0oooo00D0k^k^038b<P3^
k^h0oooo0000000J0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool0o`00A@3oool<
000000`0oooo00H0000008N7Q`3^k^h0oooo07MgM`0b<S8N0?ooo`007`3oool0102YZJT0IVIV0?oo
o`00000@0?ooo`D00000103oool00`000000oooo0?ooo`0m0?ooo`040000003oool0oooo0?l004D0
oooo3@00000;0?ooo`060:VYZ@0b<S8000000000001EEED0k^k^7P3oool00200oooo00<0A4A40<c<
c00000003P3oool9000000030?ooo`000000oooo03l0oooo00@000000?ooo`3oool0o`00A@3oool=
000002l0oooo000P0?ooo`030=gMg@14A4@0000000d0oooo2`0000110?ooo`040000003oool0oooo
0?l004@0oooo3`00000^0?ooo`008@3oool00`1gMgL0410@0?ooo`0;0?ooo`d00000@03oool01000
0000oooo0?ooo`3o00140?ooo`l00000;P3oool002l0oooo3@0000100?ooo`040000003oool0oooo
0?l00380oooo8@00000^0?ooo`00;P3oool?000003l0oooo00@000000?ooo`3oool0o`00<P00000B
0?ooo`l00000;P3oool002h0oooo3`00000A0?oooc40000000<0o`000?ooo`3oool0@P3oool?0000
02h0oooo000^0?ooob000000;P3oool010000000oooo0?ooo`3o00150?ooo`d00000;`3oool002h0
oooo3`00000o0?ooo`040000003oool0oooo0?l004D0oooo3@00000_0?ooo`00;P3oool?000003l0
oooo00@000000?ooo`3oool0o`00AP3oool;00000300oooo000_0?ooo`d00000@@3oool00`000000
oooo0?l000170?ooo`T00000<@3oool002l0oooo3@0000110?ooo`030000003oool0o`0004L0oooo
00<000000?ooo`0000001000000c0?ooo`00<03oool;00000480oooo00<000000?ooo`3o0000AP3o
ool00`000000oooo0?ooo`0h0?ooo`00<@3oool9000004<0oooo00<000000?ooo`3o0000AP3oool0
0`000000oooo0?ooo`0h0?ooo`00<`3oool5000000030?ooo`000000oooo0480oooo00<000000?oo
o`3o0000A@3oool00`000000oooo0?ooo`0i0?ooo`00>P3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0o`0004@0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?l000140?ooo`030000003oool0oooo03X0oooo000k0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3o0000@`3oool00`000000oooo0?ooo`0k0?ooo`00?03oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0o`000480oooo00<000000?ooo`3oool0?03oool0
03`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?l000120?ooo`030000003oool0oooo
03`0oooo000m0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o0000@@3oool00`000000
oooo0?ooo`0m0?ooo`00?P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0o`000400oooo
00<000000?ooo`3oool0?P3oool003h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?l0
00100?ooo`030000003oool0oooo03h0oooo000o0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3o0000?`3oool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0o`0003h0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?l0000n0?ooo`030000003oool0oooo0400oooo00110?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3o0000?@3oool00`000000oooo0?ooo`110?ooo`00@P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0o`0003d0oooo00<000000?ooo`3oool0@@3o
ool00480oooo00<000000?ooo`3oool0>03oool00`000000oooo0?l0000l0?ooo`030000003oool0
oooo0480oooo00130?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o0000>`3oool00`00
0000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0o`0003/0
oooo00<000000?ooo`3oool0@`3oool004@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?l0000j0?ooo`030000003oool0oooo04@0oooo00150?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3o0000>@3oool00`000000oooo0?ooo`150?ooo`00A@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0o`0003T0oooo00<000000?ooo`3oool0A@3oool004H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?l0000h0?ooo`030000003oool0oooo04H0oooo00170?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3o0000=`3oool00`000000oooo0?ooo`170?ooo`00
A`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0o`0003L0oooo00<000000?ooo`3oool0
A`3oool004P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?l0000f0?ooo`030000003o
ool0oooo04P0oooo00190?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o0000=@3oool0
0`000000oooo0?ooo`190?ooo`00B@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0o`00
03D0oooo00<000000?ooo`3oool0B@3oool004X0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?l0000d0?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3o0000<`3oool00`000000oooo0?ooo`1;0?ooo`00B`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0o`0003<0oooo00<000000?ooo`3oool0B`3oool004`0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?l0000b0?ooo`030000003oool0oooo04`0oooo001<0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3o0000<P3oool00`000000oooo0?ooo`1<0?oo
o`00C@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0o`000340oooo00<000000?ooo`3o
ool0C@3oool004h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?l0000`0?ooo`030000
003oool0oooo04h0oooo001>0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o0000<03o
ool00`000000oooo0?ooo`1>0?ooo`00C`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
o`0002l0oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?l0000^0?ooo`030000003oool0oooo0500oooo001@0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3o0000;P3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0o`0002d0oooo00<000000?ooo`3oool0D@3oool00580oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?l0000/0?ooo`030000003oool0oooo0580oooo001B
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o0000;03oool00`000000oooo0?ooo`1B
0?ooo`00D`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0o`0002/0oooo00<000000?oo
o`3oool0D`3oool005@0oooo00<000000?ooo`3oool09`3oool00`000000o`000?ooo`0Y0?ooo`03
0000003oool0oooo05@0oooo001D0?ooo`030000003oool0oooo02L0oooo00<000000?l0003oool0
:@3oool00`000000oooo0?ooo`1D0?ooo`00E@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
0000oooo02P0oooo00<000000?ooo`3oool0E@3oool005D0oooo00<000000?ooo`3oool09P3oool0
0`000000o`000?ooo`0X0?ooo`030000003oool0oooo05D0oooo001F0?ooo`030000003oool0oooo
02D0oooo00<000000?l0003oool09`3oool00`000000oooo0?ooo`1F0?ooo`00E`3oool00`000000
oooo0?ooo`0T0?ooo`030000003o0000oooo02H0oooo00<000000?ooo`3oool0E`3oool005L0oooo
00<000000?ooo`3oool0903oool00`000000o`000?ooo`0V0?ooo`030000003oool0oooo05L0oooo
001H0?ooo`030000003oool0oooo02<0oooo00<000000?l0003oool09@3oool00`000000oooo0?oo
o`1H0?ooo`00F@3oool00`000000oooo0?ooo`0R0?ooo`030000003o0000oooo02@0oooo00<00000
0?ooo`3oool0F@3oool005T0oooo00<000000?ooo`3oool08P3oool00`000000o`000?ooo`0T0?oo
o`030000003oool0oooo05T0oooo001J0?ooo`030000003oool0oooo0240oooo00<000000?l0003o
ool08`3oool00`000000oooo0?ooo`1J0?ooo`00F`3oool00`000000oooo0?ooo`0P0?ooo`030000
003o0000oooo0280oooo00<000000?ooo`3oool0F`3oool005/0oooo00<000000?ooo`3oool0803o
ool00`000000o`000?ooo`0R0?ooo`030000003oool0oooo05/0oooo001L0?ooo`030000003oool0
oooo01l0oooo00<000000?l0003oool08@3oool00`000000oooo0?ooo`1L0?ooo`00G@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003o0000oooo0200oooo00<000000?ooo`3oool0G@3oool005d0
oooo00<000000?ooo`3oool07P3oool00`000000o`000?ooo`0P0?ooo`030000003oool0oooo05d0
oooo001N0?ooo`030000003oool0oooo01d0oooo00<000000?l0003oool07`3oool00`000000oooo
0?ooo`1N0?ooo`00G`3oool00`000000oooo0?ooo`0L0?ooo`030000003o0000oooo01l0oooo00<0
00000?ooo`3oool0GP3oool005l0oooo00<000000?ooo`3oool0703oool00`000000o`000?ooo`0N
0?ooo`030000003oool0oooo05l0oooo001P0?ooo`030000003oool0oooo01/0oooo00<000000?l0
003oool07@3oool00`000000oooo0?ooo`1P0?ooo`00H03oool00`000000oooo0?ooo`0K0?ooo`03
0000003o0000oooo01d0oooo00<000000?ooo`3oool0H03oool00640oooo00<000000?ooo`3oool0
6P3oool00`000000o`000?ooo`0L0?ooo`030000003oool0oooo0640oooo001R0?ooo`030000003o
ool0oooo01T0oooo00<000000?l0003oool06`3oool00`000000oooo0?ooo`1R0?ooo`00HP3oool0
0`000000oooo0?ooo`0I0?ooo`030000003o0000oooo01/0oooo00<000000?ooo`3oool0HP3oool0
06<0oooo00<000000?ooo`3oool0603oool00`000000o`000?ooo`0J0?ooo`030000003oool0oooo
06<0oooo001T0?ooo`030000003oool0oooo01L0oooo00<000000?l0003oool06@3oool00`000000
oooo0?ooo`1T0?ooo`00I03oool00`000000oooo0?ooo`0G0?ooo`030000003o0000oooo01T0oooo
00<000000?ooo`3oool0I03oool006D0oooo00<000000?ooo`3oool05P3oool00`000000o`000?oo
o`0H0?ooo`030000003oool0oooo06D0oooo001V0?ooo`030000003oool0oooo01D0oooo00<00000
0?l0003oool05`3oool00`000000oooo0?ooo`1V0?ooo`00IP3oool00`000000oooo0?ooo`0E0?oo
o`030000003o0000oooo01L0oooo00<000000?ooo`3oool0IP3oool006L0oooo00<000000?ooo`3o
ool0503oool00`000000o`000?ooo`0F0?ooo`030000003oool0oooo06L0oooo001X0?ooo`030000
003oool0oooo01<0oooo00<000000?l0003oool05P3oool00`000000oooo0?ooo`1W0?ooo`00J03o
ool00`000000oooo0?ooo`0C0?ooo`030000003o0000oooo01D0oooo00<000000?ooo`3oool0J03o
ool006T0oooo00<000000?ooo`3oool04P3oool00`000000o`000?ooo`0D0?ooo`030000003oool0
oooo06T0oooo001Y0?ooo`030000003oool0oooo0180oooo00<000000?l0003oool0503oool00`00
0000oooo0?ooo`1Y0?ooo`00JP3oool00`000000oooo0?ooo`0A0?ooo`030000003o0000oooo01<0
oooo00<000000?ooo`3oool0JP3oool006/0oooo00<000000?ooo`3oool0403oool00`000000o`00
0?ooo`0B0?ooo`030000003oool0oooo06/0oooo001[0?ooo`030000003oool0oooo0100oooo00<0
00000?l0003oool04P3oool00`000000oooo0?ooo`1[0?ooo`00K03oool00`000000oooo0?ooo`0?
0?ooo`030000003o0000oooo0140oooo00<000000?ooo`3oool0K03oool006d0oooo00<000000?oo
o`3oool03P3oool00`000000o`000?ooo`0@0?ooo`030000003oool0oooo06d0oooo001]0?ooo`03
0000003oool0oooo00h0oooo00<000000?l0003oool0403oool00`000000oooo0?ooo`1]0?ooo`00
KP3oool00`000000oooo0?ooo`0=0?ooo`030000003o0000oooo00l0oooo00<000000?ooo`3oool0
KP3oool006l0oooo00<000000?ooo`3oool0303oool00`000000o`000?ooo`0>0?ooo`030000003o
ool0oooo06l0oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?l0003oool03P3oool0
0`000000oooo0?ooo`1_0?ooo`00L03oool00`000000oooo0?ooo`0;0?ooo`030000003o0000oooo
00d0oooo00<000000?ooo`3oool0L03oool00740oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo001a0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1a0?ooo`00LP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0LP3oool00780oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0780oooo001c0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?oo
o`00M03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0M03oool007@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo07@0oooo001e0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1e0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0MP3oool007H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo001g0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`00N03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0N03oool007P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07P0oooo001i
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1i
0?ooo`00NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0NP3oool007X0oooo00<000000?ooo`3oool01@0000020?ooo`030000003oool0oooo07X0
oooo001k0?ooo`T00000O@3oool007X0oooo2`00001l0?ooo`00N@3oool=000007/0oooo001i0?oo
o`d00000N`3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3o
ool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001i0?ooo`d00000N`3oool007T0oooo
3@00001k0?ooo`00NP3oool;000007`0oooo001k0?ooo`T00000O@3oool007d0oooo1@00001o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o
0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo
0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o
0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00O@3oool400000003010@403oool0oooo07d0
oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o
0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`03
0000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001m0?ooo`0300000014
A4@000000840oooo001m0?ooo`030<c<c01EEED000000840oooo003o0?ooo`80oooo003o0?ooo`80
oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80
oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80
oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.77215 .50069 Mdot
.5 Mabswid
[ ] 0 setdash
.77215 .50069 m
.52309 .24841 L
s
.77215 .50069 m
.18941 .48627 L
s
.4958 .947 m
.77215 .50069 L
s
15 Mabswid
.18941 .48627 Mdot
.5 Mabswid
.18941 .48627 m
.52309 .24841 L
s
.4958 .947 m
.18941 .48627 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.52309 .24841 L
s
15 Mabswid
.52309 .24841 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.84738 .46819 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.53251 .12368 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.1054 .44938 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00Q@3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kWH0oooo00250?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8bMP3oool008X0
oooo00<000000?ooo`3oool0M03oool008T0oooo00<0MgMg024Q8@3oool0M@3oool008L0oooo00@0
8B4Q000000000000^[ZjMP3oool008P0oooo00<0k^k^07MgM`0b<S80MP3oool008X0oooo00<00000
0?ooo`3oool0M03oool008D0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S9f0?ooo`00Q@3oool0
1P2j^[X0A4A4000000000000A4A40>k^kWH0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo00240?ooo`D00000N03oool00880oooo2@00001f0?ooo`00P@3oool;
000007D0oooo00200?ooo`d00000M03oool00800oooo3@00001d0?ooo`00O`3oool?000007<0oooo
001o0?ooo`l00000L`3oool007l0oooo3`00001c0?ooo`00O`3oool?000007<0oooo001o0?ooo`l0
0000L`3oool00800oooo3@00001d0?ooo`00P03oool=000007@0oooo001n0?ooo`80000000<0oooo
0000000000002@00001e0?ooo`00O@3oool00`000000oooo0?ooo`020?ooo`X00000M@3oool007`0
oooo00<000000?ooo`3oool01@3oool5000000<0oooo00<000000?ooo`3oool0LP3oool007X0oooo
0P00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L@3oool007T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0700oooo001g
0?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06l0oooo001f0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1^0?oo
o`00M@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0K@3oool007<0oooo0P00000A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
K03oool00780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo06/0oooo001`0?ooo`8000004`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo06X0oooo001_0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1Y0?ooo`00KP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0J03oool006`0oooo0P00000G0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0I`3oool006/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo06H0oooo001Z0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`00J03oool2000001/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1T0?ooo`00I`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0H`3oool006D0oooo0P00000N0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0640oooo001S0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`00H@3oool20000
0280oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1O0?ooo`00H03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0GP3oool005h0oooo
0P00000U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0G@3oool005d0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05`0oooo001L
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1K
0?ooo`00FP3oool2000002T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1J0?oo
o`00F@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0F@3oool005P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo05P0oooo001F0?ooo`800000;@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo05L0oooo001E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`1F0?ooo`00D`3oool200000300oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1E0?ooo`00DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0E03oool00540oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo
0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0D`3oool004l0oooo0P00
000^0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1B0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0080oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1A0?ooo`00C03oool200000340oooo00<0o`000?oo
o`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0500oooo001;0?ooo`03
0000003oool0oooo0340oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo001:0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04h0oooo00180?ooo`800000=@3o
ool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0C@3o
ool004L0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0C03oool004D0oooo0P00000h0?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`00A03oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`1:0?ooo`00@`3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0080oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`190?ooo`006`3oool200000003010@403o
ool0oooo0240oooo0P00000l0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`180?ooo`00703oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo03`0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo04L0oooo000H0?ooo`H000008@3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`160?ooo`00603oool01@1gMgL0
ZJVY0?ooo`3oool000000200oooo0P0000100?ooo`030?l0003oool0oooo0080oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`150?ooo`00603oool01@3^k^h0<S8b0>k^kP3oool00000
01l0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0A03oool001T0oooo00@0ZJVY06IVIP3oool000007@3oool20000
04<0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01P0oooo1P00000U0?ooo`006P3oool00`14A4@0c<c<0000000A0?ooo`D000001P3oool00`000000
oooo0?ooo`130?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0G0?ooo`0309RHV0000000c<c<0080oooo00<0410@0?ooo`3oool08`3oool001X0oooo
00<0gMgM04A4A00000003`3oool9000000<0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool05`3oool00`2HV9P00000
0<c<c00W0?ooo`006`3oool00`1gMgL0410@0?ooo`0=0?ooo`d00000A`3oool00`3o0000oooo0?oo
o`020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05`3oool00`2YZJT0410@0<c<
c00V0?ooo`00:P3oool=000004P0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0080oooo1@00000@0?ooo`030<c<c00@4100c<c<02D0oooo000Z0?oo
o`d00000B03oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`0000002000000?0?ooo`030:VYZ@0b<S80oooo02@0oooo000Y0?ooo`l00000A`3oool00`3o0000
oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo2`00000?0?ooo`030000003oool0oooo02<0
oooo000Y0?ooo`l00000A`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo
3@0000090?ooo`0600000027QhL0k^k^0?ooo`1gMgL0<S8b9@3oool002T0oooo8@00000e0?ooo`03
0?l0003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool=000000T0oooo00H0ZJVY038b<P00
0000000005EEE@3^k^hU0?ooo`00:@3oool?00000180oooo<P0000030?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0>03oool?000003<0oooo000Y0?ooo`l00000A03oool300000003
0?l000000000000002`000004@3oool?000003<0oooo000Z0?ooo`d00000B03oool01@3o0000oooo
0?ooo`3oool0000002X0oooo8000000c0?ooo`00:P3oool=000004P0oooo00D0o`000?ooo`3oool0
oooo0000000k0?ooo`l00000<`3oool002/0oooo2`0000190?ooo`050?l0003oool0oooo0?ooo`00
0000>`3oool?000003<0oooo000/0?ooo`T00000BP3oool01@3o0000oooo0?ooo`3oool0000003`0
oooo3@00000d0?ooo`00;P3oool5000000030?ooo`000000oooo04T0oooo00D0o`000?ooo`3oool0
oooo0000000l0?ooo`d00000=03oool003D0oooo00<000000?ooo`3oool0A`3oool01@3o0000oooo
0?ooo`3oool0000003d0oooo2`00000e0?ooo`00=P3oool00`000000oooo0?ooo`160?ooo`050?l0
003oool0oooo0?ooo`000000?P3oool9000003H0oooo000f0?ooo`030000003oool0oooo04H0oooo
00D0o`000?ooo`3oool0oooo0000000n0?ooo`030000003oool0000000@00000>03oool003L0oooo
00<000000?ooo`3oool0A@3oool01@3o0000oooo0?ooo`3oool0000003d0oooo00<000000?ooo`3o
ool0?@3oool003P0oooo00<000000?ooo`3oool0A03oool01@3o0000oooo0?ooo`3oool0000003d0
oooo00<000000?ooo`3oool0?@3oool003P0oooo00<000000?ooo`3oool0A03oool01@3o0000oooo
0?ooo`3oool0000003`0oooo00<000000?ooo`3oool0?P3oool003T0oooo00<000000?ooo`3oool0
@`3oool01@3o0000oooo0?ooo`3oool0000003`0oooo00<000000?ooo`3oool0?P3oool003X0oooo
00<000000?ooo`3oool0@P3oool01@3o0000oooo0?ooo`3oool0000003/0oooo00<000000?ooo`3o
ool0?`3oool003X0oooo00<000000?ooo`3oool0@P3oool01@3o0000oooo0?ooo`3oool0000003X0
oooo00<000000?ooo`3oool0@03oool003/0oooo00<000000?ooo`3oool0@@3oool01@3o0000oooo
0?ooo`3oool0000003X0oooo00<000000?ooo`3oool0@03oool003`0oooo00<000000?ooo`3oool0
@03oool01@3o0000oooo0?ooo`3oool0000003T0oooo00<000000?ooo`3oool0@@3oool003`0oooo
00<000000?ooo`3oool0@03oool01@3o0000oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3o
ool0@P3oool003d0oooo00<000000?ooo`3oool0?`3oool01@3o0000oooo0?ooo`3oool0000003P0
oooo00<000000?ooo`3oool0@P3oool003h0oooo00<000000?ooo`3oool0?P3oool01@3o0000oooo
0?ooo`3oool0000003L0oooo00<000000?ooo`3oool0@`3oool003h0oooo00<000000?ooo`3oool0
?P3oool01@3o0000oooo0?ooo`3oool0000003L0oooo00<000000?ooo`3oool0@`3oool003l0oooo
00<000000?ooo`3oool0?@3oool01@3o0000oooo0?ooo`3oool0000003H0oooo00<000000?ooo`3o
ool0A03oool00400oooo00<000000?ooo`3oool0?03oool01@3o0000oooo0?ooo`3oool0000003D0
oooo00<000000?ooo`3oool0A@3oool00400oooo00<000000?ooo`3oool0?03oool01@3o0000oooo
0?ooo`3oool0000003D0oooo00<000000?ooo`3oool0A@3oool00440oooo00<000000?ooo`3oool0
>`3oool01@3o0000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool0AP3oool00480oooo
00<000000?ooo`3oool0>P3oool01@3o0000oooo0?ooo`3oool0000003<0oooo00<000000?ooo`3o
ool0A`3oool00480oooo00<000000?ooo`3oool0>P3oool01@3o0000oooo0?ooo`3oool0000003<0
oooo00<000000?ooo`3oool0A`3oool004<0oooo00<000000?ooo`3oool0>@3oool0103o0000oooo
0?ooo`00000c0?ooo`030000003oool0oooo04P0oooo00140?ooo`030000003oool0oooo03P0oooo
00@0o`000?ooo`3oool00000<`3oool00`000000oooo0?ooo`180?ooo`00A03oool00`000000oooo
0?ooo`0h0?ooo`040?l0003oool0oooo00000380oooo00<000000?ooo`3oool0B@3oool004D0oooo
00<000000?ooo`3oool0=`3oool0103o0000oooo0?ooo`00000a0?ooo`030000003oool0oooo04X0
oooo00160?ooo`030000003oool0oooo03H0oooo00@0o`000?ooo`3oool00000<@3oool00`000000
oooo0?ooo`1:0?ooo`00AP3oool00`000000oooo0?ooo`0f0?ooo`040?l0003oool0oooo00000300
oooo00<000000?ooo`3oool0B`3oool004L0oooo00<000000?ooo`3oool0=@3oool0103o0000oooo
0?ooo`00000`0?ooo`030000003oool0oooo04/0oooo00180?ooo`030000003oool0oooo03@0oooo
00@0o`000?ooo`3oool00000;`3oool00`000000oooo0?ooo`1<0?ooo`00B03oool00`000000oooo
0?ooo`0d0?ooo`040?l0003oool0oooo000002h0oooo00<000000?ooo`3oool0C@3oool004T0oooo
00<000000?ooo`3oool0<`3oool0103o0000oooo0?ooo`00000^0?ooo`030000003oool0oooo04d0
oooo001:0?ooo`030000003oool0oooo0380oooo00@0o`000?ooo`3oool00000;@3oool00`000000
oooo0?ooo`1>0?ooo`00BP3oool00`000000oooo0?ooo`0b0?ooo`040?l0003oool0oooo000002`0
oooo00<000000?ooo`3oool0C`3oool004/0oooo00<000000?ooo`3oool0<@3oool0103o0000oooo
0?ooo`00000/0?ooo`030000003oool0oooo04l0oooo001<0?ooo`030000003oool0oooo0300oooo
00@0o`000?ooo`3oool00000:`3oool00`000000oooo0?ooo`1@0?ooo`00C03oool00`000000oooo
0?ooo`0`0?ooo`040?l0003oool0oooo000002/0oooo00<000000?ooo`3oool0D03oool004d0oooo
00<000000?ooo`3oool0;`3oool0103o0000oooo0?ooo`00000Z0?ooo`030000003oool0oooo0540
oooo001>0?ooo`030000003oool0oooo02h0oooo00@0o`000?ooo`3oool00000:@3oool00`000000
oooo0?ooo`1B0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`040?l0003oool0oooo000002T0
oooo00<000000?ooo`3oool0DP3oool004l0oooo00<000000?ooo`3oool0;@3oool0103o0000oooo
0?ooo`00000X0?ooo`030000003oool0oooo05<0oooo001@0?ooo`030000003oool0oooo02`0oooo
00@0o`000?ooo`3oool00000:03oool00`000000oooo0?ooo`1C0?ooo`00D03oool00`000000oooo
0?ooo`0/0?ooo`040?l0003oool0oooo000002L0oooo00<000000?ooo`3oool0E03oool00540oooo
00<000000?ooo`3oool0:`3oool0103o0000oooo0?ooo`00000V0?ooo`030000003oool0oooo05D0
oooo001B0?ooo`030000003oool0oooo02X0oooo00@0o`000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1E0?ooo`00DP3oool00`000000oooo0?ooo`0Z0?ooo`040?l0003oool0oooo000002D0
oooo00<000000?ooo`3oool0EP3oool005<0oooo00<000000?ooo`3oool0:@3oool0103o0000oooo
0?ooo`00000T0?ooo`030000003oool0oooo05L0oooo001D0?ooo`030000003oool0oooo02P0oooo
00@0o`000?ooo`3oool00000903oool00`000000oooo0?ooo`1G0?ooo`00E03oool00`000000oooo
0?ooo`0X0?ooo`030?l0003oool0000002@0oooo00<000000?ooo`3oool0F03oool005D0oooo00<0
00000?ooo`3oool09`3oool00`3o0000oooo0000000T0?ooo`030000003oool0oooo05P0oooo001F
0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`0000008`3oool00`000000oooo0?ooo`1I
0?ooo`00EP3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool000000280oooo00<000000?oo
o`3oool0FP3oool005L0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0000000R0?ooo`03
0000003oool0oooo05X0oooo001H0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`000000
8@3oool00`000000oooo0?ooo`1K0?ooo`00F@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003o
ool000000200oooo00<000000?ooo`3oool0G03oool005T0oooo00<000000?ooo`3oool08`3oool0
0`3o0000oooo0000000P0?ooo`030000003oool0oooo05`0oooo001J0?ooo`030000003oool0oooo
0280oooo00<0o`000?ooo`0000007`3oool00`000000oooo0?ooo`1M0?ooo`00F`3oool00`000000
oooo0?ooo`0Q0?ooo`030?l0003oool0000001l0oooo00<000000?ooo`3oool0G@3oool005/0oooo
00<000000?ooo`3oool08@3oool00`3o0000oooo0000000N0?ooo`030000003oool0oooo05h0oooo
001L0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`0000007@3oool00`000000oooo0?oo
o`1O0?ooo`00G@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0000001d0oooo00<00000
0?ooo`3oool0G`3oool005d0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0000000L0?oo
o`030000003oool0oooo0600oooo001N0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`00
0000703oool00`000000oooo0?ooo`1P0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`030?l0
003oool0000001/0oooo00<000000?ooo`3oool0H@3oool005l0oooo00<000000?ooo`3oool07@3o
ool00`3o0000oooo0000000J0?ooo`030000003oool0oooo0680oooo001P0?ooo`030000003oool0
oooo01`0oooo00<0o`000?ooo`0000006P3oool00`000000oooo0?ooo`1R0?ooo`00H@3oool00`00
0000oooo0?ooo`0K0?ooo`030?l0003oool0000001T0oooo00<000000?ooo`3oool0H`3oool00640
oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0000000H0?ooo`030000003oool0oooo06@0
oooo001R0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`000000603oool00`000000oooo
0?ooo`1T0?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0000001L0oooo00<0
00000?ooo`3oool0I@3oool006<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0000000G
0?ooo`030000003oool0oooo06D0oooo001T0?ooo`030000003oool0oooo01P0oooo00<0o`000?oo
o`0000005P3oool00`000000oooo0?ooo`1V0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`03
0?l0003oool0000001D0oooo00<000000?ooo`3oool0I`3oool006D0oooo00<000000?ooo`3oool0
5`3oool00`3o000000000?ooo`0E0?ooo`030000003oool0oooo06L0oooo001V0?ooo`030000003o
ool0oooo01H0oooo00<0o`000000003oool0503oool00`000000oooo0?ooo`1X0?ooo`00I`3oool0
0`000000oooo0?ooo`0E0?ooo`030?l000000000oooo01@0oooo00<000000?ooo`3oool0J03oool0
06L0oooo00<000000?ooo`3oool05@3oool00`3o000000000?ooo`0C0?ooo`030000003oool0oooo
06T0oooo001X0?ooo`030000003oool0oooo01@0oooo00<0o`000000003oool04P3oool00`000000
oooo0?ooo`1Z0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030?l000000000oooo0180oooo
00<000000?ooo`3oool0JP3oool006T0oooo00<000000?ooo`3oool04`3oool00`3o000000000?oo
o`0A0?ooo`030000003oool0oooo06/0oooo001Z0?ooo`030000003oool0oooo0180oooo00<0o`00
0000003oool0403oool00`000000oooo0?ooo`1/0?ooo`00J`3oool00`000000oooo0?ooo`0A0?oo
o`030?l000000000oooo0100oooo00<000000?ooo`3oool0K03oool006/0oooo00<000000?ooo`3o
ool04@3oool00`3o000000000?ooo`0?0?ooo`030000003oool0oooo06d0oooo001/0?ooo`030000
003oool0oooo0100oooo00<0o`000000003oool03`3oool00`000000oooo0?ooo`1]0?ooo`00K@3o
ool00`000000oooo0?ooo`0?0?ooo`030?l000000000oooo00h0oooo00<000000?ooo`3oool0KP3o
ool006d0oooo00<000000?ooo`3oool03`3oool00`3o000000000?ooo`0=0?ooo`030000003oool0
oooo06l0oooo001^0?ooo`030000003oool0oooo00h0oooo00<0o`000000003oool03@3oool00`00
0000oooo0?ooo`1_0?ooo`00K`3oool00`000000oooo0?ooo`0=0?ooo`030?l000000000oooo00`0
oooo00<000000?ooo`3oool0L03oool006l0oooo00<000000?ooo`3oool03@3oool00`3o00000000
0?ooo`0<0?ooo`030000003oool0oooo0700oooo001`0?ooo`030000003oool0oooo00`0oooo00<0
o`000000003oool02`3oool00`000000oooo0?ooo`1a0?ooo`00L@3oool00`000000oooo0?ooo`0;
0?ooo`030?l000000000oooo00X0oooo00<000000?ooo`3oool0LP3oool00740oooo00<000000?oo
o`3oool02`3oool00`3o000000000?ooo`0:0?ooo`030000003oool0oooo0780oooo001b0?ooo`03
0000003oool0oooo00X0oooo00<0o`000000003oool02@3oool00`000000oooo0?ooo`1c0?ooo`00
L`3oool00`000000oooo0?ooo`090?ooo`030?l000000000oooo00P0oooo00<000000?ooo`3oool0
M03oool007<0oooo00<000000?ooo`3oool02@3oool00`3o000000000?ooo`080?ooo`030000003o
ool0oooo07@0oooo001d0?ooo`030000003oool0oooo00P0oooo00<0o`000000003oool01`3oool0
0`000000oooo0?ooo`1e0?ooo`00M@3oool00`000000oooo0?ooo`070?ooo`030?l000000000oooo
00L0oooo00<000000?ooo`3oool0M@3oool007D0oooo00<000000?ooo`3oool01`3oool00`3o0000
00000?ooo`060?ooo`030000003oool0oooo07H0oooo001f0?ooo`030000003oool0oooo00H0oooo
00<0o`000000003oool01@3oool00`000000oooo0?ooo`1g0?ooo`00M`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool007L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07P0oooo001h0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1i0?oo
o`00N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0N@3oool007T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo07X0oooo001j0?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?oo
o`1j0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?ooo`00
N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?0000
07X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo001i
0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D00000
O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool0
07l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo0?oo
o`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?oo
o`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool00`00
0000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.74886 .51226 Mdot
.5 Mabswid
[ ] 0 setdash
.74886 .51226 m
.56398 .25064 L
s
.74886 .51226 m
.17262 .47258 L
s
.4958 .947 m
.74886 .51226 L
s
15 Mabswid
.17262 .47258 Mdot
.5 Mabswid
.17262 .47258 m
.56398 .25064 L
s
.4958 .947 m
.17262 .47258 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.56398 .25064 L
s
15 Mabswid
.56398 .25064 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.81707 .4832 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.58708 .12689 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08293 .43145 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00T`3oool0
1P2YZJT08B4Q000000000000EEEE0>k^kVP0oooo002C0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8bJ03oool009P0oooo00<000000?ooo`3oool0IP3oool009L0oooo00<0MgMg024Q8@3oool0I`3o
ool009D0oooo00@08B4Q000000000000^[ZjJ03oool009H0oooo00<0k^k^07MgM`0b<S80J03oool0
09P0oooo00<000000?ooo`3oool0IP3oool009<0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S9X
0?ooo`00T`3oool01P2j^[X0A4A4000000000000A4A40>k^kVP0oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo002>0?ooo`D00000KP3oool008`0oooo2@00001/
0?ooo`00R`3oool;000006/0oooo002:0?ooo`d00000JP3oool008X0oooo3@00001Z0?ooo`00R@3o
ool?000006T0oooo00290?ooo`l00000J@3oool008T0oooo3`00001Y0?ooo`00R@3oool?000006T0
oooo00290?ooo`l00000J@3oool008X0oooo3@00001Z0?ooo`00R03oool?000006X0oooo00260?oo
o`8000000`3oool;000006/0oooo00250?ooo`030000003oool0oooo00@0oooo2@00001/0?ooo`00
P`3oool2000000T0oooo1@0000020?ooo`030000003oool0oooo06T0oooo00210?ooo`800000303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo001o0?ooo`8000003P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo001n0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`00O03oool200000140
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?ooo`00NP3oool2000001<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?ooo`00N03oool2000001D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`00M`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool007D0oooo0P00000H0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool007<0oooo0P00000J0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00740oooo0P00000K0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00700oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo001^0?ooo`8000007P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo001/0?ooo`800000803oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo001Z0?ooo`8000008P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo001Y0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`00I`3oool2000002D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1N0?ooo`00I@3oool2000002L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`00H`3oool2000002T0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`00HP3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00600oooo0P00000[0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0F`3oool005h0oooo0P00000]0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0FP3oool005`0oooo0P00000_0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0FP3oool005X0oooo0P00000a0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0F@3oool005T0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo05P0oooo001G0?ooo`800000=03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05L0oooo001E0?ooo`800000=P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo05L0oooo001C0?ooo`800000>03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo05H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1E0?ooo`00D03oool2000003/0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1E0?ooo`00CP3oool2000002l0oooo00<0o`000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0oooo001<0?ooo`800000<@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D`3o
ool004/0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0DP3oool004T0oooo0P00000d0?ooo`030?l0003oool0oooo
00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1B0?ooo`00A`3oool2000003H0
oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0540
oooo00150?ooo`800000>03oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0D03oool001D0oooo0P0000000`0@4100oooo0?ooo`0Z0?ooo`030000003o
ool0oooo03P0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0500oooo000F0?ooo`030000003oool0oooo02T0oooo0P00000k0?ooo`030?l0003oool0
oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1?0?ooo`004P3oool60000
02P0oooo0P00000m0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1>0?ooo`004P3oool01@1gMgL0ZJVY0?ooo`3oool0000002L0oooo0P00000o0?oo
o`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1=0?oo
o`004P3oool01@3^k^h0<S8b0>k^kP3oool0000002H0oooo00<000000?ooo`3oool0?`3oool00`3o
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0C@3oool001<0
oooo00@0ZJVY06IVIP3oool00000903oool200000480oooo00<0o`000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo04`0oooo000D0?ooo`0304A4A03<c<`000000280
oooo0P0000140?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`1;0?ooo`00503oool00`3MgMd0A4A40000000C0?ooo`D00000203oool2000004H0oooo
00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04/0oooo
000E0?ooo`0307MgM`0@4100oooo0100oooo2@0000050?ooo`030000003oool0oooo04H0oooo00<0
o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04X0oooo000W
0?ooo`/000000P3oool2000004T0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo04T0oooo000V0?ooo`h00000B`3oool00`3o0000oooo0?ooo`090?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B03oool002H0oooo3@00001<0?ooo`03
0?l0003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`180?ooo`00
9@3oool?000004/0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo04L0oooo000U0?ooo`l00000B`3oool00`3o0000oooo0?ooo`090?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0AP3oool002D0oooo3`00001;0?ooo`030?l0003oool0
oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0C0?ooo`H00000;@3oool0
02D0oooo7P00000l0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0B0?ooo`0309RHV0000000c<c<0080oooo00<0410@0?ooo`3oool0:`3oool002D0
oooo3`00000?0?ooo`l00000;@3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool04P3oool00`2HV9P000000<c<c00_0?ooo`009P3oool=000001l0oooo
3`00000N0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`05000000d0oooo00<0ZJVY010@403<c<`0;P3oool002H0oooo3@00000^0?ooo`l000003`3o
ool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo02h0oooo2P00000<0?ooo`030<c<c00@
4100c<c<02d0oooo000W0?ooo`/00000?P3oool>000000030?ooo`3o0000oooo00T0oooo00<00000
0?ooo`3oool0;P3oool;000000`0oooo00<0ZJVY038b<P3oool0;03oool002P0oooo2@00001=0?oo
o`030000003o0000000000`00000;@3oool=000000`0oooo00<000000?ooo`3oool0:`3oool002X0
oooo1@0000000`3oool000000?ooo`1=0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3o
ool03`00000N0?ooo`d000001`3oool01P000000QhN70>k^kP3oool0MgMg038b<Rd0oooo000a0?oo
o`030000003oool0oooo04/0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?oo
o`l000003P3oool?000000H0oooo00H0ZJVY038b<P000000000005EEE@3^k^h]0?ooo`00<P3oool0
0`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool07P3ooolM
000003T0oooo000b0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0203oool00`00
0000oooo0?ooo`0/0?ooo`l00000>@3oool003<0oooo00<000000?ooo`3oool0B@3oool00`3o0000
oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo3`00000i0?ooo`00=03oool00`000000oooo
0?ooo`180?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool?000003T0oooo
000e0?ooo`030000003oool0oooo04L0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?oo
o`0^0?ooo`d00000>P3oool003D0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`07
0?ooo`030000003oool0oooo02h0oooo3@00000j0?ooo`00=P3oool00`000000oooo0?ooo`160?oo
o`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0;`3oool;000003/0oooo000g0?ooo`03
0000003oool0oooo04D0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`T0
0000?03oool003L0oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo0300oooo00<000000?ooo`0000001000000n0?ooo`00>03oool00`000000oooo0?oo
o`140?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`120?ooo`00>@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo00L0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`130?ooo`00>@3oool00`000000oooo0?ooo`130?oo
o`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`140?oo
o`00>P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`140?ooo`00>`3oool00`000000oooo0?ooo`110?ooo`030?l0
003oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?ooo`00>`3o
ool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`150?ooo`00?03oool00`000000oooo0?ooo`100?ooo`030?l0003oool0
oooo00H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`160?ooo`00?@3oool00`00
0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`160?ooo`00?@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00H0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`170?ooo`00?P3oool00`000000oooo
0?ooo`0n0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`180?ooo`00?`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00H0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00?`3oool00`000000oooo0?ooo`0m
0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00@03oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo00H0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`190?ooo`00@@3oool00`000000oooo0?ooo`0k0?ooo`03
0?l0003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1:0?ooo`00
@@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1:0?ooo`00@P3oool00`000000oooo0?ooo`0j0?ooo`030?l0003o
ool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1;0?ooo`00@`3oool0
0`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1<0?ooo`00@`3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo
00D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1<0?ooo`00A03oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1=0?ooo`00A@3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo00D0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1=0?ooo`00AP3oool00`000000oooo0?oo
o`0f0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`1>0?ooo`00AP3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo00D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`1?0?ooo`00A`3oool00`000000oooo0?ooo`0e0?oo
o`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1?0?oo
o`00B03oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1@0?ooo`00B03oool00`000000oooo0?ooo`0d0?ooo`030?l0
003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1@0?ooo`00B@3o
ool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1A0?ooo`00BP3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1A0?ooo`00BP3oool00`00
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1B0?ooo`00B`3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo00@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1C0?ooo`00C03oool00`000000oooo
0?ooo`0`0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1C0?ooo`00C03oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`1D0?ooo`00C@3oool00`000000oooo0?ooo`0_
0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1D
0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo00@0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1E0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`03
0?l0003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1F0?ooo`00
C`3oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`1F0?ooo`00D03oool00`000000oooo0?ooo`0/0?ooo`030?l0003o
ool0oooo00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1G0?ooo`00D03oool0
0`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1G0?ooo`00D@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo
00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1H0?ooo`00DP3oool00`000000
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1H0?ooo`00DP3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1I0?ooo`00D`3oool00`000000oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1J0?ooo`00E03oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00<0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1J0?ooo`00E03oool00`000000oooo0?ooo`0X0?oo
o`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?oo
o`00E@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1K0?ooo`00EP3oool00`000000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`00E`3o
ool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1L0?ooo`00E`3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0
oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1M0?ooo`00F03oool00`00
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1N0?ooo`00F@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1N0?ooo`00F@3oool00`000000oooo
0?ooo`0S0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`1O0?ooo`00FP3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0080oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1O0?ooo`00F`3oool00`000000oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1P
0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0080oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1Q0?ooo`00G03oool00`000000oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1Q0?ooo`00
G@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1R0?ooo`00G@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1R0?ooo`00GP3oool0
0`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1S0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1S0?ooo`00G`3oool00`000000
oooo0?ooo`0M0?ooo`050?l0003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`1T0?oo
o`00H03oool00`000000oooo0?ooo`0L0?ooo`050?l0003oool0oooo0?ooo`0000005@3oool00`00
0000oooo0?ooo`1U0?ooo`00H@3oool00`000000oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?oo
o`0000005@3oool00`000000oooo0?ooo`1U0?ooo`00H@3oool00`000000oooo0?ooo`0K0?ooo`05
0?l0003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`1V0?ooo`00HP3oool00`000000
oooo0?ooo`0J0?ooo`050?l0003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`1V0?oo
o`00H`3oool00`000000oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`0000004`3oool00`00
0000oooo0?ooo`1W0?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?oo
o`0000004`3oool00`000000oooo0?ooo`1W0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`05
0?l0003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`1X0?ooo`00I@3oool00`000000
oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`1Y0?oo
o`00I@3oool00`000000oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`0000004@3oool00`00
0000oooo0?ooo`1Y0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`040?l0003oool0oooo0000
0140oooo00<000000?ooo`3oool0JP3oool006L0oooo00<000000?ooo`3oool05@3oool0103o0000
oooo0?ooo`00000A0?ooo`030000003oool0oooo06X0oooo001X0?ooo`030000003oool0oooo01@0
oooo00@0o`000?ooo`3oool00000403oool00`000000oooo0?ooo`1[0?ooo`00J03oool00`000000
oooo0?ooo`0D0?ooo`040?l0003oool0oooo000000l0oooo00<000000?ooo`3oool0K03oool006T0
oooo00<000000?ooo`3oool04`3oool0103o0000oooo0?ooo`00000?0?ooo`030000003oool0oooo
06`0oooo001Z0?ooo`030000003oool0oooo0180oooo00@0o`000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`1]0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`040?l0003oool0oooo0000
00h0oooo00<000000?ooo`3oool0K@3oool006/0oooo00<000000?ooo`3oool04@3oool0103o0000
oooo0?ooo`00000=0?ooo`030000003oool0oooo06h0oooo001/0?ooo`030000003oool0oooo0100
oooo00@0o`000?ooo`3oool000003@3oool00`000000oooo0?ooo`1^0?ooo`00K03oool00`000000
oooo0?ooo`0@0?ooo`040?l0003oool0oooo000000`0oooo00<000000?ooo`3oool0K`3oool006d0
oooo00<000000?ooo`3oool03`3oool0103o0000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0700oooo001^0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`000000303oool00`000000
oooo0?ooo`1`0?ooo`00KP3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0000000/0oooo
00<000000?ooo`3oool0L@3oool006l0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0000
000;0?ooo`030000003oool0oooo0740oooo001`0?ooo`030000003oool0oooo00`0oooo00<0o`00
0?ooo`0000002P3oool00`000000oooo0?ooo`1b0?ooo`00L03oool00`000000oooo0?ooo`0<0?oo
o`030?l0003oool0000000T0oooo00<000000?ooo`3oool0L`3oool00740oooo00<000000?ooo`3o
ool02`3oool00`3o0000oooo000000090?ooo`030000003oool0oooo07<0oooo001b0?ooo`030000
003oool0oooo00X0oooo00<0o`000?ooo`000000203oool00`000000oooo0?ooo`1d0?ooo`00LP3o
ool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0000000P0oooo00<000000?ooo`3oool0M03o
ool007<0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo000000070?ooo`030000003oool0
oooo07D0oooo001d0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`0000001`3oool00`00
0000oooo0?ooo`1e0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`030?l000000000oooo00H0
oooo00<000000?ooo`3oool0MP3oool007D0oooo00<000000?ooo`3oool01`3oool00`3o00000000
0?ooo`050?ooo`030000003oool0oooo07L0oooo001f0?ooo`030000003oool0oooo00H0oooo00<0
o`000000003oool01@3oool00`000000oooo0?ooo`1g0?ooo`00MP3oool00`000000oooo0?ooo`06
0?ooo`030?l000000000oooo00@0oooo00<000000?ooo`3oool0N03oool007L0oooo00<000000?oo
o`3oool01@3oool00`3o000000000?ooo`040?ooo`030000003oool0oooo07P0oooo001h0?ooo`03
0000003oool0oooo00@0oooo00<0o`000000003oool00`3oool00`000000oooo0?ooo`1i0?ooo`00
N@3oool00`000000oooo0?ooo`030?ooo`030?l000000000oooo00<0oooo00<000000?ooo`3oool0
N@3oool007T0oooo00<000000?ooo`3oool00`3oool00`3o000000000?ooo`020?ooo`030000003o
ool0oooo07X0oooo001j0?ooo`030000003oool0oooo00D0000000<0oooo0000003oool0O03oool0
07/0oooo2@00001m0?ooo`00NP3oool;000007`0oooo001i0?ooo`d00000N`3oool007T0oooo3@00
001k0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00
N03oool?000007X0oooo001h0?ooo`l00000NP3oool007T0oooo3@00001k0?ooo`00N@3oool=0000
07/0oooo001j0?ooo`/00000O03oool007/0oooo2@00001m0?ooo`00O@3oool5000007l0oooo001o
0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`03
0?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003o
ool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo
07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo
001o0?ooo`030?l0003oool0oooo07l0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80
oooo003o0?ooo`80oooo003o0?ooo`80oooo001m0?ooo`@0000000<0410@0?ooo`3oool0O@3oool0
07l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo
00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<00000
0?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007d0oooo00<0000004A4A000
0000P@3oool007d0oooo00<0c<c<05EEE@000000P@3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.72333 .52271 Mdot
.5 Mabswid
[ ] 0 setdash
.72333 .52271 m
.60388 .25493 L
s
.72333 .52271 m
.15894 .45807 L
s
.4958 .947 m
.72333 .52271 L
s
15 Mabswid
.15894 .45807 Mdot
.5 Mabswid
.15894 .45807 m
.60388 .25493 L
s
.4958 .947 m
.15894 .45807 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.60388 .25493 L
s
15 Mabswid
.60388 .25493 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.78411 .49671 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.6402 .13303 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.06426 .41233 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00X@3oool01P2YZJT08B4Q000000000000EEEE0>k^kUX0oooo002Q0?oo
o`06010@402j^[X0oooo0?ooo`2YZJT0<S8bFP3oool00:H0oooo00<000000?ooo`3oool0F03oool0
0:D0oooo00<0MgMg024Q8@3oool0F@3oool00:<0oooo00@08B4Q000000000000^[ZjFP3oool00:@0
oooo00<0k^k^07MgM`0b<S80FP3oool00:H0oooo00<000000?ooo`3oool0F03oool00:40oooo00H0
8B4Q0:VYZ@3oool0oooo06IVIP0b<S9J0?ooo`00X@3oool01P2j^[X0A4A4000000000000A4A40>k^
kUX0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo002I0?ooo`D00000H`3oool0
09L0oooo2@00001Q0?ooo`00UP3oool;00000600oooo002E0?ooo`d00000G`3oool009D0oooo3@00
001O0?ooo`00U03oool?000005h0oooo002D0?ooo`l00000GP3oool009@0oooo3`00001N0?ooo`00
U03oool?000005h0oooo002D0?ooo`l00000GP3oool009<0oooo3`00001O0?ooo`00T@3oool20000
0080oooo3@00001O0?ooo`00S`3oool2000000D0oooo2`00001P0?ooo`00S@3oool2000000P0oooo
2@00001Q0?ooo`00RP3oool3000000`0oooo1P00001R0?ooo`00R03oool200000100oooo00D00000
0?ooo`3oool0oooo0000001R0?ooo`00QP3oool200000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1O0?ooo`00Q03oool2000001@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1O0?ooo`00PP3oool2000001D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1N0?ooo`00O`3oool3000001L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1N0?ooo`00O@3oool2000001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1N0?ooo`00N`3oool2000001`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1M
0?ooo`00N@3oool2000001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1M0?oo
o`00M`3oool200000200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1L0?ooo`00
M03oool300000240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1L0?ooo`00LP3o
ool2000002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`00L03oool2
000002H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`00KP3oool20000
02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`00J`3oool3000002X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1J0?ooo`00J@3oool2000002d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1J0?ooo`00I`3oool2000002h0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1I0?ooo`00I@3oool200000300oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1I0?ooo`00H`3oool200000380oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1H0?ooo`00H03oool3000003@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1H0?ooo`00GP3oool2000003L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1G0?ooo`00G03oool2000003T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1G0?ooo`00FP3oool2000003/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1G0?ooo`00F03oool2000003`0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1F0?ooo`00E@3oool3000003h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1F0?ooo`00D`3oool200000440oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1E0?ooo`00D@3oool2000004<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1E0?ooo`00C`3oool2000004D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1D
0?ooo`00C03oool3000004L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?oo
o`00BP3oool2000003<0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo05@0oooo00180?ooo`800000=@3oool00`3o0000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0D`3oool00100oooo0P0000000`0@4100oooo0?oo
o`0a0?ooo`800000=`3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0D`3oool00140oooo00<000000?ooo`3oool0<03oool2000003T0oooo00<0o`00
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0580oooo000=0?oo
o`H00000;P3oool3000003/0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0580oooo000=0?ooo`0507MgM`2YZJT0oooo0?ooo`000000;@3oool20000
03h0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0540oooo000=0?ooo`050>k^kP0b<S80k^k^0?ooo`000000:`3oool200000400oooo00<0o`000?oo
o`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0540oooo000>0?ooo`04
0:VYZ@1VIVH0oooo000002T0oooo0P0000120?ooo`030?l0003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1A0?ooo`003`3oool00`14A4@0c<c<0000000W0?ooo`80
0000A03oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0D03oool000l0oooo00<0gMgM04A4A0000000503oool5000000/0oooo0`0000160?ooo`030?l0
003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1@0?ooo`00403o
ool00`1gMgL0410@0?ooo`0A0?ooo`T000001`3oool2000004T0oooo00<0o`000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04l0oooo000S0?ooo`/00000103oool2
000004/0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04l0oooo000R0?ooo`d0000000<0oooo000000000000C@3oool00`3o0000oooo0?ooo`0B0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool00280oooo3P00001?0?ooo`03
0?l0003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1>0?ooo`00
8@3oool?000004l0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo04d0oooo000Q0?ooo`l00000C`3oool00`3o0000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0C@3oool00240oooo3`00001?0?ooo`030?l0003oool0
oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1=0?ooo`008@3ooolE0000
04T0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
04`0oooo000Q0?ooo`l000001P3oool800000440oooo00<0o`000?ooo`3oool04@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo04`0oooo000R0?ooo`d000003`3oool9000003P0oooo
00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04/0oooo
000R0?ooo`d00000603oool800000300oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo04/0oooo000S0?ooo`/000008@3oool9000002L0oooo00<0o`00
0?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04X0oooo000T0?oo
o`T00000:`3oool8000001l0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo04X0oooo000V0?ooo`D0000000<0oooo0000003oool0<P3oool9000001H0
oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0
oooo1P00000e0?ooo`00;@3oool00`000000oooo0?ooo`0i0?ooo`T000003@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03P3oool00`2HV9P00000
0<c<c0020?ooo`03010@403oool0oooo03<0oooo000^0?ooo`030000003oool0oooo0440oooo2000
00050?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0?0?ooo`0309RHV0000000c<c<03L0oooo000_0?ooo`030000003oool0oooo04P0oooo1@000000
103o0000000000000000000>0?ooo`030000003oool0oooo0280oooo1P00000<0?ooo`030:VYZ@0@
4100c<c<03H0oooo000_0?ooo`030000003oool0oooo04d0oooo00@0o`000?ooo`3oool0oooo2000
00060?ooo`030000003oool0oooo0240oooo2@00000;0?ooo`030<c<c00@4100c<c<03D0oooo000`
0?ooo`030000003oool0oooo04`0oooo00<0o`000?ooo`3oool02@3oool900000200oooo2`00000;
0?ooo`030:VYZ@0b<S80oooo03@0oooo000a0?ooo`030000003oool0oooo04/0oooo00<0o`000?oo
o`3oool03`3oool00`000000oooo0?ooo`08000001L0oooo3@00000;0?ooo`030000003oool0oooo
03<0oooo000a0?ooo`030000003oool0oooo04/0oooo00<0o`000?ooo`3oool03`3oool00`000000
oooo0?ooo`080?ooo`T000003P3oool=000000H0oooo00H0000008N7Q`3^k^h0oooo07MgM`0b<S8e
0?ooo`00<P3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo00l0oooo00<000000?oo
o`3oool04@3oool8000000D0oooo3`0000050?ooo`060:VYZ@0b<S8000000000001EEED0k^k^=@3o
ool003<0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0
oooo01X0oooo500000100?ooo`00<`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo
00h0oooo00<000000?ooo`3oool07`3oool?00000400oooo000d0?ooo`030000003oool0oooo04P0
oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`l00000@03oool003D0oooo
00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo
3`0000100?ooo`00=@3oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo00h0oooo00<0
00000?ooo`3oool0803oool=00000440oooo000f0?ooo`030000003oool0oooo04H0oooo00<0o`00
0?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`d00000@@3oool003L0oooo00<000000?oo
o`3oool0A@3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo2`0000120?oo
o`00>03oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3o
ool08`3oool9000004<0oooo000h0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0T0?ooo`H00000A@3oool003T0oooo00<000000?ooo`3oool0@`3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B@3o
ool003X0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0BP3oool003X0oooo00<000000?ooo`3oool0@P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0BP3oool003/0
oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0B`3oool003`0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo
0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0B`3oool003`0oooo00<0
00000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0C03oool003d0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0C03oool003h0oooo00<000000?oo
o`3oool0?P3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0C@3oool003h0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0C@3oool003l0oooo00<000000?ooo`3oool0
?@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
CP3oool00400oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0CP3oool00440oooo00<000000?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C`3oool0
0440oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0C`3oool00480oooo00<000000?ooo`3oool0>P3oool00`3o0000
oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0D03oool004<0oooo
00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0D03oool004<0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D@3oool004@0oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0DP3oool004D0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0DP3oool004D0oooo00<000000?ooo`3o
ool0=`3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0D`3oool004H0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0D`3oool004L0oooo00<000000?ooo`3oool0=@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0E03o
ool004L0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0E03oool004P0oooo00<000000?ooo`3oool0=03oool00`3o
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0E@3oool004T0
oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0E@3oool004T0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo
0?ooo`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0EP3oool004X0oooo00<0
00000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0EP3oool004/0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`09
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E`3oool004`0oooo00<000000?oo
o`3oool0<03oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0E`3oool004`0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`090?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0F03oool004d0oooo00<000000?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
F03oool004h0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`080?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0F@3oool004h0oooo00<000000?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F@3oool0
04l0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0FP3oool00500oooo00<000000?ooo`3oool0;03oool00`3o0000
oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0F`3oool00500oooo
00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0F`3oool00540oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`070?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G03oool00580oooo00<00000
0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0G03oool00580oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`070?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0G@3oool005<0oooo00<000000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0G@3oool005@0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool005D0oooo00<000000?ooo`3oool09`3o
ool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0GP3o
ool005D0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0G`3oool005H0oooo00<000000?ooo`3oool09P3oool00`3o
0000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0G`3oool005L0
oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0H03oool005L0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo
0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0H03oool005P0oooo00<0
00000?ooo`3oool0903oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0H@3oool005T0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0H@3oool005T0oooo00<000000?oo
o`3oool08`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0HP3oool005X0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0H`3oool005/0oooo00<000000?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
H`3oool005/0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`050?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0I03oool005`0oooo00<000000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0I03oool0
05d0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0I@3oool005h0oooo00<000000?ooo`3oool07P3oool00`3o0000
oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I@3oool005h0oooo
00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool005l0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0IP3oool00600oooo00<00000
0?ooo`3oool0703oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0I`3oool00600oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0I`3oool00640oooo00<000000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0J03oool00680oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`040?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0J03oool00680oooo00<000000?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0J@3o
ool006<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0J@3oool006@0oooo00<000000?ooo`3oool0603oool00`3o
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0JP3oool006@0
oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0J`3oool006D0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0J`3oool006H0oooo00<0
00000?ooo`3oool05P3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0K03oool006H0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`03
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K03oool006L0oooo00<000000?oo
o`3oool05@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0K@3oool006P0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0K@3oool006T0oooo00<000000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
KP3oool006T0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0KP3oool006X0oooo00<000000?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K`3oool0
06/0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0K`3oool006/0oooo00<000000?ooo`3oool04@3oool01@3o0000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L03oool006`0oooo00<000000?ooo`3o
ool0403oool01@3o0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L03oool006d0
oooo00<000000?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0L@3oool006d0oooo00<000000?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool0L@3oool006h0oooo00<000000?ooo`3oool03P3oool01@3o0000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0LP3oool006l0oooo00<000000?ooo`3o
ool03@3oool01@3o0000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0LP3oool006l0
oooo00<000000?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0L`3oool00700oooo00<000000?ooo`3oool0303oool0103o0000oooo0?ooo`0000070?oo
o`030000003oool0oooo07@0oooo001a0?ooo`030000003oool0oooo00/0oooo00@0o`000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`1d0?ooo`00LP3oool00`000000oooo0?ooo`0:0?ooo`04
0?l0003oool0oooo000000H0oooo00<000000?ooo`3oool0M@3oool00780oooo00<000000?ooo`3o
ool02P3oool0103o0000oooo0?ooo`0000060?ooo`030000003oool0oooo07D0oooo001c0?ooo`03
0000003oool0oooo00T0oooo00@0o`000?ooo`3oool000001@3oool00`000000oooo0?ooo`1f0?oo
o`00M03oool00`000000oooo0?ooo`080?ooo`040?l0003oool0oooo000000D0oooo00<000000?oo
o`3oool0MP3oool007@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo000000050?ooo`03
0000003oool0oooo07L0oooo001e0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`000000
1@3oool00`000000oooo0?ooo`1g0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0000000@0oooo00<000000?ooo`3oool0N03oool007H0oooo00<000000?ooo`3oool01P3oool0
0`3o0000oooo000000040?ooo`030000003oool0oooo07P0oooo001g0?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`0000000`3oool00`000000oooo0?ooo`1i0?ooo`00N03oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0000000<0oooo00<000000?ooo`3oool0N@3oool007P0oooo
00<000000?ooo`3oool0103oool00`3o000000000?ooo`020?ooo`030000003oool0oooo07X0oooo
001i0?ooo`030000003oool0oooo00<0oooo00<0o`000000003oool00P3oool00`000000oooo0?oo
o`1j0?ooo`00NP3oool00`000000oooo0?ooo`05000000030?ooo`000000oooo07`0oooo001k0?oo
o`T00000O@3oool007X0oooo2`00001l0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3o
ool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo
3`00001j0?ooo`00N03oool?000007X0oooo001i0?ooo`d00000N`3oool007T0oooo3@00001k0?oo
o`00NP3oool;000007`0oooo001k0?ooo`T00000O@3oool007d0oooo1@00001o0?ooo`00O`3oool0
0`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000
oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?oo
o`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00O@3oool400000003010@403oool0oooo07d0oooo001o0?oo
o`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000
003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0
oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001m0?ooo`0300000014A4@000000840
oooo001m0?ooo`030<c<c01EEED000000840oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.69583 .53198 Mdot
.5 Mabswid
[ ] 0 setdash
.69583 .53198 m
.6422 .26119 L
s
.69583 .53198 m
.14861 .44286 L
s
.4958 .947 m
.69583 .53198 L
s
15 Mabswid
.14861 .44286 Mdot
.5 Mabswid
.14861 .44286 m
.6422 .26119 L
s
.4958 .947 m
.14861 .44286 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.6422 .26119 L
s
15 Mabswid
.6422 .26119 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.74885 .50863 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.69106 .14197 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.04972 .39216 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00[P3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kTd0oooo002^0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8bC@3oool00;<0
oooo00<000000?ooo`3oool0B`3oool00;80oooo00<0MgMg024Q8@3oool0C03oool00;00oooo00@0
8B4Q000000000000^[ZjC@3oool00;40oooo00<0k^k^07MgM`0b<S80C@3oool00;<0oooo00<00000
0?ooo`3oool0B`3oool00:h0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S9=0?ooo`00[P3oool0
1P2j^[X0A4A4000000000000A4A40>k^kTd0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo002S0?ooo`D00000F@3oool00:40oooo2@00001G0?ooo`00X03oool;000005H0oooo002O
0?ooo`d00000E@3oool009l0oooo3@00001E0?ooo`00WP3oool?000005@0oooo002N0?ooo`l00000
E03oool009h0oooo3`00001D0?ooo`00WP3oool?000005@0oooo002N0?ooo`l00000E03oool009/0
oooo0`0000000`3oool000000000000;000005D0oooo002I0?ooo`800000103oool=000005D0oooo
002F0?ooo`<000001`3oool;000005H0oooo002C0?ooo`<000002`3oool9000005L0oooo002@0?oo
o`<00000403oool5000005T0oooo002>0?ooo`8000004`3oool010000000oooo0?ooo`00001J0?oo
o`00R`3oool3000001D0oooo00D000000?ooo`3oool0oooo0000001I0?ooo`00R03oool3000001P0
oooo00D000000?ooo`3oool0oooo0000001I0?ooo`00Q@3oool3000001/0oooo00D000000?ooo`3o
ool0oooo0000001I0?ooo`00PP3oool3000001h0oooo00D000000?ooo`3oool0oooo0000001I0?oo
o`00P03oool200000200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00
O@3oool300000280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1F0?ooo`00NP3o
ool3000002D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1F0?ooo`00M`3oool3
000002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1F0?ooo`00M@3oool20000
02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?ooo`00LP3oool3000002`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?ooo`00K`3oool3000002l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?ooo`00K03oool300000380oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`00JP3oool2000003D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`00I`3oool3000003H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`00I03oool3000003T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1E0?ooo`00H@3oool3000003`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1E0?ooo`00G`3oool2000003l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1D0?ooo`00G03oool300000400oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1D0?ooo`00F@3oool3000004<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1D0?ooo`00EP3oool3000004H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1D0?ooo`00E03oool2000004T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1D0?ooo`00303oool200000003010@403oool0oooo0400oooo0`00001;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0D`3oool000d0oooo00<000000?ooo`3oool0?P3oool3
000004d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1C0?ooo`002@3oool60000
03`0oooo0`00001@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0D`3oool000T0
oooo00D0MgMg0:VYZ@3oool0oooo0000000k0?ooo`800000D`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo05<0oooo00090?ooo`050>k^kP0b<S80k^k^0?ooo`000000>03oool30000
03H0oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
05<0oooo000:0?ooo`040:VYZ@1VIVH0oooo000003D0oooo0`00000i0?ooo`030?l0003oool0oooo
01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1B0?ooo`002`3oool00`14A4@0
c<c<0000000b0?ooo`<00000?03oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0DP3oool000/0oooo00<0gMgM04A4A0000000;`3oool3000003l0oooo
00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0580oooo
000<0?ooo`0307MgM`0@4100oooo02`0oooo0P0000120?ooo`030?l0003oool0oooo01/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1B0?ooo`00903oool5000000l0oooo0`000014
0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1B
0?ooo`008P3oool9000000X0oooo0`0000170?ooo`030?l0003oool0oooo01X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1B0?ooo`008@3oool;000000H0oooo0`00001:0?ooo`03
0?l0003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1A0?ooo`00
803oool=000000<0oooo0P00001=0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1A0?ooo`00803oool@000004l0oooo00<0o`000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0540oooo000O0?ooo`l00000D@3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0D@3oool0
01l0oooo3`00001A0?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1A0?ooo`007`3oool?00000540oooo00<0o`000?ooo`3oool06@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0500oooo000O0?oooa400000C`3oool00`3o0000oooo
0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0D03oool001l0oooo3`00
00020?ooo`H00000B@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0D03oool00200oooo3@0000090?ooo`H00000@`3oool00`3o0000oooo0?ooo`0I
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0D03oool00200oooo3@00000?0?oo
o`H00000?@3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0D03oool00240oooo2`00000F0?ooo`H00000=`3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0C`3oool00280oooo2@00000M0?ooo`L00000
<03oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
C`3oool002@0oooo1@0000000`3oool000000?ooo`0S0?ooo`H00000:P3oool00`3o0000oooo0?oo
o`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C`3oool002/0oooo00<00000
0?ooo`3oool09`3oool6000002@0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04l0oooo000/0?ooo`030000003oool0oooo02`0oooo1P00000N0?oo
o`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1?0?oo
o`00;@3oool00`000000oooo0?ooo`0a0?ooo`H00000603oool00`3o0000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0C`3oool002d0oooo00<000000?ooo`3oool0
=`3oool600000180oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04h0oooo000^0?ooo`030000003oool0oooo03`0oooo1P00000<0?ooo`030?l0003o
ool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1>0?ooo`00;`3oool0
0`000000oooo0?ooo`110?ooo`H000001P3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0CP3oool002l0oooo00<000000?ooo`3oool0A`3oool60000
00030?l0003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?oo
o`H00000?P3oool00300oooo00<000000?ooo`3oool0C03oool00`3o0000000000000003000001<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`0309RHV0000000c<c<0080
oooo00<0410@0?ooo`3oool0?03oool00340oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo
0?ooo`030?ooo`H000003@3oool00`000000oooo0?ooo`0E0?ooo`D000002@3oool00`2HV9P00000
0<c<c0100?ooo`00<@3oool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0oooo00T0oooo1`00
00060?ooo`030000003oool0oooo01<0oooo2@0000080?ooo`030:VYZ@0@4100c<c<03l0oooo000b
0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0403oool6000001D0oooo2`000008
0?ooo`030<c<c00@4100c<c<03h0oooo000c0?ooo`030000003oool0oooo04T0oooo00<0o`000?oo
o`3oool05@3oool7000000h0oooo3@0000080?ooo`030:VYZ@0b<S80oooo03d0oooo000c0?ooo`03
0000003oool0oooo04T0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`H0
0000203oool=000000T0oooo00<000000?ooo`3oool0?03oool003@0oooo00<000000?ooo`3oool0
B03oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo1P0000000`3oool00000
0000000=000000<0oooo00H0000008N7Q`3^k^h0oooo07MgM`0b<S8n0?ooo`00=@3oool00`000000
oooo0?ooo`170?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool@000000<0
oooo00H0ZJVY038b<P000000000005EEE@3^k^hn0?ooo`00=@3oool00`000000oooo0?ooo`170?oo
o`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool?000004L0oooo000f0?ooo`03
0000003oool0oooo04H0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`l0
0000A`3oool003L0oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`0D0?ooo`030000
003oool0oooo0180oooo3`0000170?ooo`00=`3oool00`000000oooo0?ooo`150?ooo`030?l0003o
ool0oooo01@0oooo00<000000?ooo`3oool04`3oool=000004P0oooo000h0?ooo`030000003oool0
oooo04@0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`d00000B03oool0
03T0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo
01D0oooo2`0000190?ooo`00>P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo01<0
oooo00<000000?ooo`3oool05P3oool9000004X0oooo000j0?ooo`030000003oool0oooo0480oooo
00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`H00000C03oool003/0oooo00<0
00000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0D03oool003`0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0B
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D03oool003`0oooo00<000000?oo
o`3oool0@03oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0D@3oool003d0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0D@3oool003h0oooo00<000000?ooo`3oool0
?P3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
D@3oool003h0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0DP3oool003l0oooo00<000000?ooo`3oool0?@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0DP3oool0
0400oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0D`3oool00400oooo00<000000?ooo`3oool0?03oool00`3o0000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D`3oool00440oooo
00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0E03oool00480oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E03oool00480oooo00<00000
0?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0E@3oool004<0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0@0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool004@0oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0EP3oool004@0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0EP3oool004D0oooo00<000000?ooo`3oool0=`3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0E`3o
ool004H0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0E`3oool004L0oooo00<000000?ooo`3oool0=@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F03oool004L0
oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0F03oool004P0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo
0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F@3oool004T0oooo00<0
00000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0F@3oool004T0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0>
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0FP3oool004X0oooo00<000000?oo
o`3oool0<P3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0FP3oool004/0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0F`3oool004/0oooo00<000000?ooo`3oool0
<@3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
F`3oool004`0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0F`3oool004d0oooo00<000000?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool0
04d0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0G03oool004h0oooo00<000000?ooo`3oool0;P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3oool004l0oooo
00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0G@3oool004l0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?oo
o`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00500oooo00<00000
0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0GP3oool00540oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G`3oool00540oooo00<000000?ooo`3o
ool0:`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0G`3oool00580oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0H03oool005<0oooo00<000000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0H03o
ool005@0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0H@3oool005@0oooo00<000000?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0H@3oool005D0
oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0HP3oool005H0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0HP3oool005H0oooo00<0
00000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0H`3oool005L0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H`3oool005P0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0I03oool005P0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`090?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0I03oool005T0oooo00<000000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
I@3oool005X0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0I@3oool005X0oooo00<000000?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0IP3oool0
05/0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0IP3oool005`0oooo00<000000?ooo`3oool0803oool00`3o0000
oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0IP3oool005`0oooo
00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0I`3oool005d0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0I`3oool005h0oooo00<00000
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0J03oool005h0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`070?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0J03oool005l0oooo00<000000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0J@3oool00600oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0J@3oool00640oooo00<000000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0JP3o
ool00640oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0JP3oool00680oooo00<000000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool006<0
oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0J`3oool006<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K03oool006@0oooo00<0
00000?ooo`3oool0603oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0K03oool006D0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K@3oool006D0oooo00<000000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0K@3oool006H0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0KP3oool006L0oooo00<000000?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
KP3oool006L0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0K`3oool006P0oooo00<000000?ooo`3oool0503oool0
0`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0K`3oool0
06T0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0L03oool006T0oooo00<000000?ooo`3oool04`3oool00`3o0000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L03oool006X0oooo
00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0L03oool006/0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool006/0oooo00<00000
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0L@3oool006`0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0LP3oool006d0oooo00<000000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0LP3oool006h0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0L`3oool006h0oooo00<000000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L`3o
ool006l0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0M03oool00700oooo00<000000?ooo`3oool0303oool00`3o
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M03oool00700
oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0M@3oool00740oooo00<000000?ooo`3oool02`3oool01@3o0000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0M@3oool00780oooo00<000000?ooo`3oool0
2P3oool01@3o0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0MP3oool00780oooo
00<000000?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0MP3oool007<0oooo00<000000?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0M`3oool007@0oooo00<000000?ooo`3oool0203oool01@3o0000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0M`3oool007@0oooo00<000000?ooo`3oool0
203oool0103o0000oooo0?ooo`0000030?ooo`030000003oool0oooo07P0oooo001e0?ooo`030000
003oool0oooo00L0oooo00@0o`000?ooo`3oool000000`3oool00`000000oooo0?ooo`1h0?ooo`00
MP3oool00`000000oooo0?ooo`060?ooo`040?l0003oool0oooo00000080oooo00<000000?ooo`3o
ool0N@3oool007H0oooo00<000000?ooo`3oool01P3oool0103o0000oooo0?ooo`0000020?ooo`03
0000003oool0oooo07T0oooo001g0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`000000
0P3oool00`000000oooo0?ooo`1j0?ooo`00N03oool00`000000oooo0?ooo`040?ooo`030?l0003o
ool000000080oooo00<000000?ooo`3oool0NP3oool007P0oooo00<000000?ooo`3oool0103oool0
0`3o0000oooo000000020?ooo`030000003oool0oooo07X0oooo001i0?ooo`030000003oool0oooo
00<0oooo00D0o`000?ooo`000000oooo0000001m0?ooo`00NP3oool00`000000oooo0?ooo`050000
00030?ooo`000000oooo07`0oooo001k0?ooo`T00000O@3oool007X0oooo2`00001l0?ooo`00N@3o
ool=000007/0oooo001i0?ooo`d00000N`3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0
oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001i0?oo
o`d00000N`3oool007T0oooo3@00001k0?ooo`00NP3oool;000007`0oooo001k0?ooo`T00000O@3o
ool007d0oooo1@00001o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000
oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?oo
o`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00O@3oool40000
0003010@403oool0oooo07d0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000
003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0
oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0
oooo001m0?ooo`0300000014A4@000000840oooo001m0?ooo`030<c<c01EEED000000840oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.66664 .54 Mdot
.5 Mabswid
[ ] 0 setdash
.66664 .54 m
.67841 .26932 L
s
.66664 .54 m
.14183 .42708 L
s
.4958 .947 m
.66664 .54 L
s
15 Mabswid
.14183 .42708 Mdot
.5 Mabswid
.14183 .42708 m
.67841 .26932 L
s
.4958 .947 m
.14183 .42708 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.67841 .26932 L
s
15 Mabswid
.67841 .26932 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71163 .51893 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.73889 .15354 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03963 .37112 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00^P3oool01P2YZJT08B4Q000000000000EEEE0>k^kT40oooo002j0?oo
o`06010@402j^[X0oooo0?ooo`2YZJT0<S8b@@3oool00;l0oooo00<000000?ooo`3oool0?`3oool0
0;h0oooo00<0MgMg024Q8@3oool0@03oool00;`0oooo00@08B4Q000000000000^[Zj@@3oool00;d0
oooo00<0k^k^07MgM`0b<S80@@3oool00;l0oooo00<000000?ooo`3oool0?`3oool00;X0oooo00H0
8B4Q0:VYZ@3oool0oooo06IVIP0b<S910?ooo`00^P3oool01P2j^[X0A4A4000000000000A4A40>k^
kT40oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo002/0?ooo`D00000D03oool00:X0oooo2@00001>
0?ooo`00Z@3oool;000004d0oooo002X0?ooo`d00000C03oool00:P0oooo3@00001<0?ooo`00Y`3o
ool?000004/0oooo002W0?ooo`l00000B`3oool00:L0oooo3`00001;0?ooo`00Y`3oool?000004/0
oooo002U0?oooa400000B`3oool00:80oooo0`0000030?ooo`d00000C03oool009h0oooo10000006
0?ooo`d00000C03oool009/0oooo0`00000;0?ooo`/00000C@3oool009P0oooo0`00000?0?ooo`T0
0000CP3oool009@0oooo1000000D0?ooo`D00000D03oool00940oooo0`00000H0?ooo`030000003o
ool000000580oooo002=0?ooo`@000006`3oool00`000000oooo0000001B0?ooo`00RP3oool30000
01h0oooo00@000000?ooo`3oool00000DP3oool008H0oooo1000000Q0?ooo`040000003oool0oooo
00000580oooo00230?ooo`<000009@3oool00`000000oooo0000001C0?ooo`00O`3oool4000002P0
oooo00<000000?ooo`000000D`3oool007`0oooo0`00000[0?ooo`040000003oool0oooo000005<0
oooo001i0?ooo`<00000;P3oool010000000oooo0?ooo`00001C0?ooo`00M@3oool400000340oooo
00@000000?ooo`3oool00000D`3oool00780oooo0`00000e0?ooo`040000003oool0oooo000005<0
oooo001^0?ooo`@00000=`3oool01@000000oooo0?ooo`3oool0000005<0oooo001[0?ooo`<00000
>`3oool01@000000oooo0?ooo`3oool0000005<0oooo001W0?ooo`@00000?P3oool01@000000oooo
0?ooo`3oool0000005<0oooo001T0?ooo`<00000@@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0540oooo001P0?ooo`@00000A03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0540oooo000:0?ooo`80000000<0410@0?ooo`3oool0CP3oool3000004P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1A0?ooo`002`3oool00`000000oooo0?ooo`1;0?oo
o`@00000B`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo00070?ooo`H0
0000B@3oool3000004h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1A0?ooo`00
1`3oool01@1gMgL0ZJVY0?ooo`3oool0000004L0oooo0`00001A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0D@3oool000L0oooo00D0k^k^038b<P3^k^h0oooo000000130?ooo`@0
0000E03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0540oooo00080?ooo`040:VY
Z@1VIVH0oooo00000400oooo0`00001H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0D@3oool000T0oooo00<0A4A40<c<c0000000?03oool4000005X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1A0?ooo`002@3oool00`3MgMd0A4A40000000i0?ooo`<00000GP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0540oooo000:0?ooo`0307MgM`0@4100
oooo03@0oooo1000001Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0D@3oool0
03h0oooo0`00000n0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1A0?ooo`008P3oool5000001<0oooo100000110?ooo`030?l0003oool0oooo02<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`00803oool9000000h0oooo
0`0000150?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1A0?ooo`007`3oool;000000X0oooo0`0000180?ooo`030?l0003oool0oooo02<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`007P3oool=000000D0oooo1000001;
0?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1B
0?ooo`007P3oool=00000080oooo0`00001?0?ooo`030?l0003oool0oooo0280oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1B0?ooo`007@3oool@00000580oooo00<0o`000?ooo`3o
ool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0580oooo000M0?ooo`l00000
D`3oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
DP3oool001d0oooo3`00001C0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1B0?ooo`007@3oool?000005<0oooo00<0o`000?ooo`3oool08@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0580oooo000M0?oooa@00000CP3oool00`3o
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool001h0
oooo3@0000060?ooo`@00000BP3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0DP3oool001h0oooo3@00000:0?ooo`D00000A@3oool00`3o0000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0DP3oool001l0oooo2`00
000@0?ooo`D00000@03oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0DP3oool00200oooo2@00000F0?ooo`@00000?03oool00`3o0000oooo0?ooo`0P
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0DP3oool00280oooo1@0000000`3o
ool000000?ooo`0I0?ooo`D00000=`3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0DP3oool002T0oooo00<000000?ooo`3oool0703oool500000380
oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0580
oooo000Z0?ooo`030000003oool0oooo0200oooo1000000^0?ooo`030?l0003oool0oooo01l0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1B0?ooo`00:P3oool00`000000oooo0?oo
o`0T0?ooo`D00000:@3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0DP3oool002/0oooo00<000000?ooo`3oool0:03oool5000002@0oooo00<0o`00
0?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0580oooo000/0?oo
o`030000003oool0oooo02`0oooo1000000P0?ooo`030?l0003oool0oooo01h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1B0?ooo`00;03oool00`000000oooo0?ooo`0`0?ooo`D0
00006`3oool00`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0DP3oool002d0oooo00<000000?ooo`3oool0=03oool5000001H0oooo00<0o`000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0580oooo000^0?ooo`030000003o
ool0oooo03P0oooo1000000B0?ooo`030?l0003oool0oooo01d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1B0?ooo`00;`3oool00`000000oooo0?ooo`0k0?ooo`D000003@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0DP3oool0
02l0oooo00<000000?ooo`3oool0@03oool4000000T0oooo00<0o`000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0580oooo000`0?ooo`030000003oool0oooo04<0
oooo1@0000040?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1C0?ooo`00<@3oool00`000000oooo0?ooo`170?ooo`@0000000<0o`000?ooo`3oool0
703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05<0oooo000a0?ooo`030000003o
ool0oooo04/0oooo00<0o`000000000000000P00000J0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0D`3oool00380oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`02
0?ooo`D000005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo1P000018
0?ooo`00<`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo00L0oooo1@00000?0?oo
o`030000003oool0oooo00T0oooo1@0000050?ooo`0309RHV0000000c<c<0080oooo00<0410@0?oo
o`3oool0AP3oool003<0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0<0?ooo`@0
00002`3oool00`000000oooo0?ooo`070?ooo`T00000103oool00`2HV9P000000<c<c01:0?ooo`00
=03oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0100oooo1@0000060?ooo`030000
003oool0oooo00H0oooo2`0000040?ooo`030:VYZ@0@4100c<c<04T0oooo000e0?ooo`030000003o
ool0oooo04L0oooo00<0o`000?ooo`3oool05@3oool5000000030?ooo`000000oooo00H0oooo3@00
00040?ooo`030<c<c00@4100c<c<04P0oooo000e0?ooo`030000003oool0oooo04L0oooo00<0o`00
0?ooo`3oool06P3oool4000000D0oooo3@0000050?ooo`030:VYZ@0b<S80oooo04L0oooo000f0?oo
o`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool06P3oool010000000oooo0?ooo`3ooolC
000000D0oooo00<000000?ooo`3oool0AP3oool003L0oooo00<000000?ooo`3oool0A@3oool00`3o
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo400000001@27QhL0k^k^0?ooo`1gMgL0
<S8b04P0oooo000g0?ooo`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`l0000000H0ZJVY038b<P000000000005EEE@3^k^i80?ooo`00>03oool0
0`000000oooo0?ooo`140?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool?
000004h0oooo000i0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`l00000CP3oool003T0oooo00<000000?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo3@00001?0?ooo`00>P3oool00`000000oooo
0?ooo`120?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0203oool=000004l0oooo
000k0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?oo
o`090?ooo`/00000D03oool003/0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0H
0?ooo`030000003oool0oooo00X0oooo2@00001A0?ooo`00?03oool00`000000oooo0?ooo`100?oo
o`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool6000005<0oooo000m0?ooo`03
0000003oool0oooo03l0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo05H0oooo000m0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo000n0?ooo`030000003o
ool0oooo03h0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo05L0oooo000o0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo00100?ooo`030000003oool0oooo
03`0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
05P0oooo00100?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool05P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo05P0oooo00110?ooo`030000003oool0oooo03/0oooo
00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05T0oooo
00120?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo05T0oooo00120?ooo`030000003oool0oooo03X0oooo00<0o`00
0?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05T0oooo00130?oo
o`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo05X0oooo00140?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05X0oooo00140?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo05/0oooo00150?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0503o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05/0oooo00160?ooo`030000003oool0
oooo03H0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo05`0oooo00160?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0503oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo05`0oooo00170?ooo`030000003oool0oooo03D0
oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05`0
oooo00180?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05d0oooo00180?ooo`030000003oool0oooo03@0oooo00<0
o`000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05d0oooo0019
0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo05h0oooo001:0?ooo`030000003oool0oooo0380oooo00<0o`000?oo
o`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05h0oooo001:0?ooo`03
0000003oool0oooo0380oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo05l0oooo001;0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0
4P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05l0oooo001<0?ooo`030000003o
ool0oooo0300oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo05l0oooo001<0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool04@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0600oooo001=0?ooo`030000003oool0oooo
02l0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0600oooo001>0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool04@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0640oooo001>0?ooo`030000003oool0oooo02h0oooo
00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0640oooo
001?0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0640oooo001@0?ooo`030000003oool0oooo02`0oooo00<0o`00
0?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0680oooo001@0?oo
o`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0680oooo001A0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06<0oooo001B0?ooo`030000
003oool0oooo02X0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06<0oooo001C0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool03`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06@0oooo001C0?ooo`030000003oool0
oooo02T0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo06@0oooo001D0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06@0oooo001E0?ooo`030000003oool0oooo02L0
oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06D0
oooo001E0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo06D0oooo001F0?ooo`030000003oool0oooo02H0oooo00<0
o`000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo001G
0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo06H0oooo001G0?ooo`030000003oool0oooo02D0oooo00<0o`000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo001H0?ooo`03
0000003oool0oooo02@0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo06L0oooo001I0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo001I0?ooo`030000003o
ool0oooo02<0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo06P0oooo001J0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo001K0?ooo`030000003oool0oooo
0240oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
06T0oooo001K0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo06T0oooo001L0?ooo`030000003oool0oooo0200oooo
00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06T0oooo
001M0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06X0oooo001M0?ooo`030000003oool0oooo01l0oooo00<0o`00
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06X0oooo001N0?oo
o`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06/0oooo001O0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06/0oooo001O0?ooo`030000
003oool0oooo01d0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo06`0oooo001P0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo001Q0?ooo`030000003oool0
oooo01/0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06`0oooo001Q0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06d0oooo001R0?ooo`030000003oool0oooo01X0
oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06d0
oooo001S0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06h0oooo001S0?ooo`030000003oool0oooo01T0oooo00<0
o`000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06h0oooo001T
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo06h0oooo001U0?ooo`030000003oool0oooo01L0oooo00<0o`000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06l0oooo001V0?ooo`03
0000003oool0oooo01H0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo06l0oooo001V0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo001W0?ooo`030000003o
ool0oooo01D0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0700oooo001X0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0740oooo001X0?ooo`030000003oool0oooo
01@0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0740oooo001Y0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0740oooo001Z0?ooo`030000003oool0oooo0180oooo
00<0o`000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000007@0oooo001Z0?ooo`030000
003oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0780oooo001[0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000007D0oooo001/0?ooo`030000003oool0oooo0100oooo00<0
o`000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000007D0oooo001/0?ooo`030000003o
ool0oooo0100oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo07<0oooo001]0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000007H0oooo001^0?ooo`030000003oool0oooo00h0oooo00<0o`00
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000007H0oooo001^0?ooo`030000003oool0
oooo00h0oooo00<0o`000?ooo`3oool0103oool010000000oooo0?ooo`00001g0?ooo`00K`3oool0
0`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001g0?ooo`00L03oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00<0oooo00@00000
0?ooo`3oool00000N03oool00700oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`03
0?ooo`040000003oool0oooo000007P0oooo001a0?ooo`030000003oool0oooo00/0oooo00<0o`00
0?ooo`3oool00`3oool010000000oooo0?ooo`00001h0?ooo`00LP3oool00`000000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo0080oooo00@000000?ooo`3oool00000N@3oool00780oooo00<00000
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`040000003oool0oooo000007T0oooo001c
0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0000001j
0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`1h0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`070?l0003oool0oooo
0?ooo`000000oooo0000001k0?ooo`00M@3oool00`000000oooo0?ooo`070?ooo`070?l0003oool0
oooo0?ooo`000000oooo0000001k0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`070?l0003o
ool0oooo0?ooo`000000oooo0000001k0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`060?l0
003oool0oooo0000003oool00000O03oool007L0oooo00<000000?ooo`3oool01@3oool01P3o0000
oooo0?ooo`000000oooo000007`0oooo001h0?ooo`030000003oool0oooo00@0oooo00<0o`000?oo
o`3oool00P00001m0?ooo`00N@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0080
0000O@3oool007T0oooo00<000000?ooo`3oool00`3oool01@3o0000oooo0000003oool0000007d0
oooo001j0?ooo`030000003oool0oooo00H00000OP3oool007/0oooo2@00001m0?ooo`00NP3oool;
000007`0oooo001i0?ooo`d00000N`3oool007T0oooo3@00001k0?ooo`00N03oool?000007X0oooo
001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l0
0000NP3oool007T0oooo3@00001k0?ooo`00N@3oool=000007/0oooo001j0?ooo`/00000O03oool0
07/0oooo2@00001m0?ooo`00O@3oool5000007l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo
001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?oo
o`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0
003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0
oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0oooo001o0?ooo`030?l0003oool0oooo07l0
oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80
oooo001m0?ooo`@0000000<0410@0?ooo`3oool0O@3oool007l0oooo00<000000?ooo`3oool0O`3o
ool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0
oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<0
00000?ooo`3oool0O`3oool007d0oooo00<0000004A4A0000000P@3oool007d0oooo00<0c<c<05EE
E@000000P@3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00001\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.63603 .54674 Mdot
.5 Mabswid
[ ] 0 setdash
.63603 .54674 m
.71202 .27916 L
s
.63603 .54674 m
.1388 .41089 L
s
.4958 .947 m
.63603 .54674 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.1388 .41089 Mdot
.5 Mabswid
.1388 .41089 m
.71202 .27916 L
s
.4958 .947 m
.1388 .41089 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.71202 .27916 L
s
15 Mabswid
.71202 .27916 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.67277 .52755 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.78303 .16751 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03428 .3494 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00aP3oool01P2YZJT08B4Q000000000000EEEE0>k^kSD0oooo00360?ooo`06010@402j^[X0
oooo0?ooo`2YZJT0<S8b=@3oool00</0oooo00<000000?ooo`3oool0<`3oool00<X0oooo00<0MgMg
024Q8@3oool0=03oool00<P0oooo00@08B4Q000000000000^[Zj=@3oool00<T0oooo00<0k^k^07Mg
M`0b<S80=@3oool00</0oooo00<000000?ooo`3oool0<`3oool00<H0oooo00H08B4Q0:VYZ@3oool0
oooo06IVIP0b<S8e0?ooo`00aP3oool01P2j^[X0A4A4000000000000A4A40>k^kSD0oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo002d0?oo
o`D00000B03oool00;80oooo2@0000160?ooo`00/@3oool;000004D0oooo002`0?ooo`d00000A03o
ool00;00oooo3@0000140?ooo`00[`3oool?000004<0oooo002_0?ooo`l00000@`3oool00:l0oooo
3`0000130?ooo`00[`3oool?000004<0oooo002[0?oooa<00000@`3oool00:L0oooo100000050?oo
o`d00000A03oool00:<0oooo100000090?ooo`d00000A03oool009h0oooo1@00000>0?ooo`/00000
A@3oool009X0oooo1000000D0?ooo`T00000AP3oool009H0oooo1000000J0?ooo`D00000B03oool0
0940oooo1@00000N0?ooo`030000003oool0oooo04X0oooo002=0?ooo`@000008P3oool2000004`0
oooo00290?ooo`@000009P3oool00`000000oooo0?ooo`1;0?ooo`00Q03oool5000002X0oooo00<0
00000?ooo`3oool0B`3oool00800oooo1000000^0?ooo`800000C@3oool007`0oooo1000000b0?oo
o`800000C@3oool007L0oooo1@00000f0?ooo`030000003oool0oooo04`0oooo00080?ooo`800000
00<0410@0?ooo`3oool0IP3oool4000003X0oooo0P00001>0?ooo`002@3oool00`000000oooo0?oo
o`1S0?ooo`@00000?P3oool2000004h0oooo00050?ooo`H00000G`3oool500000480oooo00<00000
0?ooo`3oool0C@3oool000D0oooo00D0MgMg0:VYZ@3oool0oooo0000001L0?ooo`@00000AP3oool2
000004l0oooo00050?ooo`050>k^kP0b<S80k^k^0?ooo`000000F03oool4000004X0oooo0P00001?
0?ooo`001P3oool0102YZJT0IVIV0?ooo`00001C0?ooo`D00000CP3oool2000004l0oooo00070?oo
o`0304A4A03<c<`0000004l0oooo1000001B0?ooo`800000D03oool000L0oooo00<0gMgM04A4A000
0000B`3oool4000005H0oooo0P00001@0?ooo`00203oool00`1gMgL0410@0?ooo`150?ooo`D00000
FP3oool200000500oooo001<0?ooo`@00000GP3oool00`000000oooo0000001@0?ooo`00B03oool4
00000680oooo0P00001A0?ooo`00@`3oool5000006H0oooo0P00001A0?ooo`008@3oool5000001T0
oooo1000001[0?ooo`800000D@3oool001l0oooo2@00000C0?ooo`@00000KP3oool200000580oooo
000N0?ooo`/000003@3oool500000780oooo0P00001B0?ooo`007@3oool=000000P0oooo10000019
0?ooo`030?l0003oool0oooo02/0oooo0P00001B0?ooo`007@3oool=000000@0oooo1000001=0?oo
o`030?l0003oool0oooo02X0oooo00<000000?ooo`000000DP3oool001`0oooo4P00001A0?ooo`03
0?l0003oool0oooo02X0oooo0P00001C0?ooo`00703oool?000005@0oooo00<0o`000?ooo`3oool0
:P3oool2000005<0oooo000L0?ooo`l00000E03oool00`3o0000oooo0?ooo`0Y0?ooo`030000003o
ool0000005<0oooo000L0?ooo`l00000E03oool00`3o0000oooo0?ooo`0Y0?ooo`800000E03oool0
01`0oooo4@00001B0?ooo`030?l0003oool0oooo02T0oooo0P00001D0?ooo`007@3oool=000000<0
oooo1000001>0?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`000000E03oool001d0oooo
3@0000070?ooo`<00000B`3oool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0000005@0oooo
000N0?ooo`/000002`3oool4000004L0oooo00<0o`000?ooo`3oool0:03oool2000005D0oooo000O
0?ooo`T00000403oool4000004<0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0000001E
0?ooo`008@3oool5000000030?ooo`000000oooo01<0oooo0`0000100?ooo`030?l0003oool0oooo
02L0oooo00<000000?ooo`000000E@3oool002P0oooo00<000000?ooo`3oool0503oool4000003`0
oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0000001E0?ooo`00:@3oool00`000000oooo
0?ooo`0G0?ooo`@00000>03oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0000005H0oooo
000Y0?ooo`030000003oool0oooo01/0oooo0`00000e0?ooo`030?l0003oool0oooo02H0oooo00<0
00000?ooo`000000EP3oool002X0oooo00<000000?ooo`3oool07@3oool400000340oooo00<0o`00
0?ooo`3oool09P3oool00`000000oooo0000001F0?ooo`00:`3oool00`000000oooo0?ooo`0P0?oo
o`@00000;@3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0000005L0oooo000[0?ooo`03
0000003oool0oooo02@0oooo0`00000Z0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`00
0000E`3oool002`0oooo00<000000?ooo`3oool09P3oool4000002H0oooo00<0o`000?ooo`3oool0
9@3oool00`000000oooo0000001G0?ooo`00;@3oool00`000000oooo0?ooo`0Y0?ooo`@000008P3o
ool00`3o0000oooo0?ooo`0T0?ooo`040000003oool0oooo000005L0oooo000]0?ooo`030000003o
ool0oooo02d0oooo0`00000O0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`000000F03o
ool002h0oooo00<000000?ooo`3oool0;`3oool4000001/0oooo00<0o`000?ooo`3oool0903oool0
0`000000oooo0000001H0?ooo`00;`3oool00`000000oooo0?ooo`0b0?ooo`@000005`3oool00`3o
0000oooo0?ooo`0T0?ooo`030000003oool0000005P0oooo000_0?ooo`030000003oool0oooo03H0
oooo0`00000D0?ooo`030?l0003oool0oooo02<0oooo00@000000?ooo`3oool00000F03oool00300
oooo00<000000?ooo`3oool0>03oool400000100oooo00<0o`000?ooo`3oool08`3oool00`000000
oooo0000001I0?ooo`00<@3oool00`000000oooo0?ooo`0k0?ooo`@00000303oool00`3o0000oooo
0?ooo`0S0?ooo`030000003oool0000005T0oooo000a0?ooo`030000003oool0oooo03l0oooo0`00
00090?ooo`030?l0003oool0oooo0280oooo00@000000?ooo`3oool00000F@3oool00380oooo00<0
00000?ooo`3oool0@@3oool4000000D0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0000
001J0?ooo`00<`3oool00`000000oooo0?ooo`140?ooo`@0000000<0oooo0?l0003oool08`3oool0
0`000000oooo0000001J0?ooo`00<`3oool00`000000oooo0?ooo`180?ooo`030000003o00000000
0280oooo00@000000?ooo`3oool00000FP3oool003@0oooo00<000000?ooo`3oool0B03oool00`3o
0000oooo00000003000001h0oooo00@000000?ooo`3oool00000FP3oool003D0oooo00<000000?oo
o`3oool0A`3oool00`3o0000oooo0?ooo`030?ooo`@000006P3oool00`000000oooo000000030?oo
o`H00000DP3oool003D0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`070?ooo`<0
00005@3oool5000000<0oooo00<0V9RH0000003<c<`00P3oool00`0@4100oooo0?ooo`1@0?ooo`00
=P3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo00X0oooo1000000?0?ooo`T00000
0P3oool00`2HV9P000000<c<c01D0?ooo`00=`3oool00`000000oooo0?ooo`150?ooo`030?l0003o
ool0oooo00h0oooo1000000:0?ooo`/000000P3oool00`2YZJT0410@0<c<c01C0?ooo`00=`3oool0
0`000000oooo0?ooo`150?ooo`030?l0003oool0oooo0180oooo0`0000060?ooo`d000000P3oool0
0`3<c<`0410@0<c<c01B0?ooo`00>03oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo
01D0oooo100000020?ooo`d000000`3oool00`2YZJT0<S8b0?ooo`1A0?ooo`00>@3oool00`000000
oooo0?ooo`130?ooo`030?l0003oool0oooo01T0oooo400000030?ooo`030000003oool0oooo0500
oooo000i0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool06P3oool?000000040>k^
kP3oool0MgMg038b<U80oooo000j0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0
6P3ooolA0000000305EEE@3^k^h0oooo0540oooo000k0?ooo`030000003oool0oooo0440oooo00<0
o`000?ooo`3oool06P3oool?000005H0oooo000k0?ooo`030000003oool0oooo0440oooo00<0o`00
0?ooo`3oool06P3oool?000005H0oooo000l0?ooo`030000003oool0oooo0400oooo00<0o`000?oo
o`3oool06`3oool=000005L0oooo000m0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3o
ool06`3oool=000005L0oooo000m0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0
703oool;000005P0oooo000n0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0703o
ool:000005T0oooo000o0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0703oool0
0`000000oooo0?ooo`05000005/0oooo000o0?ooo`030000003oool0oooo03d0oooo00<0o`000?oo
o`3oool0703oool00`000000oooo0000001P0?ooo`00@03oool00`000000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo01/0oooo00@000000?ooo`3oool00000H03oool00440oooo00<000000?ooo`3o
ool0>`3oool00`3o0000oooo0?ooo`0K0?ooo`040000003oool0oooo00000600oooo00110?ooo`03
0000003oool0oooo03/0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0000001Q0?ooo`00
@P3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo01X0oooo00@000000?ooo`3oool0
0000H@3oool004<0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0J0?ooo`040000
003oool0oooo00000640oooo00130?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0
6P3oool00`000000oooo0000001R0?ooo`00A03oool00`000000oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo01T0oooo00@000000?ooo`3oool00000HP3oool004D0oooo00<000000?ooo`3oool0=`3o
ool00`3o0000oooo0?ooo`0I0?ooo`040000003oool0oooo00000680oooo00150?ooo`030000003o
ool0oooo03L0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0000001S0?ooo`00AP3oool0
0`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo01P0oooo00@000000?ooo`3oool00000H`3o
ool004L0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0H0?ooo`040000003oool0
oooo000006<0oooo00170?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0603oool0
0`000000oooo0000001T0?ooo`00B03oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo
01L0oooo00@000000?ooo`3oool00000I03oool004T0oooo00<000000?ooo`3oool0<`3oool00`3o
0000oooo0?ooo`0G0?ooo`030000003oool0000006D0oooo00190?ooo`030000003oool0oooo03<0
oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0000001U0?ooo`00BP3oool00`000000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo01H0oooo00@000000?ooo`3oool00000I@3oool004/0oooo
00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0000006H0oooo
001;0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0000
001V0?ooo`00C03oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo01D0oooo00@00000
0?ooo`3oool00000IP3oool004d0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0E
0?ooo`030000003oool0000006L0oooo001=0?ooo`030000003oool0oooo02l0oooo00<0o`000?oo
o`3oool05@3oool00`000000oooo0000001W0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`03
0?l0003oool0oooo01D0oooo00<000000?ooo`000000I`3oool004l0oooo00<000000?ooo`3oool0
;@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0000006P0oooo001?0?ooo`030000003o
ool0oooo02d0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0000001X0?ooo`00D03oool0
0`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`000000J03oool0
0540oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool00000
06T0oooo001A0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool04`3oool00`000000
oooo0000001Y0?ooo`00DP3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo01<0oooo
00<000000?ooo`000000J@3oool005<0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`0B0?ooo`030000003oool0000006X0oooo001C0?ooo`030000003oool0oooo02T0oooo00<0o`00
0?ooo`3oool04P3oool00`000000oooo0000001Z0?ooo`00E03oool00`000000oooo0?ooo`0X0?oo
o`030?l0003oool0oooo0180oooo00<000000?ooo`000000JP3oool005D0oooo00<000000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0000006/0oooo001E0?ooo`030000
003oool0oooo02L0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0000001[0?ooo`00EP3o
ool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0140oooo0P00001/0?ooo`00E`3oool0
0`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0100oooo00<000000?ooo`000000K03oool0
05L0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool00000
06`0oooo001H0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0403oool2000006d0
oooo001I0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo
0000001]0?ooo`00F@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00l0oooo00<0
00000?ooo`000000K@3oool005X0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0?
0?ooo`800000KP3oool005/0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000003oool0000006h0oooo001K0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3o
ool03P3oool00`000000oooo0000001^0?ooo`00G03oool00`000000oooo0?ooo`0P0?ooo`030?l0
003oool0oooo00h0oooo0P00001_0?ooo`00G@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo00d0oooo00<000000?ooo`000000K`3oool005d0oooo00<000000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000003oool0000006l0oooo001N0?ooo`030000003oool0oooo
01h0oooo00<0o`000?ooo`3oool03@3oool200000700oooo001O0?ooo`030000003oool0oooo01d0
oooo00<0o`000?ooo`3oool03@3oool200000700oooo001O0?ooo`030000003oool0oooo01d0oooo
00<0o`000?ooo`3oool0303oool00`000000oooo0000001`0?ooo`00H03oool00`000000oooo0?oo
o`0L0?ooo`030?l0003oool0oooo00`0oooo0P00001a0?ooo`00H@3oool00`000000oooo0?ooo`0K
0?ooo`030?l0003oool0oooo00`0oooo0P00001a0?ooo`00H@3oool00`000000oooo0?ooo`0K0?oo
o`030?l0003oool0oooo00/0oooo00<000000?ooo`000000L@3oool00680oooo00<000000?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0;0?ooo`800000LP3oool006<0oooo00<000000?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0;0?ooo`800000LP3oool006<0oooo00<000000?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool000000780oooo001T0?ooo`030000003oool0
oooo01P0oooo00<0o`000?ooo`3oool02P3oool2000007<0oooo001U0?ooo`030000003oool0oooo
01L0oooo00<0o`000?ooo`3oool02P3oool2000007<0oooo001U0?ooo`030000003oool0oooo01L0
oooo00<0o`000?ooo`3oool02@3oool2000007@0oooo001V0?ooo`030000003oool0oooo01H0oooo
00<0o`000?ooo`3oool02@3oool2000007@0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0
o`000?ooo`3oool02@3oool2000007@0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0o`00
0?ooo`3oool0203oool2000007D0oooo001X0?ooo`030000003oool0oooo01@0oooo00<0o`000?oo
o`3oool0203oool2000007D0oooo001Y0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o
ool0203oool2000007D0oooo001Y0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0
1`3oool2000007H0oooo001Z0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool01`3o
ool2000007H0oooo001[0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool01`3oool2
000007H0oooo001[0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool01P3oool20000
07L0oooo001/0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool2000007L0
oooo001]0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool2000007L0oooo
001]0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool01@3oool2000007P0oooo001^
0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool2000007P0oooo001_0?oo
o`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool2000007P0oooo001_0?ooo`03
0000003oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`00
L03oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo0P00001i0?ooo`00L@3o
ool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo0P00001i0?ooo`00L@3oool0
0`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0N03oool0
0780oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`800000NP3oool007<0
oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo07T0
oooo001c0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo
0?ooo`1i0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo0P00
001k0?ooo`00M@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<00000
0?ooo`3oool0NP3oool007D0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?oo
o`030000003oool0oooo07X0oooo001f0?ooo`030000003oool0oooo00H0oooo00@0o`000?ooo`3o
ool0oooo0P00001l0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`050?l0003oool0oooo0?oo
o`000000O@3oool007L0oooo00<000000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool00000
07d0oooo001h0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool00P00001m0?ooo`00
N@3oool00`000000oooo0?ooo`030?ooo`040?l0003oool0oooo000007h0oooo001i0?ooo`030000
003oool0oooo00<0oooo00@0o`000?ooo`3oool00000OP3oool007X0oooo00<000000?ooo`3oool0
1P00001n0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?oo
o`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?
000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo
001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D0
0000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0
oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0
o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?oo
o`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3o
ool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo
0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o
0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00
O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool0
0`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.60427 .55215 Mdot
.5 Mabswid
[ ] 0 setdash
.60427 .55215 m
.74263 .29055 L
s
.60427 .55215 m
.13966 .39444 L
s
.4958 .947 m
.60427 .55215 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.13966 .39444 Mdot
.5 Mabswid
.13966 .39444 m
.74263 .29055 L
s
.4958 .947 m
.13966 .39444 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.74263 .29055 L
s
15 Mabswid
.74263 .29055 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.6326 .53446 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.8229 .18362 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03393 .3272 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00d03oool0
1P2YZJT08B4Q000000000000EEEE0>k^kR/0oooo003@0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8b:`3oool00=D0oooo00<000000?ooo`3oool0:@3oool00=@0oooo00<0MgMg024Q8@3oool0:P3o
ool00=80oooo00@08B4Q000000000000^[Zj:`3oool00=<0oooo00<0k^k^07MgM`0b<S80:`3oool0
0=D0oooo00<000000?ooo`3oool0:@3oool00=00oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S8[
0?ooo`00d03oool01P2j^[X0A4A4000000000000A4A40>k^kR/0oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo002l0?ooo`D00000@03oool00;X0oooo2@00000n
0?ooo`00^@3oool;000003d0oooo002h0?ooo`d00000?03oool00;P0oooo3@00000l0?ooo`00]`3o
ool?000003/0oooo002g0?ooo`l00000>`3oool00;L0oooo3`00000k0?ooo`00]@3ooolA000003/0
oooo002`0?ooo`D000000P3oool?000003/0oooo002Z0?ooo`H00000203oool=000003`0oooo002T
0?ooo`H000003P3oool=000003`0oooo002N0?ooo`H000005@3oool;000003d0oooo002I0?ooo`D0
0000703oool9000003h0oooo00080?ooo`80000000<0410@0?ooo`3oool0QP3oool600000280oooo
1P0000100?ooo`002@3oool00`000000oooo0?ooo`210?ooo`H000009`3oool2000004D0oooo0005
0?ooo`H00000O03oool6000002d0oooo0P0000150?ooo`001@3oool01@1gMgL0ZJVY0?ooo`3oool0
000007P0oooo1@00000b0?ooo`800000AP3oool000D0oooo00D0k^k^038b<P3^k^h0oooo0000001b
0?ooo`H00000=`3oool2000004H0oooo00060?ooo`040:VYZ@1VIVH0oooo000006`0oooo1P00000l
0?ooo`030000003oool0000004H0oooo00070?ooo`0304A4A03<c<`0000006H0oooo1P0000110?oo
o`030000003oool0000004L0oooo00070?ooo`030=gMg@14A4@000000640oooo1@0000170?ooo`03
0000003oool0000004L0oooo00080?ooo`0307MgM`0@4100oooo05X0oooo1P00001;0?ooo`040000
003oool0oooo000004L0oooo001O0?ooo`H00000D@3oool00`000000oooo000000180?ooo`00FP3o
ool5000005H0oooo00@000000?ooo`3oool00000B03oool005@0oooo1P00001K0?ooo`030000003o
ool0000004T0oooo001>0?ooo`H00000H03oool010000000oooo0?ooo`0000190?ooo`008@3oool5
00000280oooo1P00001V0?ooo`040000003oool0oooo000004T0oooo000O0?ooo`T000006`3oool5
000006/0oooo00@000000?ooo`3oool00000BP3oool001h0oooo2`00000D0?ooo`H00000L03oool0
10000000oooo0?ooo`00001:0?ooo`007@3oool=000000d0oooo1P00001e0?ooo`050000003oool0
oooo0?ooo`000000BP3oool001d0oooo3@0000070?ooo`H00000N`3oool010000000oooo0?ooo`00
001;0?ooo`00703oool?000000030?ooo`000000000000<00000P03oool01@000000oooo0?ooo`3o
ool0000004/0oooo000L0?oooa000000Q@3oool010000000oooo0?ooo`00001<0?ooo`00703oool?
000005@0oooo00<0o`000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool0000004`0oooo000L
0?ooo`l00000E03oool00`3o0000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000C03o
ool001`0oooo4000001C0?ooo`030?l0003oool0oooo02d0oooo00D000000?ooo`3oool0oooo0000
001=0?ooo`007@3oool=00000080oooo0`00001@0?ooo`030?l0003oool0oooo02d0oooo00D00000
0?ooo`3oool0oooo0000001=0?ooo`007@3oool=000000D0oooo0`00001=0?ooo`030?l0003oool0
oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`007P3oool;0000
00T0oooo0`00001:0?ooo`030?l0003oool0oooo02`0oooo00D000000?ooo`3oool0oooo0000001>
0?ooo`007`3oool9000000d0oooo0`0000170?ooo`030?l0003oool0oooo02/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1<0?ooo`008@3oool5000000030?ooo`000000oooo00l0
oooo0`0000140?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1<0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`<00000@@3oool00`3o0000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool002T0oooo00<0
00000?ooo`3oool04P3oool3000003h0oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04d0oooo000Y0?ooo`030000003oool0oooo01D0oooo0`00000k
0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1>
0?ooo`00:P3oool00`000000oooo0?ooo`0G0?ooo`<00000>03oool00`3o0000oooo0?ooo`0X0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0CP3oool002X0oooo00<000000?ooo`3o
ool06P3oool3000003D0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04h0oooo000[0?ooo`030000003oool0oooo01`0oooo0`00000b0?ooo`030?l0
003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`00;03o
ool00`000000oooo0?ooo`0N0?ooo`<00000;`3oool00`3o0000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0C`3oool002`0oooo00<000000?ooo`3oool08@3oool3
000002`0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo04l0oooo000]0?ooo`030000003oool0oooo02<0oooo0`00000Y0?ooo`030?l0003oool0oooo
02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`00;P3oool00`000000
oooo0?ooo`0U0?ooo`<000009P3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0D03oool002h0oooo00<000000?ooo`3oool0:03oool3000002<0oooo
00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0540oooo
000_0?ooo`030000003oool0oooo02X0oooo0`00000P0?ooo`030?l0003oool0oooo02@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1A0?ooo`00<03oool00`000000oooo0?ooo`0/
0?ooo`<000007@3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0D@3oool00300oooo00<000000?ooo`3oool0;`3oool3000001X0oooo00<0o`000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0580oooo000a0?ooo`03
0000003oool0oooo0340oooo0`00000G0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1B0?ooo`00<P3oool00`000000oooo0?ooo`0c0?ooo`<00000
503oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
DP3oool00380oooo00<000000?ooo`3oool0=P3oool300000140oooo00<0o`000?ooo`3oool08P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05<0oooo000c0?ooo`030000003oool0
oooo03P0oooo0`00000>0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1C0?ooo`00=03oool00`000000oooo0?ooo`0j0?ooo`<000002`3oool00`3o
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E03oool003@0
oooo00<000000?ooo`3oool0?@3oool3000000P0oooo00<0o`000?ooo`3oool0803oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo05@0oooo000e0?ooo`030000003oool0oooo03l0oooo
0`0000050?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1D0?ooo`00=@3oool00`000000oooo0?ooo`120?ooo`<000000P3oool00`3o0000oooo0?oo
o`0O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool003H0oooo00<00000
0?ooo`3oool0A03oool2000000030?l0003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1E0?ooo`00=`3oool00`000000oooo0?ooo`150?ooo`040?l0000000000000
000001d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`00=`3oool00`00
0000oooo0?ooo`150?ooo`040?l0003oool0oooo0?ooo`<000006@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo05H0oooo000h0?ooo`030000003oool0oooo04@0oooo00<0o`000?oo
o`3oool0103oool300000100oooo1@0000000`3oool0000000000004000000<0oooo00<000000?oo
o`3oool0EP3oool003T0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`070?ooo`<0
00002`3oool:000000040<c<c03oool0oooo010@4080oooo00<000000?ooo`3oool0E`3oool003T0
oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0:0?ooo`<000001`3oool<00000003
0<c<c03oool0oooo0080oooo00<000000?ooo`3oool0E`3oool003X0oooo00<000000?ooo`3oool0
@P3oool00`3o0000oooo0?ooo`0=0?ooo`<000000`3oool=00000003010@403<c<`0oooo0080oooo
00<000000?ooo`3oool0E`3oool003/0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?oo
o`0@0?oooa00000000D0c<c<010@403<c<`0oooo0000001J0?ooo`00>`3oool00`000000oooo0?oo
o`110?ooo`030?l0003oool0oooo0180oooo3`000000102YZJT0<S8b0?ooo`00001J0?ooo`00?03o
ool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0180oooo3`000000103oool000000?oo
o`00001J0?ooo`00?@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0180oooo3`00
00000`1gMgL0<S8b0000001K0?ooo`00?@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0
oooo0180oooo3`0000000`1EEED0k^k^0000001K0?ooo`00?P3oool00`000000oooo0?ooo`0n0?oo
o`030?l0003oool0oooo0180oooo3`0000000`3oool000000?ooo`1K0?ooo`00?`3oool00`000000
oooo0?ooo`0m0?ooo`030?l0003oool0oooo01<0oooo3@0000020?ooo`030000003oool0oooo05X0
oooo000o0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool04`3oool=00000080oooo
00<000000?ooo`3oool0FP3oool00400oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?oo
o`0D0?ooo`/000000P3oool00`000000oooo0?ooo`1K0?ooo`00@03oool00`000000oooo0?ooo`0l
0?ooo`030?l0003oool0oooo01D0oooo2@0000030?ooo`030000003oool0oooo05/0oooo00110?oo
o`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool05`3oool5000000D0oooo00<000000?oo
o`3oool0F`3oool00480oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0G03oool00480oooo00<000000?ooo`3oool0
>P3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
G03oool004<0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0G@3oool004@0oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool0
04@0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0G@3oool004D0oooo00<000000?ooo`3oool0=`3oool00`3o0000
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0GP3oool004H0oooo
00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0GP3oool004H0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?oo
o`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0GP3oool004L0oooo00<00000
0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0G`3oool004P0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`0D0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G`3oool004P0oooo00<000000?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0H03oool004T0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0H03oool004X0oooo00<000000?ooo`3oool0<P3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H03o
ool004X0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0H@3oool004/0oooo00<000000?ooo`3oool0<@3oool00`3o
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H@3oool004/0
oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0H@3oool004`0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0HP3oool004d0oooo00<0
00000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0HP3oool004d0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool004h0oooo00<000000?oo
o`3oool0;P3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0H`3oool004l0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0H`3oool004l0oooo00<000000?ooo`3oool0
;@3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I03oool00500oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0I03oool00540oooo00<000000?ooo`3oool0:`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool0
0540oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I@3oool00580oooo00<000000?ooo`3oool0:P3oool00`3o0000
oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool005<0oooo
00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0I@3oool005<0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0IP3oool005@0oooo00<00000
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0IP3oool005D0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0I`3oool005D0oooo00<000000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0I`3oool005H0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0I`3oool005L0oooo00<000000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03o
ool005L0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0J03oool005P0oooo00<000000?ooo`3oool0903oool00`3o
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool005P0
oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0J@3oool005T0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J@3oool005X0oooo00<0
00000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0JP3oool005X0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool005/0oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0JP3oool005`0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0J`3oool005`0oooo00<000000?ooo`3oool0
803oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
J`3oool005d0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0J`3oool005h0oooo00<000000?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool0
05h0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0K03oool005l0oooo00<000000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000K`3oool00600oooo00<000000?ooo`3o
ool0703oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0K@3oool00600oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0K@3oool00640oooo00<000000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000L03oool00680oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0KP3oool00680oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool006<0oooo00<000000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000L@3oool0
06<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`000000L@3oool006@0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`000000LP3oool006D0oooo00<000000?ooo`3oool05`3oool00`3o
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000LP3oool006D0oooo00<000000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000LP3oool0
06H0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`080?ooo`040000003oool0oooo
000007<0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000007<0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000007<0oooo001X0?ooo`030000003oool0oooo
01@0oooo00<0o`000?ooo`3oool01`3oool010000000oooo0?ooo`00001d0?ooo`00J@3oool00`00
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000001d
0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00H0oooo00@000000?oo
o`3oool00000M@3oool006X0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`060?oo
o`040000003oool0oooo000007D0oooo001[0?ooo`030000003oool0oooo0140oooo00<0o`000?oo
o`3oool01P3oool010000000oooo0?ooo`00001e0?ooo`00J`3oool00`000000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00D0oooo00@000000?ooo`3oool00000MP3oool006`0oooo00<000000?oo
o`3oool0403oool00`3o0000oooo0?ooo`050?ooo`040000003oool0oooo000007H0oooo001]0?oo
o`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool01@3oool010000000oooo0?ooo`00001f
0?ooo`00K@3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo00<000000?oo
o`000000M`3oool006h0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`04
0000003oool0oooo000007L0oooo001^0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0103oool010000000oooo0?ooo`00001g0?ooo`00K`3oool00`000000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00@0oooo00<000000?ooo`000000N03oool00700oooo00<000000?ooo`3oool0
303oool00`3o0000oooo0?ooo`030?ooo`040000003oool0oooo000007P0oooo001`0?ooo`030000
003oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0000001i0?ooo`00L@3o
ool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`000000N@3o
ool00780oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0
000007T0oooo001b0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`00
0000oooo0000001j0?ooo`00L`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0080
oooo00<000000?ooo`000000NP3oool007@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0000007X0oooo001d0?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool00P3oool2000007/0oooo001e0?ooo`030000003oool0oooo00L0oooo00L0o`00
0?ooo`3oool0oooo0000003oool0000007/0oooo001f0?ooo`030000003oool0oooo00H0oooo00@0
o`000?ooo`3oool0oooo0P00001l0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`040?l0003o
ool0oooo0?ooo`800000O03oool007L0oooo00<000000?ooo`3oool01@3oool01P3o0000oooo0?oo
o`000000oooo000007`0oooo001h0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0P00001m0?ooo`00N03oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo00800000O@3o
ool007T0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`02000007d0oooo001i0?oo
o`030000003oool0oooo00<0oooo00@0o`000?ooo`0000000000OP3oool007X0oooo00<000000?oo
o`3oool01P00001n0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00
001k0?ooo`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00
N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=0000
07/0oooo001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m
0?ooo`D00000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0
oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0
o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0
oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@
4100oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo
0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o
0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00
O@3oool00`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.57163 .55621 Mdot
.5 Mabswid
[ ] 0 setdash
.57163 .55621 m
.76985 .30331 L
s
.57163 .55621 m
.14453 .37793 L
s
.4958 .947 m
.57163 .55621 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.14453 .37793 Mdot
.5 Mabswid
.14453 .37793 m
.76985 .30331 L
s
.4958 .947 m
.14453 .37793 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.76985 .30331 L
s
15 Mabswid
.76985 .30331 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.59143 .53963 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.85804 .20156 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.0388 .30477 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00f@3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kR80oooo003I0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8b8P3oool00=h0
oooo00<000000?ooo`3oool0803oool00=d0oooo00<0MgMg024Q8@3oool08@3oool00=/0oooo00@0
8B4Q000000000000^[Zj8P3oool00=`0oooo00<0k^k^07MgM`0b<S808P3oool00=h0oooo00<00000
0?ooo`3oool0803oool00=T0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S8R0?ooo`00f@3oool0
1P2j^[X0A4A4000000000000A4A40>k^kR80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo00330?ooo`D00000>@3oool00<40oooo2@00000g0?ooo`00`03oool;
000003H0oooo002o0?ooo`d00000=@3oool000X0oooo0P0000000`0@4100oooo0?ooo`2`0?ooo`d0
0000=@3oool000/0oooo00<000000?ooo`3oool0/03oool?000003@0oooo00070?ooo`H00000/@3o
ool?000003@0oooo00070?ooo`0507MgM`2YZJT0oooo0?ooo`000000/P3oool?000003@0oooo0007
0?ooo`050>k^kP0b<S80k^k^0?ooo`000000[03ooolE000003@0oooo00080?ooo`040:VYZ@1VIVH0
oooo00000:@0oooo200000060?ooo`l00000=03oool000T0oooo00<0A4A40<c<c0000000W03oool8
000000l0oooo3@00000e0?ooo`002@3oool00`3MgMd0A4A40000002C0?ooo`T000005`3oool=0000
03D0oooo000:0?ooo`0307MgM`0@4100oooo08X0oooo2000000Q0?ooo`/00000=P3oool008h0oooo
2@00000Z0?ooo`T00000=`3oool008H0oooo2000000b0?ooo`030000003oool0000000D00000>@3o
ool007d0oooo2@00000i0?ooo`040000003oool0oooo000003h0oooo001e0?ooo`P00000@@3oool0
10000000oooo0?ooo`00000o0?ooo`00K@3oool8000004P0oooo00D000000?ooo`3oool0oooo0000
000o0?ooo`00I03oool900000500oooo00D000000?ooo`3oool0oooo0000000o0?ooo`008`3oool5
000003@0oooo2000001H0?ooo`050000003oool0oooo0?ooo`000000@03oool00240oooo2@00000Y
0?ooo`T00000G`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo000P0?oo
o`/00000803oool8000006L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?oo
o`007`3oool=000001H0oooo2@00001^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0?`3oool001l0oooo3@00000>0?ooo`P00000M`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0400oooo000N0?ooo`l000001@3oool8000007h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`100?ooo`007P3ooolD000008D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`100?ooo`007P3oool?000008T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`110?ooo`007P3oool?000008P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`110?ooo`007P3oool?000008P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`120?ooo`007`3oool?000008H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`120?ooo`007`3oool=00000080oooo0`00001>0?ooo`030?l0003oool0oooo0340oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`130?ooo`00803oool;000000H0oooo0P00001<0?oo
o`030?l0003oool0oooo0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`130?oo
o`008@3oool9000000T0oooo0`0000190?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`130?ooo`008`3oool5000000030?ooo`000000oooo00/0oooo
0P0000170?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`140?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`<00000A03oool00`3o0000oooo0?oo
o`0^0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A03oool002X0oooo00<00000
0?ooo`3oool03P3oool200000480oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo04D0oooo000[0?ooo`030000003oool0oooo00l0oooo0P0000100?oo
o`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`150?oo
o`00:`3oool00`000000oooo0?ooo`0A0?ooo`<00000?@3oool00`3o0000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3oool002`0oooo00<000000?ooo`3oool0
4`3oool2000003/0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04H0oooo000]0?ooo`030000003oool0oooo01@0oooo0`00000h0?ooo`030?l0003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`160?ooo`00;@3oool0
0`000000oooo0?ooo`0G0?ooo`800000=P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0A`3oool002h0oooo00<000000?ooo`3oool0603oool30000
03<0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
04L0oooo000_0?ooo`030000003oool0oooo01X0oooo0P00000a0?ooo`030?l0003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`180?ooo`00;`3oool00`000000oooo
0?ooo`0L0?ooo`800000;`3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0B03oool00300oooo00<000000?ooo`3oool07@3oool3000002`0oooo00<0
o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo000`
0?ooo`030000003oool0oooo0200oooo0P00000Z0?ooo`030?l0003oool0oooo02D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`00<@3oool00`000000oooo0?ooo`0Q0?oo
o`<000009`3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0B@3oool00380oooo00<000000?ooo`3oool08`3oool2000002D0oooo00<0o`000?ooo`3o
ool0903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04X0oooo000b0?ooo`030000
003oool0oooo02D0oooo0`00000R0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1:0?ooo`00<`3oool00`000000oooo0?ooo`0W0?ooo`800000803o
ool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B`3o
ool003<0oooo00<000000?ooo`3oool0:@3oool2000001h0oooo00<0o`000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04/0oooo000d0?ooo`030000003oool0oooo
02X0oooo0`00000K0?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1;0?ooo`00=@3oool00`000000oooo0?ooo`0/0?ooo`8000006@3oool00`3o0000
oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0C03oool003D0oooo
00<000000?ooo`3oool0;P3oool3000001H0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo04`0oooo000f0?ooo`030000003oool0oooo0300oooo0P00
000D0?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1=0?ooo`00=`3oool00`000000oooo0?ooo`0a0?ooo`8000004P3oool00`3o0000oooo0?ooo`0M
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0C@3oool003L0oooo00<000000?oo
o`3oool0<`3oool3000000l0oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo04h0oooo000h0?ooo`030000003oool0oooo03D0oooo0P00000=0?ooo`03
0?l0003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1>0?ooo`00
>03oool00`000000oooo0?ooo`0g0?ooo`<000002P3oool00`3o0000oooo0?ooo`0K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0CP3oool003T0oooo00<000000?ooo`3oool0>@3o
ool2000000P0oooo00<0o`000?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo04l0oooo000j0?ooo`030000003oool0oooo03X0oooo0`0000050?ooo`030?l0003oool0
oooo01T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1?0?ooo`00>P3oool00`00
0000oooo0?ooo`0m0?ooo`8000000`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0D03oool003/0oooo00<000000?ooo`3oool0?P3oool200000003
0?ooo`3o0000oooo01T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1@0?ooo`00
?03oool00`000000oooo0?ooo`0o0?ooo`030000003o0000000001P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1A0?ooo`00?03oool00`000000oooo0?ooo`100?ooo`040?l0003o
ool00000000000d0oooo2P00000C0?ooo`030000003oool0oooo0540oooo000m0?ooo`030000003o
ool0oooo03l0oooo00@0o`000?ooo`3oool0oooo0`0000080?ooo`X0000000<0oooo010@403oool0
4P3oool00`000000oooo0?ooo`1A0?ooo`00?@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003o
ool0oooo00@0oooo0P0000050?ooo`/00000503oool00`000000oooo0?ooo`1B0?ooo`00?P3oool0
0`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo00H0oooo0`0000000`3oool000000000000;
000001<0oooo00<000000?ooo`3oool0DP3oool003l0oooo00<000000?ooo`3oool0?@3oool00`3o
0000oooo0?ooo`090?ooo`h0000000<0c<c<0?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?oo
o`00?`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00T0oooo3`00000A0?ooo`03
0000003oool0oooo05<0oooo00100?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0
2@3oool?00000100oooo00<000000?ooo`3oool0E03oool00400oooo00<000000?ooo`3oool0?03o
ool00`3o0000oooo0?ooo`090?ooo`l00000403oool00`000000oooo0?ooo`1D0?ooo`00@@3oool0
0`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo00T0oooo3`00000@0?ooo`030000003oool0
oooo05@0oooo00120?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool02@3oool?0000
00l0oooo00<000000?ooo`3oool0E@3oool00480oooo00<000000?ooo`3oool0>P3oool00`3o0000
oooo0?ooo`0:0?ooo`d00000403oool00`000000oooo0?ooo`1E0?ooo`00@`3oool00`000000oooo
0?ooo`0i0?ooo`030?l0003oool0oooo00X0oooo3@00000?0?ooo`030000003oool0oooo05H0oooo
00140?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool02`3oool;00000100oooo00<0
00000?ooo`3oool0EP3oool004@0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0<
0?ooo`T000004@3oool00`000000oooo0?ooo`1F0?ooo`00A@3oool00`000000oooo0?ooo`0g0?oo
o`030?l0003oool0oooo00h0oooo1@00000B0?ooo`030000003oool0oooo05L0oooo00150?ooo`03
0000003oool0oooo03L0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo05L0oooo00160?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05P0oooo00170?ooo`030000003o
ool0oooo03D0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo05P0oooo00170?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05T0oooo00180?ooo`030000003oool0oooo
03@0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
05T0oooo00180?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool03P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo05T0oooo00190?ooo`030000003oool0oooo03<0oooo
00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo
001:0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo05X0oooo001:0?ooo`030000003oool0oooo0380oooo00<0o`00
0?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo001;0?oo
o`030000003oool0oooo0340oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05/0oooo001<0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo001<0?ooo`030000
003oool0oooo0300oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo05`0oooo001=0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0303o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo001=0?ooo`030000003oool0
oooo02l0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo05d0oooo001>0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0303oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0oooo001?0?ooo`030000003oool0oooo02d0
oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0
oooo001?0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0303oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo05h0oooo001@0?ooo`030000003oool0oooo02`0oooo00<0
o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05l0oooo001@
0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo05l0oooo001A0?ooo`030000003oool0oooo02/0oooo00<0o`000?oo
o`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05l0oooo001B0?ooo`03
0000003oool0oooo02X0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0600oooo001B0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0600oooo001C0?ooo`030000003o
ool0oooo02T0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0640oooo001D0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0640oooo001D0?ooo`030000003oool0oooo
02P0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0680oooo001E0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0680oooo001E0?ooo`030000003oool0oooo02L0oooo
00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0680oooo
001F0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo06<0oooo001G0?ooo`030000003oool0oooo02D0oooo00<0o`00
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06<0oooo001G0?oo
o`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo06@0oooo001H0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06@0oooo001H0?ooo`030000
003oool0oooo02@0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo06@0oooo001I0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06D0oooo001J0?ooo`030000003oool0
oooo0280oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo06D0oooo001J0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo06H0oooo001K0?ooo`030000003oool0oooo0240
oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06H0
oooo001L0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0203oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo06L0oooo001L0?ooo`030000003oool0oooo0200oooo00<0
o`000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06L0oooo001M
0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo06L0oooo001M0?ooo`030000003oool0oooo01l0oooo00<0o`000?oo
o`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06P0oooo001N0?ooo`03
0000003oool0oooo01h0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06P0oooo001O0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo001O0?ooo`030000003o
ool0oooo01d0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo06T0oooo001P0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06X0oooo001P0?ooo`030000003oool0oooo
01`0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
06X0oooo001Q0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo06X0oooo001R0?ooo`030000003oool0oooo01X0oooo
00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo
001R0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo06/0oooo001S0?ooo`030000003oool0oooo01T0oooo00<0o`00
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06`0oooo001T0?oo
o`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo06`0oooo001T0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06d0oooo001U0?ooo`030000
003oool0oooo01L0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06d0oooo001U0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06d0oooo001V0?ooo`030000003oool0
oooo01H0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo06h0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo001W0?ooo`030000003oool0oooo01D0
oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06l0
oooo001X0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo06l0oooo001Y0?ooo`030000003oool0oooo01<0oooo00<0
o`000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0700oooo001Y
0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0700oooo001Z0?ooo`030000003oool0oooo0180oooo00<0o`000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700oooo001Z0?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0740oooo001[0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo001/0?ooo`030000003o
ool0oooo0100oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0780oooo001/0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0780oooo001]0?ooo`030000003oool0oooo
00l0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0780oooo001]0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo07<0oooo001^0?ooo`030000003oool0oooo00h0oooo
00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07<0oooo
001_0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo07@0oooo001_0?ooo`030000003oool0oooo00d0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07@0oooo001`0?oo
o`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07D0oooo001a0?ooo`030000003oool0oooo00/0oooo00D0o`000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo07D0oooo001a0?ooo`030000003oool0oooo00/0
oooo00D0o`000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo07D0oooo001b0?ooo`03
0000003oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
07H0oooo001b0?ooo`030000003oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo07H0oooo001c0?ooo`030000003oool0oooo00T0oooo00D0o`000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo07L0oooo001d0?ooo`030000003oool0oooo00P0
oooo00@0o`000?ooo`3oool00000103oool00`000000oooo0?ooo`1g0?ooo`00M03oool00`000000
oooo0?ooo`080?ooo`040?l0003oool0oooo000000<0oooo00<000000?ooo`3oool0N03oool007D0
oooo00<000000?ooo`3oool01`3oool0103o0000oooo0?ooo`0000030?ooo`030000003oool0oooo
07P0oooo001e0?ooo`030000003oool0oooo00L0oooo00@0o`000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`1h0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`040?l0003oool0oooo0000
0080oooo00<000000?ooo`3oool0N@3oool007L0oooo00<000000?ooo`3oool01@3oool0103o0000
oooo0?ooo`0000020?ooo`030000003oool0oooo07T0oooo001g0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`0000000P3oool00`000000oooo0?ooo`1j0?ooo`00N03oool00`000000oooo
0?ooo`040?ooo`030?l0003oool000000080oooo00<000000?ooo`3oool0NP3oool007T0oooo00<0
00000?ooo`3oool00`3oool01@3o0000oooo0000003oool0000007d0oooo001i0?ooo`030000003o
ool0oooo00<0oooo00D0o`000?ooo`000000oooo0000001m0?ooo`00NP3oool00`000000oooo0?oo
o`020?ooo`050?l0003oool000000?ooo`000000O@3oool007X0oooo00<000000?ooo`3oool01P00
001n0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?ooo`00
N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?0000
07X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo001i
0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D00000
O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool0
07l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo0?oo
o`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?oo
o`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool00`00
0000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.53839 .5589 Mdot
.5 Mabswid
[ ] 0 setdash
.53839 .5589 m
.79341 .31722 L
s
.53839 .5589 m
.15349 .36155 L
s
.4958 .947 m
.53839 .5589 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.15349 .36155 Mdot
.5 Mabswid
.15349 .36155 m
.79341 .31722 L
s
.4958 .947 m
.15349 .36155 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.79341 .31722 L
s
15 Mabswid
.79341 .31722 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.54957 .54305 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.88808 .22104 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.04905 .28237 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00h@3oool01P2YZJT08B4Q0000
00000000EEEE0>k^kQX0oooo003Q0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8b6P3oool00>H0
oooo00<000000?ooo`3oool0603oool00>D0oooo00<0MgMg024Q8@3oool06@3oool00><0oooo00@0
8B4Q000000000000^[Zj6P3oool00>@0oooo00<0k^k^07MgM`0b<S806P3oool00>H0oooo00<00000
0?ooo`3oool0603oool00>40oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S8J0?ooo`00h@3oool0
1P2j^[X0A4A4000000000000A4A40>k^kQX0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo000<0?oo
o`80000000<0410@0?ooo`3oool0l03oool000d0oooo00<000000?ooo`3oool0l@3oool000T0oooo
1P00003b0?ooo`002@3oool01@1gMgL0ZJVY0?ooo`3oool000000?<0oooo00090?ooo`050>k^kP0b
<S80k^k^0?ooo`000000l`3oool000X0oooo00@0ZJVY06IVIP3oool00000^`3oool5000003<0oooo
000;0?ooo`0304A4A03<c<`000000;T0oooo2@00000a0?ooo`002`3oool00`3MgMd0A4A40000002h
0?ooo`/00000<03oool000`0oooo00<0MgMg010@403oool0]P3oool=000002l0oooo00350?ooo`d0
0000;`3oool00<@0oooo3`00000^0?ooo`00a03oool?000002h0oooo00340?ooo`l00000;P3oool0
0;D0oooo7P00000^0?ooo`00YP3oool?000000l0oooo3`00000^0?ooo`00U`3oool?000001l0oooo
3@00000_0?ooo`009@3oool5000005h0oooo3`00000^0?ooo`d00000;`3oool002<0oooo2@00001=
0?ooo`l00000?@3oool<00000300oooo000R0?ooo`/00000?@3oool?000004/0oooo00<000000?oo
o`3oool02@00000a0?ooo`008@3oool=000002d0oooo3`00001I0?ooo`030000003oool0oooo0080
oooo1P00000c0?ooo`008@3oool=000001h0oooo3`00001W0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=`3oool00200oooo3`00000>0?ooo`l00000M@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo03L0oooo000P0?oooad00000P`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03L0oooo000P0?ooo`l00000T03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03P0oooo000P0?ooo`l00000S`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03P0oooo000P0?ooo`l00000SP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo03T0oooo000Q0?ooo`h00000S@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo03T0oooo000Q0?ooo`d0000000<0oooo000000000000RP3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03X0oooo000R0?ooo`/00000103oool2000008L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`008`3oool9000000L0oooo0P0000240?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0>`3oool002D0oooo1@0000000`3oool00000
0?ooo`080?ooo`800000P@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03/0oooo
000[0?ooo`030000003oool0oooo00T0oooo0P00001n0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0?03oool002`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`13
0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l
0?ooo`00;@3oool00`000000oooo0?ooo`0:0?ooo`800000@`3oool00`3o0000oooo0?ooo`0b0?oo
o`8000002`3oool00`000000oooo0?ooo`0m0?ooo`00;@3oool00`000000oooo0?ooo`0<0?ooo`80
0000@@3oool00`3o0000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0?@3oool002h0oooo00<000000?ooo`3oool03@3oool2000003l0oooo00<0o`000?ooo`3oool0
<03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo000^0?ooo`030000003o
ool0oooo00l0oooo0P00000m0?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0n0?ooo`00;`3oool00`000000oooo0?ooo`0@0?ooo`800000>`3oool0
0`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?P3oool0
02l0oooo00<000000?ooo`3oool04P3oool2000003T0oooo00<0o`000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03l0oooo000`0?ooo`030000003oool0oooo01<0
oooo0P00000g0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0o0?ooo`00<@3oool00`000000oooo0?ooo`0D0?ooo`800000=@3oool00`3o0000oooo
0?ooo`0[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@03oool00340oooo00<0
00000?ooo`3oool05P3oool2000003<0oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0400oooo000b0?ooo`030000003oool0oooo01L0oooo0P00000a
0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`11
0?ooo`00<P3oool00`000000oooo0?ooo`0I0?ooo`800000;`3oool00`3o0000oooo0?ooo`0X0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool003<0oooo00<000000?ooo`3o
ool06P3oool2000002d0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0480oooo000d0?ooo`030000003oool0oooo01/0oooo0P00000[0?ooo`030?l0
003oool0oooo02H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`120?ooo`00=03o
ool00`000000oooo0?ooo`0M0?ooo`800000:@3oool00`3o0000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0@`3oool003D0oooo00<000000?ooo`3oool07P3oool2
000002L0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo04<0oooo000e0?ooo`030000003oool0oooo0200oooo0P00000U0?ooo`030?l0003oool0oooo
02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`140?ooo`00=P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool08P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo000f0?ooo`030000003oool0oooo0280oooo
0P00000R0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`150?ooo`00=`3oool00`000000oooo0?ooo`0S0?ooo`800000803oool00`3o0000oooo0?oo
o`0P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0A@3oool003P0oooo00<00000
0?ooo`3oool0903oool2000001h0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04H0oooo000h0?ooo`030000003oool0oooo02H0oooo0P00000L0?oo
o`030?l0003oool0oooo01d0oooo0P00000G0?ooo`030000003oool0oooo04H0oooo000i0?ooo`03
0000003oool0oooo02L0oooo0P00000J0?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`160?ooo`00>@3oool00`000000oooo0?ooo`0Y0?ooo`800000
603oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
A`3oool003X0oooo00<000000?ooo`3oool0:P3oool2000001H0oooo00<0o`000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04L0oooo000k0?ooo`030000003oool0
oooo02/0oooo0P00000D0?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`180?ooo`00>`3oool00`000000oooo0?ooo`0]0?ooo`8000004P3oool00`3o
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B03oool003`0
oooo00<000000?ooo`3oool0;P3oool200000100oooo00<0o`000?ooo`3oool05`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo04T0oooo000l0?ooo`030000003oool0oooo0300oooo
0P00000>0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`190?ooo`00?@3oool00`000000oooo0?ooo`0a0?ooo`800000303oool00`3o0000oooo0?oo
o`0E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0BP3oool003d0oooo00<00000
0?ooo`3oool0<`3oool2000000X0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo04X0oooo000n0?ooo`030000003oool0oooo03@0oooo0P0000080?oo
o`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1;0?oo
o`00?`3oool00`000000oooo0?ooo`0e0?ooo`8000001P3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0B`3oool003l0oooo00<000000?ooo`3oool0
=`3oool2000000@0oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo04`0oooo00100?ooo`030000003oool0oooo03P0oooo00D000000?ooo`3oool0oooo
0?l0000B0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C03oool00400oooo00<0
00000?ooo`3oool0>@3oool2000000030?ooo`3o0000oooo00L0oooo200000000`3oool000000?oo
o`0N0?ooo`030000003oool0oooo04d0oooo00110?ooo`030000003oool0oooo03X0oooo00<00000
0?l0003oool01@3oool900000003010@40000000oooo01l0oooo00<000000?ooo`3oool0C@3oool0
0480oooo00<000000?ooo`3oool0>P3oool00`3o00000000000000030?ooo`/00000803oool00`00
0000oooo0?ooo`1>0?ooo`00@P3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo00l0
00007`3oool00`000000oooo0?ooo`1>0?ooo`00@`3oool00`000000oooo0?ooo`0i0?ooo`030?l0
003oool0oooo0080oooo3@00000O0?ooo`030000003oool0oooo04h0oooo00130?ooo`030000003o
ool0oooo03T0oooo00@0o`000?ooo`3oool0oooo3`00000M0?ooo`030000003oool0oooo04l0oooo
00140?ooo`030000003oool0oooo03P0oooo00@0o`000?ooo`3oool0oooo3`00000M0?ooo`030000
003oool0oooo04l0oooo00140?ooo`030000003oool0oooo03P0oooo00@0o`000?ooo`3oool0oooo
3`00000L0?ooo`030000003oool0oooo0500oooo00150?ooo`030000003oool0oooo03L0oooo00@0
o`000?ooo`3oool0oooo3`00000L0?ooo`030000003oool0oooo0500oooo00160?ooo`030000003o
ool0oooo03H0oooo00@0o`000?ooo`3oool0oooo3`00000K0?ooo`030000003oool0oooo0540oooo
00160?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool00P3oool=000001`0oooo00<0
00000?ooo`3oool0D@3oool004L0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`02
0?ooo`d000006`3oool00`000000oooo0?ooo`1B0?ooo`00A`3oool00`000000oooo0?ooo`0e0?oo
o`030?l0003oool0oooo00<0oooo2`00000L0?ooo`030000003oool0oooo0580oooo00180?ooo`03
0000003oool0oooo03@0oooo00<0o`000?ooo`3oool0103oool9000001`0oooo00<000000?ooo`3o
ool0D`3oool004T0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`060?ooo`D00000
7P3oool00`000000oooo0?ooo`1C0?ooo`00B@3oool00`000000oooo0?ooo`0c0?ooo`030?l0003o
ool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1D0?ooo`00BP3oool0
0`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1D0?ooo`00BP3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo
00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`00B`3oool00`000000
oooo0?ooo`0a0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1E0?ooo`00B`3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo00L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1E0?ooo`00C03oool00`000000oooo0?oo
o`0`0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1F0?ooo`00C@3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo00L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1F0?ooo`00C@3oool00`000000oooo0?ooo`0_0?oo
o`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?oo
o`00CP3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1G0?ooo`00CP3oool00`000000oooo0?ooo`0^0?ooo`030?l0
003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1H0?ooo`00C`3o
ool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1H0?ooo`00D03oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0
oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1I0?ooo`00D03oool00`00
0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1I0?ooo`00D@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00H0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1J0?ooo`00D@3oool00`000000oooo
0?ooo`0[0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`1J0?ooo`00DP3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00H0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1K0?ooo`00DP3oool00`000000oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K
0?ooo`00D`3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00E03oool00`000000oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1L0?ooo`00
E03oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1M0?ooo`00E@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo00D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1M0?ooo`00E@3oool0
0`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`1M0?ooo`00EP3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo
00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1N0?ooo`00EP3oool00`000000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1N0?ooo`00E`3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1O0?ooo`00F03oool00`000000oooo0?oo
o`0T0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1O0?ooo`00F03oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1P0?ooo`00F@3oool00`000000oooo0?ooo`0S0?oo
o`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1P0?oo
o`00F@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1Q0?ooo`00FP3oool00`000000oooo0?ooo`0R0?ooo`030?l0
003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00F`3o
ool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1R0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1R0?ooo`00G03oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1S0?ooo`00G03oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00G@3oool00`000000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1T0?ooo`00G@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1T0?ooo`00GP3oool00`000000oooo0?ooo`0N
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1T
0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1U0?ooo`00
H03oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`1V0?ooo`00H03oool00`000000oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1V0?ooo`00H@3oool0
0`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1W0?ooo`00HP3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo
00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1W0?ooo`00HP3oool00`000000
oooo0?ooo`0J0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1X0?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1X0?ooo`00H`3oool00`000000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1Y0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1Y0?ooo`00I03oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Z0?oo
o`00I@3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1Z0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1[0?ooo`00IP3o
ool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1[0?ooo`00I`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1/0?ooo`00I`3oool00`00
0000oooo0?ooo`0E0?ooo`050?l0003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`1/
0?ooo`00J03oool00`000000oooo0?ooo`0D0?ooo`050?l0003oool0oooo0?ooo`0000003P3oool0
0`000000oooo0?ooo`1/0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`050?l0003oool0oooo
0?ooo`0000003@3oool00`000000oooo0?ooo`1]0?ooo`00J@3oool00`000000oooo0?ooo`0C0?oo
o`050?l0003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`1]0?ooo`00JP3oool00`00
0000oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`1^
0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`1^0?ooo`00J`3oool00`000000oooo0?ooo`0A0?ooo`050?l0003oool0oooo
0?ooo`0000002`3oool00`000000oooo0?ooo`1_0?ooo`00J`3oool00`000000oooo0?ooo`0A0?oo
o`050?l0003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`1_0?ooo`00K03oool00`00
0000oooo0?ooo`0@0?ooo`050?l0003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1`
0?ooo`00K@3oool00`000000oooo0?ooo`0?0?ooo`040?l0003oool0oooo000000/0oooo00<00000
0?ooo`3oool0L03oool006d0oooo00<000000?ooo`3oool03`3oool0103o0000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0740oooo001^0?ooo`030000003oool0oooo00h0oooo00@0o`000?oo
o`3oool000002P3oool00`000000oooo0?ooo`1a0?ooo`00KP3oool00`000000oooo0?ooo`0>0?oo
o`040?l0003oool0oooo000000T0oooo00<000000?ooo`3oool0LP3oool006l0oooo00<000000?oo
o`3oool03@3oool0103o0000oooo0?ooo`0000090?ooo`030000003oool0oooo0780oooo001`0?oo
o`030000003oool0oooo00`0oooo00@0o`000?ooo`3oool00000203oool00`000000oooo0?ooo`1c
0?ooo`00L03oool00`000000oooo0?ooo`0<0?ooo`040?l0003oool0oooo000000P0oooo00<00000
0?ooo`3oool0L`3oool00740oooo00<000000?ooo`3oool02`3oool0103o0000oooo0?ooo`000007
0?ooo`030000003oool0oooo07@0oooo001a0?ooo`030000003oool0oooo00/0oooo00@0o`000?oo
o`3oool000001`3oool00`000000oooo0?ooo`1d0?ooo`00LP3oool00`000000oooo0?ooo`0:0?oo
o`030?l0003oool0000000P0oooo00<000000?ooo`3oool0M03oool00780oooo00<000000?ooo`3o
ool02P3oool00`3o0000oooo000000070?ooo`030000003oool0oooo07D0oooo001c0?ooo`030000
003oool0oooo00T0oooo00<0o`000?ooo`0000001`3oool00`000000oooo0?ooo`1e0?ooo`00M03o
ool00`000000oooo0?ooo`080?ooo`030?l0003oool0000000H0oooo00<000000?ooo`3oool0MP3o
ool007@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo000000060?ooo`030000003oool0
oooo07H0oooo001e0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`0000001@3oool00`00
0000oooo0?ooo`1g0?ooo`00M@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0000000D0
oooo00<000000?ooo`3oool0M`3oool007H0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo
000000040?ooo`030000003oool0oooo07P0oooo001g0?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`000000103oool00`000000oooo0?ooo`1h0?ooo`00M`3oool00`000000oooo0?ooo`05
0?ooo`030?l000000000oooo00<0oooo00<000000?ooo`3oool0N@3oool007P0oooo00<000000?oo
o`3oool0103oool00`3o000000000?ooo`030?ooo`030000003oool0oooo07T0oooo001h0?ooo`03
0000003oool0oooo00@0oooo00<0o`000000003oool00P3oool00`000000oooo0?ooo`1j0?ooo`00
N@3oool00`000000oooo0?ooo`030?ooo`030?l000000000oooo0080oooo00<000000?ooo`3oool0
NP3oool007T0oooo00<000000?ooo`3oool00`3oool01@3o000000000?ooo`3oool0000007d0oooo
001j0?ooo`030000003oool0oooo0080oooo00D0o`000000003oool0oooo0000001m0?ooo`00N`3o
ool00`000000oooo00000004000000030?ooo`000000oooo07`0oooo001k0?ooo`T00000O@3oool0
07X0oooo2`00001l0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007P0oooo3`00
001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00
N03oool?000007X0oooo001i0?ooo`d00000N`3oool007T0oooo3@00001k0?ooo`00NP3oool;0000
07`0oooo001k0?ooo`T00000O@3oool007d0oooo1@00001o0?ooo`00O`3oool00`3o0000oooo0?oo
o`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o
0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo
0?ooo`1o0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00O@3oool400000003010@403oool0oooo07d0oooo001o0?ooo`030000003oool0
oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0
oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o
0?ooo`030000003oool0oooo07l0oooo001m0?ooo`0300000014A4@000000840oooo001m0?ooo`03
0<c<c01EEED000000840oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.5048 .5602 Mdot
.5 Mabswid
[ ] 0 setdash
.5048 .5602 m
.81309 .33208 L
s
.5048 .5602 m
.16656 .3455 L
s
.4958 .947 m
.5048 .5602 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.16656 .3455 Mdot
.5 Mabswid
.16656 .3455 m
.81309 .33208 L
s
.4958 .947 m
.16656 .3455 L
s
15 Mabswid
.81309 .33208 Mdot
.5 Mabswid
.4958 .947 m
.81309 .33208 L
s
15 Mabswid
.4958 .947 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.50733 .5447 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.91279 .24172 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.06477 .26028 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00i`3oool0
1P2YZJT08B4Q000000000000EEEE0>k^kQ@0oooo003W0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8b503oool00>`0oooo00<000000?ooo`3oool04P3oool00>/0oooo00<0MgMg024Q8@3oool04`3o
ool00100oooo0P0000000`0@4100oooo0?ooo`3D0?ooo`04024Q8@00000000000;Zj^Q@0oooo000A
0?ooo`030000003oool0oooo0=H0oooo00<0k^k^07MgM`0b<S80503oool000d0oooo1P00003I0?oo
o`030000003oool0oooo0180oooo000=0?ooo`0507MgM`2YZJT0oooo0?ooo`000000e@3oool01P0Q
8B40ZJVY0?ooo`3oool0IVIV038b<Q@0oooo000=0?ooo`050>k^kP0b<S80k^k^0?ooo`000000e@3o
ool01P2j^[X0A4A4000000000000A4A40>k^kQ@0oooo000>0?ooo`040:VYZ@1VIVH0oooo00000>l0
oooo000?0?ooo`0304A4A03<c<`000000>l0oooo000?0?ooo`030=gMg@14A4@000000>l0oooo000@
0?ooo`0307MgM`0@4100oooo0>h0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo
003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003>0?ooo`D00000;P3oool00<`0oooo
2@00000/0?ooo`00b`3oool;000002/0oooo000X0?ooo`D00000W@3oool=000002X0oooo000V0?oo
o`T00000V`3oool=000002X0oooo000U0?ooo`/00000V@3oool?000002T0oooo000T0?ooo`d00000
V03oool?000002T0oooo000T0?ooo`d00000P`3ooolT000002T0oooo000S0?ooo`l00000B`3ooolg
000001D0oooo3`00000Y0?ooo`008`3oool?000001@0oooo=`00001<0?ooo`l00000:@3oool002<0
oooo8`0000240?ooo`d00000:P3oool002<0oooo3`00002H0?ooo`d00000:P3oool002<0oooo3`00
002G0?ooo`030000003oool0000000X00000:`3oool002@0oooo3@00002F0?ooo`8000000`3oool9
000002`0oooo000T0?ooo`h00000U03oool00`000000oooo0?ooo`040?ooo`H00000;P3oool002D0
oooo2`0000020?ooo`800000T@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0380
oooo000V0?ooo`T000001@3oool00`000000oooo0?ooo`2<0?ooo`8000001`3oool00`000000oooo
0?ooo`0b0?ooo`00:03oool5000000030?ooo`000000oooo00D0oooo0P00002;0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0<`3oool002h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<`3oool0
02l0oooo00<000000?ooo`3oool01P3oool2000008D0oooo0P0000090?ooo`030000003oool0oooo
03@0oooo000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000`0?ooo`030000003oool0oooo00P0oooo
0P0000200?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=@3oool00300oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1k0?ooo`800000303oool00`000000oooo0?oo
o`0e0?ooo`00<@3oool00`000000oooo0?ooo`0:0?ooo`800000?`3oool00`3o0000oooo0?ooo`0h
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=P3oool00340oooo00<000000?oo
o`3oool0303oool2000003d0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03H0oooo000b0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0>P3oool00`3o0000oooo0?ooo`0e0?ooo`8000003P3oool00`000000oooo0?ooo`0g0?ooo`00
<`3oool00`000000oooo0?ooo`0=0?ooo`800000>P3oool00`3o0000oooo0?ooo`0d0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0=`3oool003<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0h0?ooo`00=03oool00`000000oooo0?ooo`0?0?ooo`800000=`3oool0
0`3o0000oooo0?ooo`0a0?ooo`800000403oool00`000000oooo0?ooo`0i0?ooo`00=03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo03T0oooo000e0?ooo`030000003oool0oooo0140
oooo0P00000d0?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0j0?ooo`00=@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo
00<0o`000?ooo`3oool0;@3oool2000001<0oooo00<000000?ooo`3oool0>P3oool003H0oooo00<0
00000?ooo`3oool04`3oool200000340oooo00<0o`000?ooo`3oool0;03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03/0oooo000f0?ooo`030000003oool0oooo01D0oooo0P00000_
0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k
0?ooo`00=`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<0o`000?oo
o`3oool0:@3oool2000001D0oooo00<000000?ooo`3oool0?03oool003L0oooo00<000000?ooo`3o
ool05`3oool2000002`0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03`0oooo000h0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
:@3oool00`3o0000oooo0?ooo`0V0?ooo`8000005`3oool00`000000oooo0?ooo`0m0?ooo`00>@3o
ool00`000000oooo0?ooo`0H0?ooo`800000:@3oool00`3o0000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0?@3oool003T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0n0?ooo`00>P3oool00`000000oooo0?ooo`0J0?ooo`8000009P3oool00`3o
0000oooo0?ooo`0R0?ooo`8000006P3oool00`000000oooo0?ooo`0n0?ooo`00>P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool08@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo03l0oooo000k0?ooo`030000003oool0oooo01`0oooo
0P00000S0?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`00>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<0
o`000?ooo`3oool07P3oool2000001`0oooo00<000000?ooo`3oool0@03oool003`0oooo00<00000
0?ooo`3oool07P3oool200000200oooo00<0o`000?ooo`3oool07@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0400oooo000l0?ooo`030000003oool0oooo0200oooo0P00000N0?oo
o`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`110?oo
o`00?@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3o
ool06P3oool2000001l0oooo00<000000?ooo`3oool0@@3oool003d0oooo00<000000?ooo`3oool0
8P3oool2000001/0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0480oooo000n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@P3o
ool003l0oooo00<000000?ooo`3oool08`3oool2000001P0oooo00<0o`000?ooo`3oool05P3oool2
00000240oooo00<000000?ooo`3oool0@`3oool003l0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`130?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`8000005@3oool00`3o0000
oooo0?ooo`0D0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A03oool00400oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0180oooo
0P00000T0?ooo`030000003oool0oooo04@0oooo00110?ooo`030000003oool0oooo02L0oooo0P00
000B0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`150?ooo`00@@3oool00`000000oooo0?ooo`0Y0?ooo`800000403oool00`3o0000oooo0?ooo`0@
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0A@3oool00480oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo0P00000V0?oo
o`030000003oool0oooo04H0oooo00120?ooo`030000003oool0oooo02/0oooo0P00000=0?ooo`03
0?l0003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`160?ooo`00
@`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0
303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04L0oooo00140?ooo`030000003o
ool0oooo02`0oooo0P00000:0?ooo`030?l0003oool0oooo00X0oooo0P00000Y0?ooo`030000003o
ool0oooo04L0oooo00140?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B03oool0
04D0oooo00<000000?ooo`3oool0;P3oool2000000L0oooo1P0000050?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0B03oool004D0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`020?ooo`80000000<0V000000000000000100000020?ooo`800000:`3oool00`000000
oooo0?ooo`190?ooo`00AP3oool00`000000oooo0?ooo`0`0?ooo`80000000D0oooo000000000000
00000?l00008000002d0oooo00<000000?ooo`3oool0B@3oool004H0oooo00<000000?ooo`3oool0
<P3oool4000000030?l000000000000000H00000;03oool00`000000oooo0?ooo`1:0?ooo`00A`3o
ool00`000000oooo0?ooo`0a0?ooo`@0000000<0o`000000000000001P00000/0?ooo`030000003o
ool0oooo04X0oooo00170?ooo`030000003oool0oooo0300oooo1@0000000`3o0000000000000007
000002X0oooo00<000000?ooo`3oool0B`3oool004P0oooo00<000000?ooo`3oool0;`3oool50000
00030?l000000000000000L00000:P3oool00`000000oooo0?ooo`1;0?ooo`00B03oool00`000000
oooo0?ooo`0_0?ooo`l00000:@3oool00`000000oooo0?ooo`1<0?ooo`00B@3oool00`000000oooo
0?ooo`0^0?ooo`D0000000<0Z@000000000000001`00000X0?ooo`030000003oool0oooo04d0oooo
001:0?ooo`030000003oool0oooo02d0oooo1@0000000`3o0000000000000007000002P0oooo00<0
00000?ooo`3oool0C@3oool004X0oooo00<000000?ooo`3oool0;P3oool4000000030?l000000000
000000H00000:03oool00`000000oooo0?ooo`1>0?ooo`00B`3oool00`000000oooo0?ooo`0]0?oo
o`@0000000<0o`000000000000001P00000X0?ooo`030000003oool0oooo04h0oooo001;0?ooo`03
0000003oool0oooo02h0oooo0`0000000`3o0000000000000005000002P0oooo00<000000?ooo`3o
ool0C`3oool004`0oooo00<000000?ooo`3oool0;P3oool2000000030?l000000000000000@00000
:@3oool00`000000oooo0?ooo`1?0?ooo`00C03oool00`000000oooo0?ooo`0`0?ooo`030?l00000
0000000000800000:P3oool00`000000oooo0?ooo`1@0?ooo`00C@3oool00`000000oooo0?ooo`0_
0?ooo`030?l0003oool0000002`0oooo00<000000?ooo`3oool0D03oool004d0oooo00<000000?oo
o`3oool0;`3oool00`3o0000oooo0000000[0?ooo`030000003oool0oooo0540oooo001>0?ooo`03
0000003oool0oooo02h0oooo00<0o`000?ooo`000000:`3oool00`000000oooo0?ooo`1A0?ooo`00
CP3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0000002X0oooo00<000000?ooo`3oool0
DP3oool004l0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0000000Z0?ooo`030000003o
ool0oooo0580oooo001@0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`000000:@3oool0
0`000000oooo0?ooo`1C0?ooo`00D03oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool00000
02T0oooo00<000000?ooo`3oool0D`3oool00540oooo00<000000?ooo`3oool0:`3oool00`3o0000
oooo0000000X0?ooo`030000003oool0oooo05@0oooo001A0?ooo`030000003oool0oooo02/0oooo
00<0o`000?ooo`000000:03oool00`000000oooo0?ooo`1D0?ooo`00DP3oool00`000000oooo0?oo
o`0Z0?ooo`030?l0003oool0000002L0oooo00<000000?ooo`3oool0E@3oool00580oooo00<00000
0?ooo`3oool0:P3oool00`3o0000oooo0000000W0?ooo`030000003oool0oooo05D0oooo001C0?oo
o`030000003oool0oooo02T0oooo00<0o`000?ooo`0000009P3oool00`000000oooo0?ooo`1F0?oo
o`00D`3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0000002H0oooo00<000000?ooo`3o
ool0EP3oool005@0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0000000U0?ooo`030000
003oool0oooo05L0oooo001E0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`0000009@3o
ool00`000000oooo0?ooo`1G0?ooo`00E@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0
000002@0oooo00<000000?ooo`3oool0F03oool005H0oooo00<000000?ooo`3oool09P3oool00`3o
0000oooo0000000T0?ooo`030000003oool0oooo05P0oooo001F0?ooo`030000003oool0oooo02H0
oooo00<0o`000?ooo`0000008`3oool00`000000oooo0?ooo`1I0?ooo`00E`3oool00`000000oooo
0?ooo`0U0?ooo`030?l000000000oooo02<0oooo00<000000?ooo`3oool0F@3oool005L0oooo00<0
00000?ooo`3oool09@3oool00`3o000000000?ooo`0R0?ooo`030000003oool0oooo05X0oooo001H
0?ooo`030000003oool0oooo02@0oooo00<0o`000000003oool08P3oool00`000000oooo0?ooo`1J
0?ooo`00F03oool00`000000oooo0?ooo`0T0?ooo`030?l000000000oooo0240oooo00<000000?oo
o`3oool0F`3oool005T0oooo00<000000?ooo`3oool08`3oool00`3o000000000?ooo`0Q0?ooo`03
0000003oool0oooo05/0oooo001I0?ooo`030000003oool0oooo02<0oooo00<0o`000000003oool0
803oool00`000000oooo0?ooo`1L0?ooo`00FP3oool00`000000oooo0?ooo`0R0?ooo`030?l00000
0000oooo0200oooo00<000000?ooo`3oool0G03oool005/0oooo00<000000?ooo`3oool08@3oool0
0`3o000000000?ooo`0O0?ooo`030000003oool0oooo05d0oooo001K0?ooo`030000003oool0oooo
0240oooo00<0o`000000003oool07`3oool00`000000oooo0?ooo`1M0?ooo`00G03oool00`000000
oooo0?ooo`0P0?ooo`030?l000000000oooo01h0oooo00<000000?ooo`3oool0GP3oool005`0oooo
00<000000?ooo`3oool0803oool00`3o000000000?ooo`0N0?ooo`030000003oool0oooo05h0oooo
001M0?ooo`030000003oool0oooo01l0oooo00<0o`000000003oool07@3oool00`000000oooo0?oo
o`1O0?ooo`00G@3oool00`000000oooo0?ooo`0O0?ooo`030?l000000000oooo01d0oooo00<00000
0?ooo`3oool0G`3oool005h0oooo00<000000?ooo`3oool07P3oool00`3o000000000?ooo`0L0?oo
o`030000003oool0oooo0600oooo001N0?ooo`030000003oool0oooo01h0oooo00<0o`000000003o
ool0703oool00`000000oooo0?ooo`1P0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`030?l0
00000000oooo01/0oooo00<000000?ooo`3oool0H@3oool005l0oooo00<000000?ooo`3oool07@3o
ool00`3o000000000?ooo`0J0?ooo`030000003oool0oooo0680oooo001P0?ooo`030000003oool0
oooo01`0oooo00<0o`000000003oool06P3oool00`000000oooo0?ooo`1R0?ooo`00H@3oool00`00
0000oooo0?ooo`0K0?ooo`030?l000000000oooo01T0oooo00<000000?ooo`3oool0H`3oool00640
oooo00<000000?ooo`3oool06`3oool00`3o000000000?ooo`0I0?ooo`030000003oool0oooo06<0
oooo001R0?ooo`030000003oool0oooo01X0oooo00<0o`000000003oool0603oool00`000000oooo
0?ooo`1T0?ooo`00HP3oool00`000000oooo0?ooo`0J0?ooo`030?l000000000oooo01P0oooo00<0
00000?ooo`3oool0I03oool006<0oooo00<000000?ooo`3oool06@3oool00`3o000000000?ooo`0G
0?ooo`030000003oool0oooo06D0oooo001S0?ooo`030000003oool0oooo01T0oooo00<0o`000000
003oool05`3oool00`000000oooo0?ooo`1U0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`03
0?l000000000oooo01H0oooo00<000000?ooo`3oool0IP3oool006@0oooo00<000000?ooo`3oool0
603oool00`3o000000000?ooo`0F0?ooo`030000003oool0oooo06H0oooo001U0?ooo`030000003o
ool0oooo01L0oooo00<0o`000000003oool05@3oool00`000000oooo0?ooo`1W0?ooo`00IP3oool0
0`000000oooo0?ooo`0F0?ooo`030?l000000000oooo01D0oooo00<000000?ooo`3oool0I`3oool0
06H0oooo00<000000?ooo`3oool05P3oool00`3o000000000?ooo`0D0?ooo`030000003oool0oooo
06P0oooo001W0?ooo`030000003oool0oooo01D0oooo00<0o`000000003oool0503oool00`000000
oooo0?ooo`1X0?ooo`00I`3oool00`000000oooo0?ooo`0E0?ooo`030?l000000000oooo01<0oooo
00<000000?ooo`3oool0J@3oool006P0oooo00<000000?ooo`3oool0503oool00`3o000000000?oo
o`0C0?ooo`030000003oool0oooo06T0oooo001X0?ooo`030000003oool0oooo01@0oooo00<0o`00
0000003oool04P3oool00`000000oooo0?ooo`1Z0?ooo`00J@3oool00`000000oooo0?ooo`0C0?oo
o`030?l000000000oooo0180oooo00<000000?ooo`3oool0JP3oool006T0oooo00<000000?ooo`3o
ool04`3oool00`3o000000000?ooo`0A0?ooo`030000003oool0oooo06/0oooo001Z0?ooo`030000
003oool0oooo0180oooo00<0o`000000003oool04@3oool00`000000oooo0?ooo`1[0?ooo`00JP3o
ool00`000000oooo0?ooo`0B0?ooo`030?l000000000oooo0100oooo00<000000?ooo`3oool0K03o
ool006/0oooo00<000000?ooo`3oool04@3oool00`3o000000000?ooo`0@0?ooo`030000003oool0
oooo06`0oooo001/0?ooo`030000003oool0oooo0100oooo00<0o`000000003oool03`3oool00`00
0000oooo0?ooo`1]0?ooo`00K03oool00`000000oooo0?ooo`0@0?ooo`030?l000000000oooo00l0
oooo00<000000?ooo`3oool0K@3oool006d0oooo00<000000?ooo`3oool03`3oool00`3o00000000
0?ooo`0>0?ooo`030000003oool0oooo06h0oooo001]0?ooo`030000003oool0oooo00l0oooo00<0
o`000000003oool03P3oool00`000000oooo0?ooo`1^0?ooo`00KP3oool00`000000oooo0?ooo`0>
0?ooo`030?l000000000oooo00d0oooo00<000000?ooo`3oool0K`3oool006h0oooo00<000000?oo
o`3oool03P3oool00`3o000000000?ooo`0=0?ooo`030000003oool0oooo06l0oooo001_0?ooo`03
0000003oool0oooo00d0oooo00<0o`000000003oool0303oool00`000000oooo0?ooo`1`0?ooo`00
K`3oool00`000000oooo0?ooo`0=0?ooo`030?l000000000oooo00`0oooo00<000000?ooo`3oool0
L03oool00700oooo00<000000?ooo`3oool0303oool00`3o000000000?ooo`0;0?ooo`030000003o
ool0oooo0740oooo001`0?ooo`030000003oool0oooo00`0oooo00<0o`000000003oool02`3oool0
0`000000oooo0?ooo`1a0?ooo`00L@3oool00`000000oooo0?ooo`0;0?ooo`030?l000000000oooo
00X0oooo00<000000?ooo`3oool0LP3oool00780oooo00<000000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000003oool0oooo0780oooo001b0?ooo`030000003oool0oooo00X0oooo
00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`00L`3oool00`000000oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool007<0oooo00<00000
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo07@0oooo001d0?oo
o`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`1d0?oo
o`00M03oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3o
ool0M@3oool007D0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000
003oool0oooo07H0oooo001e0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1f0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<000000?ooo`3oool0M`3oool007L0oooo00<000000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo001g0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`1h0?ooo`00N03oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0N03oool007P0oooo00<0
00000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo001i
0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`1i
0?ooo`00N@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<000000?oo
o`3oool0NP3oool007X0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000003oool0oooo07X0oooo001j0?ooo`030000003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000001m0?ooo`00N`3oool00`000000oooo00000004000000030?ooo`000000oooo07`0oooo
001k0?ooo`T00000O@3oool007X0oooo2`00001l0?ooo`00N@3oool=000007/0oooo001i0?ooo`d0
0000N`3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool0
07P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001i0?ooo`d00000N`3oool007T0oooo3@00
001k0?ooo`00NP3oool;000007`0oooo001k0?ooo`T00000O@3oool007d0oooo1@00001o0?ooo`00
O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool0
0`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000
oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?oo
o`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00O@3oool400000003010@403oool0oooo07d0oooo
001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?oo
o`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000
003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001m0?ooo`0300000014A4@0
00000840oooo001m0?ooo`030<c<c01EEED000000840oooo003o0?ooo`80oooo003o0?ooo`80oooo
003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo
003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo
0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.47114 .5601 Mdot
.5 Mabswid
[ ] 0 setdash
.47114 .5601 m
.82874 .34768 L
s
.47114 .5601 m
.1837 .32999 L
s
.4958 .947 m
.47114 .5601 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.82874 .34768 Mdot
.5 Mabswid
.1837 .32999 m
.82874 .34768 L
s
.4958 .947 m
.82874 .34768 L
s
15 Mabswid
.1837 .32999 Mdot
.5 Mabswid
.4958 .947 m
.1837 .32999 L
s
15 Mabswid
.4958 .947 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.46501 .54458 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.93201 .26329 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08598 .23881 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`005P3oool200000003010@403o
ool0oooo0>H0oooo000G0?ooo`030000003oool0oooo0>L0oooo000C0?ooo`H00000j03oool001<0
oooo00D0MgMg0:VYZ@3oool0oooo0000003Y0?ooo`004`3oool01@3^k^h0<S8b0>k^kP3oool00000
0>T0oooo000D0?ooo`040:VYZ@1VIVH0oooo00000>T0oooo000E0?ooo`0304A4A03<c<`000000=@0
oooo00H0ZJVY024Q8@000000000005EEE@3^k^h?0?ooo`005@3oool00`3MgMd0A4A40000003D0?oo
o`06010@402j^[X0oooo0?ooo`2YZJT0<S8b3`3oool001H0oooo00<0MgMg010@403oool0f03oool0
0`000000oooo0?ooo`0=0?ooo`00l03oool00`1gMgL08B4Q0?ooo`0>0?ooo`00kP3oool0100Q8B40
00000000002j^[X?0?ooo`00k`3oool00`3^k^h0MgMg038b<P0?0?ooo`00l@3oool00`000000oooo
0?ooo`0=0?ooo`00k03oool01P0Q8B40ZJVY0?ooo`3oool0IVIV038b<Pl0oooo003/0?ooo`060;Zj
^P14A4@0000000000014A4@0k^k^3`3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3o
ool00?l0oooo0P3oool002d0oooo1@00003?0?ooo`00:`3oool900000<d0oooo000Z0?ooo`/00000
c03oool002T0oooo3@00003;0?ooo`00:@3oool=00000</0oooo000X0?ooo`l00000V`3oool50000
02X0oooo000X0?ooo`l00000V@3oool9000002P0oooo000X0?oooaT00000SP3oool;000002L0oooo
000X0?ooo`l000002P3ooolQ000006`0oooo3@00000V0?ooo`00:03oool?000002/0oooo8@00001;
0?ooo`d000009P3oool002T0oooo3@00001=0?ooob400000:@3oool?000002D0oooo000Y0?ooo`d0
0000KP3ooolQ000000P0oooo3`00000U0?ooo`00:P3oool;000000030?ooo`000000oooo08d0oooo
5`00000U0?ooo`00:`3oool9000000<0oooo00<000000?ooo`3oool0T`3oool?000002D0oooo000]
0?ooo`H000001@3oool00`000000oooo0?ooo`2B0?ooo`l000009@3oool003<0oooo00<000000?oo
o`3oool00`3oool2000009<0oooo3@00000V0?ooo`00<`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08h0oooo3`00000V0?ooo`00=03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo08`0oooo00@000000?ooo`3oool0oooo2`00000W0?ooo`00=03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08T0oooo0P0000050?ooo`T00000:03oool003D0oooo00<0
00000?ooo`3oool01P3oool2000008L0oooo0P0000070?ooo`030000003oool0000000@00000:P3o
ool003D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0;P3oool003H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`200?ooo`8000002@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo07d0oooo0P00000;0?ooo`030000003oool0oooo02l0
oooo000g0?ooo`030000003oool0oooo00T0oooo0P00001l0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0<03oool003L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0g0?ooo`030?l0003oool0oooo03d0oooo0P00000=0?ooo`030000003oool0oooo0300oooo000h
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0k
0?ooo`8000003P3oool00`000000oooo0?ooo`0a0?ooo`00>03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0340oooo000i0?ooo`030000003oool0oooo00`0oooo0P00000e0?ooo`03
0?l0003oool0oooo03P0oooo0P00000@0?ooo`030000003oool0oooo0380oooo000i0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0f0?ooo`800000
4@3oool00`000000oooo0?ooo`0c0?ooo`00>P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0340oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo03<0oooo000j0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`0c0?ooo`8000004`3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`00
0000oooo0?ooo`0?0?ooo`800000<03oool00`3o0000oooo0?ooo`0a0?ooo`8000005@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02d0
oooo00<0o`000?ooo`3oool0;`3oool2000001H0oooo00<000000?ooo`3oool0=@3oool003`0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo02h0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0e0?ooo`00?03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0;03oool2000001P0oooo00<0
00000?ooo`3oool0=P3oool003d0oooo00<000000?ooo`3oool04P3oool2000002/0oooo00<0o`00
0?ooo`3oool0:P3oool2000001X0oooo00<000000?ooo`3oool0=P3oool003d0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo02T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0g0?ooo`00?P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02L0oooo00<0o`000?ooo`3oool09`3oool2000001/0oooo00<000000?ooo`3o
ool0>03oool003h0oooo00<000000?ooo`3oool05@3oool2000002L0oooo00<0o`000?ooo`3oool0
9@3oool2000001d0oooo00<000000?ooo`3oool0>03oool003l0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo02<0oooo00<0o`000?ooo`3oool08P3oool2000001l0oooo00<000000?ooo`3oool0>@3oool0
0400oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
0200oooo0P00000P0?ooo`030000003oool0oooo03X0oooo00100?ooo`030000003oool0oooo01P0
oooo0P00000R0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0j0?ooo`00@@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01l0oooo
00<0o`000?ooo`3oool07@3oool200000280oooo00<000000?ooo`3oool0>`3oool00440oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo01/0oooo0P00
000T0?ooo`030000003oool0oooo03/0oooo00120?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0?03oool00480oooo00<000000?ooo`3oool06`3oool2000001d0oooo00<0o`000?oo
o`3oool0603oool2000002H0oooo00<000000?ooo`3oool0?03oool004<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo01H0oooo0P00000W0?ooo`03
0000003oool0oooo03d0oooo00130?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0D0?ooo`800000:03oool00`000000oooo0?ooo`0n0?ooo`00A03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03h0oooo00140?ooo`030000003oool0
oooo01h0oooo0P00000H0?ooo`030?l0003oool0oooo0140oooo0P00000Z0?ooo`030000003oool0
oooo03l0oooo00150?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0?0?ooo`800000;03oool00`000000oooo0?ooo`0o0?ooo`00A@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool03P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0400oooo00160?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0<0?ooo`800000;P3oool00`000000oooo
0?ooo`100?ooo`00AP3oool00`000000oooo0?ooo`0Q0?ooo`8000004`3oool00`3o0000oooo0?oo
o`0:0?ooo`800000;`3oool00`000000oooo0?ooo`110?ooo`00A`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0440oooo00170?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`070?ooo`800000<@3oool00`000000oooo0?ooo`120?oo
o`00B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3o
ool01@3oool200000380oooo00<000000?ooo`3oool0@`3oool004P0oooo00<000000?ooo`3oool0
903oool2000000h0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo04<0oooo00190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3o
ool5000000<0oooo00<0o`000?ooo`3oool00P3oool2000003@0oooo00<000000?ooo`3oool0A03o
ool004T0oooo00<000000?ooo`3oool09P3oool00`000000oooo00000009000000040?ooo`3o0000
oooo0?ooo`800000=P3oool00`000000oooo0?ooo`140?ooo`00BP3oool00`000000oooo0?ooo`0V
0?ooo``0000000<0o`000?ooo`000000=`3oool00`000000oooo0?ooo`150?ooo`00BP3oool00`00
0000oooo0?ooo`0V0?ooo``0000000<0o`000000003oool0=`3oool00`000000oooo0?ooo`150?oo
o`00B`3oool00`000000oooo0?ooo`0U0?ooo``0000000<0o`000?ooo`3oool0=P3oool00`000000
oooo0?ooo`160?ooo`00B`3oool00`000000oooo0?ooo`0T0?ooo`d0000000<0o`000000003oool0
=P3oool00`000000oooo0?ooo`160?ooo`00C03oool00`000000oooo0?ooo`0S0?ooo`d0000000<0
o`000000003oool0=@3oool00`000000oooo0?ooo`170?ooo`00C03oool00`000000oooo0?ooo`0S
0?ooo`d0000000<0o`000000003oool0=03oool00`000000oooo0?ooo`180?ooo`00C@3oool00`00
0000oooo0?ooo`0R0?ooo`d0000000<0o`000000003oool0=03oool00`000000oooo0?ooo`180?oo
o`00C@3oool00`000000oooo0?ooo`0R0?ooo`d0000000<0o`000000003oool0<`3oool00`000000
oooo0?ooo`190?ooo`00CP3oool00`000000oooo0?ooo`0R0?ooo``0000000<0o`000?ooo`3oool0
<`3oool00`000000oooo0?ooo`190?ooo`00CP3oool00`000000oooo0?ooo`0R0?ooo``0000000<0
o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`1:0?ooo`00C`3oool00`000000oooo0?ooo`0R
0?ooo`/0000000<0o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`1:0?ooo`00C`3oool00`00
0000oooo0?ooo`0S0?ooo`T0000000<0oooo0?l0003oool0<P3oool00`000000oooo0?ooo`1;0?oo
o`00D03oool00`000000oooo0?ooo`0T0?ooo`D000000`3oool00`3o0000oooo0?ooo`0a0?ooo`03
0000003oool0oooo04/0oooo001@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo001A0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0`0?ooo`030000003o
ool0oooo04`0oooo001A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo04d0oooo001B0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo
04h0oooo001B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0^0?ooo`030000003oool0oooo04h0oooo001C0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo04l0oooo
001C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0]0?ooo`030000003oool0oooo04l0oooo001D0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo001D0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0/0?oo
o`030000003oool0oooo0500oooo001E0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo0540oooo001E0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0[0?ooo`030000
003oool0oooo0540oooo001F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo001F0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0
oooo05<0oooo001G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo05<0oooo001H0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0oooo05@0
oooo001H0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0X0?ooo`030000003oool0oooo05@0oooo001I0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0oooo001I
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0W
0?ooo`030000003oool0oooo05D0oooo001J0?ooo`030000003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo0?l0000X0?ooo`030000003oool0oooo05H0oooo001J0?ooo`030000003oool0oooo
01h0oooo00D000000?ooo`3oool0oooo0?l0000X0?ooo`030000003oool0oooo05H0oooo001K0?oo
o`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0?l0000W0?ooo`030000003oool0
oooo05L0oooo001K0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0?l0000V
0?ooo`030000003oool0oooo05P0oooo001L0?ooo`030000003oool0oooo01`0oooo00D000000?oo
o`3oool0oooo0?l0000V0?ooo`030000003oool0oooo05P0oooo001L0?ooo`030000003oool0oooo
01`0oooo00D000000?ooo`3oool0oooo0?l0000U0?ooo`030000003oool0oooo05T0oooo001M0?oo
o`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0?l0000U0?ooo`030000003oool0
oooo05T0oooo001M0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0?l0000T
0?ooo`030000003oool0oooo05X0oooo001N0?ooo`030000003oool0oooo01X0oooo00D000000?oo
o`3oool0oooo0?l0000T0?ooo`030000003oool0oooo05X0oooo001N0?ooo`030000003oool0oooo
01X0oooo00D000000?ooo`3oool0oooo0?l0000S0?ooo`030000003oool0oooo05/0oooo001O0?oo
o`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0?l0000S0?ooo`030000003oool0
oooo05/0oooo001O0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0?l0000R
0?ooo`030000003oool0oooo05`0oooo001P0?ooo`030000003oool0oooo01P0oooo00D000000?oo
o`3oool0oooo0?l0000Q0?ooo`030000003oool0oooo05d0oooo001P0?ooo`030000003oool0oooo
01P0oooo00D000000?ooo`3oool0oooo0?l0000Q0?ooo`030000003oool0oooo05d0oooo001Q0?oo
o`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0?l0000P0?ooo`030000003oool0
oooo05h0oooo001Q0?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0?l0000P
0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo01H0oooo00D000000?oo
o`3oool0oooo0?l0000O0?ooo`030000003oool0oooo05l0oooo001R0?ooo`030000003oool0oooo
01L0oooo00@000000?ooo`3oool0o`007`3oool00`000000oooo0?ooo`1O0?ooo`00H`3oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo0?l001h0oooo00<000000?ooo`3oool0H03oool0
06<0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`3o000N0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0o`007@3oool0
0`000000oooo0?ooo`1Q0?ooo`00I03oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo
0?l001d0oooo00<000000?ooo`3oool0H@3oool006D0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`3o000L0?ooo`030000003oool0oooo0680oooo001U0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool0o`006`3oool00`000000oooo0?ooo`1S0?ooo`00IP3oool00`00
0000oooo0?ooo`0C0?ooo`040000003oool0oooo0?l001/0oooo00<000000?ooo`3oool0H`3oool0
06H0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`3o000J0?ooo`030000003oool0
oooo06@0oooo001W0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0o`006P3oool0
0`000000oooo0?ooo`1T0?ooo`00I`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
0?l001T0oooo00<000000?ooo`3oool0I@3oool006P0oooo00<000000?ooo`3oool04@3oool01000
0000oooo0?ooo`3o000I0?ooo`030000003oool0oooo06D0oooo001X0?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool0o`00603oool00`000000oooo0?ooo`1V0?ooo`00J@3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo0?l001P0oooo00<000000?ooo`3oool0IP3oool0
06T0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3o000G0?ooo`030000003oool0
oooo06L0oooo001Z0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0o`005P3oool0
0`000000oooo0?ooo`1X0?ooo`00JP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0o`00
01H0oooo00<000000?ooo`3oool0J03oool006/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?l0000E0?ooo`030000003oool0oooo06T0oooo001[0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3o00005@3oool00`000000oooo0?ooo`1Y0?ooo`00K03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0o`0001@0oooo00<000000?ooo`3oool0JP3oool006`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?l0000D0?ooo`030000003oool0oooo06X0oooo001]0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3o00004`3oool00`000000oooo0?ooo`1[0?oo
o`00K@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0o`0001<0oooo00<000000?ooo`3o
ool0J`3oool006h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?l0000B0?ooo`030000
003oool0oooo06`0oooo001^0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o00004@3o
ool00`000000oooo0?ooo`1]0?ooo`00K`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
o`000140oooo00<000000?ooo`3oool0K@3oool006l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?l0000@0?ooo`030000003oool0oooo06h0oooo001`0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3o0000403oool00`000000oooo0?ooo`1^0?ooo`00L03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0o`0000l0oooo00<000000?ooo`3oool0K`3oool00740oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?l0000?0?ooo`030000003oool0oooo06l0oooo001a
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o00003P3oool00`000000oooo0?ooo`1`
0?ooo`00LP3oool00`000000oooo0?ooo`080?ooo`030000003oool0o`0000h0oooo00<000000?oo
o`3oool0L03oool00780oooo00<000000?ooo`3oool0203oool00`000000oooo0?l0000=0?ooo`03
0000003oool0oooo0740oooo001c0?ooo`030000003oool0oooo00P0oooo00<000000?l0003oool0
303oool00`000000oooo0?ooo`1a0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003o
0000oooo00/0oooo00<000000?ooo`3oool0LP3oool007@0oooo00<000000?ooo`3oool01`3oool0
0`000000o`000?ooo`0:0?ooo`030000003oool0oooo07<0oooo001d0?ooo`030000003oool0oooo
00L0oooo00<000000?l0003oool02P3oool00`000000oooo0?ooo`1c0?ooo`00M@3oool00`000000
oooo0?ooo`060?ooo`030000003o0000oooo00T0oooo00<000000?ooo`3oool0M03oool007D0oooo
00<000000?ooo`3oool01P3oool00`000000o`000?ooo`090?ooo`030000003oool0oooo07@0oooo
001f0?ooo`030000003oool0oooo00D0oooo00<000000?l0003oool0203oool00`000000oooo0?oo
o`1e0?ooo`00MP3oool00`000000oooo0?ooo`050?ooo`030000003o0000oooo00P0oooo00<00000
0?ooo`3oool0M@3oool007L0oooo00<000000?ooo`3oool0103oool00`000000o`000?ooo`070?oo
o`030000003oool0oooo07H0oooo001g0?ooo`030000003oool0oooo00@0oooo00<000000?l0003o
ool01`3oool00`000000oooo0?ooo`1f0?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000
003o0000oooo00H0oooo00<000000?ooo`3oool0M`3oool007P0oooo00<000000?ooo`3oool00`3o
ool00`000000o`000?ooo`050?ooo`030000003oool0oooo07P0oooo001i0?ooo`030000003oool0
oooo0080oooo00<000000?l0003oool01@3oool00`000000oooo0?ooo`1h0?ooo`00N@3oool00`00
0000oooo0?ooo`020?ooo`030000003o0000oooo00@0oooo00<000000?ooo`3oool0N@3oool007X0
oooo00H000000?ooo`3oool0oooo0000003o00050?ooo`030000003oool0oooo07T0oooo001j0?oo
o`060000003oool0oooo0?ooo`000000o`00103oool00`000000oooo0?ooo`1j0?ooo`00N`3oool0
1@000000oooo0?ooo`000000o`0000@0oooo00<000000?ooo`3oool0NP3oool007/0oooo00<00000
0?ooo`000000100000000`3oool000000?ooo`1l0?ooo`00N`3oool9000007d0oooo001j0?ooo`/0
0000O03oool007T0oooo3@00001k0?ooo`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool0
07P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00
001j0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00
N`3oool9000007d0oooo001m0?ooo`D00000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool0
07l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3o
ool007d0oooo100000000`0@4100oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?oo
o`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`00
0000oooo0?ooo`1o0?ooo`00O@3oool00`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE
000000210?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.43767 .55861 Mdot
.5 Mabswid
[ ] 0 setdash
.43767 .55861 m
.84028 .36379 L
s
.43767 .55861 m
.2048 .31525 L
s
.4958 .947 m
.43767 .55861 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.84028 .36379 Mdot
.5 Mabswid
.2048 .31525 m
.84028 .36379 L
s
.4958 .947 m
.84028 .36379 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.2048 .31525 L
s
15 Mabswid
.2048 .31525 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42291 .54268 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.9457 .28544 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.11261 .21828 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00703oool200000003010@403o
ool0oooo0>00oooo000M0?ooo`030000003oool0oooo0>40oooo000I0?ooo`H00000hP3oool001T0
oooo00D0MgMg0:VYZ@3oool0oooo0000003S0?ooo`006@3oool01@3^k^h0<S8b0>k^kP3oool00000
0><0oooo000J0?ooo`040:VYZ@1VIVH0oooo00000><0oooo000K0?ooo`0304A4A03<c<`000000><0
oooo000K0?ooo`030=gMg@14A4@000000><0oooo000L0?ooo`0307MgM`0@4100oooo0>80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003_0?ooo`060:VYZ@0Q8B4000000000001E
EED0k^k^303oool00>l0oooo00H0410@0;Zj^P3oool0oooo0:VYZ@0b<S8<0?ooo`00m03oool00`00
0000oooo0?ooo`0:0?ooo`00l`3oool00`1gMgL08B4Q0?ooo`0;0?ooo`00<P3oool500000;X0oooo
00@08B4Q000000000000^[Zj303oool00300oooo2@00002i0?ooo`030>k^kP1gMgL0<S8b00`0oooo
000_0?ooo`/00000^P3oool00`000000oooo0?ooo`0:0?ooo`00;P3oool=00000;@0oooo00H08B4Q
0:VYZ@3oool0oooo06IVIP0b<S8<0?ooo`00;P3oool=00000;@0oooo00H0^[Zj04A4A00000000000
04A4A03^k^h<0?ooo`00;@3oool?00000<D0oooo000]0?ooo`l00000a@3oool002d0oooo3`000035
0?ooo`00;@3ooolL00000;P0oooo000]0?ooo`l000003@3oool>00000:X0oooo000^0?ooo`d00000
703oool>000009`0oooo000^0?ooo`d00000:P3oool=000008l0oooo000_0?ooo`/00000>03oool>
000005D0oooo1@00000W0?ooo`00<03oool:000004H0oooo3@0000160?ooo`T000009@3oool00380
oooo1P0000020?ooo`030000003oool0oooo0500oooo3P00000g0?ooo`/00000903oool003L0oooo
00D000000?ooo`3oool0oooo0000001O0?ooo`d00000:@3oool=000002<0oooo000h0?ooo`050000
003oool0oooo0?ooo`000000J`3oool>000001/0oooo3@00000S0?ooo`00>03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07H0oooo3P00000<0?ooo`l000008P3oool003T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`230?oooa/000008P3oool003T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2>0?ooo`l000008P3oool003X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2=0?ooo`l000008P3oool003X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2<0?ooo`l000008P3oool003/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2;0?ooo`h000008`3oool003/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`280?ooo`80000000<0oooo0000000000002`00000S0?ooo`00?03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo08D0oooo0P0000040?ooo`/00000903oool0
03`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`220?ooo`8000001`3oool90000
02D0oooo000m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0O`3oool2000000T0
oooo00<000000?ooo`0000001000000W0?ooo`00?@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03D0oooo00<0o`000?ooo`3oool0@`3oool3000000/0oooo00<000000?ooo`3oool0
:`3oool003d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`030?l0003o
ool0oooo0440oooo0P00000=0?ooo`030000003oool0oooo02`0oooo000n0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0o0?ooo`8000003P3oool0
0`000000oooo0?ooo`0]0?ooo`00?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0380oooo00<0o`000?ooo`3oool0?@3oool200000100oooo00<000000?ooo`3oool0;@3oool003l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo03/0
oooo0P00000A0?ooo`030000003oool0oooo02h0oooo000o0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0i0?ooo`8000004`3oool00`000000oooo
0?ooo`0^0?ooo`00@03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02l0oooo00<0
o`000?ooo`3oool0=`3oool2000001@0oooo00<000000?ooo`3oool0;`3oool00400oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo03D0oooo0P00000E
0?ooo`030000003oool0oooo0300oooo00110?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0;@3oool00`3o0000oooo0?ooo`0c0?ooo`8000005`3oool00`000000oooo0?ooo`0`0?oo
o`00@@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3o
ool0<@3oool2000001P0oooo00<000000?ooo`3oool0<@3oool00480oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02l0oooo0P00000J0?ooo`030000
003oool0oooo0340oooo00120?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`0]0?ooo`8000006`3oool00`000000oooo0?ooo`0b0?ooo`00@`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool0:`3oool2
000001d0oooo00<000000?ooo`3oool0<P3oool004<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo02T0oooo0P00000N0?ooo`030000003oool0oooo
03<0oooo00140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`3o0000
oooo0?ooo`0W0?ooo`8000007`3oool00`000000oooo0?ooo`0d0?ooo`00A03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool09@3oool200000240oooo
00<000000?ooo`3oool0=03oool004@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0V0?ooo`030?l0003oool0oooo02<0oooo0P00000R0?ooo`030000003oool0oooo03D0oooo0015
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0P
0?ooo`<00000903oool00`000000oooo0?ooo`0e0?ooo`00A@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool07P3oool2000002H0oooo00<000000?oo
o`3oool0=P3oool004H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo01`0oooo0P00000W0?ooo`030000003oool0oooo03L0oooo00160?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0J0?ooo`800000
:@3oool00`000000oooo0?ooo`0g0?ooo`00A`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0240oooo00<0o`000?ooo`3oool0603oool2000002X0oooo00<000000?ooo`3oool0>03o
ool004L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0
oooo01H0oooo0P00000/0?ooo`030000003oool0oooo03P0oooo00180?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0D0?ooo`800000;@3oool00`00
0000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<0o`000?ooo`3oool04P3oool2000002l0oooo00<000000?ooo`3oool0>@3oool004T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0100oooo
0P00000`0?ooo`030000003oool0oooo03X0oooo00190?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0703oool00`3o0000oooo0?ooo`0>0?ooo`800000<@3oool00`000000oooo0?oo
o`0k0?ooo`00BP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo00<0o`00
0?ooo`3oool0303oool2000003<0oooo00<000000?ooo`3oool0>`3oool004X0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00X0oooo0P00000d0?oo
o`030000003oool0oooo03`0oooo001:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool06@3oool00`3o0000oooo0?ooo`080?ooo`800000=P3oool00`000000oooo0?ooo`0l0?ooo`00
B`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0
1P3oool2000003L0oooo00<000000?ooo`3oool0?@3oool004/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00@0oooo0P00000h0?ooo`030000003o
ool0oooo03h0oooo001<0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`020?ooo`800000>P3oool00`000000oooo0?ooo`0n0?ooo`00C03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool00P00000k0?oo
o`030000003oool0oooo03l0oooo001=0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0503oool00`3o000000000000000m0?ooo`030000003oool0oooo03l0oooo001=0?ooo`030000
003oool0oooo01T0oooo2P00000:0?ooo`80000000<0o`000?ooo`3oool0?03oool00`000000oooo
0?ooo`100?ooo`00CP3oool00`000000oooo0?ooo`0H0?ooo`0309RHV0000000c<c<00T000001P3o
ool200000080oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`110?ooo`00CP3oool0
0`000000oooo0?ooo`0I0?ooo`0309RHV0000000000000T000000`3oool2000000@0oooo00<0o`00
0?ooo`3oool0>`3oool00`000000oooo0?ooo`110?ooo`00C`3oool00`000000oooo0?ooo`0H0?oo
o`l000001P3oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo001?0?ooo`03
0000003oool0oooo01P0oooo3@0000080?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3o
ool0@P3oool00500oooo00<000000?ooo`3oool05P3oool?000000L0oooo00<0o`000?ooo`3oool0
>@3oool00`000000oooo0?ooo`130?ooo`00D03oool00`000000oooo0?ooo`0F0?ooo`l000001`3o
ool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04<0oooo001@0?ooo`030000003oool0
oooo01H0oooo3`0000070?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0A03oool0
0540oooo00<000000?ooo`3oool05@3oool?000000L0oooo00<0o`000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`150?ooo`00D@3oool00`000000oooo0?ooo`0E0?ooo`l000001`3oool00`3o0000
oooo0?ooo`0g0?ooo`030000003oool0oooo04D0oooo001B0?ooo`030000003oool0oooo01D0oooo
3@0000080?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0AP3oool00580oooo00<0
00000?ooo`3oool05@3oool=000000P0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?oo
o`160?ooo`00D`3oool00`000000oooo0?ooo`0E0?ooo`/000002@3oool00`3o0000oooo0?ooo`0e
0?ooo`030000003oool0oooo04L0oooo001C0?ooo`030000003oool0oooo01H0oooo2@00000:0?oo
o`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0B03oool005@0oooo00<000000?ooo`3o
ool05`3oool5000000`0oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`180?ooo`00
E03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0
<`3oool00`000000oooo0?ooo`190?ooo`00E@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00/0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`190?ooo`00E@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`1:0?ooo`00EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00X0oooo00<0o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`1:0?ooo`00EP3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0<@3oool00`000000
oooo0?ooo`1;0?ooo`00EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo
00<0o`000?ooo`3oool0<03oool00`000000oooo0?ooo`1<0?ooo`00E`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0<03oool00`000000oooo0?oo
o`1<0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1=0?ooo`00F03oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`1=0?oo
o`00F03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1>0?ooo`00F@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00T0oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`1?0?ooo`00F@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`1?0?ooo`00FP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00T0oooo00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`1@0?ooo`00FP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1@0?ooo`00F`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0
oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`1A0?ooo`00F`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo
0?ooo`1B0?ooo`00G03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`1B0?ooo`00G03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`1C
0?ooo`00G@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0o`000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00P0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`1D0?ooo`00
G@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0
:03oool00`000000oooo0?ooo`1D0?ooo`00GP3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00P0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`1E0?ooo`00GP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1F0?ooo`00G`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`1F0?ooo`00G`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool09@3oool00`000000
oooo0?ooo`1G0?ooo`00H03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo
00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`1G0?ooo`00H03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?oo
o`1H0?ooo`00H@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<0o`00
0?ooo`3oool08`3oool00`000000oooo0?ooo`1I0?ooo`00H@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`1I0?oo
o`00HP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1J0?ooo`00HP3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00H0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`1J0?ooo`00H`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool08@3o
ool00`000000oooo0?ooo`1K0?ooo`00H`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00H0oooo00<0o`000?ooo`3oool0803oool00`000000oooo0?ooo`1L0?ooo`00H`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0803oool00`00
0000oooo0?ooo`1L0?ooo`00I03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0
oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`1M0?ooo`00I03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo
0?ooo`1M0?ooo`00I@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`00I@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`1N
0?ooo`00IP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<0o`000?oo
o`3oool07@3oool00`000000oooo0?ooo`1O0?ooo`00IP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`1P0?ooo`00
I`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0
703oool00`000000oooo0?ooo`1P0?ooo`00I`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`1Q0?ooo`00J03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool06`3oool0
0`000000oooo0?ooo`1Q0?ooo`00J03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00@0oooo00<0o`000?ooo`3oool06P3oool00`000000oooo0?ooo`1R0?ooo`00J@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool06@3oool00`000000
oooo0?ooo`1S0?ooo`00J@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo
00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`00J@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?oo
o`1T0?ooo`00JP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0603oool00`000000oooo0?ooo`1T0?ooo`00JP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`1U0?oo
o`00J`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1U0?ooo`00J`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`1V0?ooo`00K03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1W0?ooo`00K03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool00`00
0000oooo0?ooo`1X0?ooo`00K@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`1X0?ooo`00KP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo
0?ooo`1Y0?ooo`00KP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<0
o`000?ooo`3oool04P3oool00`000000oooo0?ooo`1Z0?ooo`00K`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`1Z
0?ooo`00K`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool04@3oool00`000000oooo0?ooo`1[0?ooo`00K`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`1[0?ooo`00
L03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0
403oool00`000000oooo0?ooo`1/0?ooo`00L03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`1]0?ooo`00L@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1]0?ooo`00L@3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`3o0000403oool00`000000oooo0?ooo`1^0?ooo`00LP3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`3o0000403oool00`000000oooo0?ooo`1^0?ooo`00LP3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`3o00003`3oool00`000000oooo0?ooo`1_
0?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`3o00003`3oool0
0`000000oooo0?ooo`1_0?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`3o00003P3oool00`000000oooo0?ooo`1`0?ooo`00M03oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`3o00003@3oool00`000000oooo0?ooo`1a0?ooo`00M03oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`3o00003@3oool00`000000oooo0?ooo`1a
0?ooo`00M@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?l000`0oooo00<00000
0?ooo`3oool0LP3oool007D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o000<
0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0o`002`3oool00`000000oooo0?ooo`1c0?ooo`00MP3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo0?l000X0oooo00<000000?ooo`3oool0M03oool007H0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3o000:0?ooo`030000003oool0oooo07@0oooo001g0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0o`002@3oool00`000000oooo0?ooo`1e
0?ooo`00M`3oool00`000000oooo0?ooo`030?ooo`030000003oool0o`0000T0oooo00<000000?oo
o`3oool0M@3oool007P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?l000080?ooo`03
0000003oool0oooo07H0oooo001h0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o0000
203oool00`000000oooo0?ooo`1f0?ooo`00N@3oool01`000000oooo0?ooo`3oool000000?ooo`3o
00001`3oool00`000000oooo0?ooo`1g0?ooo`00N@3oool01`000000oooo0?ooo`3oool000000?oo
o`3o00001P3oool00`000000oooo0?ooo`1h0?ooo`00NP3oool01P000000oooo0?ooo`000000oooo
0?l000H0oooo00<000000?ooo`3oool0N03oool007X0oooo00H000000?ooo`3oool000000?ooo`3o
00050?ooo`030000003oool0oooo07T0oooo001k0?ooo`050000003oool0oooo0000003o00001@3o
ool00`000000oooo0?ooo`1i0?ooo`00N`3oool01@000000oooo0?ooo`000000o`0000@0oooo00<0
00000?ooo`3oool0NP3oool007`0oooo1P0000000`3oool000000?ooo`1l0?ooo`00N`3oool90000
07d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?ooo`00N@3oool=000007/0oooo001h
0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000
NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007X0
oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D00000O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0
oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0
o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo0?ooo`1m0?ooo`00O`3oool00`00
0000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo
0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o
0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool00`000000A4A4000000210?ooo`00
O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.40466 .55574 Mdot
.5 Mabswid
[ ] 0 setdash
.40466 .55574 m
.8477 .3802 L
s
.40466 .55574 m
.22971 .30148 L
s
.4958 .947 m
.40466 .55574 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.8477 .3802 Mdot
.5 Mabswid
.22971 .30148 m
.8477 .3802 L
s
.4958 .947 m
.8477 .3802 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.22971 .30148 L
s
15 Mabswid
.22971 .30148 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.38134 .53902 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.95392 .30786 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.14447 .19899 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`009@3oool200000003010@403o
ool0oooo0=L0oooo000V0?ooo`030000003oool0oooo0=P0oooo000R0?ooo`H00000f@3oool00280
oooo00D0MgMg0:VYZ@3oool0oooo0000003J0?ooo`008P3oool01@3^k^h0<S8b0>k^kP3oool00000
0=X0oooo000S0?ooo`040:VYZ@1VIVH0oooo00000=X0oooo000T0?ooo`0304A4A03<c<`000000=X0
oooo000T0?ooo`030=gMg@14A4@000000=X0oooo000U0?ooo`0307MgM`0@4100oooo0=T0oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo000i0?ooo`D00000``3oool003L0oooo2@00
00310?ooo`00=P3oool;00000<00oooo000e0?ooo`d00000_`3oool003D0oooo3@00002o0?ooo`00
=03oool?00000;h0oooo000d0?ooo`l00000[`3oool01P2YZJT08B4Q000000000000EEEE0>k^kPT0
oooo000d0?ooo`l00000[`3oool01P0@4100^[Zj0?ooo`3oool0ZJVY038b<PT0oooo000d0?oooa@0
0000[`3oool00`000000oooo0?ooo`070?ooo`00=03oool?000000D0oooo2000002V0?ooo`0307Mg
M`0Q8B40oooo00P0oooo000e0?ooo`d000003P3oool8000009`0oooo00@08B4Q000000000000^[Zj
2@3oool003D0oooo3@00000F0?ooo`P00000U@3oool00`3^k^h0MgMg038b<P090?ooo`00=P3oool;
000001l0oooo1`00002@0?ooo`030000003oool0oooo00L0oooo000g0?ooo`T000009`3oool80000
08<0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S890?ooo`00>@3oool7000002l0oooo2000001k
0?ooo`060;Zj^P14A4@0000000000014A4@0k^k^2@3oool003h0oooo00<000000?ooo`000000=P3o
ool800000880oooo000n0?ooo`040000003oool0oooo000003d0oooo2000001j0?ooo`00?`3oool0
0`000000oooo000000150?ooo`P00000LP3oool003l0oooo00@000000?ooo`3oool00000C03oool8
000006X0oooo00100?ooo`040000003oool0oooo000005<0oooo2000001R0?ooo`00@03oool01000
0000oooo0?ooo`00001K0?ooo`P00000<03oool5000002D0oooo00110?ooo`040000003oool0oooo
00000680oooo2000000V0?ooo`T000008`3oool00440oooo00D000000?ooo`3oool0oooo0000001Y
0?ooo`L000007P3oool;00000280oooo00110?ooo`050000003oool0oooo0?ooo`000000L03oool8
000001D0oooo3@00000Q0?ooo`00@P3oool01@000000oooo0?ooo`3oool0000007L0oooo2000000=
0?ooo`d000008@3oool00480oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1l0?oo
o`P00000103oool?00000200oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0P`3ooolC00000200oooo00130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
Q`3oool?00000200oooo00130?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3o
ool?00000200oooo00140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Q@3oool?
00000200oooo00140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0P`3oool@0000
0240oooo00150?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool00`3o0000
oooo0?ooo`1<0?ooo`8000000`3oool=00000240oooo00150?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`190?ooo`<000001P3oool;00000280oooo
00150?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?oo
o`170?ooo`8000002P3oool9000002<0oooo00160?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`140?ooo`<00000303oool00`000000oooo00000004
000002D0oooo00160?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool00`3o
0000oooo0?ooo`110?ooo`<000003P3oool00`000000oooo0?ooo`0Z0?ooo`00A`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0?`3oool200000140
oooo00<000000?ooo`3oool0:P3oool004L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0]0?ooo`030?l0003oool0oooo03`0oooo0`00000B0?ooo`030000003oool0oooo02/0oooo
00170?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?oo
o`0j0?ooo`8000005@3oool00`000000oooo0?ooo`0[0?ooo`00B03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0=`3oool3000001H0oooo00<00000
0?ooo`3oool0;03oool004P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?oo
o`030?l0003oool0oooo03D0oooo0P00000H0?ooo`030000003oool0oooo02d0oooo00190?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0b0?ooo`<0
00006P3oool00`000000oooo0?ooo`0]0?ooo`00B@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02X0oooo00<0o`000?ooo`3oool0<03oool2000001`0oooo00<000000?ooo`3oool0
;P3oool004X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003o
ool0oooo02d0oooo0`00000M0?ooo`030000003oool0oooo02l0oooo001:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0[0?ooo`800000803oool0
0`000000oooo0?ooo`0_0?ooo`00BP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02P0oooo00<0o`000?ooo`3oool0:03oool300000240oooo00<000000?ooo`3oool0<03oool004/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo02H0
oooo0P00000T0?ooo`030000003oool0oooo0300oooo001;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0S0?ooo`<000009@3oool00`000000oooo
0?ooo`0a0?ooo`00C03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo00<0
o`000?ooo`3oool08@3oool2000002L0oooo00<000000?ooo`3oool0<P3oool004`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01h0oooo0`00000Y
0?ooo`030000003oool0oooo0380oooo001<0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`0K0?ooo`<00000:`3oool00`000000oooo0?ooo`0c0?oo
o`00C@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3o
ool06@3oool2000002h0oooo00<000000?ooo`3oool0<`3oool004d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01H0oooo0`00000_0?ooo`030000
003oool0oooo03@0oooo001>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`0D0?ooo`800000<@3oool00`000000oooo0?ooo`0e0?ooo`00CP3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool04@3oool3
000003<0oooo00<000000?ooo`3oool0=@3oool004h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00l0oooo0P00000e0?ooo`030000003oool0oooo
03H0oooo001?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`3o0000
oooo0?ooo`0<0?ooo`<00000=P3oool00`000000oooo0?ooo`0g0?ooo`00C`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool02P3oool2000003T0oooo
00<000000?ooo`3oool0=`3oool00500oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo00L0oooo0`00000j0?ooo`030000003oool0oooo03P0oooo001@
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`05
0?ooo`800000?@3oool00`000000oooo0?ooo`0h0?ooo`00D@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool00P3oool3000003h0oooo00<000000?oo
o`3oool0>@3oool00540oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo00800000@03oool00`000000oooo0?ooo`0j0?ooo`00D@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<0o`00000000000000@P3oool00`000000oooo
0?ooo`0j0?ooo`00DP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo0P00
00000`3o0000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo001B0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05P3oool300000080oooo00<0o`000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0l0?ooo`00D`3oool00`000000oooo0?ooo`080?ooo`H0000000<0oooo0000
000000000`00000=0?ooo`<000001@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo
03`0oooo001C0?ooo`030000003oool0oooo00P0oooo00<0V9RH0000003<c<`00P3oool9000000T0
oooo0P0000080?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool005<0oooo
00<000000?ooo`3oool02@3oool00`2HV9P000000<c<c00;000000D0oooo0`00000:0?ooo`030?l0
003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool005@0oooo00<000000?ooo`3oool02@3o
ool00`2YZJT000000000000;00000080oooo0P00000=0?ooo`030?l0003oool0oooo03h0oooo00<0
00000?ooo`3oool0?P3oool005@0oooo00<000000?ooo`3oool02P3oool?000000l0oooo00<0o`00
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0o0?ooo`00E@3oool00`000000oooo0?ooo`080?oo
o`l00000403oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo03l0oooo001E0?ooo`03
0000003oool0oooo00P0oooo3`00000@0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3o
ool0@03oool005D0oooo00<000000?ooo`3oool01P3oool00`000000QhN70000000>00000100oooo
00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`100?ooo`00EP3oool00`000000oooo0?oo
o`050?ooo`030:VYZ@0b<S80000000h00000403oool00`3o0000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0440oooo001F0?ooo`030000003oool0oooo00L0oooo3`00000@0?ooo`030?l0003oool0
oooo03X0oooo00<000000?ooo`3oool0@P3oool005L0oooo00<000000?ooo`3oool01`3oool=0000
0140oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`120?ooo`00E`3oool00`000000
oooo0?ooo`070?ooo`d000004@3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04<0
oooo001G0?ooo`030000003oool0oooo00P0oooo2`00000B0?ooo`030?l0003oool0oooo03P0oooo
00<000000?ooo`3oool0A03oool005P0oooo00<000000?ooo`3oool0203oool9000001<0oooo00<0
o`000?ooo`3oool0>03oool00`000000oooo0?ooo`140?ooo`00F03oool00`000000oooo0?ooo`0:
0?ooo`D000005@3oool00`3o0000oooo0?ooo`0g0?ooo`030000003oool0oooo04D0oooo001I0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0g0?oo
o`030000003oool0oooo04D0oooo001I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo04H0oooo001J0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0e0?ooo`030000
003oool0oooo04L0oooo001J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo04L0oooo001J0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0
oooo04P0oooo001K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0d0?ooo`030000003oool0oooo04P0oooo001K0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo04T0
oooo001L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0b0?ooo`030000003oool0oooo04X0oooo001L0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo04X0oooo001L
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0a
0?ooo`030000003oool0oooo04/0oooo001M0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo001M0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0`0?ooo`03
0000003oool0oooo04`0oooo001N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
403oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo04d0oooo001N0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0_0?ooo`030000003o
ool0oooo04d0oooo001N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo04h0oooo001O0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo
04l0oooo001O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0]0?ooo`030000003oool0oooo04l0oooo001P0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo0500oooo
001P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0/0?ooo`030000003oool0oooo0500oooo001P0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo0540oooo001Q0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0580oooo001Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo001R0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000
003oool0oooo05<0oooo001R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0oooo05@0oooo001S0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0X0?ooo`030000003oool0
oooo05@0oooo001S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0oooo001S0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0
oooo001T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0V0?ooo`030000003oool0oooo05H0oooo001T0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo05L0oooo001U
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0U
0?ooo`030000003oool0oooo05L0oooo001U0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo001U0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`03
0000003oool0oooo05P0oooo001V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
303oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001V0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0R0?ooo`030000003o
ool0oooo05X0oooo001W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo05X0oooo001W0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo
05/0oooo001W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0P0?ooo`030000003oool0oooo05`0oooo001X0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo05`0oooo
001X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0O0?ooo`030000003oool0oooo05d0oooo001Y0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo001Y0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0N0?oo
o`030000003oool0oooo05h0oooo001Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo05l0oooo001Z0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0M0?ooo`030000
003oool0oooo05l0oooo001Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo0600oooo001[0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0
oooo0600oooo001[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo001/0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0680
oooo001/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0J0?ooo`030000003oool0oooo0680oooo001/0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo001]
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0H
0?ooo`030000003oool0oooo06@0oooo001]0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo06@0oooo001^0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000003oool0oooo06D0oooo001^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo06D0oooo001^0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0F0?ooo`030000003o
ool0oooo06H0oooo001_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo001_0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo
06L0oooo001`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo001`0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo06T0oooo
001`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0C0?ooo`030000003oool0oooo06T0oooo001a0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0oooo001a0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?oo
o`030000003oool0oooo06X0oooo001b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001b0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`030000
003oool0oooo06`0oooo001c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0oooo001c0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0
oooo06d0oooo001c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0oooo001d0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0oooo001d0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000003oool0oooo06l0oooo001e0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`3o0000
oooo0?ooo`0=0?ooo`030000003oool0oooo06l0oooo001e0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0700oooo001e0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo0740
oooo001f0?ooo`050000003oool0oooo0?ooo`000000103oool00`3o0000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0740oooo001f0?ooo`050000003oool0oooo0?ooo`000000103oool00`3o0000
oooo0?ooo`0:0?ooo`030000003oool0oooo0780oooo001g0?ooo`040000003oool0oooo000000@0
oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool010000000oooo
0?ooo`0000040?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool007L0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3o
ool0M03oool007P0oooo00@000000?ooo`3oool000000`3oool00`3o0000oooo0?ooo`080?ooo`03
0000003oool0oooo07@0oooo001h0?ooo`040000003oool0oooo000000<0oooo00<0o`000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1e0?ooo`00N@3oool00`000000oooo000000030?ooo`030?l0
003oool0oooo00L0oooo00<000000?ooo`3oool0M@3oool007T0oooo00@000000?ooo`3oool00000
0P3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo001i0?ooo`040000003o
ool0oooo00000080oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`00NP3o
ool00`000000oooo000000020?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0M`3o
ool007X0oooo00<000000?ooo`0000000P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0
oooo07P0oooo001k0?ooo`050000003oool000000?ooo`3o00001@3oool00`000000oooo0?ooo`1i
0?ooo`00N`3oool01@000000oooo0000003oool0o`0000D0oooo00<000000?ooo`3oool0N@3oool0
07`0oooo0P0000000`3oool0o`000?ooo`030?ooo`030000003oool0oooo07X0oooo001l0?ooo`H0
00000P3oool00`000000oooo0?ooo`1j0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03o
ool007T0oooo3@00001k0?ooo`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo
3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?oo
o`00N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool9
000007d0oooo001m0?ooo`D00000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0
oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0
oooo100000000`0@4100oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`00
0000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo
0?ooo`1o0?ooo`00O@3oool00`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE00000021
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.37238 .55149 Mdot
.5 Mabswid
[ ] 0 setdash
.37238 .55149 m
.85103 .39671 L
s
.37238 .55149 m
.25817 .2889 L
s
.4958 .947 m
.37238 .55149 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.85103 .39671 Mdot
.5 Mabswid
.25817 .2889 m
.85103 .39671 L
s
.4958 .947 m
.85103 .39671 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.25817 .2889 L
s
15 Mabswid
.25817 .2889 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.3406 .53361 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.95677 .33027 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.1813 .18128 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00;P3oool200000003010@403o
ool0oooo0<h0oooo000_0?ooo`030000003oool0oooo0<l0oooo000[0?ooo`H00000d03oool002/0
oooo00D0MgMg0:VYZ@3oool0oooo0000003A0?ooo`00:`3oool01@3^k^h0<S8b0>k^kP3oool00000
0=40oooo000/0?ooo`040:VYZ@1VIVH0oooo00000=40oooo000]0?ooo`0304A4A03<c<`000000=40
oooo000]0?ooo`030=gMg@14A4@000000=40oooo000^0?ooo`0307MgM`0@4100oooo0=00oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo0010
0?ooo`D00000_03oool003h0oooo2@00002j0?ooo`00?@3oool;00000;T0oooo000l0?ooo`d00000
^03oool003`0oooo3@00002h0?ooo`00>`3oool?00000;L0oooo000k0?ooo`l00000]`3oool003/0
oooo3`00002g0?ooo`00>`3oool@00000;H0oooo000k0?ooo`l0000000<0oooo0000000000001000
002`0?ooo`00?03oool=000000P0oooo1@00002[0?ooo`00?03oool=000000d0oooo1@00002V0?oo
o`00?@3oool;000001<0oooo1P00002P0?ooo`00?P3oool9000001X0oooo1@00002K0?ooo`00@03o
ool600000200oooo1P0000260?ooo`060:VYZ@0Q8B4000000000001EEED0k^k^2@3oool004D0oooo
00<000000?ooo`3oool0903oool500000840oooo00H0410@0;Zj^P3oool0oooo0:VYZ@0b<S890?oo
o`00A@3oool2000002X0oooo1P0000200?ooo`030000003oool0oooo00L0oooo00150?ooo`800000
<03oool5000007X0oooo00<0MgMg024Q8@3oool0203oool004H0oooo0P00000d0?ooo`D00000L`3o
ool0100Q8B4000000000002j^[X90?ooo`00AP3oool2000003T0oooo1P00001^0?ooo`030>k^kP1g
MgL0<S8b00T0oooo00170?ooo`030000003oool0oooo03d0oooo1@00001[0?ooo`030000003oool0
oooo00L0oooo00170?ooo`800000@`3oool600000600oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b
<S890?ooo`00A`3oool2000004T0oooo1@00001K0?ooo`060;Zj^P14A4@0000000000014A4@0k^k^
2@3oool004P0oooo0P00001=0?ooo`H00000I03oool004P0oooo0P00001C0?ooo`D00000G`3oool0
04P0oooo00<000000?ooo`000000E`3oool5000005X0oooo00190?ooo`800000G03oool6000005@0
oooo00190?ooo`800000HP3oool5000004l0oooo00190?ooo`030000003oool0000006H0oooo1P00
000P0?ooo`D00000903oool004X0oooo0P00001/0?ooo`D000006@3oool900000280oooo001:0?oo
o`030000003oool000000700oooo1P00000B0?ooo`/000008@3oool004X0oooo00<000000?ooo`00
0000MP3oool5000000`0oooo3@00000P0?ooo`00B`3oool00`000000oooo0000001j0?ooo`D00000
1`3oool=00000200oooo001;0?ooo`030000003oool0000007l0oooo5@00000O0?ooo`00C03oool2
00000340oooo00<0o`000?ooo`3oool0D@3oool?000001l0oooo001<0?ooo`030000003oool00000
0300oooo00<0o`000?ooo`3oool0D@3oool?000001l0oooo001<0?ooo`030000003oool000000300
oooo00<0o`000?ooo`3oool0D@3oool?000001l0oooo001=0?ooo`030000003oool0000002l0oooo
00<0o`000?ooo`3oool0D03oool@000001l0oooo001=0?ooo`030000003oool0000002l0oooo00<0
o`000?ooo`3oool0C@3oool300000080oooo3@00000P0?ooo`00C@3oool010000000oooo0?ooo`00
000^0?ooo`030?l0003oool0oooo04X0oooo0`0000050?ooo`d00000803oool004h0oooo00<00000
0?ooo`000000;P3oool00`3o0000oooo0?ooo`170?ooo`<000002@3oool;00000240oooo001>0?oo
o`040000003oool0oooo000002d0oooo00<0o`000?ooo`3oool0@`3oool4000000d0oooo2@00000R
0?ooo`00CP3oool010000000oooo0?ooo`00000]0?ooo`030?l0003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0000000@00000903oool004l0oooo00<000000?ooo`000000;@3oool00`3o
0000oooo0?ooo`0m0?ooo`<000004`3oool00`000000oooo0?ooo`0Y0?ooo`00C`3oool010000000
oooo0?ooo`00000/0?ooo`030?l0003oool0oooo03X0oooo0`00000F0?ooo`030000003oool0oooo
02T0oooo001@0?ooo`030000003oool0000002`0oooo00<0o`000?ooo`3oool0=`3oool3000001P0
oooo00<000000?ooo`3oool0:P3oool00500oooo00@000000?ooo`3oool00000:`3oool00`3o0000
oooo0?ooo`0d0?ooo`<000006P3oool00`000000oooo0?ooo`0[0?ooo`00D03oool010000000oooo
0?ooo`00000[0?ooo`030?l0003oool0oooo0340oooo0`00000M0?ooo`030000003oool0oooo02/0
oooo001A0?ooo`040000003oool0oooo000002X0oooo00<0o`000?ooo`3oool0;@3oool4000001l0
oooo00<000000?ooo`3oool0;03oool00540oooo00@000000?ooo`3oool00000:P3oool00`3o0000
oooo0?ooo`0Z0?ooo`<000008P3oool00`000000oooo0?ooo`0]0?ooo`00D@3oool010000000oooo
0?ooo`00000Z0?ooo`030?l0003oool0oooo02L0oooo0`00000U0?ooo`030000003oool0oooo02d0
oooo001B0?ooo`040000003oool0oooo000002T0oooo00<0o`000?ooo`3oool0903oool3000002L0
oooo00<000000?ooo`3oool0;P3oool00580oooo00@000000?ooo`3oool00000:@3oool00`3o0000
oooo0?ooo`0Q0?ooo`<00000:@3oool00`000000oooo0?ooo`0_0?ooo`00DP3oool01@000000oooo
0?ooo`3oool0000002P0oooo00<0o`000?ooo`3oool07P3oool3000002`0oooo00<000000?ooo`3o
ool0;`3oool005<0oooo00@000000?ooo`3oool00000:03oool00`3o0000oooo0?ooo`0J0?ooo`@0
0000;P3oool00`000000oooo0?ooo`0`0?ooo`00D`3oool01@000000oooo0?ooo`3oool0000002L0
oooo00<0o`000?ooo`3oool05`3oool300000340oooo00<000000?ooo`3oool0<@3oool005@0oooo
00@000000?ooo`3oool000009`3oool00`3o0000oooo0?ooo`0D0?ooo`<00000=03oool00`000000
oooo0?ooo`0a0?ooo`00E03oool010000000oooo0?ooo`00000W0?ooo`030?l0003oool0oooo0140
oooo0`00000f0?ooo`030000003oool0oooo0380oooo001D0?ooo`050000003oool0oooo0?ooo`00
00009P3oool00`3o0000oooo0?ooo`0>0?ooo`<00000>03oool00`000000oooo0?ooo`0c0?ooo`00
E@3oool010000000oooo0?ooo`00000V0?ooo`030?l0003oool0oooo00/0oooo0`00000k0?ooo`03
0000003oool0oooo03<0oooo001E0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`3o0000
oooo0?ooo`080?ooo`<00000?@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool01@000000oooo
0?ooo`3oool0000002D0oooo00<0o`000?ooo`3oool0103oool400000400oooo00<000000?ooo`3o
ool0=03oool005H0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`040?l0003oool0oooo0?oo
o`<00000@`3oool00`000000oooo0?ooo`0e0?ooo`00EP3oool01@000000oooo0?ooo`3oool00000
02@0oooo00@0o`000000000000000000A@3oool00`000000oooo0?ooo`0f0?ooo`00EP3oool01@00
0000oooo0?ooo`3oool000000280oooo0P0000000`3o0000oooo0?ooo`160?ooo`030000003oool0
oooo03H0oooo001G0?ooo`050000003oool0oooo0?ooo`0000007P3oool300000080oooo00<0o`00
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0g0?ooo`00E`3oool01@000000oooo0?ooo`3oool0
000001/0oooo0`0000050?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
05@0oooo1P0000020?ooo`H000004@3oool4000000P0oooo00<0o`000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0h0?ooo`00E03oool01`2HV9P000000<c<c03oool00000010@403oool02@00000<
0?ooo`<00000303oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo03T0oooo001E0?oo
o`0509RHV0000000c<c<0000003oool02`0000080?ooo`<000003`3oool00`3o0000oooo0?ooo`12
0?ooo`030000003oool0oooo03X0oooo001F0?ooo`030:VYZ@0@4100c<c<00d00000103oool30000
0180oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0j0?ooo`00E`3oool00`3<c<`0
410@0000000<000000040?ooo`0000000000000001D0oooo00<0o`000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0k0?ooo`00F03oool?000001P0oooo00<0o`000?ooo`3oool0@03oool00`000000
oooo0?ooo`0l0?ooo`00F03oool?000001P0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo
0?ooo`0l0?ooo`00E03oool010000000QhN70>k^kP3oool?000001P0oooo00<0o`000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0m0?ooo`00E03oool00`2YZJT0<S8b0000000@000001P0oooo00<0
o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0m0?ooo`00F03oool?000001P0oooo00<0o`00
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`00F@3oool=000001T0oooo00<0o`000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0o0?ooo`00F@3oool=000001T0oooo00<0o`000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0o0?ooo`00FP3oool;000001X0oooo00<0o`000?ooo`3oool0
?03oool00`000000oooo0?ooo`100?ooo`00F`3oool9000001/0oooo00<0o`000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`110?ooo`00G@3oool5000001d0oooo00<0o`000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`110?ooo`00G@3oool01@000000oooo0?ooo`3oool0000001d0oooo00<0o`00
0?ooo`3oool0>P3oool00`000000oooo0?ooo`120?ooo`00G@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`130?oo
o`00GP3oool01@000000oooo0?ooo`3oool0000001`0oooo00<0o`000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`130?ooo`00GP3oool01@000000oooo0?ooo`3oool0000001`0oooo00<0o`000?oo
o`3oool0>03oool00`000000oooo0?ooo`140?ooo`00GP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01T0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`150?ooo`00
G`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<0o`000?ooo`3oool0=`3oool00`000000
oooo0?ooo`150?ooo`00G`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<0o`000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`160?ooo`00G`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`170?ooo`00H03o
ool01@000000oooo0?ooo`3oool0000001X0oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo
0?ooo`170?ooo`00H03oool01@000000oooo0?ooo`3oool0000001X0oooo00<0o`000?ooo`3oool0
=03oool00`000000oooo0?ooo`180?ooo`00H@3oool010000000oooo0?ooo`00000J0?ooo`030?l0
003oool0oooo03@0oooo00<000000?ooo`3oool0B03oool00640oooo00D000000?ooo`3oool0oooo
0000000I0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0B@3oool00640oooo00D0
00000?ooo`3oool0oooo0000000I0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0
BP3oool00680oooo00@000000?ooo`3oool000006@3oool00`3o0000oooo0?ooo`0b0?ooo`030000
003oool0oooo04X0oooo001R0?ooo`050000003oool0oooo0?ooo`000000603oool00`3o0000oooo
0?ooo`0a0?ooo`030000003oool0oooo04/0oooo001R0?ooo`050000003oool0oooo0?ooo`000000
603oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo001S0?ooo`040000003o
ool0oooo000001P0oooo00<0o`000?ooo`3oool0<03oool00`000000oooo0?ooo`1<0?ooo`00H`3o
ool01@000000oooo0?ooo`3oool0000001L0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1=0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000001L0oooo00<0o`000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1>0?ooo`00I03oool010000000oooo0?ooo`00000G0?ooo`030?l0
003oool0oooo02h0oooo00<000000?ooo`3oool0CP3oool006@0oooo00D000000?ooo`3oool0oooo
0000000F0?ooo`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool0C`3oool006@0oooo00D0
00000?ooo`3oool0oooo0000000F0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0
D03oool006D0oooo00@000000?ooo`3oool000005P3oool00`3o0000oooo0?ooo`0/0?ooo`030000
003oool0oooo0500oooo001U0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`3o0000oooo
0?ooo`0[0?ooo`030000003oool0oooo0540oooo001V0?ooo`040000003oool0oooo000001D0oooo
00<0o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`1B0?ooo`00IP3oool010000000oooo0?oo
o`00000E0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0DP3oool006H0oooo00D0
00000?ooo`3oool0oooo0000000D0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0
D`3oool006L0oooo00@000000?ooo`3oool00000503oool00`3o0000oooo0?ooo`0Y0?ooo`030000
003oool0oooo05<0oooo001W0?ooo`040000003oool0oooo000001@0oooo00<0o`000?ooo`3oool0
:03oool00`000000oooo0?ooo`1D0?ooo`00I`3oool010000000oooo0?ooo`00000D0?ooo`030?l0
003oool0oooo02L0oooo00<000000?ooo`3oool0E@3oool006P0oooo00@000000?ooo`3oool00000
4`3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0oooo001X0?ooo`040000003o
ool0oooo000001<0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`1F0?ooo`00J03o
ool010000000oooo0?ooo`00000C0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0
E`3oool006T0oooo00@000000?ooo`3oool000004P3oool00`3o0000oooo0?ooo`0U0?ooo`030000
003oool0oooo05L0oooo001Y0?ooo`040000003oool0oooo00000180oooo00<0o`000?ooo`3oool0
903oool00`000000oooo0?ooo`1H0?ooo`00JP3oool00`000000oooo0000000B0?ooo`030?l0003o
ool0oooo02<0oooo00<000000?ooo`3oool0F@3oool006X0oooo00@000000?ooo`3oool000004@3o
ool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001Z0?ooo`040000003oool0
oooo00000140oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`1J0?ooo`00J`3oool0
0`000000oooo0000000A0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0F`3oool0
06/0oooo00@000000?ooo`3oool00000403oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0
oooo05/0oooo001[0?ooo`040000003oool0oooo00000100oooo00<0o`000?ooo`3oool0803oool0
0`000000oooo0?ooo`1L0?ooo`00K03oool00`000000oooo0000000@0?ooo`030?l0003oool0oooo
0200oooo00<000000?ooo`3oool0G03oool006`0oooo00@000000?ooo`3oool000003`3oool00`3o
0000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo001/0?ooo`040000003oool0oooo0000
00l0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`00K@3oool00`000000
oooo0000000?0?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool006d0oooo
00<000000?ooo`0000003`3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo05l0oooo
001]0?ooo`040000003oool0oooo000000h0oooo00<0o`000?ooo`3oool0703oool00`000000oooo
0?ooo`1P0?ooo`00KP3oool00`000000oooo0000000>0?ooo`030?l0003oool0oooo01`0oooo00<0
00000?ooo`3oool0H03oool006h0oooo00<000000?ooo`0000003P3oool00`3o0000oooo0?ooo`0K
0?ooo`030000003oool0oooo0640oooo001_0?ooo`030000003oool0000000d0oooo00<0o`000?oo
o`3oool06P3oool00`000000oooo0?ooo`1R0?ooo`00K`3oool00`000000oooo0000000=0?ooo`03
0?l0003oool0oooo01X0oooo00<000000?ooo`3oool0HP3oool006l0oooo00<000000?ooo`000000
3@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo001`0?ooo`030000003o
ool0000000`0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`1T0?ooo`00L03oool0
0`000000oooo0000000<0?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0I03oool0
0700oooo00<000000?ooo`000000303oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo
06D0oooo001a0?ooo`030000003oool0000000/0oooo00<0o`000?ooo`3oool05P3oool00`000000
oooo0?ooo`1V0?ooo`00L@3oool00`000000oooo0000000;0?ooo`030?l0003oool0oooo01H0oooo
00<000000?ooo`3oool0IP3oool00740oooo00<000000?ooo`0000002`3oool00`3o0000oooo0?oo
o`0E0?ooo`030000003oool0oooo06L0oooo001b0?ooo`030000003oool0000000X0oooo00<0o`00
0?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`00LP3oool00`000000oooo0000000:0?oo
o`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0J03oool007<0oooo0P00000:0?ooo`03
0?l0003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool007<0oooo0P00000:0?ooo`030?l0
003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool007<0oooo00<000000?ooo`0000002@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0oooo001d0?ooo`8000002@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001d0?ooo`8000002@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001d0?ooo`030000003oool0000000P0
oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`1/0?ooo`00M@3oool2000000P0oooo
00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`1]0?ooo`00M@3oool2000000P0oooo00<0
o`000?ooo`3oool03`3oool00`000000oooo0?ooo`1]0?ooo`00M@3oool00`000000oooo00000007
0?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0KP3oool007H0oooo0P0000070?oo
o`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0K`3oool007H0oooo0P0000070?ooo`03
0?l0003oool0oooo00d0oooo00<000000?ooo`3oool0K`3oool007L0oooo0P0000060?ooo`030?l0
003oool0oooo00`0oooo00<000000?ooo`3oool0L03oool007L0oooo0P0000060?ooo`030?l0003o
ool0oooo00`0oooo00<000000?ooo`3oool0L03oool007L0oooo0P0000060?ooo`030?l0003oool0
oooo00/0oooo00<000000?ooo`3oool0L@3oool007P0oooo0P0000050?ooo`030?l0003oool0oooo
00X0oooo00<000000?ooo`3oool0LP3oool007P0oooo0P0000050?ooo`030?l0003oool0oooo00X0
oooo00<000000?ooo`3oool0LP3oool007P0oooo0P0000050?ooo`030?l0003oool0oooo00T0oooo
00<000000?ooo`3oool0L`3oool007T0oooo0P0000040?ooo`030?l0003oool0oooo00P0oooo00<0
00000?ooo`3oool0M03oool007T0oooo0P0000040?ooo`030?l0003oool0oooo00P0oooo00<00000
0?ooo`3oool0M03oool007T0oooo0P0000040?ooo`030?l0003oool0oooo00L0oooo00<000000?oo
o`3oool0M@3oool007X0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`03
0000003oool0oooo07H0oooo001j0?ooo`8000000`3oool00`3o0000oooo0?ooo`060?ooo`030000
003oool0oooo07H0oooo001j0?ooo`8000000`3oool00`3o0000oooo0?ooo`050?ooo`030000003o
ool0oooo07L0oooo001k0?ooo`050000003oool0oooo0?ooo`3o00001P3oool00`000000oooo0?oo
o`1h0?ooo`00N`3oool200000080oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`1h
0?ooo`00O03oool010000000oooo0?ooo`3o00050?ooo`030000003oool0oooo07T0oooo001l0?oo
o`040000003oool0oooo0?l000@0oooo00<000000?ooo`3oool0NP3oool007`0oooo1P0000020?oo
o`030000003oool0oooo07X0oooo001k0?ooo`T00000O@3oool007X0oooo2`00001l0?ooo`00N@3o
ool=000007/0oooo001i0?ooo`d00000N`3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0
oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001i0?oo
o`d00000N`3oool007T0oooo3@00001k0?ooo`00NP3oool;000007`0oooo001k0?ooo`T00000O@3o
ool007d0oooo1@00001o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000
oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?oo
o`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?oo
o`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00O`3o
ool00`3o0000oooo0?ooo`1o0?ooo`00O`3oool00`3o0000oooo0?ooo`1o0?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00O@3oool40000
0003010@403oool0oooo07d0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000
003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0
oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0
oooo001m0?ooo`0300000014A4@000000840oooo001m0?ooo`030<c<c01EEED000000840oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.3411 .54589 Mdot
.5 Mabswid
[ ] 0 setdash
.3411 .54589 m
.85036 .41313 L
s
.3411 .54589 m
.28987 .27771 L
s
.4958 .947 m
.3411 .54589 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.85036 .41313 Mdot
.5 Mabswid
.28987 .27771 m
.85036 .41313 L
s
.4958 .947 m
.85036 .41313 L
s
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.28987 .27771 L
s
15 Mabswid
.28987 .27771 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.301 .52647 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.95445 .35242 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.2227 .16546 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00>@3oool2
00000003010@403oool0oooo0<<0oooo000j0?ooo`030000003oool0oooo0<@0oooo000f0?ooo`H0
0000a@3oool003H0oooo00D0MgMg0:VYZ@3oool0oooo000000360?ooo`00=P3oool01@3^k^h0<S8b
0>k^kP3oool000000<H0oooo000g0?ooo`040:VYZ@1VIVH0oooo00000<H0oooo000h0?ooo`0304A4
A03<c<`000000<H0oooo000h0?ooo`030=gMg@14A4@000000<H0oooo000i0?ooo`0307MgM`0@4100
oooo0<D0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo00180?ooo`D00000]03oool004H0oooo2@00002b0?ooo`00A@3o
ool;00000;40oooo00140?ooo`d00000/03oool004@0oooo3@00002`0?ooo`00@`3oool?00000:l0
oooo00130?ooo`l00000[`3oool004<0oooo3`00002_0?ooo`00@`3oool?00000:l0oooo00130?oo
oa800000[03oool004@0oooo3@0000040?ooo`@00000Z03oool004@0oooo3@0000080?ooo`D00000
X`3oool004D0oooo2`00000>0?ooo`@00000W`3oool004H0oooo2@00000C0?ooo`@00000V`3oool0
04P0oooo1@00000I0?ooo`@00000U`3oool004/0oooo0P00000M0?ooo`@00000T`3oool004`0oooo
0P00000P0?ooo`@00000S`3oool004`0oooo0P00000T0?ooo`@00000R`3oool004`0oooo0P00000X
0?ooo`@00000Q`3oool004`0oooo00<000000?ooo`000000:`3oool4000008<0oooo001<0?ooo`03
0000003oool0000002l0oooo1@00001n0?ooo`00C@3oool2000003@0oooo1000001j0?ooo`00C@3o
ool2000003P0oooo1000001f0?ooo`00C@3oool00`000000oooo0000000k0?ooo`@00000H`3oool0
1P2YZJT08B4Q000000000000EEEE0>k^kPT0oooo001=0?ooo`030000003oool0000003l0oooo1000
001O0?ooo`06010@402j^[X0oooo0?ooo`2YZJT0<S8b2@3oool004d0oooo00<000000?ooo`000000
@`3oool400000600oooo00<000000?ooo`3oool01`3oool004d0oooo00@000000?ooo`3oool00000
AP3oool4000005/0oooo00<0MgMg024Q8@3oool0203oool004h0oooo00<000000?ooo`000000BP3o
ool4000005D0oooo00@08B4Q000000000000^[Zj2@3oool004h0oooo00<000000?ooo`000000CP3o
ool400000580oooo00<0k^k^07MgM`0b<S802@3oool004h0oooo00@000000?ooo`3oool00000D@3o
ool5000004l0oooo00<000000?ooo`3oool01`3oool004h0oooo00@000000?ooo`3oool00000EP3o
ool4000004H0oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S890?ooo`00CP3oool010000000oooo
0?ooo`00001J0?ooo`@00000@P3oool01P2j^[X0A4A4000000000000A4A40>k^kPT0oooo001?0?oo
o`040000003oool0oooo000005d0oooo1000001=0?ooo`00C`3oool010000000oooo0?ooo`00001Q
0?ooo`@00000B@3oool004l0oooo00@000000?ooo`3oool00000I@3oool4000004D0oooo001?0?oo
o`040000003oool0oooo000006T0oooo1000000H0?ooo`D00000903oool004l0oooo00D000000?oo
o`3oool0oooo0000001/0?ooo`@000004P3oool900000280oooo001@0?ooo`040000003oool0oooo
000002/0oooo00<0o`000?ooo`3oool0@P3oool4000000d0oooo2`00000Q0?ooo`00D03oool01000
0000oooo0?ooo`00000[0?ooo`030?l0003oool0oooo04H0oooo1@0000070?ooo`d00000803oool0
0500oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030?l0003oool0oooo04/0oooo10000003
0?ooo`d00000803oool00500oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030?l0003oool0
oooo04l0oooo4@00000O0?ooo`00D03oool01@000000oooo0?ooo`3oool0000002X0oooo00<0o`00
0?ooo`3oool0D@3oool?000001l0oooo001A0?ooo`050000003oool0oooo0?ooo`000000:@3oool0
0`3o0000oooo0?ooo`1A0?ooo`l000007`3oool00540oooo00D000000?ooo`3oool0oooo0000000Y
0?ooo`030?l0003oool0oooo0540oooo3`00000O0?ooo`00D@3oool01@000000oooo0?ooo`3oool0
000002T0oooo00<0o`000?ooo`3oool0CP3ooolB000001l0oooo001A0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`1;0?ooo`<00000103oool=0000
0200oooo001A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`3o0000
oooo0?ooo`170?ooo`@000001`3oool=00000200oooo001A0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`130?ooo`@00000303oool;00000240oooo
001B0?ooo`050000003oool0oooo0?ooo`000000:03oool00`3o0000oooo0?ooo`0o0?ooo`@00000
4@3oool900000280oooo001B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`0k0?ooo`@000005@3oool00`000000oooo00000004000002@0oooo001B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0g
0?ooo`@00000603oool00`000000oooo0?ooo`0Y0?ooo`00DP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0<`3oool4000001/0oooo00<000000?oo
o`3oool0:P3oool00580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`03
0?l0003oool0oooo0300oooo0`00000O0?ooo`030000003oool0oooo02X0oooo001C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0/0?ooo`@00000
8@3oool00`000000oooo0?ooo`0[0?ooo`00D`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02@0oooo00<0o`000?ooo`3oool0:03oool4000002@0oooo00<000000?ooo`3oool0;03o
ool005<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0
oooo02@0oooo1000000X0?ooo`030000003oool0oooo02`0oooo001C0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0P0?ooo`@00000:`3oool00`00
0000oooo0?ooo`0]0?ooo`00D`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0
oooo00<0o`000?ooo`3oool0703oool4000002h0oooo00<000000?ooo`3oool0;P3oool005@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo01P0oooo
1000000b0?ooo`030000003oool0oooo02h0oooo001D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0E0?ooo`<00000=@3oool00`000000oooo0?oo
o`0_0?ooo`00E03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<0o`00
0?ooo`3oool04@3oool4000003L0oooo00<000000?ooo`3oool0<03oool005@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00d0oooo1000000k0?oo
o`030000003oool0oooo0300oooo001D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`090?ooo`@00000?P3oool00`000000oooo0?ooo`0a0?ooo`00
E03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
1@3oool400000440oooo00<000000?ooo`3oool0<P3oool005D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Q0?ooo`040?l0003oool0oooo0?ooo`@00000A@3oool00`000000oooo
0?ooo`0b0?ooo`00E@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00@0
o`000000000000000000B03oool00`000000oooo0?ooo`0c0?ooo`00E@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01d0oooo0`0000000`3o0000oooo0?ooo`180?ooo`030000003o
ool0oooo03@0oooo001E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool4
000000<0oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0d0?ooo`00BP3oool60000
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`@000001`3oool00`3o
0000oooo0?ooo`170?ooo`030000003oool0oooo03D0oooo001:0?ooo`0309RHV0000000c<c<0080
oooo00<0410@0?ooo`3oool00`3oool5000000<0oooo00<000000?ooo`3oool0403oool4000000/0
oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0f0?ooo`00B`3oool00`2HV9P00000
0<c<c0050?ooo`T0000000<0oooo0000003oool03@3oool4000000l0oooo00<0o`000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0f0?ooo`00C03oool00`2YZJT0410@0<c<c0030?ooo`/0000000<0
oooo0000003oool0203oool4000001<0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0g0?ooo`00C@3oool0103<c<`0410@0<c<c03oool>000000D0oooo1000000G0?ooo`030?l0003o
ool0oooo04@0oooo00<000000?ooo`3oool0>03oool004h0oooo00<0ZJVY038b<P3oool03P000002
0?ooo`<000006`3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo001?0?oo
oa8000007P3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo03T0oooo001:0?ooo`06
00000027QhL0k^k^0?ooo`1gMgL0<S8b4000000O0?ooo`030?l0003oool0oooo0480oooo00<00000
0?ooo`3oool0>P3oool004X0oooo00H0ZJVY038b<P000000000005EEE@3^k^h@000001l0oooo00<0
o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0j0?ooo`00D03oool@000001l0oooo00<0o`00
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0k0?ooo`00D03oool?000000030?ooo`000000oooo
01d0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0l0?ooo`00D@3oool=00000080
oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo03`0
oooo001A0?ooo`d000000P3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo03l0oooo
00<000000?ooo`3oool0?@3oool00580oooo2`0000040?ooo`030000003oool0oooo01/0oooo00<0
o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`00D`3oool9000000D0oooo00<00000
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo001E0?oo
o`H000001P3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo03d0oooo00<000000?oo
o`3oool0?`3oool005X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo03`0oooo00<000000?ooo`3oool0@03oool005X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0
@03oool005/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo03/0oooo00<000000?ooo`3oool0@@3oool005/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool0
05/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo
03X0oooo00<000000?ooo`3oool0@P3oool005`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0@`3oool005`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo03P0oooo
00<000000?ooo`3oool0A03oool005d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0H0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0A03oool005d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03L0oooo00<00000
0?ooo`3oool0A@3oool005d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0AP3oool005h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3o
ool0AP3oool005h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030?l0
003oool0oooo03D0oooo00<000000?ooo`3oool0A`3oool005l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0B03o
ool005l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0
oooo03@0oooo00<000000?ooo`3oool0B03oool005l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0B@3oool00600
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0380
oooo00<000000?ooo`3oool0BP3oool00600oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0BP3oool00640oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0340oooo00<0
00000?ooo`3oool0B`3oool00640oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool0C03oool00640oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0300oooo00<000000?oo
o`3oool0C03oool00680oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`03
0?l0003oool0oooo02l0oooo00<000000?ooo`3oool0C@3oool00680oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0
CP3oool00680oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo02h0oooo00<000000?ooo`3oool0CP3oool006<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool0C`3oool0
06<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo
02`0oooo00<000000?ooo`3oool0D03oool006@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0C0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0D03oool006@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo02/0oooo
00<000000?ooo`3oool0D@3oool006@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0DP3oool006D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo02X0oooo00<00000
0?ooo`3oool0DP3oool006D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0D`3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3o
ool0D`3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030?l0
003oool0oooo02P0oooo00<000000?ooo`3oool0E03oool006H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0E@3o
ool006L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo02L0oooo00<000000?ooo`3oool0E@3oool006L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0EP3oool006P0
oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030?l0003oool0oooo02D0oooo00<000000?oo
o`3oool0E`3oool006P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo02D0oooo00<000000?ooo`3oool0E`3oool006P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0
F03oool006T0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030?l0003oool0oooo02<0oooo
00<000000?ooo`3oool0F@3oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0F@3oool006T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0280oooo00<00000
0?ooo`3oool0FP3oool006X0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030?l0003oool0
oooo0240oooo00<000000?ooo`3oool0F`3oool006X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0F`3oool006/0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030?l0003oool0oooo0200oooo00<000000?oo
o`3oool0G03oool006/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030?l0003oool0oooo
01l0oooo00<000000?ooo`3oool0G@3oool006/0oooo00D000000?ooo`3oool0oooo0000000?0?oo
o`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0G@3oool006`0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool006`0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030?l0003oool0oooo01d0oooo00<000000?oo
o`3oool0G`3oool006d0oooo00@000000?ooo`3oool000003P3oool00`3o0000oooo0?ooo`0M0?oo
o`030000003oool0oooo05l0oooo001]0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`3o
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0600oooo001]0?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo001^0?ooo`04
0000003oool0oooo000000d0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`1Q0?oo
o`00KP3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0o`000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1R0?ooo`00KP3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0o`000?oo
o`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`00K`3oool010000000oooo0?ooo`00000<0?oo
o`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0H`3oool006l0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0I03oool00700
oooo00@000000?ooo`3oool000002`3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo
06D0oooo001`0?ooo`040000003oool0oooo000000/0oooo00<0o`000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1U0?ooo`00L03oool010000000oooo0?ooo`00000;0?ooo`030?l0003oool0oooo
01H0oooo00<000000?ooo`3oool0IP3oool00740oooo00@000000?ooo`3oool000002P3oool00`3o
0000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo001a0?ooo`040000003oool0oooo0000
00X0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`00LP3oool00`000000
oooo0000000:0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0J03oool00780oooo
00@000000?ooo`3oool000002@3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo06T0
oooo001b0?ooo`040000003oool0oooo000000T0oooo00<0o`000?ooo`3oool04`3oool00`000000
oooo0?ooo`1Y0?ooo`00L`3oool00`000000oooo000000090?ooo`030?l0003oool0oooo0180oooo
00<000000?ooo`3oool0JP3oool007<0oooo00@000000?ooo`3oool00000203oool00`3o0000oooo
0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001d0?ooo`030000003oool0000000P0oooo00<0
o`000?ooo`3oool04@3oool00`000000oooo0?ooo`1[0?ooo`00M03oool00`000000oooo00000008
0?ooo`030?l0003oool0oooo0100oooo00<000000?ooo`3oool0K03oool007@0oooo00@000000?oo
o`3oool000001`3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0oooo001e0?oo
o`030000003oool0000000L0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`1]0?oo
o`00M@3oool00`000000oooo000000070?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3o
ool0KP3oool007D0oooo00<000000?ooo`0000001`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
003oool0oooo06l0oooo001f0?ooo`030000003oool0000000H0oooo00<0o`000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1_0?ooo`00MP3oool00`000000oooo000000060?ooo`030?l0003oool0
oooo00`0oooo00<000000?ooo`3oool0L03oool007L0oooo0P0000060?ooo`030?l0003oool0oooo
00/0oooo00<000000?ooo`3oool0L@3oool007L0oooo00<000000?ooo`0000001@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo001g0?ooo`030000003oool0000000D0oooo
00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`1b0?ooo`00N03oool2000000D0oooo00<0
o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`00N03oool00`000000oooo00000004
0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool007T0oooo0P0000040?oo
o`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0M03oool007T0oooo0P0000040?ooo`03
0?l0003oool0oooo00L0oooo00<000000?ooo`3oool0M@3oool007T0oooo00<000000?ooo`000000
0`3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo07D0oooo001j0?ooo`8000000`3o
ool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo001j0?ooo`8000000`3oool0
0`3o0000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo001k0?ooo`050000003oool0oooo
0?ooo`3o00001`3oool00`000000oooo0?ooo`1g0?ooo`00N`3oool200000080oooo00<0o`000?oo
o`3oool0103oool00`000000oooo0?ooo`1h0?ooo`00N`3oool200000080oooo00<0o`000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1i0?ooo`00O03oool010000000oooo0?ooo`3o00050?ooo`03
0000003oool0oooo07T0oooo001l0?ooo`H000000P3oool00`000000oooo0?ooo`1j0?ooo`00N`3o
ool9000007d0oooo001j0?ooo`/00000O03oool007T0oooo3@00001k0?ooo`00N@3oool=000007/0
oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?oo
o`l00000NP3oool007P0oooo3`00001j0?ooo`00N@3oool=000007/0oooo001i0?ooo`d00000N`3o
ool007X0oooo2`00001l0?ooo`00N`3oool9000007d0oooo001m0?ooo`D00000O`3oool007l0oooo
00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`00
0?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3o
ool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3o
ool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0
oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool0
0?l0oooo0P3oool00?l0oooo0P3oool007d0oooo100000000`0@4100oooo0?ooo`1m0?ooo`00O`3o
ool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`00
0000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo
0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O@3oool00`000000A4A400000021
0?ooo`00O@3oool00`3<c<`0EEEE000000210?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3o
ool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 -1.11022e-16 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.31108 .53898 Mdot
.5 Mabswid
[ ] 0 setdash
.31108 .53898 m
.84584 .42928 L
s
.31108 .53898 m
.32445 .26809 L
s
.4958 .947 m
.31108 .53898 L
s
15 Mabswid
.84584 .42928 Mdot
.5 Mabswid
.32445 .26809 m
.84584 .42928 L
s
.4958 .947 m
.84584 .42928 L
s
1 0 0 r
.49597 1.01236 m
.4944 .3954 L
s
0 g
15 Mabswid
.4958 .947 Mdot
.5 Mabswid
.4958 .947 m
.32445 .26809 L
s
15 Mabswid
.32445 .26809 Mdot
gsave
.49606 1.04977 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26285 .51761 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.94719 .37406 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26817 .1518 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.161199,
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00A03oool200000003010@403oool0oooo0;P0oooo00150?ooo`030000
003oool0oooo0;T0oooo00110?ooo`H00000^P3oool00440oooo00D0MgMg0:VYZ@3oool0oooo0000
002k0?ooo`00@@3oool01@3^k^h0<S8b0>k^kP3oool000000;/0oooo00120?ooo`040:VYZ@1VIVH0
oooo00000;/0oooo00130?ooo`0304A4A03<c<`000000;/0oooo00130?ooo`030=gMg@14A4@00000
0;/0oooo00140?ooo`0307MgM`0@4100oooo0;X0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001A0?ooo`D00000Z`3o
ool004l0oooo2@00002Y0?ooo`00CP3oool;00000:P0oooo001=0?ooo`d00000Y`3oool004d0oooo
3@00002W0?ooo`00C03oool?00000:H0oooo001<0?ooo`l00000YP3oool004`0oooo3`00002V0?oo
o`00C03oool?00000:H0oooo001<0?oooa000000Y@3oool004d0oooo3@0000020?ooo`<00000XP3o
ool004d0oooo3@0000050?ooo`<00000W`3oool004h0oooo2`0000090?ooo`@00000V`3oool004l0
oooo2@00000>0?ooo`<00000V03oool00540oooo1@00000C0?ooo`<00000U@3oool005<0oooo00<0
00000?ooo`0000005P3oool300000980oooo001C0?ooo`030000003oool0000001T0oooo0`00002?
0?ooo`00DP3oool010000000oooo0?ooo`00000L0?ooo`@00000R`3oool00580oooo00D000000?oo
o`3oool0oooo0000000O0?ooo`<00000R03oool00580oooo00D000000?ooo`3oool0oooo0000000R
0?ooo`<00000Q@3oool00580oooo00D000000?ooo`3oool0oooo0000000U0?ooo`<00000PP3oool0
0580oooo00D000000?ooo`3oool0oooo0000000X0?ooo`<00000O`3oool00580oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`<00000O03oool00580oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0[0?ooo`@00000N03oool00580oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0_0?ooo`<00000M@3oool00580oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0b0?ooo`<00000LP3oool00580oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0d0?ooo`<00000K`3oool00580oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0g0?ooo`<00000K03oool00580oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0j0?ooo`@00000J03oool00580oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0n0?ooo`<00000I@3oool00580oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`100?ooo`<00000HP3oool00580oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`13
0?ooo`<00000G`3oool00580oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?oo
o`<00000B`3oool01P2YZJT08B4Q000000000000EEEE0>k^kP/0oooo001B0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0B@3oool4000004L0oooo00H0410@0;Zj^P3oool0oooo0:VY
Z@0b<S8;0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04`0oooo0`00
00190?ooo`030000003oool0oooo00T0oooo001A0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0C`3oool3000004D0oooo00<0MgMg024Q8@3oool02P3oool00540oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`<00000@03oool0100Q8B4000000000002j^[X;
0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo0`00000n0?oo
o`030>k^kP1gMgL0<S8b00/0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0E`3oool4000003`0oooo00<000000?ooo`3oool02@3oool00540oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1K0?ooo`<00000=03oool01P0Q8B40ZJVY0?ooo`3oool0IVIV038b
<P/0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`3o0000
oooo0?ooo`0j0?ooo`<00000<@3oool01P2j^[X0A4A4000000000000A4A40>k^kP/0oooo001A0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0m0?oo
o`<00000?`3oool00540oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo0400oooo0`00000B0?ooo`D000009@3oool00540oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo04<0oooo0`00000=0?ooo`T00000
8`3oool00540oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo04H0oooo100000080?ooo`/000008P3oool00540oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo04X0oooo0`0000040?ooo`d000008@3oool0
0540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
04d0oooo0`0000000`3oool000000000000;00000240oooo001A0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`1@0?ooo`l00000803oool00540oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0500oooo
3`00000P0?ooo`00D@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0oooo00<0
o`000?ooo`3oool0D03oool?00000200oooo001A0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`1@0?ooo`l00000803oool00540oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo04/0oooo5000000P0?oo
o`00D03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3o
ool0AP3oool5000000H0oooo3@00000Q0?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01h0oooo00<0o`000?ooo`3oool0@@3oool5000000/0oooo3@00000Q0?ooo`00D03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0?03o
ool500000140oooo2`00000R0?ooo`00D03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01d0oooo00<0o`000?ooo`3oool0=`3oool5000001L0oooo2@00000S0?ooo`00D03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0<P3oool50000
01`0oooo00<000000?ooo`0000001000000U0?ooo`00D03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01d0oooo00<0o`000?ooo`3oool0;@3oool500000200oooo00<000000?ooo`3o
ool0:P3oool00500oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`030?l0
003oool0oooo02P0oooo1@00000T0?ooo`030000003oool0oooo02/0oooo001@0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0S0?ooo`D00000:@3o
ool00`000000oooo0?ooo`0[0?ooo`00D03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01`0oooo00<0o`000?ooo`3oool07P3oool5000002d0oooo00<000000?ooo`3oool0;03oool0
0500oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
01T0oooo1@00000a0?ooo`030000003oool0oooo02d0oooo001@0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0D0?ooo`D00000=P3oool00`000000
oooo0?ooo`0]0?ooo`00D03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01/0oooo
00<0o`000?ooo`3oool0403oool4000003X0oooo00<000000?ooo`3oool0;P3oool00500oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00/0oooo1@00
000m0?ooo`030000003oool0oooo02l0oooo001@0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`060?ooo`D00000@P3oool00`000000oooo0?ooo`0_
0?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00@0o`000?oo
o`3oool0oooo1@0000160?ooo`030000003oool0oooo0300oooo001@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool06@3oool00`000000o`0000000002000004X0oooo00<000000?oo
o`3oool0<@3oool00500oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`D0
000000<0oooo0?l0003oool0B`3oool00`000000oooo0?ooo`0b0?ooo`00@03oool6000000T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`D000001P3oool00`3o0000oooo
0?ooo`1:0?ooo`030000003oool0oooo0380oooo00100?ooo`0309RHV0000000c<c<0080oooo00<0
410@0?ooo`3oool01@3oool500000140oooo00<000000?ooo`3oool02@3oool5000000/0oooo00<0
o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`0c0?ooo`00@@3oool00`2HV9P000000<c<c007
0?ooo`T000003`3oool00`000000oooo0?ooo`040?ooo`D00000403oool00`3o0000oooo0?ooo`18
0?ooo`030000003oool0oooo03@0oooo00120?ooo`030:VYZ@0@4100c<c<00D0oooo2`00000>0?oo
o`030000003oool0000000@000005@3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0oooo
03@0oooo00130?ooo`030<c<c00@4100c<c<00<0oooo3@00000:0?ooo`D000006P3oool00`3o0000
oooo0?ooo`170?ooo`030000003oool0oooo03D0oooo00140?ooo`030:VYZ@0b<S80oooo0080oooo
3@0000050?ooo`D00000103oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo04H0oooo
00<000000?ooo`3oool0=P3oool004D0oooo00<000000?ooo`3oool04`0000090?ooo`030000003o
ool0oooo01P0oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0f0?ooo`00@03oool0
1P000000QhN70>k^kP3oool0MgMg038b<P80oooo3`00000=0?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0g0?ooo`00@03oool01P2YZJT0<S8b0000
00000000EEEE0>k^kP80oooo3`00000=0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0h0?ooo`00B03oool?000000h0oooo00<000000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00180?ooo`l000003P3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0>@3o
ool004T0oooo3@00000?0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0j0?ooo`00B@3oool=000000l0oooo00<000000?ooo`3oool05`3oool00`3o
0000oooo0?ooo`120?ooo`030000003oool0oooo03X0oooo001:0?ooo`/000004@3oool00`000000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0>`3oool004/0oooo
2@00000B0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo
0?ooo`0l0?ooo`00C@3oool6000001<0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`100?ooo`030000003oool0oooo03`0oooo001B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo03d0oooo001C0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0n0?oo
o`030000003oool0oooo03h0oooo001C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo001D0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0m0?ooo`030000
003oool0oooo03l0oooo001D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo001E0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0
oooo0400oooo001E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`3o
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo001F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo0480
oooo001F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`3o0000oooo
0?ooo`0j0?ooo`030000003oool0oooo0480oooo001G0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04<0oooo001G
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0h
0?ooo`030000003oool0oooo04@0oooo001G0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo04@0oooo001H0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0g0?ooo`03
0000003oool0oooo04D0oooo001H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo04H0oooo001I0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0f0?ooo`030000003o
ool0oooo04H0oooo001I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo04L0oooo001J0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo
04P0oooo001J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0c0?ooo`030000003oool0oooo04T0oooo001K0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo04T0oooo
001K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0b0?ooo`030000003oool0oooo04X0oooo001L0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0a0?ooo`030000003oool0oooo04/0oooo001L0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0a0?oo
o`030000003oool0oooo04/0oooo001L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo001M0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0_0?ooo`030000
003oool0oooo04d0oooo001M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo04d0oooo001N0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0
oooo04h0oooo001N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0]0?ooo`030000003oool0oooo04l0oooo001O0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo04l0
oooo001O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0/0?ooo`030000003oool0oooo0500oooo001P0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo0540oooo001P
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0[
0?ooo`030000003oool0oooo0540oooo001Q0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo001Q0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo05<0oooo001R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo05<0oooo001R0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0X0?ooo`030000003o
ool0oooo05@0oooo001R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0oooo001S0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo
05D0oooo001S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`3o0000
oooo0?ooo`0V0?ooo`030000003oool0oooo05H0oooo001T0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo05L0oooo
001T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0U0?ooo`030000003oool0oooo05L0oooo001U0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo001U0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0S0?oo
o`030000003oool0oooo05T0oooo001V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001V0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0R0?ooo`030000
003oool0oooo05X0oooo001W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo05/0oooo001W0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0
oooo05/0oooo001W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0P0?ooo`030000003oool0oooo05`0oooo001X0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0
oooo001X0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0N0?ooo`030000003oool0oooo05h0oooo001Y0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo001Y
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0M
0?ooo`030000003oool0oooo05l0oooo001Z0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo0600oooo001Z0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0600oooo001[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo001[0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0680oooo001/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0680oooo001/0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo
06<0oooo001/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0H0?ooo`030000003oool0oooo06@0oooo001]0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo06@0oooo
001]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0G0?ooo`030000003oool0oooo06D0oooo001^0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo06H0oooo001^0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000003oool0oooo06H0oooo001_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo001_0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`030000
003oool0oooo06P0oooo001`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo001`0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0
oooo06T0oooo001a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0oooo001a0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo06X0
oooo001b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0A0?ooo`030000003oool0oooo06/0oooo001b0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0oooo001b
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@
0?ooo`030000003oool0oooo06`0oooo001c0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0oooo001c0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000003oool0oooo06h0oooo001d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0oooo001d0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`030000003o
ool0oooo06l0oooo001e0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`3o0000oooo0?oo
o`0<0?ooo`030000003oool0oooo0700oooo001e0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0700oooo001f0?oo
o`050000003oool0oooo0?ooo`000000103oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0
oooo0740oooo001f0?ooo`050000003oool0oooo0?ooo`000000103oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo0780oooo001g0?ooo`040000003oool0oooo000000@0oooo00<0o`00
0?ooo`3oool02P3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`1d
0?ooo`00N03oool010000000oooo0?ooo`0000030?ooo`030?l0003oool0oooo00L0oooo00<00000
0?ooo`3oool0M@3oool007P0oooo00@000000?ooo`3oool000000`3oool00`3o0000oooo0?ooo`07
0?ooo`030000003oool0oooo07D0oooo001i0?ooo`040000003oool0oooo00000080oooo00<0o`00
0?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`00N@3oool010000000oooo0?ooo`000002
0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool007X0oooo00<000000?oo
o`0000000P3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo001j0?ooo`03
0000003oool000000080oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`1h0?ooo`00
N`3oool01@000000oooo0000003oool0o`0000D0oooo00<000000?ooo`3oool0N@3oool007/0oooo
00D000000?ooo`000000oooo0?l000050?ooo`030000003oool0oooo07T0oooo001l0?ooo`H00000
0P3oool00`000000oooo0?ooo`1j0?ooo`00N`3oool9000007d0oooo001j0?ooo`/00000O03oool0
07T0oooo3@00001k0?ooo`00N@3oool=000007/0oooo001h0?ooo`l00000NP3oool007P0oooo3`00
001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo3`00001j0?ooo`00
N@3oool=000007/0oooo001i0?ooo`d00000N`3oool007X0oooo2`00001l0?ooo`00N`3oool90000
07d0oooo001m0?ooo`D00000O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0
o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?oo
o`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0
O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool0
07l0oooo00<0o`000?ooo`3oool0O`3oool007l0oooo00<0o`000?ooo`3oool0O`3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool007d0oooo
100000000`0@4100oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool0
0`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000
oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool00`000000oooo0?oo
o`1o0?ooo`00O@3oool00`000000A4A4000000210?ooo`00O@3oool00`3<c<`0EEEE000000210?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?oo
o`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}]
}, Closed]],

Cell[TextData[{
  "The above rotation implies a ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "4"},
            {"1", "3", "4", "2"}
            }], ")"}]]],
  "-permutation. "
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
If your compound has only one rotation axis, one generator is \
sufficient. A rotation with the smallest possible rotation angle generates \
all other rotations of the point group. Take the rotation generator and enter \
the corresponding permutation of substituent site labels further below. \
\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
You will need a second rotation generator if your compound \
possesses more than one rotation axis. Take a rotation around an axis \
adjacent to the first rotation axis. Again, consider a rotation with the \
smallest possible angle and enter the resulting substituent site permutation \
below. Thus, the program should be able to generate all reflection-free point \
group elements. \
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Example:",
    FontVariations->{"Underline"->True}],
  " double click to the right of the graphic below to see a second rotation \
generator for a tetrahedral compound around the red ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  "-axis."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
[ ] 0 setdash
.31032 .58002 m
.32361 .31563 L
s
.84774 .47301 m
.31032 .58002 L
s
.49581 .95212 m
.31032 .58002 L
s
15 Mabswid
.84774 .47301 Mdot
.5 Mabswid
.84774 .47301 m
.32361 .31563 L
s
.49581 .95212 m
.84774 .47301 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.49581 .95212 Mdot
.5 Mabswid
.49581 .95212 m
.32361 .31563 L
s
15 Mabswid
.32361 .31563 Mdot
gsave
.49605 1.04681 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.94985 .42173 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00@@3oool0
1P2YZJT08B4Q000000000000EEEE0>k^k[X0oooo00110?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8b^P3oool004H0oooo00<000000?ooo`3oool0^03oool004D0oooo00<0MgMg024Q8@3oool0^@3o
ool004<0oooo00@08B4Q000000000000^[Zj^P3oool004@0oooo00<0k^k^07MgM`0b<S80^P3oool0
04H0oooo00<000000?ooo`3oool0^03oool00440oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S:j
0?ooo`00@@3oool01P2j^[X0A4A4000000000000A4A40>k^k[X0oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001A0?oo
o`D00000Z`3oool004l0oooo2@00002Y0?ooo`00CP3oool;00000:P0oooo001=0?ooo`d00000Y`3o
ool004d0oooo3@00002W0?ooo`00C03oool?00000:H0oooo001<0?ooo`l00000YP3oool004`0oooo
3`00002V0?ooo`00C03oool?00000:H0oooo001<0?oooa000000Y@3oool004d0oooo3@0000020?oo
o`@00000X@3oool004d0oooo3@0000060?ooo`<00000WP3oool004h0oooo2`00000:0?ooo`<00000
V`3oool004l0oooo2@00000>0?ooo`@00000U`3oool00540oooo1@00000D0?ooo`<00000U03oool0
05<0oooo00<000000?ooo`0000005`3oool300000940oooo001B0?ooo`040000003oool0oooo0000
01X0oooo1000002=0?ooo`00DP3oool01@000000oooo0?ooo`3oool0000001d0oooo0`00002:0?oo
o`00DP3oool01@000000oooo0?ooo`3oool000000200oooo100000260?ooo`00DP3oool01@000000
oooo0?ooo`3oool0000002@0oooo0`0000230?ooo`00DP3oool01@000000oooo0?ooo`3oool00000
02L0oooo0`0000200?ooo`00DP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0
oooo1000001l0?ooo`00DP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo
0`00001i0?ooo`00DP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo0`00
001f0?ooo`00DP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo1000001b
0?ooo`00DP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo0`00001_0?oo
o`00DP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo0`00001/0?ooo`00
DP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo1000001X0?ooo`00DP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo0`00001U0?ooo`00DP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo0`00001R0?ooo`00DP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo1000001N0?ooo`00DP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo0`00001;0?ooo`H000002P3oool00580oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`190?ooo`<00000B03oool00`2HV9P00000
0<c<c0020?ooo`03010@403oool0oooo00P0oooo001A0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0C03oool4000004D0oooo00<0V9RH0000003<c<`0303oool00540oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`<00000@`3oool00`2YZJT0410@0<c<c00;
0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo0`0000110?oo
o`030<c<c00@4100c<c<00X0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0E@3oool4000003h0oooo00<0ZJVY038b<P3oool02@3oool00540oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1I0?ooo`<00000?03oool00`000000oooo0?ooo`080?ooo`00B03o
ool20?l000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1L0?ooo`@00000<`3o
ool01P000000QhN70>k^kP3oool0MgMg038b<PX0oooo001:0?ooo`030?l0003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1O0?ooo`<00000<03oool01P2YZJT0<S8b
000000000000EEEE0>k^kPX0oooo001;0?ooo`80o`00103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0680oooo0`00000C0?ooo`D000009@3oool004d0oooo00D0o`000?ooo`3oool0
oooo0000000:0?ooo`030000003oool0oooo06D0oooo1000000=0?ooo`T000008`3oool004h0oooo
0P3o00000`3oool000000?ooo`090?ooo`030000003oool0oooo06T0oooo0`0000090?ooo`/00000
8P3oool00500oooo00<0o`000000003oool02P3oool00`000000oooo0?ooo`1[0?ooo`<000001@3o
ool=00000240oooo001A0?ooo`80o`002P3oool00`000000oooo0?ooo`1^0?ooo`@0000000<0oooo
0000000000002`00000Q0?ooo`00D@3oool00`000000oooo0?l000090?ooo`030000003oool0oooo
0780oooo3`00000P0?ooo`00D@3oool00`000000oooo0?ooo`020?l000L0oooo00<000000?ooo`3o
ool0LP3oool?00000200oooo001A0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1a0?ooo`l00000803oool00540oooo00<000000?ooo`3oool00`3o
ool20?l000D0oooo00<000000?ooo`3oool0L@3oool?00000200oooo001A0?ooo`030000003oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?oooa@00000803oool0
0500oooo00<000000?ooo`3oool01`3oool20?l00080oooo00<000000?ooo`3oool0I`3oool50000
00H0oooo3@00000Q0?ooo`00D03oool00`000000oooo0?ooo`090?ooo`040?l0003oool0oooo0000
06<0oooo1@00000;0?ooo`d000008@3oool00500oooo00<000000?ooo`3oool02P3oool00`3o0000
oooo0000001N0?ooo`D000004@3oool;00000280oooo001@0?ooo`030000003oool0oooo00/0oooo
00<0o`000000003oool0F03oool5000001L0oooo2@00000S0?ooo`00D03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0540oooo1@00000K0?ooo`030000003oool0oooo00D000009@3o
ool00500oooo00<000000?ooo`3oool03@3oool00`000000o`000?l0001<0?ooo`D00000803oool0
0`000000oooo0?ooo`0Z0?ooo`00D03oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
0?l004H0oooo1@00000T0?ooo`030000003oool0oooo02/0oooo001@0?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool0oooo0P3o000o0?ooo`D00000:03oool00`000000oooo0?ooo`0/
0?ooo`00D03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool0=`3oool5000002`0oooo00<000000?ooo`3oool0;@3oool00500oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`80o`00<P3oool500000340oooo00<000000?ooo`3o
ool0;@3oool00500oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo02X0oooo1@00000e0?ooo`030000003oool0oooo02h0oooo001@0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01P3oool20?l002H0oooo1000000i0?ooo`030000003o
ool0oooo02l0oooo001@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0N0?ooo`D00000?03oool00`000000oooo0?ooo`0`0?ooo`00D03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo0P3o000I0?ooo`D00000@@3oool00`00
0000oooo0?ooo`0`0?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo00<0o`000?ooo`3oool04@3oool5000004D0oooo00<000000?ooo`3oool0<@3oool00500oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`80o`00303oool5000004T0oooo
00<000000?ooo`3oool0<P3oool00500oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00@0oooo1@00001=0?ooo`030000003oool0oooo03<0oooo0013
0?ooo`80000000<0410@0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00d0oooo0P3o000400000580oooo00<000000?ooo`3oool0<`3oool004@0oooo00<000000?oo
o`3oool01P3oool500000140oooo00<000000?ooo`3oool02@3oool5000000030?ooo`3o0000oooo
05<0oooo00<000000?ooo`3oool0=03oool00400oooo1P0000050?ooo`T00000403oool00`000000
oooo0?ooo`030?ooo`D000001`3oool20?l00540oooo00<000000?ooo`3oool0=@3oool00400oooo
00D0MgMg0:VYZ@3oool0oooo000000050?ooo`/000003`3oool6000000h0oooo00<0o`000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`0e0?ooo`00@03oool01@3^k^h0<S8b0>k^kP3oool0000000@0
oooo3@00000:0?ooo`D00000503oool20?l004d0oooo00<000000?ooo`3oool0=P3oool00440oooo
00@0ZJVY06IVIP3oool00000103oool=000000D0oooo1@0000040?ooo`030000003oool0oooo01@0
oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`0g0?ooo`00@P3oool00`14A4@0c<c<
000000030?oooa<000002P3oool00`000000oooo0?ooo`0D0?ooo`80o`00B03oool00`000000oooo
0?ooo`0h0?ooo`00@P3oool00`3MgMd0A4A4000000030?ooo`l000003P3oool00`000000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0>03oool004<0oooo00<0MgMg
010@403oool00P3oool?000000h0oooo00<000000?ooo`3oool05`3oool20?l004@0oooo00<00000
0?ooo`3oool0>@3oool004P0oooo3`00000>0?ooo`030000003oool0oooo01T0oooo00<0o`000?oo
o`3oool0@03oool00`000000oooo0?ooo`0j0?ooo`00B03oool?000000l0oooo00<000000?ooo`3o
ool06@3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo03/0oooo00190?ooo`d00000
403oool00`000000oooo0?ooo`0J0?ooo`80o`00?P3oool00`000000oooo0?ooo`0k0?ooo`00B@3o
ool=00000100oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0j0?ooo`030000003o
ool0oooo03`0oooo001:0?ooo`/000004P3oool00`000000oooo0?ooo`0L0?ooo`80o`00>@3oool0
0`000000oooo0?ooo`0m0?ooo`00B`3oool9000001<0oooo00<000000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0e0?ooo`030000003oool0oooo03h0oooo001=0?ooo`H00000503oool00`000000
oooo0?ooo`0O0?ooo`80o`00=@3oool00`000000oooo0?ooo`0n0?ooo`00D`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0o0?ooo`00D`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo0P3o
000`0?ooo`030000003oool0oooo0400oooo001D0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo0400oooo001D0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0903oool20?l002`0oooo00<000000?oo
o`3oool0@@3oool005D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo02P0oooo00<000000?ooo`3oool0@P3oool005D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0V0?ooo`80o`009`3oool00`000000oooo0?ooo`130?ooo`00EP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0903o
ool00`000000oooo0?ooo`130?ooo`00EP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02T0oooo0P3o000S0?ooo`030000003oool0oooo04@0oooo001G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo
04D0oooo001G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:`3oool20?l001h0
oooo00<000000?ooo`3oool0AP3oool005P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0]0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0AP3oool005P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0^0?ooo`80o`006P3oool00`000000oooo0?oo
o`170?ooo`00F@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<0o`00
0?ooo`3oool05P3oool00`000000oooo0?ooo`180?ooo`00F@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0300oooo0P3o000F0?ooo`030000003oool0oooo04P0oooo001J0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000003oool0oooo04T0oooo001J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<`3oool20?l00140oooo00<000000?ooo`3oool0BP3oool005/0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0B`3o
ool005/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0e0?ooo`80o`003@3oool0
0`000000oooo0?ooo`1;0?ooo`00G03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
03L0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1<0?ooo`00G03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool01`3oool00`000000
oooo0?ooo`1=0?ooo`00G@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03P0oooo
0P3o00060?ooo`030000003oool0oooo04h0oooo001M0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo04h0oooo001N
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>`3oool20?l00080oooo00<00000
0?ooo`3oool0C`3oool005h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0l0?oo
o`030?l000000000oooo0540oooo001O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0?03oool00`000000o`000?l0001A0?ooo`00G`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03`0oooo00@000000?ooo`3oool0o`00D03oool00600oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo0P3o001>0?ooo`00H03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`1;0?ooo`00H@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool01P3oool20?l004/0oooo001Q0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo
04P0oooo001R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo04L0oooo001R0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1F0?ooo`00H`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0EP3oool006<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05L0oooo001T0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1H0?oo
o`00I03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0F@3oool006D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo05T0oooo001U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`1J0?ooo`00IP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0F`3oool006H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo05`0oooo001W0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1L0?ooo`00J03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G@3oool006P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05h0oooo001Y
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1N
0?ooo`00J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0G`3oool006X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0600oooo001Z0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1Q0?ooo`00J`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0H@3oool006/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0680oooo001/0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1S0?ooo`00K03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0I03oool006d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06@0oooo
001]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1U0?ooo`00KP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0IP3oool006h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06H0oooo001_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1W0?ooo`00K`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool00700oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06T0oooo001`0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1Y0?ooo`00L@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0JP3oool00740
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06/0
oooo001b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1/0?ooo`00LP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0K03oool007<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo06d0oooo001c0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1^0?ooo`00M03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06l0oooo001e0?ooo`050000003o
ool0oooo0?ooo`000000503oool00`000000oooo0?ooo`1`0?ooo`00M@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0L@3oool007H0oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0740oooo001f0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`3oool0L`3oool007L0oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`030000003oool0oooo07@0oooo001h0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0M03oool007P0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`1e0?ooo`00N@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo07H0oooo001i
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0M`3oool007X0oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`1g0?ooo`00NP3oool00`000000oooo000000090?oo
o`030000003oool0oooo07P0oooo001k0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0N@3oool007/0oooo00<000000?ooo`000000100000020?ooo`030000003oool0oooo07X0oooo
001k0?ooo`X00000O03oool007X0oooo2`00001l0?ooo`00N@3oool=000007/0oooo001i0?ooo`d0
0000N`3oool007P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool0
07P0oooo3`00001j0?ooo`00N03oool?000007X0oooo001i0?ooo`d00000N`3oool007T0oooo3@00
001k0?ooo`00NP3oool;000007`0oooo001k0?ooo`T00000O@3oool007d0oooo1@00001o0?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00O@3oool400000003
010@403oool0oooo07d0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003o
ool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo
07l0oooo001o0?ooo`030000003oool0oooo07l0oooo001o0?ooo`030000003oool0oooo07l0oooo
001m0?ooo`0300000014A4@000000840oooo001m0?ooo`030<c<c01EEED000000840oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo0000\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.29271 .60162 Mdot
.5 Mabswid
[ ] 0 setdash
.29271 .60162 m
.34445 .29104 L
s
.84131 .48758 m
.29271 .60162 L
s
.49936 .94101 m
.29271 .60162 L
s
15 Mabswid
.84131 .48758 Mdot
.5 Mabswid
.84131 .48758 m
.34445 .29104 L
s
.49936 .94101 m
.84131 .48758 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.49936 .94101 Mdot
.5 Mabswid
.49936 .94101 m
.34445 .29104 L
s
15 Mabswid
.34445 .29104 Mdot
gsave
.50051 1.03398 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.93999 .4419 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.29476 .17392 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.23927 .58953 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.27521 .62195 Mdot
.5 Mabswid
[ ] 0 setdash
.27521 .62195 m
.36477 .26868 L
s
.83328 .50416 m
.27521 .62195 L
s
.50502 .92696 m
.27521 .62195 L
s
15 Mabswid
.83328 .50416 Mdot
.5 Mabswid
.83328 .50416 m
.36477 .26868 L
s
.50502 .92696 m
.83328 .50416 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.50502 .92696 Mdot
.5 Mabswid
.50502 .92696 m
.36477 .26868 L
s
15 Mabswid
.36477 .26868 Mdot
gsave
.50767 1.01735 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.92812 .46462 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.32181 .14632 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.21671 .616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.25796 .6408 Mdot
.5 Mabswid
[ ] 0 setdash
.25796 .6408 m
.3843 .24883 L
s
.82376 .52255 m
.25796 .6408 L
s
.51278 .91008 m
.25796 .6408 L
s
15 Mabswid
.82376 .52255 Mdot
.5 Mabswid
.82376 .52255 m
.3843 .24883 L
s
.51278 .91008 m
.82376 .52255 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.3843 .24883 Mdot
.5 Mabswid
.51278 .91008 m
.3843 .24883 L
s
15 Mabswid
.51278 .91008 Mdot
gsave
.51751 .99702 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.9144 .4896 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.34761 .12241 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.19427 .64077 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.24113 .65801 Mdot
.5 Mabswid
[ ] 0 setdash
.24113 .65801 m
.40279 .23171 L
s
.81288 .54255 m
.24113 .65801 L
s
.5226 .89051 m
.24113 .65801 L
s
15 Mabswid
.81288 .54255 Mdot
.5 Mabswid
.81288 .54255 m
.40279 .23171 L
s
.5226 .89051 m
.81288 .54255 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.40279 .23171 Mdot
.5 Mabswid
.5226 .89051 m
.40279 .23171 L
s
15 Mabswid
.5226 .89051 Mdot
gsave
.53001 .97314 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.89903 .51655 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37182 .10246 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.17212 .66361 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.22486 .67339 Mdot
.5 Mabswid
[ ] 0 setdash
.22486 .67339 m
.42 .21749 L
s
.80076 .56394 m
.22486 .67339 L
s
.53441 .86844 m
.22486 .67339 L
s
15 Mabswid
.80076 .56394 Mdot
.5 Mabswid
.80076 .56394 m
.42 .21749 L
s
.53441 .86844 m
.80076 .56394 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.42 .21749 Mdot
.5 Mabswid
.53441 .86844 m
.42 .21749 L
s
15 Mabswid
.53441 .86844 Mdot
gsave
.54507 .94591 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.88217 .5452 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.39416 .08662 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.15047 .68431 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.78753 .5865 Mdot
.5 Mabswid
[ ] 0 setdash
.78753 .5865 m
.43574 .2063 L
s
.78753 .5865 m
.20931 .68676 L
s
.54808 .84411 m
.78753 .5865 L
s
15 Mabswid
.20931 .68676 Mdot
.5 Mabswid
.20931 .68676 m
.43574 .2063 L
s
.54808 .84411 m
.20931 .68676 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.43574 .2063 Mdot
.5 Mabswid
.54808 .84411 m
.43574 .2063 L
s
15 Mabswid
.54808 .84411 Mdot
gsave
.56255 .91563 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.864 .57527 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.41437 .07499 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.12949 .70263 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.77333 .61001 Mdot
.5 Mabswid
[ ] 0 setdash
.77333 .61001 m
.44985 .1982 L
s
.77333 .61001 m
.19465 .69795 L
s
.56347 .81781 m
.77333 .61001 L
s
15 Mabswid
.19465 .69795 Mdot
.5 Mabswid
.19465 .69795 m
.44985 .1982 L
s
.56347 .81781 m
.19465 .69795 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.44985 .1982 Mdot
.5 Mabswid
.56347 .81781 m
.44985 .1982 L
s
15 Mabswid
.56347 .81781 Mdot
gsave
.58226 .88267 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.84469 .60648 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.43226 .06758 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.10939 .71836 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.75829 .63428 Mdot
.5 Mabswid
[ ] 0 setdash
.75829 .63428 m
.46219 .19323 L
s
.75829 .63428 m
.18103 .70682 L
s
.58039 .78988 m
.75829 .63428 L
s
15 Mabswid
.18103 .70682 Mdot
.5 Mabswid
.18103 .70682 m
.46219 .19323 L
s
.58039 .78988 m
.18103 .70682 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.46219 .19323 Mdot
.5 Mabswid
.58039 .78988 m
.46219 .19323 L
s
15 Mabswid
.58039 .78988 Mdot
gsave
.60397 .84744 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.82441 .63859 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.44768 .06435 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.09038 .73127 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.74254 .65907 Mdot
.5 Mabswid
[ ] 0 setdash
.74254 .65907 m
.47265 .19134 L
s
.74254 .65907 m
.16862 .7132 L
s
.59862 .76068 m
.74254 .65907 L
s
15 Mabswid
.16862 .7132 Mdot
.5 Mabswid
.16862 .7132 m
.47265 .19134 L
s
.59862 .76068 m
.16862 .7132 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.47265 .19134 Mdot
.5 Mabswid
.59862 .76068 m
.47265 .19134 L
s
15 Mabswid
.59862 .76068 Mdot
gsave
.62737 .81043 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.80333 .67134 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.46052 .06518 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.07266 .74116 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.72623 .6842 Mdot
.5 Mabswid
[ ] 0 setdash
.72623 .6842 m
.48117 .19249 L
s
.72623 .6842 m
.15756 .71697 L
s
.61793 .73062 m
.72623 .6842 L
s
15 Mabswid
.15756 .71697 Mdot
.5 Mabswid
.15756 .71697 m
.48117 .19249 L
s
.61793 .73062 m
.15756 .71697 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.48117 .19249 Mdot
.5 Mabswid
.61793 .73062 m
.48117 .19249 L
s
15 Mabswid
.61793 .73062 Mdot
gsave
.65214 .77219 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.78161 .70447 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47073 .06992 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.05646 .74782 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.70948 .70944 Mdot
.5 Mabswid
[ ] 0 setdash
.70948 .70944 m
.48771 .19657 L
s
.70948 .70944 m
.14802 .71802 L
s
.63804 .70012 m
.70948 .70944 L
s
15 Mabswid
.14802 .71802 Mdot
.5 Mabswid
.14802 .71802 m
.48771 .19657 L
s
.63804 .70012 m
.14802 .71802 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.48771 .19657 Mdot
.5 Mabswid
.63804 .70012 m
.48771 .19657 L
s
15 Mabswid
.63804 .70012 Mdot
gsave
.67792 .73328 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.75941 .73775 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47828 .07836 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.04199 .75108 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.69244 .7346 Mdot
.5 Mabswid
[ ] 0 setdash
.69244 .7346 m
.49224 .20345 L
s
.69244 .7346 m
.14014 .71625 L
s
.65866 .66962 m
.69244 .7346 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.49224 .20345 Mdot
.5 Mabswid
.14014 .71625 m
.49224 .20345 L
s
.65866 .66962 m
.49224 .20345 L
s
15 Mabswid
.14014 .71625 Mdot
.5 Mabswid
.65866 .66962 m
.14014 .71625 L
s
15 Mabswid
.65866 .66962 Mdot
gsave
.70432 .69429 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.7369 .77094 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.4832 .09027 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.02946 .75077 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.67524 .75947 Mdot
.5 Mabswid
[ ] 0 setdash
.67524 .75947 m
.49478 .21297 L
s
.67524 .75947 m
.13406 .71161 L
s
.6795 .63956 m
.67524 .75947 L
s
15 Mabswid
.49478 .21297 Mdot
.5 Mabswid
.13406 .71161 m
.49478 .21297 L
s
.6795 .63956 m
.49478 .21297 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.13406 .71161 Mdot
.5 Mabswid
.6795 .63956 m
.13406 .71161 L
s
15 Mabswid
.6795 .63956 Mdot
gsave
.73093 .65584 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71423 .80379 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.48552 .10539 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.01908 .74676 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.65803 .78385 Mdot
.5 Mabswid
[ ] 0 setdash
.65803 .78385 m
.49535 .22496 L
s
.65803 .78385 m
.12989 .70406 L
s
.70026 .61037 m
.65803 .78385 L
s
15 Mabswid
.49535 .22496 Mdot
.5 Mabswid
.12989 .70406 m
.49535 .22496 L
s
.70026 .61037 m
.49535 .22496 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.12989 .70406 Mdot
.5 Mabswid
.70026 .61037 m
.12989 .70406 L
s
15 Mabswid
.70026 .61037 Mdot
gsave
.75733 .61849 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.69158 .83607 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.48532 .12344 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.01106 .73895 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.64094 .80754 Mdot
.5 Mabswid
[ ] 0 setdash
.64094 .80754 m
.49401 .23922 L
s
.64094 .80754 m
.12775 .69359 L
s
.72065 .58246 m
.64094 .80754 L
s
15 Mabswid
.49401 .23922 Mdot
.5 Mabswid
.12775 .69359 m
.49401 .23922 L
s
.72065 .58246 m
.49401 .23922 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.12775 .69359 Mdot
.5 Mabswid
.72065 .58246 m
.12775 .69359 L
s
15 Mabswid
.72065 .58246 Mdot
gsave
.78314 .58283 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66911 .86754 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.48269 .14416 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.00558 .72728 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.62411 .83034 Mdot
.5 Mabswid
[ ] 0 setdash
.62411 .83034 m
.49082 .25554 L
s
.62411 .83034 m
.12771 .68026 L
s
.74036 .55622 m
.62411 .83034 L
s
15 Mabswid
.49082 .25554 Mdot
.5 Mabswid
.12771 .68026 m
.49082 .25554 L
s
.74036 .55622 m
.49082 .25554 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.12771 .68026 Mdot
.5 Mabswid
.74036 .55622 m
.12771 .68026 L
s
15 Mabswid
.74036 .55622 Mdot
gsave
.80797 .54936 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.64698 .89797 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47775 .16723 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.0028 .71175 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.60769 .85204 Mdot
.5 Mabswid
[ ] 0 setdash
.60769 .85204 m
.48586 .27373 L
s
.60769 .85204 m
.12985 .66413 L
s
.75915 .532 m
.60769 .85204 L
s
15 Mabswid
.48586 .27373 Mdot
.5 Mabswid
.12985 .66413 m
.48586 .27373 L
s
.75915 .532 m
.48586 .27373 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.12985 .66413 Mdot
.5 Mabswid
.75915 .532 m
.12985 .66413 L
s
15 Mabswid
.75915 .532 Mdot
gsave
.83145 .51856 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.62535 .92711 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.4706 .19238 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.00287 .69241 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.47922 .29355 Mdot
.5 Mabswid
[ ] 0 setdash
.13419 .64534 m
.47922 .29355 L
s
.59182 .87246 m
.47922 .29355 L
s
.77675 .5101 m
.47922 .29355 L
s
15 Mabswid
.59182 .87246 Mdot
.5 Mabswid
.59182 .87246 m
.13419 .64534 L
s
.77675 .5101 m
.59182 .87246 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.13419 .64534 Mdot
.5 Mabswid
.77675 .5101 m
.13419 .64534 L
s
15 Mabswid
.77675 .5101 Mdot
gsave
.85328 .49082 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.60442 .95472 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.46138 .21931 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.00588 .66935 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.471 .31478 Mdot
.5 Mabswid
[ ] 0 setdash
.14074 .62407 m
.471 .31478 L
s
.57665 .8914 m
.471 .31478 L
s
.79295 .49079 m
.471 .31478 L
s
15 Mabswid
.57665 .8914 Mdot
.5 Mabswid
.57665 .8914 m
.14074 .62407 L
s
.79295 .49079 m
.57665 .8914 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.14074 .62407 Mdot
.5 Mabswid
.79295 .49079 m
.14074 .62407 L
s
15 Mabswid
.79295 .49079 Mdot
gsave
.87317 .46648 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.58435 .98055 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.45024 .24774 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.0119 .64277 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.46131 .33722 Mdot
.5 Mabswid
[ ] 0 setdash
.14945 .60052 m
.46131 .33722 L
s
.56232 .90866 m
.46131 .33722 L
s
.80757 .47426 m
.46131 .33722 L
s
15 Mabswid
.56232 .90866 Mdot
.5 Mabswid
.56232 .90866 m
.14945 .60052 L
s
.80757 .47426 m
.56232 .90866 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.14945 .60052 Mdot
.5 Mabswid
.80757 .47426 m
.14945 .60052 L
s
15 Mabswid
.80757 .47426 Mdot
gsave
.8909 .44579 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.56532 1.00435 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.43731 .2774 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.02096 .6129 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.45026 .36062 Mdot
.5 Mabswid
[ ] 0 setdash
.16027 .57497 m
.45026 .36062 L
s
.54898 .92405 m
.45026 .36062 L
s
.82043 .46068 m
.45026 .36062 L
s
15 Mabswid
.54898 .92405 Mdot
.5 Mabswid
.54898 .92405 m
.16027 .57497 L
s
.82043 .46068 m
.54898 .92405 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.82043 .46068 Mdot
.5 Mabswid
.82043 .46068 m
.16027 .57497 L
s
15 Mabswid
.16027 .57497 Mdot
gsave
.90629 .42892 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.54753 1.02587 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42273 .30802 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03301 .58007 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.43798 .38479 Mdot
.5 Mabswid
[ ] 0 setdash
.17309 .54773 m
.43798 .38479 L
s
.53677 .93739 m
.43798 .38479 L
s
.83143 .45014 m
.43798 .38479 L
s
15 Mabswid
.53677 .93739 Mdot
.5 Mabswid
.53677 .93739 m
.17309 .54773 L
s
.83143 .45014 m
.53677 .93739 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.83143 .45014 Mdot
.5 Mabswid
.83143 .45014 m
.17309 .54773 L
s
15 Mabswid
.17309 .54773 Mdot
gsave
.91919 .41599 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.53116 1.04485 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.40667 .33932 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.04796 .54467 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.42457 .40949 Mdot
.5 Mabswid
[ ] 0 setdash
.18776 .51914 m
.42457 .40949 L
s
.52583 .94851 m
.42457 .40949 L
s
.84048 .4427 m
.42457 .40949 L
s
15 Mabswid
.52583 .94851 Mdot
.5 Mabswid
.52583 .94851 m
.18776 .51914 L
s
.84048 .4427 m
.52583 .94851 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.84048 .4427 Mdot
.5 Mabswid
.84048 .4427 m
.18776 .51914 L
s
15 Mabswid
.18776 .51914 Mdot
gsave
.92953 .40703 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5164 1.06103 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.38926 .37107 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.06566 .50717 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.41017 .43452 Mdot
.5 Mabswid
[ ] 0 setdash
.2041 .48959 m
.41017 .43452 L
s
.51632 .95724 m
.41017 .43452 L
s
.8475 .43836 m
.41017 .43452 L
s
15 Mabswid
.51632 .95724 Mdot
.5 Mabswid
.51632 .95724 m
.2041 .48959 L
s
.8475 .43836 m
.51632 .95724 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.8475 .43836 Mdot
.5 Mabswid
.8475 .43836 m
.2041 .48959 L
s
15 Mabswid
.2041 .48959 Mdot
gsave
.93727 .40202 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.50346 1.07418 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37067 .40301 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08591 .46807 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.39491 .45967 Mdot
.5 Mabswid
[ ] 0 setdash
.2219 .45949 m
.39491 .45967 L
s
.50835 .96342 m
.39491 .45967 L
s
.85249 .43709 m
.39491 .45967 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.50835 .96342 Mdot
.5 Mabswid
.50835 .96342 m
.2219 .45949 L
s
.85249 .43709 m
.50835 .96342 L
s
15 Mabswid
.85249 .43709 Mdot
.5 Mabswid
.85249 .43709 m
.2219 .45949 L
s
15 Mabswid
.2219 .45949 Mdot
gsave
.9424 .40088 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.49252 1.08405 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.35103 .43489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.10845 .42795 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.37892 .48473 Mdot
.5 Mabswid
[ ] 0 setdash
.24092 .42926 m
.37892 .48473 L
s
.50206 .96692 m
.37892 .48473 L
s
.85545 .4388 m
.37892 .48473 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.50206 .96692 Mdot
.5 Mabswid
.50206 .96692 m
.24092 .42926 L
s
.85545 .4388 m
.50206 .96692 L
s
15 Mabswid
.85545 .4388 Mdot
.5 Mabswid
.85545 .4388 m
.24092 .42926 L
s
15 Mabswid
.24092 .42926 Mdot
gsave
.94496 .40347 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.48378 1.0904 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.33051 .46649 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.13294 .38741 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.36232 .50949 Mdot
.5 Mabswid
[ ] 0 setdash
.26089 .39934 m
.36232 .50949 L
s
.49757 .96761 m
.36232 .50949 L
s
.85639 .4434 m
.36232 .50949 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.85639 .4434 Mdot
.5 Mabswid
.85639 .4434 m
.26089 .39934 L
s
.85639 .4434 m
.49757 .96761 L
s
15 Mabswid
.49757 .96761 Mdot
.5 Mabswid
.49757 .96761 m
.26089 .39934 L
s
15 Mabswid
.26089 .39934 Mdot
gsave
.94502 .40963 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47741 1.09304 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.30926 .49756 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.15903 .34708 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.34527 .53376 Mdot
.5 Mabswid
[ ] 0 setdash
.28153 .37015 m
.34527 .53376 L
s
.49498 .96542 m
.34527 .53376 L
s
.85537 .45074 m
.34527 .53376 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.85537 .45074 Mdot
.5 Mabswid
.85537 .45074 m
.28153 .37015 L
s
.85537 .45074 m
.49498 .96542 L
s
15 Mabswid
.49498 .96542 Mdot
.5 Mabswid
.49498 .96542 m
.28153 .37015 L
s
15 Mabswid
.28153 .37015 Mdot
gsave
.94266 .41917 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47359 1.09177 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.28743 .52789 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.18633 .30757 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.32788 .55734 Mdot
.5 Mabswid
[ ] 0 setdash
.30254 .34212 m
.32788 .55734 L
s
.49437 .96026 m
.32788 .55734 L
s
.85246 .46067 m
.32788 .55734 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.85246 .46067 Mdot
.5 Mabswid
.85246 .46067 m
.30254 .34212 L
s
.85246 .46067 m
.49437 .96026 L
s
15 Mabswid
.49437 .96026 Mdot
.5 Mabswid
.49437 .96026 m
.30254 .34212 L
s
15 Mabswid
.30254 .34212 Mdot
gsave
.93801 .43186 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47245 1.08646 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.2652 .55723 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.21441 .26951 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
0 g
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
[ ] 0 setdash
.32361 .31563 m
.31032 .58002 L
s
.49581 .95212 m
.31032 .58002 L
s
.84774 .47301 m
.31032 .58002 L
s
15 Mabswid
.84774 .47301 Mdot
.5 Mabswid
.84774 .47301 m
.32361 .31563 L
s
.84774 .47301 m
.49581 .95212 L
s
1 0 0 r
.71409 .73037 m
.28112 .43559 L
s
0 g
15 Mabswid
.49581 .95212 Mdot
.5 Mabswid
.49581 .95212 m
.32361 .31563 L
s
15 Mabswid
.32361 .31563 Mdot
gsave
.93118 .44745 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47414 1.07698 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.24271 .58537 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.24283 .23346 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124,
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False]
}, Closed]],

Cell[TextData[{
  "The above rotation implies a  ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "4"},
            {"2", "1", "4", "3"}
            }], ")"}]]],
  "-permutation. "
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  "You may enter as many rotation generators as you like. This way you may \
ensure the completeness of your generator set. Furthermore, having installed \
the parent compound, you can use the ",
  StyleBox["PointGroupReport-", "Input"],
  "command on the 'Isomer Control Panel' to verify if your generators create \
a point group that completely represents the symmetry of your parent \
compound. "
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(To\ enter\ a\ rotation\ generator, \ press\ \(here!\)\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(Isomers`Isomers`Private`InsertRotation&),
      ButtonEvaluator->Automatic,
      Active->True]], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[""], "Input",
  Editable->True,
  Selectable->True,
  CellFrame->True,
  CellMargins->{{24, 24}, {20, 1}},
  Active->False,
  Evaluatable->False,
  CellFrameMargins->6,
  CellFrameLabels->{{
    Inherited, Inherited}, {
      StyleBox[ 
        "Rotation Generators", FontWeight -> "Plain", FontFamily -> 
          "Helvetica", FontSize -> 9], Inherited}},
  CellFrameLabelMargins->2,
  CellTags->"RotationGenerators"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rotation-reflections", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {8, Inherited}},
  Copyable->False,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  ScriptMinSize->9,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetic",
  FontSize->12],

Cell["\<\
Enantiomers and achiral isomers are identified by their variance or \
invariance under reflection. Hence, more point group symmetry \
transformations, so-called rotation-reflections, have to be taken into \
account. Rotation-reflections are transformations that consist of an odd \
number of reflections or inversions, and that may also include any of the \
rotations specified above.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
The rotations considered above are transformations that a molecule \
can actually undergo without changing its configuration. This does not apply \
to rotation-reflections. Hence, we consider rotation-reflections separately. \
\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  "A parent compound is chiral if ",
  StyleBox["no",
    FontVariations->{"Underline"->True}],
  " invariance under reflection, inversion, or rotation-reflection exists. In \
this case, no rotation-reflection generators can be entered, and you may \
proceed to the next section."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Example:",
    FontVariations->{"Underline"->True}],
  " double click to the right of the graphic below to see the reflection of a \
tetrahedral compound across the green plane."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
15 Mabswid
.84774 .47301 Mdot
.5 Mabswid
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.49581 .95212 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.49605 1.04681 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.94985 .42173 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  ShowGroupOpenCloseIcon->False,
  Copyable->False,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400041000182000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00@@3oool0
1P2YZJT08B4Q000000000000EEEE0>k^k[X0oooo00110?ooo`06010@402j^[X0oooo0?ooo`2YZJT0
<S8b^P3oool004H0oooo00<000000?ooo`3oool0^03oool004D0oooo00<0MgMg024Q8@3oool0^@3o
ool004<0oooo00@08B4Q000000000000^[Zj^P3oool004@0oooo00<0k^k^07MgM`0b<S80^P3oool0
04H0oooo00<000000?ooo`3oool0^03oool00440oooo00H08B4Q0:VYZ@3oool0oooo06IVIP0b<S:j
0?ooo`00@@3oool01P2j^[X0A4A4000000000000A4A40>k^k[X0oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?oo
o`80oooo003o0?ooo`80oooo00190?ooo`800?l0]P3oool004T0oooo00<00?l009WoV@00o`00]@3o
ool004T0oooo00<00?l009WoV@2IoiT00P00o`2c0?ooo`00B@3oool00`00o`00VOnI09WoV@0209Wo
V@03003o003oool0oooo0;00oooo00190?ooo`03003o002IoiT0VOnI00<0VOnI0P00o`2`0?ooo`00
B@3oool00`00o`00VOnI09WoV@0509WoV@03003o003oool0oooo0:d0oooo00190?ooo`03003o002I
oiT0VOnI00H0VOnI0P00o`2]0?ooo`00B@3oool00`00o`00VOnI09WoV@0809WoV@03003o003oool0
oooo0:X0oooo00190?ooo`03003o002IoiT0VOnI00D0VOnI10000002003o0:X0oooo00190?ooo`03
003o002IoiT0VOnI00<0VOnI200000000`00o`00oooo0?ooo`2W0?ooo`00B@3oool00`00o`00VOnI
09WoV@0209WoV@X000000P00o`2W0?ooo`00B@3oool01000o`00VOnI09WoV@2IoiT=00000003003o
003oool0oooo0:@0oooo00190?ooo`04003o002IoiT0VOnI09WoV@d0000000<0VOnI003o0000o`00
Y03oool004T0oooo00<00?l009WoV@2IoiT03`00000209WoV@03003o003oool0oooo0:40oooo0019
0?ooo`03003o002IoiT0VOnI00l000000`2IoiT2003o0:40oooo00190?ooo`03003o002IoiT0VOnI
00l000001@2IoiT00`00o`00oooo0?ooo`2N0?ooo`00B@3oool00`00o`00VOnI09WoV@0?000000H0
VOnI0P00o`2N0?ooo`00B@3oool00`00o`00VOnI09WoV@0?000000P0VOnI00<00?l00?ooo`3oool0
V`3oool004T0oooo00@00?l009WoV@2IoiT0VOnI3@00000:09WoV@800?l0V`3oool004T0oooo00@0
0?l009WoV@2IoiT0VOnI3@00000<09WoV@03003o003oool0oooo09P0oooo00190?ooo`03003o002I
oiT0VOnI0080VOnI2`00000>09WoV@800?l0V03oool004T0oooo00<00?l009WoV@2IoiT00`2IoiT9
00000003003o002IoiT0VOnI00h0VOnI00<00?l00?ooo`3oool0U@3oool004P0oooo00<00?l009Wo
V@2IoiT01P2IoiT5000000<0VOnI00<00?l009WoV@2IoiT03P2IoiT2003o00030000003oool0oooo
0980oooo00180?ooo`03003o002IoiT0VOnI00P0VOnI00<00?l009WoV@000000102IoiT00`00o`00
VOnI09WoV@0?09WoV@04003o00000000000000000940oooo00180?ooo`03003o002IoiT0VOnI00L0
VOnI00@00?l009WoV@2IoiT000001@2IoiT00`00o`00VOnI09WoV@0?09WoV@800?l000@0oooo0000
000000000000SP3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT01@00o`00VOnI09WoV@2IoiT0
000000D0VOnI00<00?l009WoV@2IoiT0402IoiT01000o`00oooo0?ooo`3oool4000008X0oooo0018
0?ooo`03003o002IoiT0VOnI00L0VOnI00D00?l009WoV@2IoiT0VOnI0000000509WoV@03003o002I
oiT0VOnI0140VOnI0P00o`050?ooo`<00000Q`3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT0
1@00o`00VOnI09WoV@2IoiT0000000H0VOnI00<00?l009WoV@2IoiT04P2IoiT00`00o`00oooo0?oo
o`050?ooo`@00000P`3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT01@00o`00VOnI09WoV@2I
oiT0000000L0VOnI00<00?l009WoV@2IoiT04P2IoiT2003o00T0oooo0`0000200?ooo`00B03oool0
0`00o`00VOnI09WoV@0709WoV@03003o002IoiT0VOnI0080VOnI00<0000009WoV@2IoiT01@2IoiT0
0`00o`00VOnI09WoV@0C09WoV@03003o003oool0oooo00T0oooo0`00001m0?ooo`00B03oool00`00
o`00VOnI09WoV@0709WoV@03003o002IoiT0VOnI0080VOnI00<0000009WoV@2IoiT01P2IoiT00`00
o`00VOnI09WoV@0C09WoV@800?l0303oool4000007T0oooo00180?ooo`03003o002IoiT0VOnI00L0
VOnI00<00?l009WoV@2IoiT00P2IoiT00`000000VOnI09WoV@0709WoV@03003o002IoiT0VOnI01@0
VOnI00<00?l00?ooo`3oool03@3oool3000007H0oooo00180?ooo`03003o002IoiT0VOnI00L0VOnI
00<00?l009WoV@2IoiT00P2IoiT00`000000VOnI09WoV@0809WoV@03003o002IoiT0VOnI01@0VOnI
0P00o`0@0?ooo`<00000L`3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT00`00o`00VOnI09Wo
V@0309WoV@030000002IoiT0VOnI00P0VOnI00<00?l009WoV@2IoiT05@2IoiT00`00o`00oooo0?oo
o`0@0?ooo`@00000K`3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT00`00o`00VOnI09WoV@03
09WoV@030000002IoiT0VOnI00T0VOnI00<00?l009WoV@2IoiT05@2IoiT2003o01@0oooo0`00001/
0?ooo`00B03oool00`00o`00VOnI09WoV@0709WoV@03003o002IoiT0VOnI00<0VOnI00<0000009Wo
V@2IoiT02P2IoiT00`00o`00VOnI09WoV@0F09WoV@03003o003oool0oooo01@0oooo0`00001Y0?oo
o`00B03oool00`00o`00VOnI09WoV@0709WoV@03003o002IoiT0VOnI00@0VOnI00<0000009WoV@2I
oiT02@2IoiT00`00o`00VOnI09WoV@0G09WoV@800?l05`3oool4000006D0oooo00180?ooo`03003o
002IoiT0VOnI00L0VOnI00<00?l009WoV@2IoiT0102IoiT00`000000VOnI09WoV@0:09WoV@03003o
002IoiT0VOnI01P0VOnI00<00?l00?ooo`3oool0603oool300000680oooo00180?ooo`03003o002I
oiT0VOnI00L0VOnI00<00?l009WoV@2IoiT0102IoiT00`000000VOnI09WoV@0;09WoV@03003o002I
oiT0VOnI01P0VOnI0P00o`0K0?ooo`@00000GP3oool004P0oooo00<00?l009WoV@2IoiT01`2IoiT0
0`00o`00VOnI09WoV@0409WoV@030000002IoiT0VOnI00`0VOnI00<00?l009WoV@2IoiT06@2IoiT0
0`00o`00oooo0?ooo`0L0?ooo`<00000B`3oool6000000X0oooo00180?ooo`03003o002IoiT0VOnI
00L0VOnI00<00?l009WoV@2IoiT01@2IoiT00`000000VOnI09WoV@0<09WoV@03003o002IoiT0VOnI
01T0VOnI0P00o`0O0?ooo`<00000B03oool00`2HV9P000000<c<c0020?ooo`03010@403oool0oooo
00P0oooo00180?ooo`03003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT01P2IoiT00`000000
VOnI09WoV@0=09WoV@03003o002IoiT0VOnI01X0VOnI0P00o`0P0?ooo`@00000A@3oool00`2HV9P0
00000<c<c00<0?ooo`00B03oool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00H0VOnI
00<0000009WoV@2IoiT03P2IoiT00`00o`00VOnI09WoV@0K09WoV@03003o003oool0oooo0240oooo
0`0000130?ooo`030:VYZ@0@4100c<c<00/0oooo00180?ooo`03003o002IoiT0VOnI00H0VOnI00<0
0?l009WoV@2IoiT01P2IoiT00`000000VOnI09WoV@0?09WoV@03003o002IoiT0VOnI01/0VOnI0P00
o`0T0?ooo`<00000@@3oool00`3<c<`0410@0<c<c00:0?ooo`00B03oool00`00o`00VOnI09WoV@06
09WoV@03003o002IoiT0VOnI00L0VOnI00<0000009WoV@2IoiT03`2IoiT00`00o`00VOnI09WoV@0L
09WoV@03003o003oool0oooo02@0oooo1000000n0?ooo`030:VYZ@0b<S80oooo00T0oooo00180?oo
o`03003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT01`2IoiT00`000000VOnI09WoV@0@09Wo
V@03003o002IoiT0VOnI01`0VOnI0P00o`0X0?ooo`<00000?03oool00`000000oooo0?ooo`080?oo
o`00B03oool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00L0VOnI00<0000009WoV@2I
oiT0402IoiT00`00o`00VOnI09WoV@0N09WoV@03003o003oool0oooo02P0oooo0`00000d0?ooo`06
00000027QhL0k^k^0?ooo`1gMgL0<S8b2P3oool004P0oooo00<00?l009WoV@2IoiT01P2IoiT00`00
o`00VOnI09WoV@0809WoV@030000002IoiT0VOnI0100VOnI00<00?l009WoV@2IoiT07P2IoiT2003o
02/0oooo1000000`0?ooo`060:VYZ@0b<S8000000000001EEED0k^k^2P3oool004P0oooo00<00?l0
09WoV@2IoiT01P2IoiT00`00o`00VOnI09WoV@0809WoV@030000002IoiT0VOnI0140VOnI00<00?l0
09WoV@2IoiT07`2IoiT00`00o`00oooo0?ooo`0/0?ooo`<000004`3oool5000002D0oooo00180?oo
o`03003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT0202IoiT00`000000VOnI09WoV@0B09Wo
V@03003o002IoiT0VOnI01l0VOnI0P00o`0_0?ooo`@000003@3oool9000002<0oooo00180?ooo`03
003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT0202IoiT00`000000VOnI09WoV@0C09WoV@03
003o002IoiT0VOnI0200VOnI00<00?l00?ooo`3oool0<03oool3000000T0oooo2`00000R0?ooo`00
B03oool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00T0VOnI00<0000009WoV@2IoiT0
4`2IoiT00`00o`00VOnI09WoV@0P09WoV@800?l0<`3oool3000000D0oooo3@00000Q0?ooo`00B03o
ool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00T0VOnI00<0000009WoV@2IoiT0502I
oiT00`00o`00VOnI09WoV@0Q09WoV@03003o003oool0oooo03<0oooo100000000`3oool000000000
000;00000240oooo00180?ooo`03003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT02@2IoiT0
0`000000VOnI09WoV@0E09WoV@03003o002IoiT0VOnI0240VOnI0P00o`0g0?ooo`l00000803oool0
04P0oooo00<00?l009WoV@2IoiT01P2IoiT00`00o`00VOnI09WoV@0909WoV@030000002IoiT0VOnI
01H0VOnI00<00?l009WoV@2IoiT08P2IoiT00`00o`00oooo0?ooo`0d0?ooo`l00000803oool004P0
oooo00<00?l009WoV@2IoiT01P2IoiT00`00o`00VOnI09WoV@0:09WoV@030000002IoiT0VOnI01H0
VOnI00<00?l009WoV@2IoiT08P2IoiT2003o03@0oooo3`00000P0?ooo`00B03oool00`00o`00VOnI
09WoV@0609WoV@03003o002IoiT0VOnI00X0VOnI00<0000009WoV@2IoiT05P2IoiT00`00o`00VOnI
09WoV@0T09WoV@03003o003oool0oooo0340oooo3`00000P0?ooo`00B03oool00`00o`00VOnI09Wo
V@0609WoV@03003o002IoiT0VOnI00X0VOnI00<0000009WoV@2IoiT05`2IoiT00`00o`00VOnI09Wo
V@0T09WoV@800?l0;03ooolD00000200oooo00180?ooo`03003o002IoiT0VOnI00D0VOnI00<00?l0
09WoV@2IoiT02`2IoiT00`000000VOnI09WoV@0H09WoV@03003o002IoiT0VOnI02D0VOnI00<00?l0
0?ooo`3oool09@3oool4000000H0oooo3@00000Q0?ooo`00B03oool00`00o`00VOnI09WoV@0509Wo
V@03003o002IoiT0VOnI00`0VOnI00<0000009WoV@2IoiT0602IoiT00`00o`00VOnI09WoV@0U09Wo
V@800?l0803oool5000000X0oooo3@00000Q0?ooo`00B03oool00`00o`00VOnI09WoV@0509WoV@03
003o002IoiT0VOnI00`0VOnI00<0000009WoV@2IoiT06@2IoiT00`00o`00VOnI09WoV@0V09WoV@03
003o003oool0oooo01P0oooo1@00000@0?ooo`/000008P3oool004P0oooo00<00?l009WoV@2IoiT0
1@2IoiT00`00o`00VOnI09WoV@0<09WoV@030000002IoiT0VOnI01X0VOnI00<00?l009WoV@2IoiT0
9P2IoiT2003o01<0oooo1@00000F0?ooo`T000008`3oool004P0oooo00<00?l009WoV@2IoiT01@2I
oiT00`00o`00VOnI09WoV@0=09WoV@030000002IoiT0VOnI01X0VOnI00<00?l009WoV@2IoiT09`2I
oiT00`00o`00oooo0?ooo`0<0?ooo`@000006P3oool00`000000oooo0?ooo`05000002D0oooo0017
0?ooo`03003o002IoiT0VOnI00H0VOnI00<00?l009WoV@2IoiT03@2IoiT00`000000VOnI09WoV@0K
09WoV@03003o002IoiT0VOnI02L0VOnI0P00o`070?ooo`D000007P3oool00`000000oooo0?ooo`0Z
0?ooo`00A`3oool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00d0VOnI00<0000009Wo
V@2IoiT0702IoiT00`00o`00VOnI09WoV@0X09WoV@03003o003oool0000000@000008P3oool00`00
0000oooo0?ooo`0[0?ooo`00A`3oool00`00o`00VOnI09WoV@0609WoV@03003o002IoiT0VOnI00d0
VOnI00<0000009WoV@2IoiT07@2IoiT00`00o`00VOnI09WoV@0W09WoV@0300000000o`000?l002D0
oooo00<000000?ooo`3oool0;03oool004L0oooo00<00?l009WoV@2IoiT01P2IoiT00`00o`00VOnI
09WoV@0>09WoV@030000002IoiT0VOnI01`0VOnI00<00?l009WoV@2IoiT0:P2IoiT00`00o`00oooo
0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo00170?ooo`03003o002IoiT0VOnI00H0VOnI00<0
0?l009WoV@2IoiT03P2IoiT00`000000VOnI09WoV@0M09WoV@03003o002IoiT0VOnI02X0VOnI0P00
o`0Q0?ooo`030000003oool0oooo02d0oooo00170?ooo`03003o002IoiT0VOnI00H0VOnI00<00?l0
09WoV@2IoiT03P2IoiT00`000000VOnI09WoV@0N09WoV@03003o002IoiT0VOnI02/0VOnI00<00?l0
0?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`00A`3oool00`00o`00VOnI09WoV@0609Wo
V@03003o002IoiT0VOnI00h0VOnI00<0000009WoV@2IoiT07`2IoiT00`00o`00VOnI09WoV@0[09Wo
V@800?l0703oool00`000000oooo0?ooo`0_0?ooo`00A`3oool00`00o`00VOnI09WoV@0609WoV@03
003o002IoiT0VOnI00l0VOnI00<0000009WoV@2IoiT07`2IoiT00`00o`00VOnI09WoV@0/09WoV@03
003o003oool0oooo01T0oooo00<000000?ooo`3oool0;`3oool004L0oooo00<00?l009WoV@2IoiT0
1P2IoiT00`00o`00VOnI09WoV@0?09WoV@030000002IoiT0VOnI0200VOnI00<00?l009WoV@2IoiT0
;02IoiT2003o01P0oooo00<000000?ooo`3oool0<03oool004L0oooo00<00?l009WoV@2IoiT01P2I
oiT00`00o`00VOnI09WoV@0?09WoV@030000002IoiT0VOnI0240VOnI00<00?l009WoV@2IoiT0;@2I
oiT00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo0340oooo00170?ooo`03003o002IoiT0
VOnI00H0VOnI00<00?l009WoV@2IoiT0402IoiT00`000000VOnI09WoV@0Q09WoV@03003o002IoiT0
VOnI02d0VOnI0P00o`0C0?ooo`030000003oool0oooo0380oooo00170?ooo`03003o002IoiT0VOnI
00H0VOnI00<00?l009WoV@2IoiT0402IoiT00`000000VOnI09WoV@0R09WoV@03003o002IoiT0VOnI
02h0VOnI00<00?l00?ooo`3oool0403oool00`000000oooo0?ooo`0b0?ooo`00@`3oool200000003
010@403oool00?l000L0VOnI00<00?l009WoV@2IoiT04@2IoiT00`000000VOnI09WoV@0S09WoV@03
003o002IoiT0VOnI02h0VOnI0P00o`0?0?ooo`030000003oool0oooo03<0oooo00140?ooo`040000
003oool0oooo003o00D0VOnI0P0000000`00o`0000000000000A09WoV@030000002IoiT0VOnI02<0
VOnI00<00?l009WoV@2IoiT0<02IoiT00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo03@0
oooo00100?ooo`H0000000<0oooo003o002IoiT00P2IoiT400000003003o00000000000000800000
402IoiT00`000000VOnI09WoV@0S09WoV@03003o002IoiT0VOnI0300VOnI0P00o`0;0?ooo`030000
003oool0oooo03@0oooo00100?ooo`0507MgM`2YZJT0oooo0?ooo`0000000P3oool00`00o`00VOnI
09WoV@0500000003003o00000000000000<000003`2IoiT00`000000VOnI09WoV@0T09WoV@03003o
002IoiT0VOnI0340VOnI00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`00@03o
ool01@3^k^h0<S8b0>k^kP3oool000000080oooo00<00?l009WoV@0000001@0000000`00o`000000
00000004000000h0VOnI00<0000009WoV@2IoiT09@2IoiT00`00o`00VOnI09WoV@0a09WoV@800?l0
1P3oool00`000000oooo0?ooo`0f0?ooo`00@@3oool0102YZJT0IVIV0?ooo`0000020?ooo`03003o
002IoiT0000000D0000000<00?l00000000000001000000>09WoV@030000002IoiT0VOnI02H0VOnI
00<00?l009WoV@2IoiT0<P2IoiT00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo
00120?ooo`0304A4A03<c<`000000080oooo00<00?l00000000000001@0000000`00o`0000000000
0005000000h0VOnI00<0000009WoV@2IoiT09P2IoiT00`00o`00VOnI09WoV@0b09WoV@800?l00P3o
ool00`000000oooo0?ooo`0g0?ooo`00@P3oool00`3MgMd0A4A4000000020?ooo`03003o00000000
000000D0000000<00?l00000000000001@00000>09WoV@030000002IoiT0VOnI02L0VOnI00<00?l0
09WoV@2IoiT0<`2IoiT00`00o`0000000?ooo`0i0?ooo`00@`3oool0101gMgL0410@0?ooo`3oool2
003o00H000000P00o`06000000h0VOnI00<0000009WoV@2IoiT0:02IoiT00`00o`00VOnI09WoV@0b
09WoV@0300000000o`00oooo03T0oooo00180?ooo`0300000000o`00000000H000000`00o`030000
00h0VOnI00<0000009WoV@2IoiT0:@2IoiT00`00o`00VOnI09WoV@0b09WoV@03003o003oool0oooo
03P0oooo00180?ooo`8000000P00o`08000000<00?l03`2IoiT00`000000VOnI09WoV@0Y09WoV@03
003o002IoiT0VOnI0300VOnI00<00?l00?ooo`3oool0>@3oool004T0oooo0`0000000`00o`000000
000000070000000409WoV@00o`000?l0003o00`0VOnI00<0000009WoV@2IoiT0:@2IoiT00`00o`00
VOnI09WoV@0`09WoV@03003o003oool0oooo03T0oooo00190?ooo`@000000P00o`07000000@0VOnI
0`00o`0909WoV@030000002IoiT0VOnI02X0VOnI00<00?l009WoV@2IoiT0;`2IoiT00`00o`00oooo
0?ooo`0i0?ooo`00BP3oool500000003003o00000000000000<00000202IoiT3003o00L0VOnI00<0
000009WoV@2IoiT0:P2IoiT00`00o`00VOnI09WoV@0]09WoV@03003o003oool0oooo03X0oooo001;
0?ooo`D0000000@00?l00000000000000000302IoiT3003o00@0VOnI00<0000009WoV@2IoiT0:`2I
oiT00`00o`00VOnI09WoV@0/09WoV@03003o003oool0oooo03X0oooo001=0?ooo`@000000P00o`0@
09WoV@<00?l000<0VOnI0000002IoiT0;@2IoiT00`00o`00VOnI09WoV@0Z09WoV@03003o003oool0
oooo03/0oooo001C0?ooo`03003o002IoiT0VOnI0100VOnI00<00?l000000000o`00;P2IoiT00`00
o`00VOnI09WoV@0Y09WoV@03003o003oool0oooo03/0oooo001C0?ooo`0300000000o`000?l00180
VOnI00@00000003o0000o`000?l0;02IoiT00`00o`00VOnI09WoV@0X09WoV@03003o003oool0oooo
03/0oooo001D0?ooo`030000003oool00?l00140VOnI00@0000009WoV@2IoiT0VOnI0`00o`0Z09Wo
V@03003o002IoiT0VOnI02H0VOnI00<00?l00?ooo`3oool0?03oool005@0oooo00<000000?ooo`3o
ool00P00o`0?09WoV@030000002IoiT0VOnI00@0VOnI0`00o`0X09WoV@03003o002IoiT0VOnI02D0
VOnI00<00?l00?ooo`3oool0?03oool005D0oooo00D000000?ooo`3oool0oooo003o000>09WoV@03
0000002IoiT0VOnI00L0VOnI0`00o`0V09WoV@03003o002IoiT0VOnI02<0VOnI00<00?l00?ooo`3o
ool0?@3oool005D0oooo00<000000?ooo`3oool00P3oool2003o00d0VOnI00<0000009WoV@2IoiT0
2@2IoiT3003o02<0VOnI00<00?l009WoV@2IoiT08`2IoiT00`00o`00oooo0?ooo`0m0?ooo`00EP3o
ool00`000000oooo0?ooo`030?ooo`03003o002IoiT0VOnI00X0VOnI00<0000009WoV@2IoiT0302I
oiT3003o0240VOnI00<00?l009WoV@2IoiT08P2IoiT00`00o`00oooo0?ooo`0m0?ooo`00EP3oool0
0`000000oooo0?ooo`040?ooo`03003o002IoiT0VOnI00T0VOnI00<0000009WoV@2IoiT03`2IoiT3
003o01l0VOnI00<00?l009WoV@2IoiT0802IoiT00`00o`00oooo0?ooo`0n0?ooo`00E`3oool00`00
0000oooo0?ooo`040?ooo`800?l02P2IoiT00`000000VOnI09WoV@0A09WoV@800?l07P2IoiT00`00
o`00VOnI09WoV@0O09WoV@03003o003oool0oooo03h0oooo001G0?ooo`030000003oool0oooo00H0
oooo00<00?l009WoV@2IoiT01`2IoiT00`000000VOnI09WoV@0C09WoV@<00?l0702IoiT00`00o`00
VOnI09WoV@0N09WoV@03003o003oool0oooo03h0oooo001H0?ooo`030000003oool0oooo00H0oooo
0P00o`0709WoV@030000002IoiT0VOnI01H0VOnI0`00o`0J09WoV@03003o002IoiT0VOnI01`0VOnI
00<00?l00?ooo`3oool0?`3oool005P0oooo00<000000?ooo`3oool0203oool00`00o`00VOnI09Wo
V@0409WoV@030000002IoiT0VOnI01T0VOnI0`00o`0H09WoV@03003o002IoiT0VOnI01/0VOnI00<0
0?l00?ooo`3oool0?`3oool005T0oooo00<000000?ooo`3oool0203oool2003o00D0VOnI00<00000
09WoV@2IoiT06`2IoiT3003o01H0VOnI00<00?l009WoV@2IoiT06@2IoiT00`00o`00oooo0?ooo`10
0?ooo`00F@3oool00`000000oooo0?ooo`0:0?ooo`03003o002IoiT0VOnI0080VOnI00<0000009Wo
V@2IoiT07P2IoiT3003o01@0VOnI00<00?l009WoV@2IoiT0602IoiT00`00o`00oooo0?ooo`100?oo
o`00FP3oool00`000000oooo0?ooo`0:0?ooo`800?l00P2IoiT00`000000VOnI09WoV@0Q09WoV@<0
0?l04P2IoiT00`00o`00VOnI09WoV@0G09WoV@03003o003oool0oooo0400oooo001J0?ooo`030000
003oool0oooo00`0oooo00<00?l009WoV@0000009P2IoiT3003o00l0VOnI00<00?l009WoV@2IoiT0
5P2IoiT00`00o`00oooo0?ooo`110?ooo`00F`3oool00`000000oooo0?ooo`0<0?ooo`800?l000<0
000009WoV@2IoiT09P2IoiT3003o00d0VOnI00<00?l009WoV@2IoiT05@2IoiT00`00o`00oooo0?oo
o`110?ooo`00F`3oool00`000000oooo0?ooo`0>0?ooo`030000002IoiT0VOnI02T0VOnI0`00o`0;
09WoV@03003o002IoiT0VOnI01<0VOnI00<00?l00?ooo`3oool0@P3oool005`0oooo00<000000?oo
o`3oool03@3oool00`0000000?l009WoV@0/09WoV@<00?l02@2IoiT00`00o`00VOnI09WoV@0B09Wo
V@03003o003oool0oooo0480oooo001L0?ooo`030000003oool0oooo00h0oooo00<00000003o0000
o`00;P2IoiT3003o00L0VOnI00<00?l009WoV@2IoiT04@2IoiT00`00o`00oooo0?ooo`120?ooo`00
G@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo003o0300VOnI0`00o`0509WoV@03
003o002IoiT0VOnI00l0VOnI00<00?l00?ooo`3oool0@`3oool005d0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`3oool2003o0340VOnI0`00o`0309WoV@03003o002IoiT0VOnI00h0
VOnI00<00?l00?ooo`3oool0@`3oool005h0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`030?ooo`03003o002IoiT0VOnI0340VOnI0`00o`000`2IoiT00?l009WoV@0=09WoV@03003o
003oool0oooo04@0oooo001N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool2003o03@0VOnI0`00o`0=09WoV@03003o003oool0oooo04@0oooo001O0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool00`00o`00VOnI09WoV@0d09WoV@03003o002IoiT0
VOnI00X0VOnI00<00?l00?ooo`3oool0A03oool005l0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`060?ooo`800?l0=02IoiT00`000000VOnI09WoV@0909WoV@03003o003oool0oooo
04D0oooo001P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00o`00
VOnI09WoV@0`09WoV@030000002IoiT0VOnI00X0VOnI00<00?l00?ooo`3oool0A@3oool00600oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`03003o002IoiT0VOnI02h0VOnI
00<0000009WoV@2IoiT02P2IoiT00`00o`00oooo0?ooo`160?ooo`00H@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo0P00o`0]09WoV@030000002IoiT0VOnI00/0VOnI00<0
0?l00?ooo`3oool0AP3oool00640oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`03003o002IoiT0VOnI02X0VOnI00<0000009WoV@2IoiT02`2IoiT00`00o`00oooo0?ooo`16
0?ooo`00HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo0P00o`0Y09Wo
V@030000002IoiT0VOnI00/0VOnI00<00?l00?ooo`3oool0A`3oool00680oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`03003o002IoiT0VOnI02D0VOnI00<0000009WoV@2I
oiT0302IoiT00`00o`00oooo0?ooo`170?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00h0oooo0P00o`0U09WoV@030000002IoiT0VOnI00`0VOnI00<00?l00?ooo`3oool0
A`3oool006<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`03003o002I
oiT0VOnI0240VOnI00<0000009WoV@2IoiT0302IoiT00`00o`00oooo0?ooo`180?ooo`00I03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00o`0P09WoV@030000002IoiT0
VOnI00d0VOnI00<00?l00?ooo`3oool0B03oool006@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0B0?ooo`03003o002IoiT0VOnI01`0VOnI00<0000009WoV@2IoiT03@2IoiT00`00
o`00oooo0?ooo`190?ooo`00I@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0
oooo00<00?l009WoV@2IoiT06`2IoiT00`000000VOnI09WoV@0=09WoV@03003o003oool0oooo04T0
oooo001U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool2003o01X0VOnI
00<0000009WoV@2IoiT03P2IoiT00`00o`00oooo0?ooo`190?ooo`00IP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<00?l009WoV@2IoiT05P2IoiT00`000000VOnI09Wo
V@0>09WoV@03003o003oool0oooo04X0oooo001V0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool05P3oool2003o01D0VOnI00<0000009WoV@2IoiT03`2IoiT00`00o`00oooo0?ooo`1:
0?ooo`00I`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<00?l009Wo
V@2IoiT04P2IoiT00`000000VOnI09WoV@0>09WoV@03003o003oool0oooo04/0oooo001X0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool2003o0140VOnI00<0000009WoV@2I
oiT03`2IoiT00`00o`00oooo0?ooo`1;0?ooo`00J03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01X0oooo00<00?l009WoV@2IoiT03@2IoiT00`000000VOnI09WoV@0@09WoV@03003o
003oool0oooo04/0oooo001Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3o
ool2003o00`0VOnI00<0000009WoV@2IoiT0402IoiT00`00o`00oooo0?ooo`1<0?ooo`00J@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<00?l009WoV@2IoiT02@2IoiT0
0`000000VOnI09WoV@0@09WoV@03003o003oool0oooo04`0oooo001Z0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool07@3oool2003o00P0VOnI00<0000009WoV@2IoiT0402IoiT00`00
o`00oooo0?ooo`1=0?ooo`00JP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0
oooo00<00?l009WoV@2IoiT0102IoiT00`000000VOnI09WoV@0A09WoV@03003o003oool0oooo04d0
oooo001[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0803oool00`00o`00VOnI
09WoV@0309WoV@030000002IoiT0VOnI0140VOnI00<00?l00?ooo`3oool0C@3oool006/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`800?l00P2IoiT00`000000VOnI09Wo
V@0A09WoV@03003o003oool0oooo04h0oooo001/0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08P3oool00`00o`00000009WoV@0C09WoV@03003o003oool0oooo04h0oooo001/0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`0000000?l0003o000B09Wo
V@03003o003oool0oooo04l0oooo001]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`00o`0A09WoV@03003o003oool0oooo04l0oooo001]0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`80
0?l03`2IoiT00`00o`00oooo0?ooo`1?0?ooo`00KP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`00o`00VOnI09WoV@0;09WoV@03003o
003oool0oooo0500oooo001^0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`070?ooo`800?l02`2IoiT00`00o`00oooo0?ooo`1@0?ooo`00K`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool0
0`00o`00VOnI09WoV@0809WoV@03003o003oool0oooo0500oooo001_0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`03003o002IoiT0VOnI
00H0VOnI00<00?l00?ooo`3oool0D@3oool00700oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo0P00o`0609WoV@03003o003oool0oooo0540
oooo001`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0?0?ooo`03003o002IoiT0VOnI0080VOnI00<00?l00?ooo`3oool0DP3oool00740oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo0P00
o`0209WoV@03003o003oool0oooo0580oooo001a0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`03003o002IoiT00?l005@0oooo001b0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?oo
o`03003o003oool0oooo05<0oooo001b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1/0?ooo`00L`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0K@3oool007<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06h0oooo001d0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1_0?ooo`00M03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0K`3oool007D0
oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo0700oooo001e0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1a0?ooo`00
MP3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0L@3oool007H0oooo
00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo0780oooo001g0?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool01@000000oooo
0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0M03oool007P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`1d0?ooo`00N03oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0oooo07D0oooo001i0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool0MP3oool007T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1g0?ooo`00
NP3oool00`000000oooo0000000:0?ooo`030000003oool0oooo07L0oooo001j0?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool0N03oool007/0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`1i0?ooo`00N`3oool00`000000oooo0000000400000080oooo00<000000?oo
o`3oool0NP3oool007/0oooo2P00001l0?ooo`00NP3oool;000007`0oooo001i0?ooo`d00000N`3o
ool007T0oooo3@00001k0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007P0oooo
3`00001j0?ooo`00N03oool?000007X0oooo001h0?ooo`l00000NP3oool007T0oooo3@00001k0?oo
o`00N@3oool=000007/0oooo001j0?ooo`/00000O03oool007/0oooo2@00001m0?ooo`00O@3oool5
000007l0oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o
0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo003o0?ooo`80oooo001m
0?ooo`@0000000<0410@0?ooo`3oool0O@3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0
oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<0
00000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?oo
o`3oool0O`3oool007d0oooo00<0000004A4A0000000P@3oool007d0oooo00<0c<c<05EEE@000000
P@3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00001\
\>"],
  ImageRangeCache->{{{0, 256.938}, {287, 0}} -> {0.106778, -0.000280409, \
0.00323686, 0.00323686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.83114 .49561 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.51446 .92673 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.52052 1.0131 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.92882 .4507 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.81444 .51834 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.533 .9015 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.5448 .97967 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.90763 .47989 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.79765 .54121 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.55141 .87643 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.56887 .94651 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.88627 .50931 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.78074 .56422 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.56971 .85152 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.59274 .91362 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.86474 .53896 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.5879 .82676 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.61642 .88101 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.84305 .56884 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.60598 .80215 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.63991 .84865 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.82119 .59895 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.62394 .77769 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.66321 .81656 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.79915 .62931 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.64179 .75339 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.68632 .78472 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.77694 .6599 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.65953 .72924 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.70925 .75314 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.75456 .69073 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.67717 .70523 Mdot
.67717 .70523 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.732 .72181 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.732 .72181 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.65953 .72924 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.75456 .69073 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.70925 .75314 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.64179 .75339 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.77694 .6599 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.68632 .78472 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.62394 .77769 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.79915 .62931 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66321 .81656 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.60598 .80215 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.82119 .59895 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.63991 .84865 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.5879 .82676 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.84305 .56884 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.61642 .88101 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.78074 .56422 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.56971 .85152 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.86474 .53896 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.59274 .91362 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.79765 .54121 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.55141 .87643 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.88627 .50931 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.56887 .94651 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.81444 .51834 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.533 .9015 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.90763 .47989 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5448 .97967 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
15 Mabswid
.83114 .49561 Mdot
0 1 0 r
.5 Mabswid
.32361 .31563 m
.67717 .70523 L
s
0 g
15 Mabswid
.51446 .92673 Mdot
.5 Mabswid
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.92882 .4507 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.52052 1.0131 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128396 1.20241 0 1.20241 [
[ 0 0 0 0 ]
[ 1 1.11634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11634 L
0 1.11634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.28575 .25693 m .27737 .57983 L .66761 .84889 L p .6 1 .6 r
F P
0 g
s
15 Mabswid
.31032 .58002 Mdot
.5 Mabswid
.66761 .84889 m .77199 .58276 L .28575 .25693 L p .6 1 .6 r
F P
0 g
s
0 1 0 r
.66761 .84889 m
.77199 .58276 L
s
0 g
.31032 .58002 m
.49581 .95212 L
s
.66308 .50978 m
.84774 .47301 L
s
0 1 0 r
.31032 .58002 m
.67717 .70523 L
s
.31032 .58002 m
.32361 .31563 L
s
.27737 .57983 m
.66761 .84889 L
s
.27737 .57983 m
.28575 .25693 L
s
0 g
15 Mabswid
.84774 .47301 Mdot
.5 Mabswid
.41371 .34268 m
.84774 .47301 L
s
.49581 .95212 m
.67717 .70523 L
s
.76873 .58058 m
.84774 .47301 L
s
0 1 0 r
.32361 .31563 m
.67717 .70523 L
s
0 g
.32361 .31563 m
.49581 .95212 L
s
15 Mabswid
.49581 .95212 Mdot
.32361 .31563 Mdot
0 1 0 r
.5 Mabswid
.28575 .25693 m
.77199 .58276 L
s
0 g
gsave
.94985 .42173 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
71.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.49605 1.04681 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26686 .20489 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26178 .5616 -67 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->True,
  ShowGroupOpenCloseIcon->False,
  Copyable->True,
  ImageSize->{257.938, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.124248,
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False]
}, Closed]],

Cell[TextData[{
  "The above rotation implies a  ",
  Cell[BoxData[
      SubscriptBox[
        RowBox[{"(", GridBox[{
              {"1", "2", "3", "4"},
              {"2", "1", "3", "4"}
              }], ")"}], "\[Sigma]"]]],
  "-permutation.  The \[Sigma] indicates the reflection."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell["\<\
If a parent compound is achiral, exactly one rotation-reflection \
generator must be given. Envisage a mirror reflection, an inversion, or a \
reflection-rotation (what ever applies) and enter the resulting substituent \
site permutation below.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(To\ enter\ a\ rotation\[Dash]reflection\ generator, \ 
        press\ \(here!\)\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(Isomers`Isomers`Private`InsertReflectionRotation&),
      ButtonEvaluator->Automatic,
      Active->True]], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[""], "Input",
  Editable->True,
  Selectable->True,
  CellFrame->True,
  CellMargins->{{24, 24}, {20, 1}},
  Active->False,
  Evaluatable->False,
  CellFrameMargins->6,
  CellFrameLabels->{{
    Inherited, Inherited}, {
      StyleBox[ 
        "Rotation-Reflection Generators", FontWeight -> "Plain", FontFamily -> 
          "Helvetica", FontSize -> 9], Inherited}},
  CellFrameLabelMargins->2,
  CellTags->"RotationReflectionGenerators"]
}, Closed]],

Cell[CellGroupData[{

Cell["Conformations", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {8, Inherited}},
  Copyable->False,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  ScriptMinSize->9,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetic",
  FontSize->12],

Cell["\<\
So far, we assumed chemical compounds to be rigid structures. This \
is not always the case. Molecules may rotate along \[Sigma]-bonds. Other \
bonds may be twisted or bent to a certain degree. We call symmetry \
transformations that include the rotation, twisting, or bending of chemical \
bonds 'conformational transformations', or in short 'conformations'. (Note, \
that conformational transformations are not point group elements. Instead, \
they extend the point group to a larger symmetry group.)\
\>", NotebookDefault,\

  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  "Conformational transformations may need a small amount of activation \
energy. Hence, they introduce a new quality of isomer equivalence. One may or \
may not want to consider these symmetry transformation in an isomer \
enumeration. We therefore treat these transformations separately. Later, they \
may be in- or excluded by setting the option ",
  StyleBox["Conformation", "Input"],
  " to ",
  StyleBox["True", "Input"],
  " or to ",
  StyleBox["False", "Input"],
  "."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[TextData[{
  StyleBox["Example:",
    FontVariations->{"Underline"->True}],
  " the graphic below shows a model of biphenyl. This molecule can rotate \
around the \[Sigma]-bond between its two benzene rings. The resulting \
conformational transformation may render two isomers as mesomers."
}], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006600019B000`400?l00000o`00003oo`3ooon7
0?ooo`00o`3ooon70?ooo`00o`3ooon70?ooo`00o`3ooon70?ooo`00o`3ooon70?ooo`00o`3ooon7
0?ooo`00TP3oool00`36a/H0oooo0?ooo`3a0?ooo`00S03oool=0;fm_Nd0oooo002:0?ooo`<0[Jf]
2`1[Jf/30:f][N/0oooo00280?ooo`<0[Jf]201SHf<706][J`<0[Jf]j@3oool008H0oooo0`2UYJD8
06=SH`<0Jf][1`1kNg/0101[Jf/0YJFU0:FUY@2UYJGW0?ooo`00Q@3oool20:FUY@H0FUYJ00@0Hf=S
06][J`1[Jf/0Jf][101cLg<508B4Q0@0Lg=c0P2UYJGV0?ooo`00Q03oool20:FUY@H0FUYJ00<0Hf=S
06][J`1cLg<00`1cLg<307]kN`L0Q8B40P1kNg/00`1cLg<0YJFU0:FUY@3U0?ooo`00P`3oool20:FU
Y@D0FUYJ00<0Hf=S06][J`1[Jf/00P1cLg<307]kN`<0Q8B41`2<S8`308B4Q00307]kN`2UYJD0YJFU
0>@0oooo00220?ooo`80YJFU101JFUX206=SH`0306][J`1cLg<0Lg=c0080Ng]k0`24Q8@308b<S0T0
W9bL00<0S8b<08B4Q01kNg/00P2UYJGS0?ooo`00P@3oool20:FUY@@0FUYJ00@0Hf=S06][J`1cLg<0
Lg=c0P1kNg/208B4Q0<0S8b<3P2LW9`208b<S0030:f][@2UYJD0oooo0>40oooo00200?ooo`80YJFU
101JFUX01@1SHf<0Jf][07=cL`1cLg<0Ng]k0080Q8B40P2<S8`709bLW0L0YJFU1@2LW9`00`2<S8`0
[Jf]0:FUY@3Q0?ooo`00P03oool00`2UYJD0FUYJ05YJFP0305YJFP0306=SH`1[Jf/0Lg=c0080Ng]k
0P24Q8@00`2<S8`0W9bL09bLW00509bLW0T0YJFU1@2LW9`00`24Q8@0YJFU0?ooo`3P0?ooo`00O`3o
ool20:FUY@<0FUYJ00H0Hf=S06][J`1cLg<0Lg=c07]kN`24Q8@308b<S0D0W9bL0`2UYJD50;Fe]@03
0;fm_@2e]KD0]KFe00<0]KFe0P2UYJD209bLW0030:f][@2UYJD0oooo0=l0oooo001o0?ooo`030:FU
Y@1JFUX0FUYJ0080FUYJ00<0Hf=S06][J`1cLg<00P1kNg/00`24Q8@0S8b<08b<S00509bLW0<0YJFU
0`2e]KD00`2m_Kd0]KFe0;fm_@020;fm_@030;Fe]@2m_Kd0]KFe0080]KFe00D0YJFU09bLW02LW9`0
W9bL0:FUY@3P0?ooo`00O`3oool00`2UYJD0FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k
00<0Q8B408b<S02LW9`0102LW9`30:FUY@<0]KFe2@2m_Kd30;Fe]@040:FUY@2LW9`0W9bL0:FUYN00
oooo001n0?ooo`80YJFU0`1JFUX01@1SHf<0Jf][07=cL`1kNg/0Q8B40080S8b<0`2LW9`30:FUY@<0
]KFe102m_Kd00`36a/H0_Kfm0<K6aP040<K6aP@0_Kfm00D0]KFe0:FUY@2LW9`0]KFe0:f][@3O0?oo
o`00OP3oool01P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`80Lg=c00<0Ng]k08B4Q02<S8`0102LW9`2
0:FUY@030;Fe]@000000]KFe00@0_Kfm00<0a/K600000036a/H01P36a/H40;fm_@040;Fe]@2UYJD0
W9bL0:f][Ml0oooo001n0?ooo`0:0:FUY@1JFUX0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0Q8B408b<
S0D0W9bL00@0YJFU0;Fe]@2e]KD00000102m_Kd20<K6aP0600000036a/H0a/K60<k>cP36a/H0c/k>
0`36a/H30;fm_@040;Fe]@2UYJD0W9bL0:f][Ml0oooo001n0?ooo`0:0:FUY@1JFUX0FUYJ05YJFP1S
Hf<0Jf][07=cL`1kNg/0Q8B408b<S0@0W9bL00D0YJFU0;Fe]@2e]KD0]KFe000000030;fm_@<0a/K6
00<000000<K6aP3>c/h0103>c/h30<K6aP80_Kfm00@0]KFe0:FUY@2LW9`0[Jf]g`3oool007h0oooo
00D0YJFU05YJFP1JFUX0FUYJ06][J`0207=cL`0307]kN`24Q8@0S8b<00<0W9bL0P2UYJD20;Fe]@04
0;fm_@000000_Kfm0;fm_@<0a/K600<0c/k>0000003>c/h01P3>c/h30<K6aP80_Kfm00<0]KFe0:FU
Y@2][Jd0g`3oool007h0oooo00T0YJFU05YJFP1JFUX0FUYJ06][J`1cLg<0Ng]k08B4Q02<S8`00`2L
W9`30:FUY@050;Fe]@2m_Kd0_Kfm0000002m_Kd00`36a/H20<k>cP060000003>c/h0c/k>0=KFeP3>
c/h0e]KF0`3>c/h30<K6aP040;fm_@2e]KD0YJFU0:f][Ml0oooo001n0?ooo`090:FUY@1JFUX0FUYJ
06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<00<0W9bL0P2UYJD0102e]KD0_Kfm0;fm_@2m_Kd800000003
0<k>cP3Fe]H0e]KF00<0e]KF0`3>c/h20<K6aP040;fm_@2e]KD0YJFU0:f][Ml0oooo001n0?ooo`04
0:FUY@1JFUX0FUYJ06=SH`80Lg=c00<0Ng]k08B4Q02<S8`00`2LW9`00`2UYJD0]KFe0;Fe]@030;fm
_@0300000036a/H0a/K600<0c/k>00<0e]KF0000003Fe]H01P3Fe]H30<k>cP050<K6aP2m_Kd0_Kfm
0;Fe]@2][Jd0g`3oool007h0oooo00P0YJFU05YJFP1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S0<0W9bL
00@0YJFU0;Fe]@2e]KD0]KFe0P2m_Kd00`36a/H000000<K6aP030<k>cP80e]KF00H000000=KFeP3F
e]H0g]kN0=KFeP3Ng]h30=KFeP<0c/k>00@0a/K60;fm_@2e]KD0]KFeg`3oool007h0oooo00P0YJFU
05YJFP1JFUX0Jf][07=cL`1kNg/0Q8B408b<S080W9bL0P2UYJD20;Fe]@80_Kfm0P36a/H010000000
c/k>0<k>cP3>c/h30=KFeP030000003Fe]H0g]kN00@0g]kN0`3Fe]H20<k>cP040<K6aP2m_Kd0]KFe
0;Fe]Ml0oooo000_0?ooo`030:FUY@3oool0oooo04`0oooo0P2UYJD01P1JFUX0Jf][07=cL`1kNg/0
Q8B408b<S080W9bL0P2UYJD00`2e]KD0_Kfm0;fm_@030<K6aP030000003>c/h0c/k>00<0e]KF00<0
g]kN0000003Ng]h01P3Ng]h30=KFeP050<k>cP36a/H0_Kfm0<K6aP2e]KD0g`3oool002T0oooo3@2U
YJE90?ooo`070:FUY@1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe0080
_Kfm0`36a/H30<k>cP<0e]KF00<0g]kN0=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP05
0<k>cP36a/H0_Kfm0;fm_@2e]KD0h03oool002L0oooo0`2UYJD;05YJFP<0YJFUA`3oool01`2UYJD0
FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3F
e]H90=kNgP<0e]KF00@0c/k>0<K6aP2m_Kd0]KFeh03oool002D0oooo0`2UYJD805YJFPL0Hf=S0`2U
YJE50?ooo`80YJFU00@0Jf][07=cL`24Q8@0S8b<0`2LW9`00`2UYJD0]KFe0;fm_@020;fm_@80a/K6
0`3>c/h30=KFeP/0g]kN0P3Fe]H0103>c/h0a/K60<K6aP2e]KGP0?ooo`008`3oool30:FUY@D0FUYJ
0`1SHf<306][J`L0Lg=c00@0Jf][0:FUY@2UYJD0YJFUA03oool01P2UYJD0FUYJ06][J`1kNg/0Q8B4
08b<S0<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF1`3Ng]h30=KFeP80c/k>00<0
a/K60;fm_@2e]KD0h@3oool00280oooo0P2UYJD605YJFP0406=SH`1[Jf/0Jf][06][J`@0Lg=c1@1k
Ng/407=cL`80YJFU@`3oool20:FUY@0407=cL`1kNg/0Q8B408b<S080W9bL00<0YJFU0;Fe]@2e]KD0
0P2m_Kd20<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>0<K6aP36a/H0]KFeRP3oool3000001@0
oooo0P00000n0?ooo`008@3oool20:FUY@H0FUYJ00<0Hf=S06][J`1cLg<00`1cLg<307]kN`L0Q8B4
0P1kNg/00`1cLg<0YJFU0:FUY@130?ooo`80YJFU00<0Lg=c07]kN`2<S8`00`2LW9`0102UYJD0]KFe
0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H70=kNgP<0e]KF00@0c/k>0<K6aP36a/H0]KFeS03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03/0oooo000P0?ooo`80YJFU1@1JFUX00`1SHf<0
Jf][06][J`0207=cL`<0Ng]k0`24Q8@708b<S0<0Q8B400<0Ng]k0:FUY@2UYJD0@`3oool20:FUY@03
07=cL`24Q8@0S8b<00<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF00<0g]kN0=KF
eP3Ng]h01@3Fe]H0103>c/h0a/K60<K6aP2e]KF10?ooo`D000000`3oool3000000040?ooo`000000
000000000080oooo0P0000001@3oool00000000000000000oooo008000000P3oool3000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool00`00000g0?ooo`007`3oool20:FUY@@0FUYJ0P1S
Hf<00`1[Jf/0Lg=c07=cL`0207]kN`<0Q8B40`2<S8`909bLW00308b<S024Q8@0Ng]k0080YJFU@`3o
ool01@2UYJD0Jf][07]kN`24Q8@0S8b<0080W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd30<K6aP<0c/k>
1`3Fe]H30<k>cP80a/K600<0]KFe0?ooo`3oool0P@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000>03oool001h0oooo0P2UYJD405YJFP0406=SH`1[Jf/0Lg=c07=cL`80Ng]k
0P24Q8@308b<S0h0W9bL0P2<S8`00`2][Jd0YJFU0?ooo`110?ooo`050:f][@1JFUX0Lg=c07]kN`2<
S8`00P2LW9`20:FUY@80]KFe0P2m_Kd30<K6aP<0c/k>00D0e]KF0<k>cP3Fe]H0c/k>0=KFeP030<k>
cP80a/K600<0]KFe0?ooo`3oool0PP3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo03H0
oooo000M0?ooo`80YJFU101JFUX01@1SHf<0Jf][07=cL`1cLg<0Ng]k0080Q8B40P2<S8`709bLW0L0
YJFU1@2LW9`00`2<S8`0[Jf]0:FUY@0o0?ooo`<0[Jf]00D0<C4a05YJFP1cLg<0Q8B408b<S00209bL
W0030:FUY@2e]KD0]KFe00<0_Kfm0`36a/H70<k>cP@0a/K600<0]KFe0?ooo`3oool0P`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0000000<000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0=P3oool001d0oooo00<0YJFU05YJFP1JFUX0
0`1JFUX00`1SHf<0Jf][07=cL`0207]kN`80Q8B400<0S8b<09bLW02LW9`01@2LW9`90:FUY@D0W9bL
00<0Q8B40:FUY@3oool0?03oool30:f][@@0<C4a00<0Hf=S07=cL`24Q8@00`2LW9`00`2UYJD0]KFe
0;fm_@030;fm_@<0a/K61@3>c/h30<K6aP030;fm_@2e]KD0oooo08D0oooo100000040?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
000h0?ooo`00703oool20:FUY@<0FUYJ00H0Hf=S06][J`1cLg<0Lg=c07]kN`24Q8@308b<S0D0W9bL
0`2UYJD50;Fe]@030;fm_@2e]KD0]KFe00<0]KFe0P2UYJD209bLW0030:f][@2UYJD0oooo03T0oooo
0`2][Jd5034a<@80>CTi00@0FUYJ06][J`1kNg/0S8b<0P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0
_Kfm0<K6aP020;fm_@030<K6aP2m_Kd0]KFe08P0oooo00D000000?ooo`3oool0oooo000000020?oo
o`80000000<0oooo0000000000000P0000030?ooo`<000000`3oool200000080oooo00@000000?oo
o`00000000000P3oool3000000050?ooo`00000000000?ooo`000000>03oool001`0oooo00<0YJFU
05YJFP1JFUX00P1JFUX00`1SHf<0Jf][07=cL`0207]kN`0308B4Q02<S8`0S8b<00D0W9bL0`2UYJD3
0;Fe]@030;fm_@2e]KD0_Kfm0080_Kfm00<0]KFe0;fm_@2e]KD00P2e]KD01@2UYJD0W9bL09bLW02L
W9`0YJFU03T0oooo0P2][Jd6034a<@0903Ti>@12@T80@T9205YJFP1SHf<0S8b<07=cL`24Q8@0S8b<
0080W9bL0P2UYJD30;Fe]@<0_Kfm00@0]KFe0;fm_@2e]KD0]KFeRP3oool01@000000oooo0?ooo`3o
ool0000000`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`00703oool0
0`2UYJD0FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B408b<S02LW9`0102LW9`3
0:FUY@<0]KFe2@2m_Kd30;Fe]@040:FUY@2LW9`0W9bL0:FUYCP0oooo0P2][Jd6034a<@0603Ti>@12
@T80@T920492@P1JFUX0Jf][0P2LW9`00`2e]KD0Lg=c08b<S00309bLW0<0YJFU00D0]KFe0:FUY@2e
]KD0YJFU0;Fe]@2;0?ooo`D00000103oool00`000000oooo0?ooo`050?ooo`8000005@3oool20000
03P0oooo000K0?ooo`80YJFU0`1JFUX01@1SHf<0Jf][07=cL`1kNg/0Q8B40080S8b<0`2LW9`30:FU
Y@<0]KFe102m_Kd00`36a/H0_Kfm0<K6aP040<K6aP@0_Kfm00D0]KFe0:FUY@2LW9`0]KFe0:f][@0f
0?ooo`80[Jf]1@0a<C400`0i>CT0@T920492@P020492@P80BTY:00`0@T9206=SH`2LW9`0YJFU0;Fe
]@2m_Kd0a/K60<k>cP3Fe]H0c/k>08b<S02LW9`2059BDP0304Y:BP12@T80[Jf]0>d0oooo000K0?oo
o`060:FUY@1JFUX0FUYJ05YJFP1SHf<0Jf][0P1cLg<00`1kNg/0Q8B408b<S00409bLW0030:FUY@00
0000]KFe0080]KFe0`2m_Kd00`000000a/K60<K6aP070<K6aP@0_Kfm00@0]KFe0:FUY@2LW9`0[Jf]
=@3oool20:f][@@0<C4a0P0i>CT30492@P80BTY:0`1BDU802P24Q8@0W9bL0;Fe]@2m_Kd0a/K60<k>
cP3Fe]H0c/k>0<K6aP24Q8@206=SH`0305YJFP1BDU80BTY:0080YJFUk03oool001/0oooo00X0YJFU
05YJFP1JFUX0FUYJ06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<1@2LW9`0102UYJD000000;Fe]@2e]KD4
0;fm_@0300000036a/H0a/K60080a/K600<0c/k>0<K6aP3>c/h00`36a/H30;fm_@040;Fe]@2UYJD0
W9bL0:f][C@0oooo0P2][Jd4034a<@0403Ti>@12@T80@T920492@P80BTY:0P1BDU8305YJFP80Hf=S
00L0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0080Jf][0`1SHf<205YJFP80YJFUj`3oool001/0
oooo00X0YJFU05YJFP1JFUX0FUYJ06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<102LW9`0102UYJD0]KFe
0000002e]KD40;fm_@050<K6aP000000a/K60<k>cP36a/H01@3>c/h30<K6aP80_Kfm00@0]KFe0:FU
Y@2LW9`0[Jf]<`3oool20:f][@@0<C4a00D0>CTi0492@P12@T80@T9204Y:BP02059BDP80FUYJ101S
Hf<306][J`80Lg=c00<0_Kfm07=cL`1cLg<00P1cLg<306][J`80Hf=S00<0FUYJ0:FUY@2UYJD0jP3o
ool001/0oooo00D0YJFU05YJFP1JFUX0FUYJ06][J`0207=cL`0307]kN`24Q8@0S8b<00<0W9bL0P2U
YJD00`2e]KD000000;fm_@030;fm_@80a/K600<000000<k>cP3>c/h01`3>c/h30<K6aP80_Kfm00<0
]KFe0:FUY@2][Jd0<`3oool00`2][Jd0<C4a034a<@03034a<@0303Ti>@12@T80@T920080BTY:0P1B
DU800`1JFUX0Hf=S06=SH`0206=SH`<0Jf][2@1cLg<306][J`80Hf=S00<0DU9B0:FUY@3oool0j@3o
ool001/0oooo00T0YJFU05YJFP1JFUX0FUYJ06][J`1cLg<0Ng]k08B4Q02<S8`00`2LW9`30:FUY@03
0;Fe]@000000_Kfm0080_Kfm0`36a/H00`000000c/k>0<k>cP020<k>cP030=KFeP3>c/h0e]KF00<0
c/k>0`36a/H0102m_Kd0]KFe0:FUY@2][Jdb0?ooo`80[Jf]0`0a<C401P0i>CT0@T920492@P12@T80
BTY:059BDP<0FUYJ0P1SHf<306][J`<0Lg=c1@1kNg/00`24Q8@0Ng]k07]kN`0307]kN`80Lg=c00@0
Jf][06=SH`2UYJD0YJFUj@3oool001/0oooo00T0YJFU05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4
Q02<S8`00`2LW9`20:FUY@030;Fe]@2m_Kd0000000L0000000<0c/k>0=KFeP3>c/h01@3Fe]H30<k>
cP80a/K600@0_Kfm0;Fe]@2UYJD0[Jf]<P3oool00`2][Jd0>CTi034a<@02034a<@0303Ti>@12@T80
@T920080BTY:00<0DU9B05YJFP1JFUX00P1SHf<306][J`<0Lg=c0`1kNg/00`24Q8@0Ng]k08B4Q002
08B4Q00307]kN`24Q8@0Ng]k0080Ng]k00D0Lg=c06][J`1SHf<0Hf=S0:FUY@3Y0?ooo`006`3oool0
102UYJD0FUYJ05YJFP1SHf<207=cL`0307]kN`24Q8@0S8b<00<0W9bL00H0YJFU0;Fe]@2e]KD0_Kfm
0000002m_Kd30<K6aP80c/k>00<000000=KFeP3Fe]H01`3Fe]H30<k>cP050<K6aP2m_Kd0_Kfm0;Fe
]@2][Jd03@3oool00`2][Jd0oooo0?ooo`0R0?ooo`030:FUY@0i>CT0>CTi0080<C4a00<0>CTi0492
@P12@T800P1:BTX0101BDU80FUYJ06=SH`1SHf<306][J`<0Lg=c0`1kNg/908B4Q0<0Ng]k00@0Lg=c
06][J`1SHf<0YJFUj@3oool001/0oooo00P0YJFU05YJFP1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S0<0
W9bL00H0YJFU0;Fe]@2e]KD0]KFe0;fm_@0000030<K6aP<0c/k>00<000000=KFeP3Fe]H00P3Fe]H0
0`3Ng]h0e]KF0=kNgP030=KFeP<0c/k>00@0a/K60;fm_@2e]KD0]KFe1`3oool=0:f][A`0oooo00@0
moOg0:f][@2UYJD0>CTi0P0a<C401@0i>CT0@T920492@P1:BTX0DU9B0080FUYJ0P1SHf<0101[Jf/0
Lg=c07=cL`1cLg<307]kN`@0Q8B400<0S8b<08B4Q02<S8`0102<S8`408B4Q00307]kN`1cLg<0Jf][
0080YJFUj03oool001/0oooo00P0YJFU05YJFP1JFUX0Jf][07=cL`1kNg/0Q8B408b<S080W9bL0P2U
YJD20;Fe]@80_Kfm00<000000<K6aP36a/H00`3>c/h01@3Fe]H000000=KFeP3Ng]h0e]KF00D0g]kN
0`3Fe]H20<k>cP040<K6aP2m_Kd0]KFe0;Fe]@D0oooo0`2][Jd;034a<@<0[Jf]6P3oool01P3gmoL0
[Jf]0492@P0i>CT0<C4a03Ti>@<0@T9200<0BTY:059BDP1JFUX00P1SHf<206][J`80Lg=c0`1kNg/4
08B4Q0T0S8b<1024Q8@0101kNg/0Lg=c06][J`2UYJGX0?ooo`006`3oool20:FUY@0605YJFP1[Jf/0
Lg=c07]kN`24Q8@0S8b<0P2LW9`20:FUY@060;Fe]@2m_Kd0_Kfm0<K6aP000000a/K60`3>c/h20=KF
eP030000003Ng]h0g]kN00L0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@2m_Kd0]KFe00<0oooo0`2][Jd8
034a<@L0>CTi0`2][JdH0?ooo`060?Ogm`2UYJD0@T9203Ti>@0a<C40>CTi0P12@T800`1:BTX0DU9B
05YJFP0206=SH`<0Jf][00@0Lg=c07]kN`1kNg/0Ng]k1024Q8@508b<S0030:FUY@2<S8`0YJFU00<0
S8b<0`24Q8@0101kNg/0Lg=c06][J`2UYJE20?ooo`030:FUY@3oool0oooo0:<0oooo000L0?ooo`07
0:FUY@1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe0080_Kfm0`36a/H3
0<k>cP<0e]KF00<0g]kN0=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP070<k>cP36a/H0
_Kfm0;fm_@2LW9`0[Jf]0:FUY@030:f][@D0<C4a0`0i>CT90492@P0304Y:BP12@T80[Jf]0080[Jf]
00<0moOg0?ooo`3oool04`3oool01P3_knl0YJFU0492@P0i>CT0<C4a03Ti>@80@T9200<0BTY:059B
DP1JFUX00P1SHf<206][J`0407=cL`1kNg/0Ng]k07]kN`80Q8B4100000000`2<S8`0YJFU08b<S005
0:FUY@<0S8b<0P24Q8@0101kNg/0Lg=c06][J`2UYJDl0?ooo`d0YJFUW`3oool001`0oooo00L0YJFU
05YJFP1SHf<0Lg=c07]kN`24Q8@0S8b<00<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0
e]KF2@3Ng]h30=KFeP070<k>cP36a/H0_Kfm09bLW02<S8`0Q8B405YJFP06034a<@0303Ti>@12@T80
@T9200D0@T921@1:BTX01P12@T80BTY:04Y:BP1:BTX0YJFU0:f][@80moOg3`3oool20>o_k`050>OW
i`2e]KD0[Jf]09bLW00i>CT00P0a<C430492@P0304Y:BP1BDU80FUYJ0080Hf=S00<0Jf][07=cL`1c
Lg<00P1kNg/208B4Q00300000024Q8@0S8b<0080S8b<00<000000:FUY@2UYJD01P2UYJD308b<S080
Q8B400<0Ng]k07=cL`2UYJD0>P3oool30:FUY@/0FUYJ0`2UYJFM0?ooo`00703oool20:FUY@0406][
J`1cLg<0Q8B408b<S0<0W9bL00<0YJFU0;Fe]@2m_Kd00P2m_Kd20<K6aP<0c/k>0`3Fe]H;0=kNgP80
e]KF00H0c/k>0<K6aP2m_Kd0W9bL0;Fe]@2LW9`2059BDP@0<C4a00<0>CTi0492@P12@T800`12@T83
04Y:BPL0DU9B00D0BTY:059BDP1BDU80YJFU0;Fe]@020?Ogm`T0oooo00h0moOg0>o_k`3WinL0g]kN
0<K6aP2e]KD0YJFU09bLW02<S8`0BTY:0492@P0i>CT0<C4a03Ti>@80@T9200<0BTY:059BDP1JFUX0
0P1SHf<01@1[Jf/0Lg=c07=cL`1cLg<0Ng]k0080Q8B400<0000008B4Q02<S8`00P2<S8`20:FUY@06
0000002UYJD0YJFU0;fm_@2UYJD0_Kfm0`2UYJD308b<S00408B4Q01kNg/0Lg=c0:FUYCP0oooo0`2U
YJD805YJFPL0Hf=S0`2UYJFK0?ooo`007@3oool01P2UYJD0FUYJ06][J`1kNg/0Q8B408b<S0<0W9bL
00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF1`3Ng]h30=KFeP80c/k>00<0a/K60;fm_@2L
W9`00P2m_Kd01P2e]KD0W9bL05YJFP1BDU80<C4a03Ti>@@0@T920`1:BTX3059BDPL0FUYJ0P1BDU82
05YJFP030:FUY@2e]KD0kno_0080moOg0`3oool02P3gmoL0kno_0>OWi`3Ng]h0a/K60;Fe]@2UYJD0
W9bL08B4Q01JFUX2059BDP0604Y:BP12@T80BTY:03Ti>@0a<C40>CTi0P12@T80101:BTX0DU9B05YJ
FP1SHf<206][J`80Lg=c00D0Ng]k08B4Q024Q8@0Q8B40000000308b<S0<0YJFU00<0_Kfm0:FUY@2m
_Kd0102m_Kd30:FUY@80S8b<00@0Q8B407]kN`1cLg<0YJFU=P3oool30:FUY@D0FUYJ0`1SHf<306][
J`L0Lg=c00@0Jf][0:FUY@2UYJD0YJFUV@3oool001d0oooo0P2UYJD0101cLg<0Ng]k08B4Q02<S8`2
09bLW0030:FUY@2e]KD0]KFe0080_Kfm0P36a/H30<k>cP<0e]KF2@3Ng]h30=KFeP040<k>cP36a/H0
_Kfm09bLW080a/K600<0_Kfm07]kN`1kNg/00P0i>CT30492@P80BTY:0`1BDU8305YJFPT0Hf=S0P1J
FUX0101SHf<0YJFU0;Fe]@3WinL30>o_k`070=kNgP36a/H0]KFe0:FUY@2LW9`0Q8B406=SH`02059B
DP0304Y:BP12@T80@T9200@0BTY:0`0i>CT01P12@T80BTY:04Y:BP1BDU80FUYJ06=SH`80Jf][00<0
Lg=c07]kN`1kNg/00`24Q8@00`000000S8b<08b<S0030:FUY@T0_Kfm0`2UYJD01@2<S8`0Q8B408B4
Q01kNg/0YJFU03D0oooo0P2UYJD605YJFP0406=SH`1[Jf/0Jf][06][J`@0Lg=c1@1kNg/407=cL`80
YJFUV03oool001h0oooo0P2UYJD00`1cLg<0Ng]k08b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0
a/K60`3>c/h30=KFePL0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@2LW9`0e]KF0080c/k>00<0a/K608B4
Q024Q8@00`12@T8204Y:BP80DU9B0`1JFUX406=SH`H0Jf][1@1SHf<0101cLg<0YJFU0:f][@2][Jd2
0:FUY@0309bLW024Q8@0Hf=S0080FUYJ00<0BTY:0492@P12@T80101:BTX305YJFP0804Y:BP0i>CT0
<C4a03Ti>@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Ng]k0P24Q8@00`2<S8`0
000008b<S0030:FUY@D0_Kfm00<0g]kN0;fm_@3Ng]h00`2m_Kd30:FUY@0408b<S024Q8@0Ng]k0:FU
YC@0oooo0P2UYJD605YJFP0306=SH`1[Jf/0Lg=c00<0Lg=c0`1kNg/708B4Q080Ng]k00<0Lg=c0:FU
Y@2UYJD0U`3oool001l0oooo0P2UYJD00`1cLg<0Q8B408b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm
_@<0a/K60`3>c/h30=KFeP030=kNgP3Fe]H0g]kN00D0e]KF00H0c/k>0<K6aP2m_Kd0W9bL0=KFeP3>
c/h20=KFeP030<k>cP2<S8`0@T920080@T9200<0BTY:059BDP1BDU800P1JFUX406=SH`<0Jf][1`1c
Lg<206][J`@0Hf=S0`1BDU8205YJFP03059BDP12@T80BTY:00@0BTY:00P0DU9B05YJFP1BDU80DU9B
05YJFP1SHf<0FUYJ059BDP80>CTi00L0@T9204Y:BP1:BTX0DU9B05YJFP1SHf<0Jf][0080Lg=c0P1k
Ng/208B4Q080S8b<00@000000:FUY@2UYJD0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP040=kNgP<0_Kfm
0P2UYJD0102<S8`0Q8B407]kN`2UYJDc0?ooo`80YJFU1@1JFUX00`1SHf<0Jf][06][J`0207=cL`<0
Ng]k0`24Q8@708b<S0<0Q8B400<0Ng]k0:FUY@2UYJD0UP3oool00200oooo0P2UYJD00`1kNg/0Q8B4
08b<S00209bLW0030:FUY@2e]KD0]KFe0080_Kfm0`36a/H30<k>cPL0e]KF0`3>c/h01036a/H0_Kfm
09bLW03Fe]H20<k>cP040=KFeP3>c/h0e]KF0:FUY@80@T920P1:BTX2059BDP0305YJFP1SHf<0Hf=S
0080Hf=S0`1[Jf/807=cL`<0Jf][00<0Hf=S05YJFP1:BTX00`12@T8404Y:BP03059BDP1JFUX0FUYJ
0080DU9B101JFUX306=SH`04059BDP12@T80>CTi0492@P80BTY:00@0DU9B05YJFP1SHf<0Hf=S0P1c
Lg<00`1kNg/0Q8B408B4Q00308b<S0030000002UYJD0YJFU00<0_Kfm00<0g]kN0000003Ng]h01P3N
g]h30;fm_@050:FUY@2<S8`0Q8B408B4Q02UYJD0<P3oool20:FUY@@0FUYJ0P1SHf<00`1[Jf/0Lg=c
07=cL`0207]kN`<0Q8B40`2<S8`909bLW00308b<S024Q8@0Ng]k0080YJFUU@3oool00240oooo0P2U
YJD0101kNg/0S8b<09bLW02LW9`20:FUY@80]KFe0P2m_Kd30<K6aP<0c/k>00D0e]KF0<k>cP3Fe]H0
c/k>0=KFeP030<k>cP060<K6aP2m_Kd0W9bL0<K6aP3>c/h0e]KF0P3>c/h01P2m_Kd0YJFU0492@P12
@T80BTY:059BDP<0FUYJ0P1SHf<306][J`<0Lg=c1@1kNg/01024Q8@0Ng]k07]kN`1kNg/207=cL`80
Jf][00<0Hf=S059BDP1:BTX00P1BDU801@1JFUX0DU9B059BDP1JFUX0Hf=S00<0FUYJ101SHf<306][
J`0306=SH`1JFUX0@T920080@T9200@0BTY:059BDP1JFUX0Hf=S0P1[Jf/00`1cLg<0Ng]k07]kN`02
08B4Q0<0S8b<00<000000:FUY@2UYJD00P2m_Kd00`000000g]kN0;fm_@030=kNgP030;fm_@3Ng]h0
_Kfm0080_Kfm00L0YJFU08b<S024Q8@0Q8B406=SH`2UYJD0[Jf]0300oooo0P2UYJD405YJFP0406=S
H`1[Jf/0Lg=c07=cL`80Ng]k0P24Q8@308b<S0h0W9bL0P2<S8`00`2][Jd0YJFU0?ooo`2C0?ooo`00
8P3oool20:FUY@0508B4Q02<S8`0W9bL09bLW02UYJD00P2e]KD30;fm_@<0a/K61`3>c/h30<K6aP0;
0;fm_@2LW9`0W9bL0;Fe]@2m_Kd0a/K60<k>cP3Fe]H0c/k>0:FUY@12@T800P1:BTX00`1BDU80FUYJ
05YJFP0206=SH`<0Jf][0`1cLg<307]kN`0308B4Q01kNg/0Q8B40080Q8B400L0Ng]k08B4Q01kNg/0
Ng]k07=cL`1[Jf/0Hf=S0080DU9B00<0FUYJ06=SH`1JFUX00P1JFUX506=SH`@0Jf][0`1cLg<207]k
N`070492@P0i>CT0@T9204Y:BP1BDU80FUYJ06=SH`0206][J`0407=cL`1kNg/0Q8B408B4Q0<0S8b<
0P2UYJD4000000T0g]kN0`2m_Kd01`2UYJD0S8b<08B4Q01SHf<0FUYJ0:FUY@2][Jd0;P3oool20:FU
Y@@0FUYJ00D0Hf=S06][J`1cLg<0Lg=c07]kN`0208B4Q080S8b<1`2LW9`70:FUY@D0W9bL00<0S8b<
0:f][@2UYJD0T`3oool002<0oooo0P2UYJD01P2][Jd0W9bL09bLW02LW9`0YJFU0;Fe]@@0_Kfm0`36
a/H50<k>cP<0a/K600X0_Kfm0;Fe]@2][Jd0YJFU06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0P12@T82
04Y:BP04059BDP1JFUX0Hf=S06=SH`<0Jf][0`1cLg<307]kN`T0Q8B40P1kNg/0101cLg<0Jf][05YJ
FP1JFUX506=SH`D0Jf][201cLg<01P1SHf<0@T9204Y:BP1:BTX0DU9B05YJFP80Hf=S00<0Jf][07=c
L`1kNg/00`24Q8@208b<S0<0YJFU0`2m_Kd;0=kNgP80_Kfm00H0YJFU08b<S024Q8@0Jf][07]kN`1S
Hf<20:FUY@030:f][@3oool0oooo02X0oooo00<0YJFU05YJFP1JFUX00`1JFUX00`1SHf<0Jf][07=c
L`0207]kN`80Q8B400<0S8b<09bLW02LW9`01@2LW9`90:FUY@D0W9bL00<0Q8B40:FUY@3oool0TP3o
ool002D0oooo00<0YJFU0:f][@2][Jd00P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP02
0;fm_@030<K6aP2m_Kd0]KFe00<0oooo00H0[Jf]03Ti>@1JFUX0Jf][07]kN`24Q8@20492@P0404Y:
BP1BDU80FUYJ05YJFP80Hf=S00@0Jf][07=cL`1cLg<0Lg=c0`1kNg/408B4Q00308b<S024Q8@0S8b<
00@0S8b<0`24Q8@0101kNg/0Lg=c06][J`1SHf<506][J`X0Lg=c00L0Ng]k08B4Q024Q8@0Q8B408b<
S012@T80BTY:0080DU9B00H0FUYJ06=SH`1SHf<0Jf][07=cL`1kNg/208B4Q0<0S8b<0`2UYJD30;fm
_@L0g]kN0`2m_Kd20:FUY@0308b<S024Q8@0Jf][0080Q8B400D0Ng]k06=SH`1JFUX0YJFU0:f][@0C
0?ooo`030:f][@3oool0oooo01@0oooo0P2UYJD305YJFP0606=SH`1[Jf/0Lg=c07=cL`1kNg/0Q8B4
0`2<S8`509bLW0<0YJFU1@2e]KD00`2m_Kd0]KFe0;Fe]@030;Fe]@80YJFU0P2LW9`00`2][Jd0YJFU
0?ooo`2A0?ooo`009`3oool00`2UYJD0[Jf]0:f][@0209bLW080YJFU0`2e]KD30;fm_@040;Fe]@2m
_Kd0]KFe0;Fe]@D0oooo00D0[Jf]034a<@0a<C40DU9B03Ti>@030492@P0304Y:BP1BDU80FUYJ0080
Hf=S0P1[Jf/207=cL`<0Ng]k1024Q8@908b<S0<0Q8B400@0Ng]k07=cL`1[Jf/0Jf][0P1cLg<407]k
N`<0Lg=c0P1kNg/208B4Q00508b<S02LW9`0W9bL08B4Q02LW9`00P2UYJD3059BDP0405YJFP1SHf<0
Jf][07=cL`80Ng]k0P24Q8@208b<S0<0YJFU0`2m_Kd90=kNgP<0_Kfm00@0YJFU08b<S024Q8@0Jf][
0P2<S8`01024Q8@0Ng]k07]kN`1SHf<20:FUY@030:f][@3oool0oooo00T0oooo3@2][Jd@0?ooo`03
0:FUY@1JFUX0FUYJ0080FUYJ00<0Hf=S06][J`1cLg<00P1kNg/00`24Q8@0S8b<08b<S00509bLW0<0
YJFU0`2e]KD00`2m_Kd0]KFe0;fm_@020;fm_@030;Fe]@2m_Kd0]KFe0080]KFe00D0YJFU09bLW02L
W9`0W9bL0:FUY@2B0?ooo`00:@3oool00`2UYJD0[Jf]0;Fe]@050;Fe]@030;fm_@2e]KD0_Kfm0080
]KFe1`3oool01@2][Jd0<C4a034a<@0a<C40>CTi0080@T9200<0BTY:059BDP1JFUX00P1SHf<306][
J`0407=cL`1kNg/0Ng]k07]kN`@000001@2<S8`00`2UYJD0S8b<0:FUY@0308b<S0<0Q8B400<0Lg=c
06][J`1kNg/00P24Q8@208b<S00308B4Q01kNg/0Ng]k0080Q8B400D0S8b<09bLW02LW9`0S8b<09bL
W0030:f][@040;fm_@3WinL0[Jf]0:FUY@80DU9B00H0FUYJ06=SH`1SHf<0Jf][07=cL`1kNg/208B4
Q0<0S8b<0`2UYJD30;fm_@L0g]kN0`2m_Kd01@2UYJD0S8b<08B4Q01[Jf/0_Kfm0080YJFU00@0S8b<
08B4Q024Q8@0Ng]k0P1SHf<20:FUY@030:f][@3oool0oooo00D0oooo0`2][Jd;034a<@<0[Jf]3P3o
ool00`2UYJD0FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B408b<S02LW9`0102L
W9`30:FUY@<0]KFe2@2m_Kd30;Fe]@040:FUY@2LW9`0W9bL0:FUYI80oooo000_0?ooo`030:f][@3o
ool0oooo00/0oooo00D0[Jf]034a<@0a<C40<C4a03Ti>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S
0P1[Jf/01@1cLg<0Ng]k07]kN`1kNg/0000000<0Q8B400D0S8b<0000002<S8`0YJFU08b<S0050:FU
Y@<0S8b<0P24Q8@01@1kNg/0Q8B407]kN`1kNg/0Q8B400@0S8b<0`2LW9`01`2UYJD0[Jf]0;Fe]@2e
]KD0a/K60>OWi`3_knl00`3gmoL01`3_knl0[Jf]0:FUY@1:BTX0DU9B05YJFP1SHf<00P1[Jf/0101c
Lg<0Ng]k08B4Q024Q8@308b<S0<0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP050;fm_@060:FUY@2<S8`0
Q8B406][J`2m_Kd0YJFU0P2m_Kd0102UYJD0S8b<08b<S024Q8@207]kN`0406=SH`1JFUX0YJFU0:f]
[@@0oooo0`2][Jd8034a<@L0>CTi0`2][Jd;0?ooo`80YJFU0`1JFUX01@1SHf<0Jf][07=cL`1kNg/0
Q8B40080S8b<0`2LW9`30:FUY@<0]KFe102m_Kd00`36a/H0_Kfm0<K6aP040<K6aP@0_Kfm00D0]KFe
0:FUY@2LW9`0]KFe0:f][@2A0?ooo`00?@3oool0102][Jd0<C4a034a<@0a<C430492@P0304Y:BP1B
DU80FUYJ0080Hf=S00<0Jf][07=cL`1cLg<00P1kNg/010000000Q8B408B4Q024Q8@308b<S0030000
002UYJD0YJFU00H0YJFU0`2<S8`208B4Q00407=cL`1kNg/0S8b<08b<S080W9bL0P2UYJD0202][Jd0
]KFe0;Fe]@36a/H0g]kN0>OWi`3_knl0moOg1P3oool00`3gmoL0[Jf]0:FUY@02059BDP0405YJFP1S
Hf<0Jf][07=cL`80Ng]k0P24Q8@308b<S0<0YJFU1`2m_Kd30:FUY@0408b<S024Q8@0Jf][0;fm_@80
YJFU00<0_Kfm0:FUY@2m_Kd00P2UYJD00`2<S8`0Q8B408B4Q00207]kN`0306=SH`2UYJD0YJFU00@0
[Jf]1@0a<C4303Ti>@/0@T9200<0YJFU0:f][@2][Jd02@3oool01P2UYJD0FUYJ05YJFP1JFUX0Hf=S
06][J`80Lg=c00<0Ng]k08B4Q02<S8`0102LW9`20:FUY@<0]KFe102m_Kd90<K6aP@0_Kfm00@0]KFe
0:FUY@2LW9`0[Jf]T@3oool003d0oooo00@0[Jf]034a<@0a<C40<C4a0P12@T800`1:BTX0DU9B05YJ
FP0206=SH`0706][J`1cLg<0Lg=c07=cL`1kNg/0Q8B40000000208B4Q0<0S8b<1@2UYJD00`2m_Kd0
YJFU0;fm_@020:FUY@0509bLW02<S8`0S8b<08b<S024Q8@00P2LW9`02P24Q8@0W9bL0:f][@2e]KD0
_Kfm0<k>cP3Ng]h0inOW0>o_k`3gmoL;0?ooo`070?Ogm`2][Jd0YJFU059BDP1JFUX0Hf=S06][J`02
07=cL`80Ng]k0P24Q8@308b<S0<0YJFU00D0_Kfm0:FUY@2m_Kd0YJFU0;fm_@030:FUY@0608b<S024
Q8@0Jf][08b<S02UYJD0_Kfm0P2UYJD40;fm_@030:FUY@2<S8`0S8b<0080Q8B400@0Ng]k06=SH`1J
FUX0DU9B1`0a<C400`0i>CT0@T920492@P050492@PD0BTY:1012@T800`2UYJD0[Jf]0?ooo`070?oo
o`0:0:FUY@1JFUX0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0Q8B408b<S0D0W9bL00@0YJFU0;Fe]@2e
]KD00000102m_Kd20<K6aP0600000036a/H0a/K60<k>cP36a/H0c/k>0`36a/H30;fm_@040;Fe]@2U
YJD0W9bL0:f][I40oooo000m0?ooo`040:f][@0a<C40<C4a03Ti>@80@T9200@0BTY:059BDP1JFUX0
Hf=S0P1[Jf/207=cL`0507]kN`24Q8@0Q8B400000024Q8@00`2<S8`30:FUY@030;fm_@2UYJD0_Kfm
00@0_Kfm0P2UYJD00`2LW9`0S8b<08b<S00308B4Q00609bLW02e]KD0g]kN0>OWi`3_knl0moOg4@3o
ool01`2][Jd0YJFU059BDP1JFUX0Hf=S06][J`1cLg<00P1kNg/308B4Q0<0S8b<1`2UYJD308b<S008
08B4Q01[Jf/0Jf][07]kN`24Q8@0S8b<0:FUY@2m_Kd20:FUY@030;fm_@2UYJD0_Kfm0080YJFU0P2<
S8`01024Q8@0Ng]k07]kN`1SHf<2059BDP@0<C4a00<0>CTi0492@P12@T800`12@T8304Y:BPL0DU9B
0P1:BTX00`12@T80YJFU0:f][@070?ooo`0:0:FUY@1JFUX0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0
Q8B408b<S0@0W9bL00D0YJFU0;Fe]@2e]KD0]KFe000000030;fm_@<0a/K600<000000<K6aP3>c/h0
103>c/h30<K6aP80_Kfm00@0]KFe0:FUY@2LW9`0[Jf]T@3oool003d0oooo00@0[Jf]034a<@0a<C40
>CTi0P12@T80101:BTX0DU9B05YJFP1SHf<206][J`0307=cL`1kNg/0Ng]k0080Q8B400@0000008b<
S02<S8`0S8b<0`2UYJD80;fm_@050;Fe]@2UYJD0YJFU0:FUY@2<S8`00`24Q8@00`2][Jd0inOW0?Og
m`0E0?ooo`<0YJFU0P1SHf<00`1[Jf/0Lg=c07]kN`0408B4Q0<0S8b<1@2UYJD208b<S0040:f][@2U
YJD0YJFU0:f][@80YJFU00@0Ng]k08B4Q02<S8`0YJFU0P2m_Kd00`2UYJD0_Kfm0;fm_@020;fm_@80
YJFU00H0S8b<08B4Q024Q8@0Ng]k06=SH`1JFUX2034a<@0303Ti>@12@T80@T920080@T920`1:BTX3
059BDPL0FUYJ0`1BDU800`1:BTX0YJFU0:f][@060?ooo`050:FUY@1JFUX0FUYJ05YJFP1[Jf/00P1c
Lg<00`1kNg/0Q8B408b<S00309bLW080YJFU0P2e]KD0102m_Kd000000;fm_@2m_Kd30<K6aP030<k>
cP000000c/k>00H0c/k>0`36a/H20;fm_@030;Fe]@2UYJD0[Jf]0940oooo000m0?ooo`080:f][@0a
<C40<C4a03Ti>@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Ng]k0P24Q8@00`00
0000S8b<08b<S0030:FUY@D0_Kfm00<0g]kN0;fm_@3Ng]h00P2m_Kd02P2e]KD0YJFU0:FUY@2UYJD0
S8b<08B4Q02<S8`0]KFe0>o_k`3gmoLG0?ooo`<0YJFU00@0Hf=S06][J`1cLg<0Lg=c0P1kNg/408B4
Q00308b<S024Q8@0S8b<0080Q8B400<0[Jf]0:FUY@2UYJD0103oool20:FUY@0606][J`1kNg/0Q8B4
08b<S02UYJD0_Kfm0P2UYJD40;fm_@040:FUY@2<S8`0S8b<08B4Q080Ng]k0P0i>CT30492@P80BTY:
0`1BDU8305YJFPT0Hf=S00D0FUYJ059BDP1:BTX0YJFU0:f][@030?ooo`<0YJFU0`1JFUX01@1[Jf/0
Lg=c07]kN`24Q8@0S8b<00<0W9bL0`2UYJD01@2e]KD0_Kfm0;fm_@000000_Kfm00<0a/K60P3>c/h0
1P000000c/k>0<k>cP3Fe]H0c/k>0=KFeP<0c/k>0`36a/H0102m_Kd0]KFe0:FUY@2][JfA0?ooo`00
?@3oool00`2][Jd0<C4a034a<@020492@P0504Y:BP1BDU80FUYJ06=SH`1[Jf/00P1cLg<207]kN`80
Q8B400<0S8b<0000002<S8`00`2UYJD20;fm_@030000003Ng]h0_Kfm00D0g]kN0`2m_Kd20:FUY@06
08b<S024Q8@0Q8B40;Fe]@3_knl0moOg6@3oool30:FUY@0406=SH`1[Jf/0Lg=c07=cL`<0Ng]k0`24
Q8@0101kNg/0YJFU0:FUY@2UYJD70?ooo`070:f][@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@020;fm
_@80YJFU00<0_Kfm0:FUY@2m_Kd00P2UYJD00`2<S8`0Q8B408B4Q0030492@P80BTY:0P1BDU8305YJ
FP@0Hf=S1`1[Jf/306=SH`80FUYJ00<0YJFU0:f][@2][Jd00P2UYJD207=cL`80FUYJ00H0Hf=S06][
J`1cLg<0Ng]k08B4Q02<S8`309bLW080YJFU00D0]KFe0;fm_@2m_Kd0_Kfm000000030<K6aP<0c/k>
00<000000<k>cP3Fe]H0103Fe]H30<k>cP80a/K600@0_Kfm0;Fe]@2UYJD0[Jf]T@3oool003d0oooo
0P2][Jd0200a<C40@T920492@P1:BTX0DU9B05YJFP1SHf<0Jf][0P1cLg<00`1kNg/0Q8B408B4Q003
08b<S0030000002UYJD0YJFU0080_Kfm00<000000=kNgP3Ng]h01`3Ng]h02@2m_Kd0]KFe0;fm_@2U
YJD0S8b<08B4Q02UYJD0]KFe0?Ogm`0L0?ooo`d0YJFU2`3oool30:FUY@0407]kN`24Q8@0S8b<0:FU
Y@80_Kfm00<0YJFU0;fm_@2m_Kd00P2m_Kd00`2UYJD0S8b<0492@P020492@P0304Y:BP1BDU80DU9B
0080FUYJ101SHf<306][J`L0Lg=c0`1[Jf/206=SH`<0FUYJ0P1cLg<207]kN`80FUYJ00H0Hf=S07=c
L`1cLg<0Ng]k08B4Q02<S8`309bLW0030:FUY@2e]KD0]KFe00<0_Kfm200000070=KFeP<0c/k>00D0
a/K60;fm_@2m_Kd0]KFe0:f][@2A0?ooo`00?P3oool0202][Jd0<C4a03Ti>@12@T80BTY:059BDP1J
FUX0Hf=S0P1[Jf/00`1cLg<0Ng]k07]kN`0208B4Q0<0S8b<100000020;fm_@030=kNgP2m_Kd0g]kN
0080g]kN00<0_Kfm0=kNgP2m_Kd00P2m_Kd01P2UYJD0S8b<08B4Q02<S8`0[Jf]0>o_kb<0oooo00<0
YJFU0?ooo`3oool04@3oool20:FUY@0606][J`1kNg/0Q8B408b<S02UYJD0_Kfm0P2UYJD0102m_Kd0
YJFU0;fm_@2UYJD20492@P80BTY:0P1BDU800`1JFUX0Hf=S06=SH`0206=SH`<0Jf][2@1cLg<306][
J`0406=SH`12@T80@T9206=SH`80Lg=c00T0W9bL07=cL`1JFUX0FUYJ06=SH`1cLg<0Ng]k08B4Q02<
S8`00`2LW9`0102UYJD0]KFe0;Fe]@2e]KD20;fm_@030<K6aP000000a/K600<0c/k>0P3Fe]H01P00
0000e]KF0=KFeP3Ng]h0e]KF0=kNgP<0e]KF0`3>c/h01036a/H0_Kfm0;Fe]@2e]KFA0?ooo`00?P3o
ool0202][Jd0<C4a03Ti>@12@T80BTY:059BDP1JFUX0Hf=S0P1[Jf/0101cLg<0Ng]k08B4Q024Q8@3
08b<S0<0YJFU0`2m_Kd90=kNgP80_Kfm00H0]KFe0:FUY@2<S8`0Q8B40:f][@3gmoLh0?ooo`070:f]
[@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@020;fm_@030:FUY@2m_Kd0YJFU0080@T9200<0BTY:059B
DP1JFUX00P1JFUX206=SH`<0Jf][0`1cLg<507]kN`0308B4Q01kNg/0Ng]k00<0Ng]k0P1cLg<00`1[
Jf/0Lg=c07=cL`0309bLW00807]kN`1JFUX0FUYJ06][J`1cLg<0Ng]k08B4Q02<S8`209bLW080YJFU
0P2e]KD20;fm_@80a/K600@000000<k>cP3>c/h0c/k>0`3Fe]H00`000000e]KF0=kNgP040=kNgP<0
e]KF0P3>c/h01036a/H0_Kfm0;Fe]@2e]KFA0?ooo`00?P3oool20:f][@80@T9200L0DU9B05YJFP1S
Hf<0Hf=S06][J`1cLg<0Ng]k00<0Q8B40P2<S8`30:FUY@<0_Kfm2`3Ng]h0102m_Kd0]KFe0:FUY@2<
S8`20:f][C/0oooo0P2UYJD01`1[Jf/0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD00P12@T8204Y:BP03
059BDP1JFUX0FUYJ0080Hf=S0`1[Jf/307=cL`<0Ng]k00<0Q8B407]kN`24Q8@00P24Q8@00`1kNg/0
Q8B407]kN`0207]kN`0407=cL`1[Jf/0Ng]k07]kN`<0W9bL00P0Q8B405YJFP1JFUX0Jf][07=cL`1k
Ng/0Q8B408b<S080W9bL0P2UYJD00`2e]KD0_Kfm0;fm_@030<K6aP030000003>c/h0c/k>00<0e]KF
00<0g]kN0000003Ng]h01P3Ng]h30=KFeP050<k>cP36a/H0_Kfm0<K6aP2e]KD0T@3oool003l0oooo
00H0[Jf]034a<@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Q8B40`2<S8`30:FU
Y@<0_Kfm1`3Ng]h30;fm_@80YJFU00@0S8b<08B4Q02UYJD0moOg?03oool0202][Jd0YJFU06=SH`1k
Ng/0Q8B408b<S02UYJD0_Kfm0P12@T8204Y:BP04059BDP1JFUX0Hf=S06=SH`<0Jf][0`1cLg<307]k
N`T0Q8B40`1kNg/00`1cLg<0Q8B408B4Q00209bLW0090:FUY@2<S8`0W9bL05YJFP1SHf<0Lg=c07]k
N`24Q8@0S8b<00<0W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd20<K6aP040000003>c/h0c/k>0<k>cP<0
e]KF00<000000=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP050<k>cP36a/H0_Kfm0;fm
_@2e]KD0TP3oool003l0oooo0P2][Jd01`12@T80BTY:059BDP1JFUX0Hf=S06][J`1cLg<00P1kNg/2
08B4Q080S8b<0`2UYJD30;fm_@T0g]kN0`2m_Kd0102UYJD0S8b<0:f][@2UYJDn0?ooo`060:f][@0i
>CT0FUYJ06][J`1cLg<0>CTi0P12@T80101:BTX0DU9B05YJFP1JFUX206=SH`0406][J`1cLg<0Lg=c
07=cL`<0Ng]k1024Q8@00`2<S8`0Q8B408b<S00408b<S0@0Q8B400<0Ng]k07=cL`2<S8`00P2UYJD0
2@2e]KD0W9bL09bLW01JFUX0Hf=S07=cL`1kNg/0Q8B408b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm
_@<0a/K60`3>c/h30=KFePT0g]kN0`3Fe]H0103>c/h0a/K60;fm_@2e]KFB0?ooo`00@03oool01@2]
[Jd0YJFU0492@P1:BTX0FUYJ0080Hf=S00<0Jf][07=cL`1kNg/00P24Q8@308b<S0<0YJFU0`2m_Kd7
0=kNgP<0_Kfm00@0YJFU08b<S02][Jd0YJFU?`3oool01@2][Jd0<C4a034a<@1BDU80>CTi00<0@T92
00<0BTY:059BDP1JFUX00P1SHf<206][J`80Lg=c0P1kNg/40000000308B4Q02<S8`0S8b<00L0S8b<
1024Q8@0301kNg/0W9bL0;Fe]@2e]KD0_Kfm0<K6aP3>c/h0FUYJ06][J`1cLg<0Q8B408b<S0<0W9bL
00<0YJFU0;Fe]@2m_Kd00P2m_Kd20<K6aP<0c/k>0`3Fe]H;0=kNgP80e]KF00@0c/k>0<K6aP36a/H0
]KFeTP3oool00440oooo00H0[Jf]0:FUY@12@T80DU9B05YJFP1SHf<206][J`0407=cL`1kNg/0Q8B4
08B4Q0<0S8b<0`2UYJD30;fm_@030=kNgP2m_Kd0g]kN00D0_Kfm00@0YJFU08b<S02][Jd0YJFU@03o
ool01@2][Jd0<C4a034a<@0a<C40>CTi0080@T9200<0BTY:059BDP1JFUX00P1SHf<306][J`0407=c
L`1kNg/0Ng]k000000@0Q8B400<0000008b<S02<S8`00P2<S8`00`2UYJD0S8b<0:FUY@0308b<S0<0
Q8B400@0Ng]k08B4Q02UYJD0YJFU0P2e]KD01`2LW9`0]KFe05YJFP1[Jf/0Ng]k08B4Q02<S8`00`2L
W9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H70=kNgP<0e]KF0P3>c/h00`36a/H0_Kfm
0;Fe]@2C0?ooo`00@P3oool0202][Jd0YJFU04Y:BP1BDU80FUYJ06=SH`1[Jf/0Lg=c0P1kNg/208B4
Q0<0S8b<0`2UYJD70;fm_@<0YJFU00<0S8b<0:f][@2UYJD0@@3oool01@2][Jd0<C4a034a<@0a<C40
>CTi0080@T9200<0BTY:059BDP1JFUX00P1SHf<206][J`0407=cL`1kNg/0Ng]k000000@0Q8B40P2<
S8`00`000000YJFU08b<S0050:FUY@<0S8b<0P24Q8@03@1kNg/0W9bL0;Fe]@2e]KD0_Kfm0<K6aP3>
c/h0e]KF05YJFP1cLg<0Ng]k08B4Q02<S8`00P2LW9`00`2UYJD0]KFe0;Fe]@020;fm_@80a/K60`3>
c/h30=KFePT0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e]KFC0?ooo`00@`3oool01P2][Jd0YJFU04Y:
BP1JFUX0Hf=S06][J`80Lg=c0P1kNg/208B4Q0<0S8b<0`2UYJD01@2m_Kd0YJFU0;fm_@2UYJD0_Kfm
00<0YJFU00<0S8b<0:f][@2UYJD0@P3oool0102][Jd0<C4a034a<@0a<C430492@P0304Y:BP1BDU80
FUYJ0080Hf=S00<0Jf][07=cL`1cLg<00P1kNg/010000000Q8B408B4Q024Q8@308b<S0T0YJFU0`2<
S8`308B4Q00608b<S02UYJD0_Kfm0;Fe]@2m_Kd0]KFe0P2UYJD00`1cLg<0Ng]k08b<S00309bLW004
0:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e]KFD
0?ooo`00A03oool01`2][Jd0YJFU059BDP1JFUX0Hf=S06][J`1cLg<00P1kNg/308B4Q0<0S8b<1`2U
YJD308b<S0030:f][@2UYJD0oooo0480oooo00@0[Jf]034a<@0a<C40<C4a0P12@T800`1:BTX0DU9B
05YJFP0206=SH`0706][J`1cLg<0Lg=c07=cL`1kNg/0Q8B40000000208B4Q0<0S8b<1@2UYJD00`2m
_Kd0YJFU0;fm_@030:FUY@<0S8b<00<0Q8B407]kN`1cLg<00P2UYJD0102][Jd0oooo0?ooo`3oool2
0:FUY@0307=cL`24Q8@0S8b<00<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF00<0
g]kN0=KFeP3Ng]h01@3Fe]H0103>c/h0a/K60<K6aP2e]KFE0?ooo`00A@3oool20:FUY@06059BDP1S
Hf<0Hf=S06][J`1cLg<0Ng]k1024Q8@308b<S0D0YJFU0P2<S8`00`2][Jd0YJFU0:FUY@140?ooo`04
0:f][@0a<C40<C4a03Ti>@80@T9200@0BTY:059BDP1JFUX0Hf=S0P1[Jf/207=cL`0507]kN`24Q8@0
Q8B400000024Q8@00`2<S8`30:FUY@030;fm_@2UYJD0_Kfm00@0_Kfm0`2UYJD208b<S00408B4Q01k
Ng/0Lg=c0:FUY@H0oooo0P2UYJD00`1kNg/0Q8B408b<S00209bLW0030:FUY@2e]KD0]KFe0080_Kfm
0`36a/H30<k>cPL0e]KF0`3>c/h20<K6aP030;Fe]@3oool0oooo09@0oooo00160?ooo`060:f][@12
@T80BTY:05YJFP1SHf<0Jf][0P1cLg<207]kN`@0Q8B400<0S8b<08B4Q02<S8`00P24Q8@00`2][Jd0
YJFU0:FUY@160?ooo`040:f][@0a<C40<C4a03Ti>@80@T9200@0BTY:059BDP1JFUX0Hf=S0P1[Jf/0
0`1cLg<0Ng]k07]kN`0208B4Q0040000002<S8`0S8b<08b<S0<0YJFU2@2m_Kd30:FUY@0508b<S024
Q8@0Q8B407]kN`2UYJD01`3oool20:FUY@0407]kN`2<S8`0W9bL09bLW080YJFU0P2e]KD20;fm_@<0
a/K60`3>c/h01@3Fe]H0c/k>0=KFeP3>c/h0e]KF00<0c/k>0P36a/H00`2e]KD0oooo0?ooo`2E0?oo
o`00AP3oool0202][Jd0<C4a059BDP12@T80DU9B05YJFP1SHf<0Jf][0P1cLg<307]kN`<0Q8B400@0
Ng]k0:FUY@2UYJD0YJFUB03oool0202][Jd0<C4a034a<@0i>CT0@T9204Y:BP1BDU80FUYJ0P1SHf<0
0`1[Jf/0Lg=c07]kN`0207]kN`80Q8B400<0000008b<S02<S8`00`2UYJD00`2m_Kd000000;fm_@02
0;fm_@030=kNgP2m_Kd0g]kN00<0_Kfm0`2UYJD0102<S8`0Q8B407]kN`2UYJD80?ooo`80YJFU00D0
Q8B408b<S02LW9`0W9bL0:FUY@020;Fe]@<0_Kfm0`36a/H70<k>cP@0a/K600<0]KFe0?ooo`3oool0
UP3oool004H0oooo00<0[Jf]03Ti>@1JFUX00P1SHf<01@12@T80FUYJ06=SH`1SHf<0Jf][0080Lg=c
1P2UYJE:0?ooo`030:f][@0a<C40<C4a0080@T9200D0BTY:059BDP1JFUX0Hf=S06][J`0207=cL`80
Ng]k0P24Q8@208b<S0090000002UYJD0YJFU0:FUY@2m_Kd000000;fm_@3Ng]h0_Kfm00D0g]kN0`2m
_Kd20:FUY@0408b<S024Q8@0Ng]k0:FUY@T0oooo0P2UYJD01P2][Jd0W9bL09bLW02LW9`0YJFU0;Fe
]@@0_Kfm0`36a/H50<k>cP<0a/K600<0_Kfm0;Fe]@3oool0V03oool004D0oooo0P2][Jd00`12@T80
Hf=S06=SH`0207]kN`0708B4Q02<S8`0YJFU0;fm_@2UYJD0FUYJ0:FUY@1?0?ooo`80[Jf]00P0<C4a
0492@P12@T80BTY:059BDP1JFUX0Hf=S06][J`80Lg=c00<0Ng]k08B4Q024Q8@00`2<S8`00`2UYJD0
000000000002000000030;fm_@3Ng]h0g]kN00L0g]kN0`2m_Kd01@2UYJD0S8b<08B4Q02][Jd0YJFU
00/0oooo00<0YJFU0:f][@2][Jd00P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP020;fm
_@030<K6aP2m_Kd0]KFe09/0oooo00150?ooo`0>0:f][@0a<C40@T9206=SH`1BDU80Hf=S07]kN`24
Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S02UYJE@0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJ
FP1SHf<206][J`0307=cL`1kNg/0Ng]k0080Q8B40`2<S8`30:FUY@<0_Kfm00<0g]kN0;fm_@3Ng]h0
0P3Ng]h00`2m_Kd0g]kN0;fm_@020;fm_@050:FUY@2<S8`0Q8B408B4Q02UYJD03P3oool00`2UYJD0
[Jf]0:f][@0209bLW080YJFU0`2e]KD30;fm_@040;Fe]@2m_Kd0]KFe0;Fe]Id0oooo00150?ooo`0>
0:f][@0a<C40@T92059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<08B4Q02UYJE@0?oo
o`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<206][J`0407=cL`1kNg/0Q8B408B4Q0<0
S8b<0`2UYJD30;fm_@T0g]kN0`2m_Kd0102UYJD0S8b<08B4Q02UYJD@0?ooo`030:FUY@2][Jd0]KFe
00D0]KFe00<0_Kfm0;Fe]@2m_Kd00P2e]KFO0?ooo`00A@3oool03P2][Jd0>CTi05YJFP1BDU80Hf=S
07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S02][Jd0YJFUD03oool20:f][@80@T9200L0DU9B05YJ
FP1SHf<0Hf=S06][J`1cLg<0Ng]k00<0Q8B40P2<S8`30:FUY@<0_Kfm2`3Ng]h20;fm_@040:FUY@2<
S8`0[Jf]0:FUYAH0oooo00<0[Jf]0?ooo`3oool0>@3oool00`2UYJD0oooo0?ooo`1W0?ooo`00@03o
ool60:f][@0<0492@P1SHf<0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0YJFUDP3o
ool01P2][Jd0<C4a0492@P1:BTX0DU9B05YJFP80Hf=S00<0Jf][07=cL`1kNg/00P24Q8@308b<S0<0
YJFU0`2m_Kd70=kNgP<0_Kfm0P2UYJD00`2<S8`0Q8B40:FUY@1=0?ooo`d0YJFUH`3oool003h0oooo
0`2][Jd5034a<@0<0492@P1SHf<0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0YJFU
DP3oool20:f][@070492@P1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`0207]kN`80Q8B40P2<S8`30:FU
Y@<0_Kfm2@3Ng]h30;fm_@040:FUY@2<S8`0[Jf]0:FUYD/0oooo0`2UYJD;05YJFP<0YJFUH@3oool0
03`0oooo0`2][Jd7034a<@0<0492@P1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S024
Q8@0YJFUD`3oool01@2][Jd0YJFU0492@P1:BTX0FUYJ0080Hf=S00<0Jf][07=cL`1kNg/00P24Q8@3
08b<S0<0YJFU0`2m_Kd70=kNgP<0_Kfm00@0YJFU08b<S02][Jd0YJFUBP3oool30:FUY@P0FUYJ1`1S
Hf<30:FUYEl0oooo000j0?ooo`<0[Jf]1@0a<C4203Ti>@0?034a<@0i>CT0FUYJ059BDP1SHf<0Ng]k
08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<08B4Q02UYJD0[Jf]05<0oooo00H0[Jf]0:FUY@12@T80DU9B
05YJFP1SHf<206][J`0407=cL`1kNg/0Q8B408B4Q0<0S8b<0`2UYJD30;fm_@030=kNgP2m_Kd0g]kN
00D0_Kfm00@0YJFU08b<S02][Jd0YJFUB@3oool30:FUY@D0FUYJ0`1SHf<306][J`L0Lg=c00@0Jf][
0:FUY@2UYJD0YJFUG@3oool003T0oooo0P2][Jd6034a<@0C03Ti>@12@T80@T92034a<@12@T80Hf=S
059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<06=SH`12@T80YJFU0:f][@1C0?ooo`08
0:f][@2UYJD0BTY:059BDP1JFUX0Hf=S06][J`1cLg<207]kN`80Q8B40`2<S8`30:FUY@L0_Kfm0`2U
YJD00`2<S8`0[Jf]0:FUY@190?ooo`80YJFU1P1JFUX0101SHf<0Jf][06][J`1[Jf/407=cL`D0Ng]k
101cLg<20:FUYE`0oooo000h0?ooo`80[Jf]1P0a<C401P0i>CT0@T920492@P12@T80<C4a0492@P80
Hf=S0P1kNg/02`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S01SHf<0BTY:0492@P2UYJD0[Jf]05<0oooo
00H0[Jf]0:FUY@1:BTX0FUYJ06=SH`1[Jf/207=cL`80Ng]k0P24Q8@308b<S0<0YJFU00D0_Kfm0:FU
Y@2m_Kd0YJFU0;fm_@030:FUY@0308b<S02][Jd0YJFU04T0oooo0P2UYJD605YJFP0306=SH`1[Jf/0
Lg=c00<0Lg=c0`1kNg/708B4Q080Ng]k00<0Lg=c0:FUY@2UYJD0F`3oool003L0oooo0P2][Jd5034a
<@0303Ti>@12@T80@T920080@T920P1:BTX03012@T80Hf=S06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm
0:FUY@2m_Kd0Q8B406=SH`80DU9B00<0BTY:0:FUY@2][Jd0D`3oool01`2][Jd0YJFU059BDP1JFUX0
Hf=S06][J`1cLg<00P1kNg/308B4Q0<0S8b<1`2UYJD308b<S0030:f][@2UYJD0oooo04P0oooo0P2U
YJD505YJFP0306=SH`1[Jf/0Jf][0080Lg=c0`1kNg/308B4Q0L0S8b<0`24Q8@00`1kNg/0YJFU0:FU
Y@1J0?ooo`00=P3oool20:f][@@0<C4a0P0i>CT30492@P80BTY:0P1BDU802`1JFUX0DU9B06=SH`1k
Ng/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0Q8B40080Hf=S00<0FUYJ059BDP1:BTX00P2UYJEC0?oo
o`80YJFU00H0DU9B06=SH`1SHf<0Jf][07=cL`1kNg/408B4Q0<0S8b<1@2UYJD208b<S0030:f][@2U
YJD0YJFU04T0oooo0P2UYJD405YJFP80Hf=S00<0Jf][07=cL`1cLg<00P1kNg/308B4Q0<0S8b<2@2L
W9`00`2<S8`0Q8B407]kN`020:FUYET0oooo000e0?ooo`80[Jf]100a<C40100i>CT0@T920492@P12
@T8204Y:BP80DU9B0`1JFUX206=SH`0707]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S00206][J`<0
Hf=S0P1JFUX20:FUYE<0oooo00H0[Jf]0492@P1:BTX0FUYJ06=SH`1[Jf/207=cL`80Ng]k1024Q8@0
0`2<S8`0Q8B408b<S00208B4Q0030:f][@2UYJD0YJFU04X0oooo0P2UYJD405YJFP0406=SH`1[Jf/0
Lg=c07=cL`80Ng]k0P24Q8@308b<S0h0W9bL0P2<S8`00`2][Jd0YJFU0?ooo`1G0?ooo`00=03oool2
0:f][@@0<C4a00D0>CTi0492@P12@T80@T9204Y:BP02059BDP80FUYJ101SHf<306][J`80Lg=c00<0
_Kfm07=cL`1cLg<00P1cLg<306][J`80Hf=S00<0FUYJ0:FUY@2UYJD0DP3oool0202][Jd0<C4a059B
DP12@T80DU9B05YJFP1SHf<0Jf][0P1cLg<307]kN`<0Q8B400@0Ng]k0:FUY@2UYJD0YJFUB`3oool2
0:FUY@@0FUYJ00D0Hf=S06][J`1cLg<0Lg=c07]kN`0208B4Q080S8b<1`2LW9`70:FUY@D0W9bL00<0
S8b<0:f][@2UYJD0E`3oool001X0oooo00<0YJFU0?ooo`3oool05`3oool00`2][Jd0<C4a034a<@03
034a<@0303Ti>@12@T80@T920080BTY:0P1BDU800`1JFUX0Hf=S06=SH`0206=SH`<0Jf][2@1cLg<3
06][J`80Hf=S00<0DU9B0:FUY@3oool0D@3oool00`2][Jd0>CTi05YJFP0206=SH`050492@P1JFUX0
Hf=S06=SH`1[Jf/00P1cLg<60:FUYDd0oooo00<0YJFU05YJFP1JFUX00`1JFUX00`1SHf<0Jf][07=c
L`0207]kN`80Q8B400<0S8b<09bLW02LW9`01@2LW9`90:FUY@D0W9bL00<0Q8B40:FUY@3oool0EP3o
ool001@0oooo3@2UYJDB0?ooo`80[Jf]0`0a<C401P0i>CT0@T920492@P12@T80BTY:059BDP<0FUYJ
0P1SHf<306][J`<0Lg=c1@1kNg/00`24Q8@0Ng]k07]kN`0307]kN`80Lg=c00@0Jf][06=SH`2UYJD0
YJFUD03oool20:f][@030492@P1SHf<0Hf=S0080Ng]k00L0Q8B408b<S02UYJD0_Kfm0:FUY@1JFUX0
YJFU0540oooo0P2UYJD305YJFP0606=SH`1[Jf/0Lg=c07=cL`1kNg/0Q8B40`2<S8`509bLW0<0YJFU
1@2e]KD00`2m_Kd0]KFe0;Fe]@030;Fe]@80YJFU0P2LW9`00`2][Jd0YJFU0?ooo`1E0?ooo`004P3o
ool30:FUY@/0FUYJ0`2UYJD@0?ooo`030:f][@0a<C40<C4a0080<C4a00<0>CTi0492@P12@T800P1:
BTX00`1BDU80FUYJ05YJFP0206=SH`<0Jf][0`1cLg<307]kN`0308B4Q01kNg/0Q8B40080Q8B400<0
Ng]k08B4Q01kNg/00P1kNg/01@1cLg<0Jf][06=SH`1SHf<0YJFU0500oooo00h0[Jf]034a<@12@T80
Hf=S059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0:FUYE40oooo00<0YJFU05YJFP1J
FUX00P1JFUX00`1SHf<0Jf][07=cL`0207]kN`0308B4Q02<S8`0S8b<00D0W9bL0`2UYJD30;Fe]@03
0;fm_@2e]KD0_Kfm0080_Kfm00<0]KFe0;fm_@2e]KD00P2e]KD01@2UYJD0W9bL09bLW02LW9`0YJFU
05H0oooo000@0?ooo`<0YJFU201JFUX706=SH`<0YJFU3P3oool00`2][Jd0<C4a034a<@02034a<@03
03Ti>@12@T80@T920080BTY:00@0DU9B05YJFP1SHf<0Hf=S0`1[Jf/307=cL`<0Ng]k2@24Q8@307]k
N`0407=cL`1[Jf/0Hf=S0:FUYE00oooo00h0[Jf]034a<@12@T80DU9B06=SH`1kNg/0Q8B408b<S02U
YJD0_Kfm0:FUY@2<S8`0Q8B40:FUYE40oooo00<0YJFU05YJFP1JFUX00P1JFUX00`1SHf<0Jf][07=c
L`0207]kN`0308B4Q02<S8`0W9bL00@0W9bL0`2UYJD30;Fe]@T0_Kfm0`2e]KD0102UYJD0W9bL09bL
W02UYJEF0?ooo`003P3oool30:FUY@D0FUYJ0`1SHf<306][J`L0Lg=c00@0Jf][0:FUY@2UYJD0YJFU
2`3oool20:f][@<0<C4a00D0>CTi0492@P12@T80BTY:059BDP0205YJFP80Hf=S00@0Jf][07=cL`1c
Lg<0Lg=c0`1kNg/408B4Q00308b<S024Q8@0S8b<00@0S8b<1024Q8@00`1kNg/0Lg=c06][J`020:FU
YDl0oooo00h0[Jf]03Ti>@1JFUX0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0[Jf]
0:FUYE00oooo0P2UYJD305YJFP0506=SH`1[Jf/0Lg=c07]kN`24Q8@00P2<S8`309bLW080YJFU00@0
00000;Fe]@2e]KD0]KFe0`2m_Kd00`000000a/K60;fm_@050<K6aP@0_Kfm00D0]KFe0:FUY@2LW9`0
]KFe0:f][@1E0?ooo`003@3oool20:FUY@H0FUYJ00@0Hf=S06][J`1[Jf/0Jf][101cLg<507]kN`@0
Lg=c0P2UYJD:0?ooo`050:f][@0a<C40<C4a034a<@0i>CT00`12@T800`1:BTX0DU9B05YJFP0206=S
H`80Jf][0P1cLg<307]kN`@0Q8B42@2<S8`408B4Q00407]kN`1cLg<0Jf][0:FUYDX0oooo1P2][Jd0
3012@T80Hf=S059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0:FUYE40oooo00H0YJFU
05YJFP1JFUX0FUYJ06=SH`1[Jf/207=cL`0307]kN`24Q8@0S8b<00@0W9bL0P2UYJD00`000000]KFe
0;Fe]@040;fm_@0300000036a/H0a/K600H0a/K6102m_Kd0102e]KD0YJFU09bLW02][JeE0?ooo`00
303oool20:FUY@H0FUYJ00<0Hf=S06][J`1cLg<00`1cLg<307]kN`L0Q8B40P1kNg/00`1cLg<0YJFU
0:FUY@090?ooo`050:f][@0a<C40<C4a034a<@0i>CT00P12@T800`1:BTX0DU9B05YJFP0206=SH`<0
Jf][00@0Lg=c07]kN`1kNg/0Ng]k1000000508b<S0030:FUY@2<S8`0YJFU00<0S8b<0`24Q8@0101k
Ng/0Lg=c06][J`2UYJE80?ooo`<0[Jf]1@0a<C403012@T80Hf=S059BDP1SHf<0Ng]k08B4Q02<S8`0
YJFU0;fm_@2UYJD0S8b<0:FUYE40oooo00X0YJFU05YJFP1JFUX0FUYJ06=SH`1[Jf/0Lg=c07]kN`24
Q8@0S8b<1@2LW9`0102UYJD0]KFe0000002e]KD40;fm_@030<K6aP000000a/K60080a/K600<0c/k>
0<K6aP3>c/h00`36a/H30;fm_@040;Fe]@2UYJD0W9bL0:f][ED0oooo000;0?ooo`80YJFU1@1JFUX0
0`1SHf<0Jf][06][J`0207=cL`<0Ng]k0`24Q8@708b<S0<0Q8B400<0Ng]k0:FUY@2UYJD0203oool0
1@2][Jd0<C4a034a<@0a<C40>CTi0080@T9200<0BTY:059BDP1JFUX00P1SHf<206][J`0507=cL`1k
Ng/0Ng]k07]kN`0000000`24Q8@01@2<S8`0000008b<S02UYJD0S8b<00D0YJFU0`2<S8`208B4Q004
07]kN`1cLg<0Jf][0:FUYDH0oooo0`2][Jd7034a<@0<0492@P1BDU80Hf=S07]kN`24Q8@0S8b<0:FU
Y@2m_Kd0YJFU08b<S024Q8@0YJFUD@3oool02P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k
08B4Q02<S8`409bLW0040:FUY@2e]KD0]KFe000000@0_Kfm0P36a/H00`000000c/k>0<K6aP050<k>
cP<0a/K60P2m_Kd0102e]KD0YJFU09bLW02][JeE0?ooo`002P3oool20:FUY@@0FUYJ0P1SHf<00`1[
Jf/0Lg=c07=cL`0207]kN`<0Q8B40`2<S8`909bLW00308b<S024Q8@0Ng]k0080YJFU1@3oool30:f]
[@<0<C4a0`12@T800`1:BTX0DU9B05YJFP0206=SH`0306][J`1cLg<0Lg=c0080Ng]k00@0000008B4
Q024Q8@0Q8B40`2<S8`00`000000YJFU0:FUY@060:FUY@<0S8b<0P24Q8@00`1kNg/0Lg=c0:FUY@14
0?ooo`<0[Jf]1@0a<C4203Ti>@0?034a<@0i>CT0FUYJ059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm
_@2UYJD0S8b<08B4Q02UYJD0[Jf]0500oooo00D0YJFU05YJFP1JFUX0FUYJ06][J`0207=cL`0307]k
N`24Q8@0S8b<00<0W9bL0P2UYJD20;Fe]@040000002m_Kd0_Kfm0;fm_@<0a/K600<000000<k>cP3>
c/h01P3>c/h30<K6aP80_Kfm00<0]KFe0:FUY@2][Jd0E@3oool000T0oooo00<0[Jf]0:FUY@1JFUX0
0`1JFUX0101SHf<0Jf][07=cL`1cLg<207]kN`80Q8B40`2<S8`>09bLW080S8b<00<0[Jf]0:FUY@2U
YJD0102][Jd5034a<@80@T9200<0BTY:059BDP1JFUX00P1SHf<01`1[Jf/0Lg=c07=cL`1cLg<0Ng]k
08B4Q00000000P24Q8@308b<S0D0YJFU00<0_Kfm0:FUY@2m_Kd00`2UYJD308b<S00408B4Q01kNg/0
Lg=c0:FUYD<0oooo0P2][Jd6034a<@0C03Ti>@12@T80@T92034a<@12@T80Hf=S059BDP1SHf<0Ng]k
08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<06=SH`12@T80YJFU0:f][@1?0?ooo`090:FUY@1JFUX0FUYJ
05YJFP1[Jf/0Lg=c07]kN`24Q8@0S8b<00<0W9bL0`2UYJD00`2e]KD0_Kfm00000007000000<0c/k>
00<0e]KF0<k>cP3Fe]H00`3>c/h30<K6aP040;fm_@2e]KD0YJFU0:f][ED0oooo00080?ooo`80[Jf]
00H0Hf=S05YJFP1JFUX0FUYJ06=SH`1[Jf/207=cL`0307]kN`24Q8@0Q8B40080S8b<1`2LW9`70:FU
Y@D0W9bL00@0S8b<05YJFP0a<C40<C4a1012@T80100i>CT0<C4a034a<@0i>CT20492@P0404Y:BP1B
DU80FUYJ06=SH`80Jf][0P1cLg<01@1kNg/0Q8B408B4Q0000000Q8B400<0S8b<0`2UYJD00`2m_Kd0
YJFU0;fm_@040;fm_@<0YJFU0P2<S8`01024Q8@0Ng]k07=cL`2UYJE20?ooo`80[Jf]1P0a<C401P0i
>CT0@T920492@P12@T80<C4a0492@P80Hf=S0P1kNg/02`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S01S
Hf<0BTY:0492@P2UYJD0[Jf]04h0oooo00T0YJFU05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<
S8`00`2LW9`20:FUY@050;Fe]@2m_Kd0_Kfm0000002m_Kd00`36a/H20<k>cP030000003Fe]H0c/k>
00D0e]KF0`3>c/h20<K6aP040;fm_@2e]KD0YJFU0:f][ED0oooo00080?ooo`030:f][@1SHf<0Hf=S
00<0FUYJ00<0Hf=S06][J`1cLg<00P1kNg/208B4Q00308b<S02LW9`0W9bL00D0W9bL2@2UYJD409bL
W0<0Lg=c00<0>CTi04Y:BP1:BTX00`12@T82034a<@0703Ti>@12@T80@T9204Y:BP1BDU80FUYJ06=S
H`0206][J`0307=cL`1kNg/0Ng]k0080Q8B400@0000008b<S02<S8`0S8b<0`2UYJD90;fm_@<0YJFU
00D0S8b<08B4Q024Q8@0Ng]k0:FUY@110?ooo`80[Jf]1@0a<C400`0i>CT0@T920492@P020492@P80
BTY:00`0@T9206=SH`1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0_Kfm08B4Q01SHf<2059BDP03
04Y:BP2UYJD0[Jf]00D0oooo00D0kno_0:f][@1cLg<0@T92010@400300000004010@4012@T80Lg=c
0:f][C`0oooo00@0YJFU05YJFP1JFUX0Hf=S0P1cLg<00`1kNg/0Q8B408b<S00309bLW0030:FUY@2e
]KD0]KFe0080_Kfm00@000000<K6aP36a/H0a/K60`3>c/h00`000000e]KF0=KFeP060=KFeP<0c/k>
00D0a/K60;fm_@2m_Kd0]KFe0:f][@1E0?ooo`001`3oool01`2m_Kd0[Jf]06=SH`1SHf<0FUYJ06=S
H`1[Jf/00P1cLg<00`1kNg/0Q8B408b<S00208b<S0D0W9bL0`2UYJD50;Fe]@030;fm_@2e]KD0]KFe
00<0]KFe0P2UYJD0102LW9`0Ng]k0492@P12@T8306=SH`80BTY:0P0a<C401@0i>CT0@T9204Y:BP1B
DU80FUYJ0080Hf=S00<0Jf][07=cL`1kNg/00P1kNg/208B4Q0030000002<S8`0S8b<00<0YJFU1@2m
_Kd00`3Ng]h0_Kfm0=kNgP030;fm_@<0YJFU00@0S8b<08B4Q01kNg/0YJFU@03oool20:f][@@0<C4a
0P0i>CT30492@P80BTY:0P1BDU802`1JFUX0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<
S8`0Q8B40080Hf=S00<0FUYJ059BDP1:BTX00P2UYJD20?ooo`070;fm_@1SHf<00000034a<@1kNg/0
_Kfm0=kNgP030?ooo`070=kNgP2m_Kd0Ng]k034a<@0@4100Hf=S0>OWi`0i0?ooo`080:FUY@1JFUX0
FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`309bLW0040:FUY@2e]KD0]KFe0;Fe]@80_Kfm00<000000<K6
aP36a/H00`3>c/h00`3Fe]H000000=KFeP020=KFeP030=kNgP3Fe]H0g]kN00<0e]KF0`3>c/h01036
a/H0_Kfm0;Fe]@2e]KEE0?ooo`001`3oool0202m_Kd0Jf][06=SH`1SHf<0FUYJ06=SH`1[Jf/0Lg=c
0P1kNg/00`24Q8@0S8b<08b<S00509bLW0<0YJFU0`2e]KD00`2m_Kd0]KFe0;fm_@020;fm_@030;Fe
]@2m_Kd0]KFe0080]KFe00<0YJFU09bLW02LW9`00P1:BTX306=SH`80DU9B0P0a<C420492@P0504Y:
BP1BDU80FUYJ06=SH`1[Jf/00P1cLg<207]kN`80Q8B400<0S8b<0000002<S8`00`2UYJD20;fm_@03
0000003Ng]h0_Kfm00D0g]kN0`2m_Kd20:FUY@0408b<S024Q8@0Ng]k0:FUYCl0oooo0P2][Jd4034a
<@0403Ti>@12@T80@T920492@P80BTY:0P1BDU8305YJFP80Hf=S00L0Ng]k08B4Q02<S8`0YJFU0;fm
_@2UYJD0S8b<0080Jf][0`1SHf<205YJFP80YJFU00@0oooo024Q8@1kNg/0g]kN2`3oool0103Ng]h0
Hf=S0000002<S8`h0?ooo`080:FUY@1JFUX0FUYJ06][J`1cLg<0Ng]k08B4Q02<S8`209bLW080YJFU
0P2e]KD20;fm_@030<K6aP000000a/K600<0c/k>0P3Fe]H00`000000g]kN0=KFeP050=kNgP<0e]KF
0P3>c/h01036a/H0_Kfm0;Fe]@2e]KEE0?ooo`001`3oool0202m_Kd0Jf][06=SH`1SHf<0FUYJ06=S
H`1[Jf/0Lg=c0P1kNg/00`24Q8@0S8b<09bLW00409bLW0<0YJFU0`2e]KD90;fm_@<0]KFe00@0YJFU
09bLW01BDU80DU9B0`1[Jf/205YJFP80<C4a0P12@T801@1:BTX0DU9B05YJFP1SHf<0Jf][0080Lg=c
00<0Ng]k08B4Q024Q8@00`2<S8`00`000000YJFU0:FUY@020;fm_@030000003Ng]h0g]kN00L0g]kN
0`2m_Kd01@2UYJD0S8b<08B4Q024Q8@0YJFU03h0oooo00@0[Jf]0:FUY@0a<C40>CTi0P0a<C401@0i
>CT0@T920492@P12@T80BTY:0080DU9B0P1JFUX406=SH`<0Jf][0P1cLg<00`2m_Kd0Lg=c07=cL`02
07=cL`<0Jf][0P1SHf<00`1JFUX0YJFU0:FUY@0@0?ooo`030=kNgP12@T80BTY:00800000=@3oool2
0:FUY@0605YJFP1[Jf/0Lg=c07]kN`24Q8@0S8b<0P2LW9`20:FUY@030;Fe]@2m_Kd0_Kfm00<0a/K6
0`3>c/h30=KFePT0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@36a/H0]KFe05D0oooo00060?ooo`030<K6
aP2m_Kd0Jf][00<0Hf=S00@0Jf][07=cL`1kNg/0Q8B40P2<S8`309bLW0<0YJFU0`2e]KD40;fm_@03
0<K6aP2m_Kd0a/K600@0a/K6102m_Kd0102e]KD0YJFU05YJFP1JFUX307=cL`80Hf=S00P0Ng]k034a
<@0i>CT0@T9204Y:BP1BDU80FUYJ06=SH`80Jf][00<0Lg=c07]kN`1kNg/00P24Q8@308b<S0@00000
0P2m_Kd00`3Ng]h0_Kfm0=kNgP020=kNgP030;fm_@3Ng]h0_Kfm0080_Kfm00L0YJFU08b<S024Q8@0
Q8B406=SH`2UYJD0[Jf]03d0oooo00<0[Jf]03Ti>@0a<C400`0a<C400`0i>CT0@T920492@P0204Y:
BP80DU9B00<0FUYJ06=SH`1SHf<00P1SHf<306][J`T0Lg=c0`1[Jf/206=SH`03059BDP2UYJD0oooo
0140oooo00<0000000P8202e]KD00P0000000`3_knl0oooo0?ooo`0a0?ooo`070:FUY@1JFUX0Hf=S
07=cL`1kNg/0Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe0080_Kfm0`36a/H30<k>cP<0e]KF00<0
g]kN0=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP050<k>cP36a/H0_Kfm0;fm_@2e]KD0
EP3oool000H0oooo00<0a/K608B4Q01[Jf/00P1SHf<01P1[Jf/0Lg=c07=cL`1kNg/0Q8B408b<S0@0
W9bL00<0YJFU0000002e]KD00P2e]KD30;fm_@0300000036a/H0a/K600L0a/K6102m_Kd00`2e]KD0
Hf=S06=SH`0407]kN`0908B4Q01cLg<0<C4a03Ti>@12@T80BTY:059BDP1JFUX0Hf=S0080Jf][00@0
Lg=c07]kN`24Q8@0Q8B40`2<S8`30:FUY@<0_Kfm2@3Ng]h30;fm_@070:FUY@2<S8`0Q8B406=SH`1J
FUX0YJFU0:f][@0k0?ooo`80[Jf]00@0>CTi034a<@0a<C40>CTi0`12@T800`1:BTX0DU9B05YJFP02
05YJFP80Hf=S0`1[Jf/307=cL`D0Ng]k00<0Q8B407]kN`1kNg/00`1kNg/207=cL`0406][J`1SHf<0
YJFU0:FUYA40oooo00H000000<k>cP0@4100YJFU0?ooo`00000c0?ooo`070:FUY@1JFUX0Hf=S07=c
L`1kNg/0Q8B408b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePT0g]kN0`3F
e]H0103>c/h0a/K60;fm_@2e]KEF0?ooo`001P3oool00`36a/H0Q8B406][J`0206=SH`0506][J`1c
Lg<0Ng]k08B4Q02<S8`01@2LW9`0102UYJD000000;Fe]@2e]KD40;fm_@0300000036a/H0a/K60080
a/K600<0c/k>0<K6aP3>c/h00`36a/H30;fm_@<0]KFe101cLg<00`1SHf<0Ng]k034a<@020492@P07
059BDP1JFUX0Hf=S06=SH`1[Jf/0Lg=c07]kN`0308B4Q080S8b<0`2UYJD30;fm_@/0g]kN0P2m_Kd0
1P2UYJD0S8b<08B4Q01[Jf/0Ng]k06=SH`80YJFU00<0[Jf]0?ooo`3oool0=`3oool00`2][Jd0@T92
03Ti>@02034a<@0303Ti>@12@T80@T920080BTY:00<0DU9B05YJFP1JFUX00P1SHf<306][J`<0Lg=c
0`1kNg/00`24Q8@0Ng]k08B4Q00208B4Q00307]kN`24Q8@0Ng]k0080Ng]k00D0Lg=c06][J`1SHf<0
Hf=S0:FUY@0B0?ooo`050000003>c/h0410@0:FUY@3oool00P00000a0?ooo`80YJFU00@0Jf][07=c
L`24Q8@0S8b<0`2LW9`00`2UYJD0]KFe0;fm_@020;fm_@80a/K60`3>c/h30=KFeP/0g]kN0P3Fe]H0
103>c/h0a/K60<K6aP2e]KEF0?ooo`001P3oool00`36a/H0Q8B406][J`0206=SH`0506][J`1cLg<0
Ng]k08B4Q02<S8`0102LW9`0102UYJD0]KFe0000002e]KD40;fm_@050<K6aP000000a/K60<k>cP36
a/H01@3>c/h30<K6aP80_Kfm00<0]KFe0:FUY@1SHf<0101kNg/02024Q8@0S8b<0:FUY@0a<C40@T92
04Y:BP1BDU80FUYJ0P1SHf<00`1[Jf/0Lg=c07]kN`0208B4Q0<0S8b<0`2UYJD30;fm_@L0g]kN0`2m
_Kd20:FUY@0308b<S024Q8@0Jf][0080Q8B400D0Ng]k06=SH`1JFUX0YJFU0:f][@0C0?ooo`030:f]
[@3oool0oooo0280oooo00<0[Jf]0492@P0i>CT00P0a<C400`0i>CT0@T920492@P0204Y:BP04059B
DP1JFUX0Hf=S06=SH`<0Jf][0`1cLg<307]kN`T0Q8B40`1kNg/0101cLg<0Jf][06=SH`2UYJDB0?oo
o`050000003oool0_Kfm010@403>c/h00P3oool00`000000oooo0?ooo`0_0?ooo`060:FUY@1JFUX0
Jf][07]kN`24Q8@0S8b<0`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H70=kNgP<0
e]KF0P3>c/h00`36a/H0_Kfm0;Fe]@1G0?ooo`001P3oool01@36a/H0Q8B406][J`1SHf<0Jf][0080
Lg=c00<0Ng]k08B4Q02<S8`00`2LW9`20:FUY@030;Fe]@000000_Kfm00<0_Kfm0P36a/H00`000000
c/k>0<k>cP070<k>cP<0a/K60P2m_Kd20;Fe]@060;fm_@36a/H0c/k>0=KFeP1[Jf/0YJFU0P2][Jd0
1`12@T80BTY:059BDP1JFUX0Hf=S06][J`1cLg<00P1kNg/208B4Q080S8b<0`2UYJD30;fm_@T0g]kN
0`2m_Kd0102UYJD0S8b<08B4Q01[Jf/208b<S00408B4Q01kNg/0Ng]k06=SH`80YJFU00<0[Jf]0?oo
o`3oool02@3oool=0:f][A`0oooo00L0moOg0;Fe]@2][Jd0@T9203Ti>@0a<C40>CTi0080@T9200@0
BTY:059BDP1JFUX0FUYJ0P1SHf<0101[Jf/0Lg=c07=cL`1cLg<307]kN`@0Q8B400<0S8b<08B4Q02<
S8`0102<S8`408B4Q00307]kN`1cLg<0Jf][0080YJFU4P3oool01@000000oooo08b<S00Q8B40kno_
0080oooo00<000000?ooo`3oool0;P3oool20:FUY@0407=cL`1kNg/0Q8B408b<S080W9bL00<0YJFU
0;Fe]@2e]KD00P2m_Kd20<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>0<K6aP36a/H0]KFeE`3o
ool000H0oooo00T0a/K608B4Q01[Jf/0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`00`2LW9`30:FUY@03
0;Fe]@000000_Kfm0080_Kfm0`36a/H00`000000c/k>0<k>cP020<k>cP030=KFeP3>c/h0e]KF00<0
c/k>0`36a/H01`2m_Kd0]KFe0=KFeP2LW9`0]KFe0;fm_@2e]KD00P2UYJD01P3oool0[Jf]0:FUY@12
@T80BTY:05YJFP80Hf=S00<0Jf][07=cL`1kNg/00P24Q8@308b<S0<0YJFU0`2m_Kd70=kNgP<0_Kfm
00D0YJFU08b<S024Q8@0Jf][0;fm_@020:FUY@0408b<S024Q8@0Q8B407]kN`80Hf=S0P2UYJD00`2]
[Jd0oooo0?ooo`050?ooo`<0[Jf]2`0a<C430:f][AX0oooo00@0moOg0;Fe]@1BDU80@T920P0i>CT3
0492@P0304Y:BP1BDU80FUYJ0080Hf=S0P1[Jf/207=cL`<0Ng]k1024Q8@908b<S0@0Q8B400@0Ng]k
07=cL`1[Jf/0YJFU4P3oool01@000000oooo0?ooo`12@T80Lg=c03@0oooo0P2UYJD00`1cLg<0Ng]k
08b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H0103>c/h0
a/K60<K6aP2e]KEH0?ooo`001P3oool00`36a/H0Q8B406][J`0206][J`0407=cL`1kNg/0Q8B408b<
S0<0W9bL0P2UYJD00`2e]KD0_Kfm00000007000000030<k>cP3Fe]H0c/k>00D0e]KF0`3>c/h20<K6
aP030;fm_@2e]KD0YJFU0080[Jf]1P3oool01P2][Jd0YJFU0492@P1BDU80FUYJ06=SH`80Jf][00@0
Lg=c07]kN`24Q8@0Q8B40`2<S8`30:FUY@<0_Kfm00<0g]kN0;fm_@3Ng]h01@2m_Kd01P2UYJD0S8b<
08B4Q01[Jf/0_Kfm0:FUY@80_Kfm00@0YJFU08b<S02<S8`0Q8B40P1kNg/0101SHf<0FUYJ0:FUY@2]
[Jd40?ooo`<0[Jf]200a<C4703Ti>@<0[Jf]103gmoLD0?ooo`030?Ogm`2e]KD0DU9B00<0>CTi0P12
@T800`1:BTX0DU9B05YJFP0206=SH`<0Jf][00@0Lg=c07]kN`1kNg/0Ng]k1024Q8@508b<S0030:FU
Y@2<S8`0YJFU00<0S8b<0`24Q8@0101kNg/0Lg=c06][J`2UYJDC0?ooo`050000003oool0g]kN0000
003Ng]h0=03oool01@2UYJD0Jf][07=cL`24Q8@0S8b<00<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36
a/H30<k>cP<0e]KF00<0g]kN0=KFeP3Ng]h01@3Fe]H0103>c/h0a/K60<K6aP2e]KEI0?ooo`001P3o
ool02@36a/H0Q8B406][J`1[Jf/0Ng]k07=cL`1kNg/0Q8B408b<S00309bLW0060:FUY@2e]KD0]KFe
0;fm_@000000_Kfm0`36a/H20<k>cP030000003Fe]H0e]KF00L0e]KF0`3>c/h01@36a/H0_Kfm0;fm
_@2e]KD0[Jf]00P0oooo00P0[Jf]0:FUY@1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`80Ng]k0P24Q8@3
08b<S0<0YJFU1`2m_Kd30:FUY@0408b<S024Q8@0Jf][0;fm_@80YJFU00<0_Kfm0:FUY@2m_Kd00P2U
YJD00`2<S8`0Q8B408B4Q00207]kN`0306=SH`2UYJD0YJFU00@0[Jf]1@0a<C4303Ti>@P0@T920P1:
BTX01012@T80YJFU0:FUY@2][Jd30?Ogm`l0oooo0`3gmoL0103_knl0inOW0:FUY@1BDU8303Ti>@80
@T9200<0BTY:059BDP1JFUX00P1SHf<206][J`0507=cL`1kNg/0Ng]k07]kN`24Q8@01000000208b<
S0030:FUY@2<S8`0YJFU00@0YJFU0`2<S8`208B4Q00407]kN`1cLg<0Jf][0:FUYA<0oooo00D00000
0?ooo`3oool0Ng]k06=SH`0b0?ooo`<0[Jf]00D0FUYJ06][J`1kNg/0Q8B408b<S00209bLW0030:FU
Y@2e]KD0]KFe0080_Kfm0`36a/H30<k>cPL0e]KF0`3>c/h20<K6aP030;Fe]@3oool0oooo05P0oooo
00060?ooo`050<K6aP24Q8@0Jf][06][J`1kNg/00P24Q8@01@2<S8`0W9bL09bLW02LW9`0YJFU00<0
]KFe00<0_Kfm00000036a/H00P36a/H30<k>cP030000003Fe]H0e]KF0080e]KF00<0g]kN0=KFeP3N
g]h00`3Fe]H30<k>cP040<K6aP2m_Kd0]KFe0;Fe]@T0oooo00H0[Jf]0:FUY@1:BTX0FUYJ06=SH`1[
Jf/207=cL`80Ng]k0P24Q8@308b<S0<0YJFU00D0_Kfm0:FUY@2m_Kd0YJFU0;fm_@030:FUY@0608b<
S024Q8@0Jf][08b<S02UYJD0_Kfm0P2UYJD40;fm_@030:FUY@2<S8`0S8b<0080Q8B400@0Ng]k06=S
H`1JFUX0DU9B1`0a<C400`0i>CT0@T920492@P050492@PP0BTY:00<0DU9B0:FUY@2][Jd00P3_knl0
0`3gmoL0oooo0?ooo`070?ooo`80moOg0P3_knl02P3WinL0g]kN0=KFeP3>c/h0[Jf]0:FUY@2<S8`0
@T9203Ti>@0a<C430492@P0304Y:BP1BDU80FUYJ0080Hf=S00<0Jf][07=cL`1cLg<00P1kNg/01024
Q8@0000008B4Q024Q8@208b<S0030000002UYJD0YJFU00L0YJFU0`2<S8`208B4Q00307]kN`1cLg<0
YJFU01@0oooo00D000000?ooo`3_knl0410@0=kNgP0_0?ooo`<0[Jf]0`0a<C40101JFUX0Lg=c07]k
N`2<S8`209bLW080YJFU0P2e]KD20;fm_@<0a/K60`3>c/h01@3Fe]H0c/k>0=KFeP3>c/h0e]KF00<0
c/k>0P36a/H00`2e]KD0oooo0?ooo`1I0?ooo`001P3oool01@36a/H0Q8B406][J`1cLg<0Ng]k0080
Q8B400<0S8b<09bLW02LW9`00P2UYJD20;Fe]@80_Kfm00<000000<K6aP36a/H00`3>c/h01@3Fe]H0
00000=KFeP3Ng]h0e]KF00D0g]kN0`3Fe]H20<k>cP040<K6aP2m_Kd0]KFe0;Fe]@X0oooo00L0[Jf]
0:FUY@1BDU80FUYJ06=SH`1[Jf/0Lg=c0080Ng]k0`24Q8@308b<S0L0YJFU0`2<S8`02024Q8@0Jf][
06][J`1kNg/0Q8B408b<S02UYJD0_Kfm0P2UYJD00`2m_Kd0YJFU0;fm_@020:FUY@80S8b<00@0Q8B4
07]kN`1kNg/0Hf=S0P1BDU84034a<@0303Ti>@12@T80@T9200<0@T920`1:BTX:059BDP030:FUY@2]
[Jd0inOW0080kno_00@0moOg0?ooo`3oool0oooo0P3gmoL20>o_k`070>OWi`3Fe]H0c/k>0;fm_@2e
]KD0YJFU08b<S00208B4Q080DU9B00<0@T9203Ti>@0a<C400P12@T800`1:BTX0DU9B05YJFP0206=S
H`0706][J`1cLg<0Lg=c07=cL`1kNg/0Q8B40000000208B4Q0<0S8b<00<0YJFU0000002UYJD00P2U
YJD00`2m_Kd0YJFU0;fm_@030:FUY@<0S8b<00@0Q8B407]kN`1cLg<0YJFU5`3oool206=SHbd0oooo
0`2][Jd5034a<@0503Ti>@1JFUX0Lg=c08B4Q02<S8`00P2LW9`00`2UYJD0]KFe0;Fe]@030;fm_@<0
a/K61`3>c/h40<K6aP030;Fe]@3oool0oooo05X0oooo00060?ooo`050<K6aP2m_Kd0Jf][07=cL`1k
Ng/00P24Q8@00`2<S8`0W9bL09bLW0020:FUY@060;Fe]@2m_Kd0_Kfm0<K6aP000000a/K60`3>c/h2
0=KFeP030000003Ng]h0g]kN00L0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@36a/H0]KFe00/0oooo0`2U
YJD206=SH`0306][J`1cLg<0Ng]k00@0Q8B40`2<S8`50:FUY@80S8b<00@0[Jf]0:FUY@2UYJD0[Jf]
0P2UYJD0101kNg/0Q8B408b<S02UYJD20;fm_@030:FUY@2m_Kd0_Kfm0080_Kfm0P2UYJD01P2<S8`0
Q8B408B4Q01kNg/0Hf=S05YJFP80<C4a00<0>CTi0492@P12@T800P12@T8304Y:BP<0DU9B1`1JFUX2
059BDP0605YJFP1SHf<0W9bL0:f][@3Ng]h0inOW103_knl02`3WinL0e]KF0<K6aP2m_Kd0]KFe0:FU
Y@2<S8`0Q8B407]kN`1SHf<0FUYJ00<0DU9B00<0BTY:03Ti>@0i>CT00P0i>CT01@12@T80DU9B059B
DP1JFUX0Hf=S0080Jf][0P1cLg<01@1kNg/0Q8B408B4Q0000000Q8B400<0S8b<0`2UYJD00`2m_Kd0
YJFU0;fm_@040;fm_@<0YJFU0P2<S8`01024Q8@0Ng]k07=cL`2UYJDG0?ooo`030=kNgP0@4100oooo
02/0oooo0P2][Jd6034a<@0603Ti>@12@T80@T9206=SH`1cLg<0Q8B40`2LW9`00`2UYJD0]KFe0;fm
_@030;fm_@<0a/K61@3>c/h30<K6aP030;fm_@2e]KD0oooo05`0oooo00070?ooo`040;fm_@1[Jf/0
Jf][07]kN`80Q8B400D0S8b<09bLW02LW9`0W9bL0:FUY@020;Fe]@80_Kfm0`36a/H30<k>cP<0e]KF
00<0g]kN0=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP050<k>cP36a/H0_Kfm0;fm_@2e
]KD03P3oool30:FUY@0406=SH`1[Jf/0Lg=c07=cL`80Ng]k1024Q8@00`2<S8`0Q8B408b<S00208B4
Q0030:f][@2UYJD0YJFU00@0oooo0P2UYJD01P1[Jf/0Ng]k08B4Q02<S8`0YJFU0;fm_@80YJFU102m
_Kd0102UYJD0S8b<08b<S024Q8@207]kN`80>CTi0`12@T8204Y:BP<0DU9B0`1JFUX906=SH`80FUYJ
00<0Hf=S09bLW02][Jd00`3>c/h02P36a/H0_Kfm0:f][@2LW9`0S8b<08B4Q01kNg/0Jf][06=SH`1J
FUX2059BDPD0BTY:00<0@T9203Ti>@0i>CT00P12@T80101:BTX0DU9B05YJFP1SHf<206][J`0307=c
L`1kNg/0Ng]k0080Q8B400@0000008b<S02<S8`0S8b<0`2UYJD90;fm_@<0YJFU00D0S8b<08B4Q024
Q8@0Ng]k0:FUY@0H0?ooo`03034a<@2][Jd0oooo02T0oooo0P2][Jd6034a<@0303Ti>@12@T80@T92
0080@T9200@0FUYJ06][J`1kNg/0S8b<0P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP02
0;fm_@030<K6aP2m_Kd0]KFe05l0oooo00070?ooo`040;fm_@1[Jf/0Jf][07]kN`80Q8B400H0S8b<
09bLW02LW9`0W9bL0:FUY@2e]KD20;fm_@<0a/K60`3>c/h30=KFePT0g]kN0`3Fe]H0103>c/h0a/K6
0;fm_@2e]KD@0?ooo`<0YJFU00@0Hf=S06][J`1cLg<0Lg=c0`1kNg/308B4Q00407]kN`2UYJD0YJFU
0:FUY@L0oooo00L0[Jf]0:FUY@2UYJD0Ng]k08B4Q02<S8`0YJFU0080_Kfm0P2UYJD00`2m_Kd0YJFU
0;fm_@020:FUY@0308b<S024Q8@0Q8B400<0@T920P1:BTX2059BDP<0FUYJ101SHf<506][J`0306=S
H`1[Jf/0Hf=S00<0Hf=S00@0Lg=c09bLW02<S8`0S8b<0P24Q8@0101kNg/0Lg=c06][J`1SHf<205YJ
FP03059BDP1:BTX0BTY:00@0DU9B0P1JFUX0201BDU80@T9203Ti>@0i>CT0@T9204Y:BP1BDU80FUYJ
0P1SHf<00`1[Jf/0Lg=c07]kN`0207]kN`80Q8B400<0000008b<S02<S8`00`2UYJD50;fm_@030=kN
gP2m_Kd0g]kN00<0_Kfm0`2UYJD0102<S8`0Q8B407]kN`2UYJDH0?ooo`0308b<S01SHf<0oooo02P0
oooo0P2][Jd5034a<@0303Ti>@12@T80@T920080@T920`1:BTX01@1[Jf/0Q8B407=cL`24Q8@0S8b<
0080W9bL0P2UYJD30;Fe]@<0_Kfm00@0]KFe0;fm_@2e]KD0]KFeH@3oool000L0oooo00H0_Kfm0:f]
[@1cLg<0Ng]k08B4Q02<S8`309bLW0030:FUY@2e]KD0_Kfm0080_Kfm0P36a/H30<k>cP<0e]KF2`3N
g]h20=KFeP040<k>cP36a/H0a/K60;Fe]A80oooo3@2UYJD;0?ooo`<0YJFU00@0Ng]k08B4Q02<S8`0
YJFU0P2m_Kd00`2UYJD0_Kfm0;fm_@020;fm_@030:FUY@2<S8`0@T920080@T9200<0BTY:059BDP1B
DU800P1JFUX406=SH`<0Jf][1`1cLg<206][J`80Hf=S00<0Jf][06=SH`1BDU800P1BDU8205YJFPT0
DU9B0`1JFUX206=SH`0305YJFP12@T80>CTi0080@T9200D0BTY:059BDP1JFUX0Hf=S06][J`0207=c
L`80Ng]k0P24Q8@00`2<S8`0000008b<S0030:FUY@<0_Kfm00<0g]kN0;fm_@3Ng]h0103Ng]h30;fm
_@80YJFU00@0S8b<08B4Q01kNg/0YJFU603oool00`3>c/h0410@0?ooo`0W0?ooo`80[Jf]100a<C42
03Ti>@<0@T920P1:BTX3059BDP0605YJFP24Q8@0W9bL0;Fe]@1cLg<0S8b<0`2LW9`30:FUY@050;Fe
]@2UYJD0]KFe0:FUY@2e]KD0H`3oool000P0oooo00<0[Jf]06=SH`1[Jf/00P24Q8@01P2<S8`0W9bL
09bLW02LW9`0YJFU0;Fe]@80_Kfm0`36a/H30<k>cP<0e]KF1`3Ng]h30=KFeP80c/k>00<0a/K60;fm
_@2e]KD06@3oool00`2UYJD0oooo0?ooo`0A0?ooo`80YJFU00H0Jf][07]kN`24Q8@0S8b<0:FUY@2m
_Kd20:FUY@040;fm_@2UYJD0_Kfm0:FUY@80@T920P1:BTX2059BDP0305YJFP1SHf<0Hf=S0080Hf=S
0`1[Jf/907=cL`<0Jf][00<0Hf=S059BDP1:BTX00P1:BTX5059BDPH0FUYJ1@1SHf<00`1JFUX0BTY:
0492@P020492@P0504Y:BP1BDU80FUYJ06=SH`1[Jf/00P1cLg<00`1kNg/0Q8B408B4Q00208b<S004
0000002UYJD0YJFU0:FUY@<0_Kfm00<000000=kNgP3Ng]h01P3Ng]h30;fm_@050:FUY@2<S8`0Q8B4
08B4Q02UYJD06@3oool00`0@4100c/k>0?ooo`0U0?ooo`80[Jf]100a<C40100i>CT0@T920492@P12
@T8204Y:BP80DU9B0`1JFUX206=SH`0909bLW02e]KD0_Kfm0<K6aP3>c/h0e]KF0<k>cP36a/H0S8b<
00<0Hf=S0P1JFUX20:FUYF80oooo00080?ooo`80[Jf]00@0Ng]k08B4Q024Q8@0S8b<0P2LW9`00`2U
YJD0]KFe0;Fe]@020;fm_@80a/K60`3>c/h30=KFePT0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e]KD^
0?ooo`070:f][@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@020;fm_@030:FUY@2m_Kd0YJFU0080@T92
00<0BTY:059BDP1JFUX00P1JFUX206=SH`<0Jf][0`1cLg<507]kN`0308B4Q01kNg/0Ng]k00@0Lg=c
00<0Jf][06=SH`1BDU800P1BDU8605YJFP80Hf=S00<0FUYJ06=SH`1SHf<00P1SHf<406][J`0706=S
H`1:BTX0@T920492@P1:BTX0DU9B05YJFP0206=SH`0406][J`1cLg<0Ng]k07]kN`80Q8B40P2<S8`0
2@000000YJFU0:FUY@2UYJD0_Kfm0000002m_Kd0g]kN0;fm_@030=kNgP030;fm_@3Ng]h0_Kfm0080
_Kfm00L0YJFU08b<S024Q8@0Q8B406=SH`2UYJD0[Jf]01P0oooo00<0@T9209bLW03oool0903oool2
0:f][@@0<C4a00D0>CTi0492@P12@T80@T9204Y:BP02059BDP80FUYJ101SHf<306][J`80Lg=c00<0
YJFU0;fm_@2UYJD00P1cLg<306][J`80Hf=S00<0FUYJ0:FUY@2UYJD0H@3oool000T0oooo00D0[Jf]
0:FUY@1cLg<0Ng]k08b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN
0`3Fe]H0103>c/h0a/K60<K6aP2e]KDa0?ooo`80YJFU00L0Jf][07]kN`24Q8@0S8b<0:FUY@2m_Kd0
YJFU0080@T920P1:BTX00`1BDU80FUYJ05YJFP0206=SH`<0Jf][0`1cLg<307]kN`0308B4Q01kNg/0
Q8B40080Q8B400<0Ng]k08B4Q01kNg/00P1kNg/00`1[Jf/0Hf=S05YJFP0205YJFP0306=SH`1JFUX0
Hf=S00<0Hf=S00<0Jf][06=SH`1SHf<0101[Jf/307=cL`80Ng]k00H0BTY:0492@P1:BTX0BTY:059B
DP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Q8B40`2<S8`00`2UYJD0000000000002000000030;fm
_@3Ng]h0g]kN00L0g]kN0`2m_Kd01`2UYJD0S8b<08B4Q01SHf<0FUYJ0:FUY@2][Jd05`3oool207]k
NbD0oooo00<0[Jf]034a<@0a<C400`0a<C400`0i>CT0@T920492@P0204Y:BP80DU9B00<0FUYJ06=S
H`1SHf<00P1SHf<306][J`T0Lg=c0`1[Jf/206=SH`03059BDP2UYJD0oooo0600oooo000:0?ooo`80
YJFU00<0Lg=c08B4Q02<S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H00`3N
g]h0e]KF0=kNgP050=KFeP040<k>cP36a/H0a/K60;Fe]C<0oooo00P0[Jf]0:FUY@1SHf<0Ng]k08B4
Q02<S8`0YJFU0;fm_@80@T920P1:BTX0101BDU80FUYJ06=SH`1SHf<306][J`<0Lg=c0`1kNg/908B4
Q080Ng]k00<0Lg=c06][J`1SHf<01P1SHf<406][J`0307=cL`1[Jf/0Lg=c00@0Lg=c0P1kNg/01P1[
Jf/0DU9B04Y:BP1:BTX0DU9B05YJFP80Hf=S00<0Jf][07=cL`1kNg/00`24Q8@208b<S0<0YJFU0`2m
_Kd;0=kNgP80_Kfm00H0YJFU08b<S024Q8@0Jf][07]kN`1SHf<20:FUY@030:f][@3oool0oooo01<0
oooo00<0W9bL0492@P3oool08`3oool20:f][@<0<C4a00H0>CTi0492@P12@T80@T9204Y:BP1BDU83
05YJFP80Hf=S0`1[Jf/307=cL`D0Ng]k00<0Q8B407]kN`1kNg/00`1kNg/207=cL`0406][J`1SHf<0
YJFU0:FUYF00oooo000;0?ooo`80YJFU00<0Ng]k08B4Q02<S8`00P2LW9`00`2UYJD0]KFe0;Fe]@02
0;fm_@<0a/K60`3>c/h70=KFeP<0c/k>0P36a/H00`2e]KD0oooo0?ooo`0c0?ooo`060:f][@0i>CT0
FUYJ06][J`1cLg<0>CTi0P12@T80101:BTX0DU9B05YJFP1JFUX206=SH`0406][J`1cLg<0Lg=c07=c
L`<0Ng]k1024Q8@00`2<S8`0Q8B408b<S00408b<S0<0Q8B400<0Ng]k07=cL`1[Jf/01@1[Jf/807=c
L`<0Ng]k0P24Q8@208b<S00309bLW01:BTX0BTY:0080DU9B00@0FUYJ06=SH`1SHf<0Jf][0P1cLg<2
08B4Q0<0S8b<0`2UYJD30;fm_@L0g]kN0`2m_Kd20:FUY@0308b<S024Q8@0Jf][0080Q8B400D0Ng]k
06=SH`1JFUX0YJFU0:f][@0D0?ooo`030;fm_@12@T80oooo02<0oooo00<0[Jf]03Ti>@0a<C400P0a
<C400`0i>CT0@T920492@P0204Y:BP03059BDP1JFUX0FUYJ0080Hf=S0`1[Jf/307=cL`<0Ng]k00<0
Q8B407]kN`24Q8@00P24Q8@00`1kNg/0Q8B407]kN`0207]kN`0507=cL`1[Jf/0Hf=S06=SH`2UYJD0
H03oool000`0oooo0P2UYJD0101kNg/0S8b<09bLW02LW9`20:FUY@80]KFe0P2m_Kd30<K6aP<0c/k>
00D0e]KF0<k>cP3Fe]H0c/k>0=KFeP030<k>cP80a/K600<0]KFe0?ooo`3oool0=03oool01@2][Jd0
<C4a034a<@1BDU80>CTi00<0@T9200<0BTY:059BDP1JFUX00P1SHf<206][J`80Lg=c0P1kNg/40000
000308B4Q02<S8`0S8b<00L0S8b<0`24Q8@00`1kNg/0Lg=c07=cL`0207=cL`0307]kN`24Q8@0Q8B4
00H0Ng]k0P24Q8@208b<S00409bLW02UYJD0S8b<0:FUY@80[Jf]00L0FUYJ059BDP1JFUX0FUYJ06=S
H`1[Jf/0Lg=c0080Ng]k0P24Q8@208b<S0<0YJFU0`2m_Kd90=kNgP<0_Kfm00@0YJFU08b<S024Q8@0
Jf][0P2<S8`01024Q8@0Ng]k07]kN`1SHf<20:FUY@030:f][@3oool0oooo0100oooo00<0S8b<010@
403oool08`3oool00`2][Jd0>CTi034a<@02034a<@0303Ti>@12@T80@T920080BTY:00@0DU9B05YJ
FP1SHf<0Hf=S0`1[Jf/307=cL`<0Ng]k2@24Q8@307]kN`0407=cL`1[Jf/0Hf=S0:FUYF00oooo000=
0?ooo`80YJFU00D0Q8B408b<S02LW9`0W9bL0:FUY@020;Fe]@<0_Kfm0`36a/H70<k>cP@0a/K600<0
]KFe0?ooo`3oool0=@3oool01@2][Jd0<C4a034a<@0a<C40>CTi0080@T9200<0BTY:059BDP1JFUX0
0P1SHf<306][J`0407=cL`1kNg/0Ng]k000000@0Q8B400<0000008b<S02<S8`00P2<S8`00`2UYJD0
S8b<0:FUY@0308b<S080Q8B40P1kNg/01@1cLg<0Ng]k08B4Q024Q8@0S8b<00<0Q8B4102<S8`00`2L
W9`0YJFU09bLW0020:f][@060;Fe]@2m_Kd0]KFe0>o_k`2e]KD0[Jf]0P1BDU801P1JFUX0Hf=S06=S
H`1[Jf/0Lg=c07]kN`80Q8B40`2<S8`30:FUY@<0_Kfm1`3Ng]h30;fm_@050:FUY@2<S8`0Q8B406][
J`2m_Kd00P2UYJD0202<S8`0Q8B408B4Q01kNg/0Hf=S05YJFP2UYJD0[Jf]2`3oool70:f][@030000
002][Jd0[Jf]00<0[Jf]7P3oool00`2][Jd0YJFU03Ti>@02034a<@0503Ti>@12@T80@T9204Y:BP1B
DU800P1JFUX206=SH`0406][J`1cLg<0Lg=c07=cL`<0Ng]k1024Q8@00`2<S8`0Q8B408b<S00408b<
S0@0Q8B400<0Ng]k07=cL`1[Jf/00P2UYJEO0?ooo`003P3oool20:FUY@060:f][@2LW9`0W9bL09bL
W02UYJD0]KFe102m_Kd30<K6aPD0c/k>0`36a/H00`2m_Kd0]KFe0?ooo`0g0?ooo`050:f][@0a<C40
<C4a034a<@0i>CT00P12@T800`1:BTX0DU9B05YJFP0206=SH`80Jf][00@0Lg=c07]kN`1kNg/00000
1024Q8@208b<S0030000002UYJD0S8b<00D0YJFU0`2<S8`208B4Q00307]kN`24Q8@0Ng]k0080Q8B4
0P2<S8`309bLW080YJFU00<0[Jf]0;Fe]@2m_Kd00P36a/H00`3WinL0kno_0?Ogm`030?Ogm`030;Fe
]@2][Jd0BTY:0080FUYJ00D0Hf=S06][J`1[Jf/0Lg=c07]kN`0208B4Q0<0S8b<0`2UYJD30;fm_@03
0=kNgP2m_Kd0g]kN00D0_Kfm00H0YJFU08b<S024Q8@0Jf][0;fm_@2UYJD20;fm_@040:FUY@2<S8`0
S8b<08B4Q080Ng]k00@0Hf=S0:FUY@2UYJD0[Jf]1`3oool30:f][@H0<C4a00<00000034a<@0a<C40
0P0a<C430:f][A/0oooo00H0moOg0:f][@0i>CT0>CTi034a<@0i>CT30492@P0304Y:BP1BDU80FUYJ
0080Hf=S0P1[Jf/207=cL`<0Ng]k1024Q8@908b<S0@0Q8B400@0Ng]k07=cL`1[Jf/0YJFUG`3oool0
0100oooo00<0YJFU0:f][@2][Jd00P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP020;fm
_@030<K6aP2m_Kd0]KFe03X0oooo00@0[Jf]034a<@0a<C40<C4a0`12@T800`1:BTX0DU9B05YJFP02
06=SH`0306][J`1cLg<0Lg=c0080Ng]k00@0000008B4Q024Q8@0Q8B40`2<S8`90:FUY@<0S8b<0P24
Q8@01@1cLg<0Q8B408B4Q02<S8`0W9bL0080YJFU00L0[Jf]0;Fe]@2m_Kd0a/K60<k>cP3WinL0kno_
00<0moOg1@3oool00`3gmoL0[Jf]0:FUY@02059BDP0405YJFP1SHf<0Jf][07=cL`80Ng]k0P24Q8@3
08b<S0<0YJFU1`2m_Kd30:FUY@0408b<S024Q8@0Jf][0;fm_@80YJFU00@0_Kfm0:FUY@2m_Kd0YJFU
100000001@1kNg/0Hf=S05YJFP2UYJD0[Jf]00@0oooo0`2][Jd8034a<@030000000i>CT0>CTi00@0
>CTi00<0[Jf]0:FUY@2][Jd0603oool20?Ogm`030:FUY@12@T80>CTi0080>CTi0P12@T800`1:BTX0
DU9B05YJFP0206=SH`<0Jf][00@0Lg=c07]kN`1kNg/0Ng]k1024Q8@508b<S0030:FUY@2<S8`0YJFU
00<0S8b<0`24Q8@0101kNg/0Lg=c06][J`2UYJEO0?ooo`004P3oool00`2UYJD0[Jf]0:f][@0209bL
W080YJFU0`2e]KD30;fm_@040;Fe]@2m_Kd0]KFe0;Fe]C`0oooo00@0[Jf]034a<@0a<C40<C4a0P12
@T800`1:BTX0DU9B05YJFP0206=SH`0706][J`1cLg<0Lg=c07=cL`1kNg/0Q8B40000000208B4Q0<0
S8b<1@2UYJD00`2m_Kd0YJFU0;fm_@030:FUY@<0S8b<00X0Q8B409bLW02LW9`0Q8B40:FUY@2e]KD0
_Kfm0<K6aP3>c/h0inOW0P3_knl20?Ogm`/0oooo00H0[Jf]0:FUY@1BDU80FUYJ06=SH`1[Jf/207=c
L`80Ng]k0P24Q8@308b<S0<0YJFU00D0_Kfm0:FUY@2m_Kd0YJFU0;fm_@030:FUY@0608b<S024Q8@0
Jf][08b<S02UYJD0_Kfm0P2UYJD01P2m_Kd0YJFU000000000000YJFU08b<S08000000P1kNg/00`1S
Hf<0YJFU0:FUY@040:f][@D0<C4a0`0i>CT20492@P0300000012@T80@T9200@0@T9200<0BTY:0492
@P2UYJD00P2][Jd20?Ogma@0oooo00L0moOg0>o_k`2UYJD0@T9203Ti>@0a<C40>CTi0080@T9200<0
BTY:059BDP1JFUX00P1SHf<206][J`0407=cL`1kNg/0Ng]k07]kN`80Q8B4100000000`2<S8`0YJFU
08b<S0050:FUY@<0S8b<0P24Q8@0101kNg/0Lg=c06][J`2UYJEO0?ooo`00503oool00`2UYJD0[Jf]
0;Fe]@050;Fe]@030;fm_@2e]KD0_Kfm0080]KFe?P3oool0102][Jd0<C4a034a<@0i>CT20492@P04
04Y:BP1BDU80FUYJ06=SH`80Jf][0P1cLg<01@1kNg/0Q8B408B4Q0000000Q8B400<0S8b<0`2UYJD0
0`2m_Kd0YJFU0;fm_@040;fm_@<0YJFU0`2<S8`0101kNg/0Q8B40:FUY@2e]KD20>OWi`030>o_k`3g
moL0moOg0100oooo00L0[Jf]0:FUY@1BDU80FUYJ06=SH`1[Jf/0Lg=c0080Ng]k0`24Q8@308b<S0L0
YJFU0`2<S8`02024Q8@0Jf][06][J`1kNg/0Q8B408b<S02UYJD0_Kfm0P2UYJD00`000000YJFU0;fm
_@020:FUY@0700000024Q8@0Q8B407]kN`1SHf<0FUYJ059BDP07034a<@0303Ti>@12@T80@T9200<0
@T9200<000000492@P1:BTX0101:BTX01P12@T80BTY:04Y:BP1:BTX0YJFU0:f][@80moOg3`3oool3
0?Ogm`050>o_k`2e]KD0YJFU09bLW00i>CT00P0a<C430492@P0304Y:BP1BDU80FUYJ0080Hf=S00<0
Jf][07=cL`1cLg<00P1kNg/208B4Q00300000024Q8@0S8b<0080S8b<00<000000:FUY@2UYJD01P2U
YJD308b<S080Q8B400<0Ng]k07=cL`2UYJD0@`3oool00`2UYJD0oooo0?ooo`0I0?ooo`006P3oool0
0`2][Jd0oooo0?ooo`120?ooo`040:f][@0a<C40<C4a03Ti>@80@T9200@0BTY:059BDP1JFUX0Hf=S
0P1[Jf/00`1cLg<0Ng]k07]kN`0208B4Q0040000002<S8`0S8b<08b<S0<0YJFU2@2m_Kd20:FUY@03
09bLW02<S8`0Q8B40080Q8B400@0[Jf]0>OWi`3gmoL0moOg503oool00`2][Jd0YJFU0:FUY@0206=S
H`0306][J`1cLg<0Ng]k00@0Q8B40`2<S8`50:FUY@80S8b<00@0[Jf]0:FUY@2UYJD0[Jf]0P2UYJD0
1`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@000000102m_Kd010000000S8b<08b<S024Q8@207]kN`03
06=SH`1BDU80DU9B00@0<C4a00<0>CTi0492@P12@T801012@T800`0820P0BTY:059BDP09059BDP04
0:FUY@2][Jd0kno_0?Ogm`X0oooo0P3gmoL01@3_knl0inOW0<K6aP2e]KD0YJFU0080W9bL00D0BTY:
0492@P0i>CT0<C4a03Ti>@020492@P0304Y:BP1BDU80FUYJ00<0Hf=S0`1cLg<01@1kNg/0Q8B408B4
Q0000000Q8B400<0S8b<0P2UYJD01P000000YJFU0:FUY@2m_Kd0YJFU0;fm_@<0YJFU0`2<S8`01024
Q8@0Ng]k07=cL`2UYJDm0?ooo`d0YJFU5@3oool005l0oooo00P0[Jf]034a<@0a<C40>CTi0492@P1:
BTX0DU9B05YJFP80Hf=S00<0Jf][07=cL`1kNg/00P1kNg/208B4Q0030000002<S8`0S8b<00<0YJFU
00<0_Kfm0000002m_Kd00P2m_Kd00`3Ng]h0_Kfm0=kNgP030;fm_@<0YJFU00H0S8b<08B4Q024Q8@0
]KFe0>o_k`3gmoLG0?ooo`<0YJFU00@0Hf=S06][J`1cLg<0Lg=c0P1kNg/408B4Q00308b<S024Q8@0
S8b<0080Q8B400<0[Jf]0:FUY@2UYJD0103oool20:FUY@0606][J`1kNg/0Q8B408b<S02UYJD00000
0P2UYJD00`2m_Kd0YJFU000000020:FUY@0908b<S024Q8@0Q8B407]kN`1SHf<0FUYJ059BDP0a<C40
>CTi00@0@T920`1:BTX00`12@T8061PH059BDP0705YJFP80DU9B0P1JFUX0102UYJD0]KFe0>o_k`3g
moL50?ooo`0;0?Ogm`3_knl0inOW0=kNgP36a/H0]KFe0:FUY@2LW9`0S8b<06=SH`1BDU800P1:BTX0
1@12@T80BTY:03Ti>@0a<C40>CTi0080@T9200@0BTY:059BDP1JFUX0Hf=S0P1[Jf/207=cL`0507]k
N`24Q8@0Q8B408B4Q00000000`2<S8`30:FUY@030;fm_@2UYJD0_Kfm00@0_Kfm0`2UYJD208b<S004
08B4Q01kNg/0Lg=c0:FUYC/0oooo0`2UYJD;05YJFP<0YJFU4`3oool005l0oooo00<0[Jf]034a<@0a
<C400P12@T801@1:BTX0DU9B05YJFP1SHf<0Jf][0080Lg=c0P1kNg/208B4Q080S8b<00T000000:FU
Y@2UYJD0YJFU0;fm_@000000_Kfm0=kNgP2m_Kd01@3Ng]h30;fm_@80YJFU00@0S8b<08B4Q024Q8@0
]KFe0P3gmoLI0?ooo`<0YJFU00@0Hf=S06][J`1cLg<0Lg=c0`1kNg/308B4Q00407]kN`2UYJD0YJFU
0:FUY@L0oooo00H0[Jf]0:FUY@2UYJD0Ng]k08B4Q02<S8`2000000030;fm_@2UYJD0000000<0_Kfm
00@0YJFU08b<S02<S8`0Q8B40P1kNg/203Ti>@<0@T920P1:BTX3059BDP030492@P0H61P0FUYJ00T0
Hf=S0P1JFUX0101SHf<0YJFU0;Fe]@3WinL30>o_k`0;0>OWi`3Ng]h0a/K60;Fe]@2UYJD0W9bL08B4
Q01[Jf/0FUYJ059BDP1:BTX00P12@T8304Y:BP050492@P0i>CT0<C4a03Ti>@12@T800P1:BTX00`1B
DU80FUYJ06=SH`0206][J`0307=cL`1kNg/0Ng]k00<0Q8B400<0000008b<S02<S8`00`2UYJD90;fm
_@<0YJFU00D0S8b<08B4Q024Q8@0Ng]k0:FUY@0i0?ooo`<0YJFU201JFUX706=SH`<0YJFU4@3oool0
05l0oooo0P2][Jd0200a<C40@T920492@P1:BTX0DU9B05YJFP1SHf<0Jf][0P1cLg<00`1kNg/0Q8B4
08B4Q00308b<S0030:FUY@00000000000080000000<0_Kfm0=kNgP3Ng]h01`3Ng]h20;fm_@070;Fe
]@2UYJD0S8b<08B4Q02][Jd0]KFe0?Ogm`0L0?ooo`d0YJFU2`3oool20:FUY@0306][J`1kNg/0Q8B4
00H0000000D0YJFU0;fm_@2UYJD0YJFU08b<S00208B4Q0<0@T920P1:BTX2059BDP<0FUYJ0P0a<C42
06=SH`H0Jf][1@1SHf<0301cLg<0YJFU0;Fe]@3>c/h0_Kfm0;Fe]@2UYJD0S8b<07]kN`1[Jf/0FUYJ
059BDPL0BTY:00@0DU9B05YJFP1JFUX0BTY:0`0i>CT01012@T80BTY:059BDP1JFUX206=SH`0306][
J`1cLg<0Ng]k0080Ng]k0P24Q8@00`2<S8`0000008b<S0030:FUY@D0_Kfm00<0g]kN0;fm_@3Ng]h0
0`2m_Kd30:FUY@0408b<S024Q8@0Ng]k0:FUYCL0oooo0`2UYJD505YJFP<0Hf=S0`1[Jf/707=cL`04
06][J`2UYJD0YJFU0:FUY@l0oooo001P0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1S
Hf<206][J`0307=cL`1kNg/0Ng]k0080Q8B40`2<S8`30:FUY@<0_Kfm00<0g]kN0;fm_@3Ng]h00P3N
g]h00`2m_Kd0g]kN0;fm_@020;fm_@060:FUY@2<S8`0Q8B408B4Q02][Jd0moOg8`3oool00`2UYJD0
oooo0?ooo`0@0?ooo`070:f][@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@020;fm_@030:FUY@2m_Kd0
YJFU0080_Kfm00<0YJFU08b<S012@T800P12@T800`1:BTX0DU9B059BDP0205YJFP<0Hf=S00@08B4Q
03Ti>@1[Jf/0Jf][1`1cLg<206=SH`0<06][J`1SHf<0Lg=c07]kN`2LW9`0S8b<07]kN`1SHf<0FUYJ
059BDP1:BTX0@T920`1:BTX2059BDP80FUYJ0P1BDU8305YJFP03059BDP0i>CT0>CTi0080@T9200D0
BTY:059BDP1JFUX0Hf=S06][J`0207=cL`80Ng]k0P24Q8@208b<S0040000002UYJD0YJFU0:FUY@<0
_Kfm00<0g]kN0;fm_@3Ng]h0103Ng]h30;fm_@80YJFU00@0S8b<08B4Q01kNg/0YJFU=P3oool20:FU
Y@H0FUYJ00@0Hf=S06][J`1[Jf/0Jf][101cLg<507]kN`@0Lg=c0P2UYJD>0?ooo`00H03oool0202]
[Jd0<C4a03Ti>@12@T80BTY:059BDP1JFUX0Hf=S0P1[Jf/0101cLg<0Ng]k08B4Q024Q8@308b<S0<0
YJFU0`2m_Kd90=kNgP80_Kfm00D0]KFe0:FUY@2<S8`0S8b<0:f][@0U0?ooo`030000003oool0oooo
0140oooo0P2UYJD0301[Jf/0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0;fm_@2UYJD0_Kfm0:FU
Y@80@T920P1:BTX2059BDP0305YJFP1SHf<0Hf=S0080Hf=S00<0410@04Y:BP1[Jf/0201cLg<606][
J`0305YJFP1BDU80@T9200@0BTY:101BDU8205YJFP0406=SH`1JFUX0FUYJ05YJFP<0Hf=S00<0DU9B
03Ti>@0i>CT00P12@T82059BDP0305YJFP1SHf<0Jf][0080Lg=c00<0Ng]k08B4Q024Q8@00`2<S8`0
0`000000YJFU0:FUY@030;fm_@030=kNgP000000g]kN00H0g]kN0`2m_Kd01@2UYJD0S8b<08B4Q024
Q8@0YJFU03D0oooo0P2UYJD605YJFP0306=SH`1[Jf/0Lg=c00<0Lg=c0`1kNg/708B4Q080Ng]k00<0
Lg=c0:FUY@2UYJD03@3oool00600oooo0P2][Jd20492@P07059BDP1JFUX0Hf=S06=SH`1[Jf/0Lg=c
07]kN`0308B4Q080S8b<0`2UYJD30;fm_@/0g]kN00@0_Kfm0;Fe]@2UYJD0S8b<0P2][JdU0?ooo`03
0000003oool0oooo0180oooo00P0[Jf]0:FUY@2UYJD0Ng]k08B4Q02<S8`0YJFU0;fm_@80YJFU00H0
_Kfm0:FUY@12@T80@T9204Y:BP1BDU8305YJFP80Hf=S0P1[Jf/0101SHf<0000007=cL`1cLg<507]k
N`0308B4Q01kNg/0Lg=c00<0Lg=c0P1[Jf/0101SHf<0DU9B04Y:BP1:BTX2059BDP0305YJFP1BDU80
FUYJ00@0FUYJ1@1SHf<306][J`0306=SH`1JFUX0>CTi0080@T9200@0BTY:059BDP1JFUX0Hf=S0P1[
Jf/00`1cLg<0Ng]k07]kN`0208B4Q0<0S8b<00<000000:FUY@2UYJD00P2m_Kd00`000000g]kN0;fm
_@030=kNgP030;fm_@3Ng]h0_Kfm0080_Kfm00H0YJFU08b<S024Q8@0Q8B406=SH`2][Jdd0?ooo`80
YJFU1@1JFUX00`1SHf<0Jf][06][J`0207=cL`<0Ng]k0`24Q8@708b<S0<0Q8B400<0Ng]k0:FUY@2U
YJD0303oool00640oooo00H0[Jf]034a<@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k
0080Q8B40`2<S8`30:FUY@<0_Kfm1`3Ng]h30;fm_@80YJFU00<0S8b<08B4Q02UYJD09P3oool00`00
0000oooo0?ooo`0D0?ooo`80YJFU00H0Jf][07=cL`1kNg/0S8b<0:FUY@2m_Kd20:FUY@040492@P1:
BTX0BTY:059BDP80FUYJ0P1SHf<306][J`0304Y:BP0H61P0Lg=c00<0Ng]k00<0Q8B407]kN`24Q8@0
0P24Q8@0201kNg/0Q8B407]kN`1kNg/0Lg=c06][J`1SHf<0FUYJ0P1BDU8505YJFP@0Hf=S1@1[Jf/3
07=cL`80Ng]k00L0@T9203Ti>@12@T80BTY:059BDP1JFUX0Hf=S0080Jf][00@0Lg=c07]kN`24Q8@0
Q8B40`2<S8`20:FUY@@000002@3Ng]h30;fm_@040:FUY@2<S8`0Q8B406=SH`80YJFU00<0[Jf]0?oo
o`3oool0;`3oool20:FUY@@0FUYJ0P1SHf<00`1[Jf/0Lg=c07=cL`0207]kN`<0Q8B40`2<S8`909bL
W00308b<S024Q8@0Ng]k0080YJFU2`3oool00640oooo0P2][Jd01`12@T80BTY:059BDP1JFUX0Hf=S
06][J`1cLg<00P1kNg/208B4Q080S8b<0`2UYJD30;fm_@T0g]kN0`2m_Kd0102UYJD0S8b<0:f][@2U
YJDV0?ooo`03010@403>c/h0oooo01D0oooo00P0[Jf]0:FUY@1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm
_@80@T920P1:BTX0101BDU80FUYJ06=SH`1SHf<306][J`0307=cL`0a<C40>CTi00<0Ng]k2@24Q8@0
1@1kNg/0Lg=c07=cL`1[Jf/0Hf=S0080FUYJ1@1SHf<406][J`T0Lg=c00H0Hf=S0492@P12@T80BTY:
059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k00<0Q8B40P2<S8`30:FUY@<0_Kfm2`3Ng]h20;fm_@08
0:FUY@2<S8`0Q8B406][J`1SHf<0FUYJ0:FUY@2][Jd_0?ooo`80YJFU101JFUX0101SHf<0Jf][07=c
L`1cLg<207]kN`80Q8B40`2<S8`>09bLW080S8b<00<0[Jf]0:FUY@3oool02@3oool00680oooo00D0
[Jf]0:FUY@12@T80BTY:05YJFP0206=SH`0306][J`1cLg<0Ng]k0080Q8B40`2<S8`30:FUY@<0_Kfm
1`3Ng]h30;fm_@040:FUY@2<S8`0[Jf]0:FUYBL0oooo00<0@T920;fm_@3oool05P3oool01P2][Jd0
>CTi05YJFP1[Jf/0Ng]k08B4Q080@T9200@0BTY:059BDP1JFUX0FUYJ0P1SHf<01`1[Jf/0Lg=c07=c
L`1cLg<0Ng]k010@401SHf<01024Q8@00`2<S8`0Q8B408b<S00408b<S0<0Q8B400<0Ng]k07=cL`1[
Jf/00P1SHf<506][J`X0Lg=c0P1kNg/208B4Q00308b<S012@T80@T920080DU9B00H0FUYJ06=SH`1S
Hf<0Jf][07=cL`1kNg/208B4Q0<0S8b<0`2UYJD30;fm_@L0g]kN0`2m_Kd20:FUY@0408b<S024Q8@0
Jf][08B4Q080Ng]k00@0Hf=S0:FUY@2UYJD0[Jf]4P3oool00`2][Jd0oooo0?ooo`0G0?ooo`80YJFU
101JFUX01@1SHf<0Jf][07=cL`1cLg<0Ng]k0080Q8B40P2<S8`709bLW0L0YJFU1@2LW9`00`2<S8`0
[Jf]0:f][@090?ooo`00H`3oool01P2][Jd0@T920492@P1BDU80FUYJ06=SH`80Jf][00@0Lg=c07]k
N`24Q8@0Q8B40`2<S8`30:FUY@<0_Kfm00<0g]kN0;fm_@3Ng]h01@2m_Kd0102UYJD0S8b<0:f][@2U
YJDX0?ooo`030492@P2LW9`0oooo01H0oooo00D0[Jf]034a<@0a<C40DU9B03Ti>@030492@P0304Y:
BP1BDU80FUYJ0080Hf=S0P1[Jf/207=cL`0307]kN`1SHf<0410@00@0Q8B42@2<S8`208B4Q080Ng]k
00@0Lg=c06=SH`1[Jf/0Jf][0P1cLg<407]kN`<0Lg=c0`1kNg/01@24Q8@0S8b<09bLW02UYJD0Q8B4
0080W9bL00P0YJFU059BDP1BDU80DU9B05YJFP1SHf<0Jf][07=cL`80Ng]k0P24Q8@208b<S0<0YJFU
0`2m_Kd90=kNgP<0_Kfm00D0YJFU08b<S024Q8@0Jf][08b<S00208B4Q00307]kN`1SHf<0Hf=S0080
YJFU00<0[Jf]0?ooo`3oool0203oool=0:f][A<0oooo00<0YJFU05YJFP1JFUX00`1JFUX00`1SHf<0
Jf][07=cL`0207]kN`80Q8B400<0S8b<09bLW02LW9`01@2LW9`90:FUY@D0W9bL00<0Q8B40:f][@3o
ool0203oool00680oooo0P2UYJD0200a<C40@T9204Y:BP1BDU80FUYJ06=SH`1[Jf/0Lg=c0P1kNg/2
08B4Q0<0S8b<0`2UYJD70;fm_@<0YJFU00<0S8b<0:f][@2UYJD0:@3oool207]kNaL0oooo00D0[Jf]
034a<@0a<C40<C4a03Ti>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S0`1[Jf/0101cLg<0Ng]k07]k
N`0a<C44000000D0S8b<00<0YJFU08b<S02UYJD00`2<S8`208B4Q00507]kN`1cLg<0Jf][07=cL`1k
Ng/00P24Q8@00`2<S8`0Q8B408B4Q00207]kN`80Q8B400H0S8b<09bLW02LW9`0S8b<09bLW02UYJD3
0:f][@060>o_k`2][Jd0YJFU04Y:BP1BDU80FUYJ0P1SHf<00`1[Jf/0Lg=c07]kN`0208B4Q0<0S8b<
0`2UYJD30;fm_@L0g]kN0`2m_Kd01P2UYJD0S8b<08B4Q01[Jf/0_Kfm0:FUY@80S8b<00L0Q8B407]k
N`1kNg/0Hf=S05YJFP2UYJD0[Jf]00L0oooo0`2][Jd;034a<@<0[Jf]403oool20:FUY@<0FUYJ00H0
Hf=S06][J`1cLg<0Lg=c07]kN`24Q8@308b<S0D0W9bL0`2UYJD50;Fe]@030;fm_@2e]KD0]KFe00<0
]KFe0P2UYJD209bLW080]KFe203oool00600oooo0`2UYJD205YJFP06034a<@12@T80BTY:05YJFP1S
Hf<0Jf][0P1cLg<207]kN`80Q8B40`2<S8`30:FUY@050;fm_@2UYJD0_Kfm0:FUY@2m_Kd00`2UYJD0
0`2<S8`0[Jf]0:FUY@0Z0?ooo`0309bLW012@T80oooo01H0oooo00D0[Jf]034a<@0a<C40<C4a03Ti
>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S0P1[Jf/01P1cLg<0Ng]k07]kN`1cLg<0000007=cL`80
Q8B400D0S8b<0000002<S8`0YJFU08b<S0050:FUY@<0S8b<0P24Q8@0101kNg/0Q8B408B4Q01kNg/2
08B4Q0@0S8b<102LW9`01P2UYJD0[Jf]0;Fe]@2m_Kd0inOW0>o_k`@0moOg00H0[Jf]0:FUY@1:BTX0
DU9B05YJFP1SHf<206][J`0407=cL`1kNg/0Q8B408B4Q0<0S8b<0`2UYJD30;fm_@030=kNgP2m_Kd0
g]kN00D0_Kfm00L0YJFU08b<S024Q8@0Jf][0;fm_@2UYJD0_Kfm0080YJFU00<0S8b<08B4Q024Q8@0
0P1kNg/0101SHf<0YJFU0:FUY@2][Jd30?ooo`<0[Jf]200a<C4703Ti>@<0[Jf]3P3oool00`2UYJD0
FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B408b<S02<S8`01@2LW9`30:FUY@<0
]KFe00<0_Kfm0;Fe]@2m_Kd00P2m_Kd00`2e]KD0_Kfm0;Fe]@020;Fe]@050:FUY@2LW9`0W9bL09bL
W02e]KD0203oool005h0oooo0`2UYJD505YJFP07034a<@12@T80DU9B05YJFP1SHf<0Jf][07=cL`02
07]kN`<0Q8B40`2<S8`70:FUY@<0S8b<00<0[Jf]0:FUY@3oool0:P3oool00`3>c/h0410@0?ooo`0F
0?ooo`040:f][@0a<C40<C4a034a<@<0@T9200<0BTY:059BDP1JFUX00P1SHf<00`1[Jf/0Lg=c07=c
L`0207]kN`040000000Q8B40Q8B408B4Q0<0S8b<00<000000:FUY@2UYJD01P2UYJD308b<S080Q8B4
0P1kNg/01024Q8@0S8b<08b<S02LW9`30:FUY@80[Jf]00D0]KFe0<K6aP3Ng]h0inOW0>o_k`060?oo
o`80moOg00P0[Jf]0:FUY@1BDU80DU9B05YJFP1SHf<0Jf][07=cL`80Ng]k0P24Q8@308b<S0<0YJFU
1`2m_Kd30:FUY@0308b<S024Q8@0Jf][0080YJFU102m_Kd00`2UYJD0S8b<08b<S00208B4Q00407]k
N`1SHf<0FUYJ0:FUY@@0[Jf]1@0a<C4303Ti>@/0@T9200<0YJFU0:f][@2][Jd0303oool00`2UYJD0
FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B408b<S02LW9`0102LW9`30:FUY@<0
]KFe2@2m_Kd30;Fe]@80YJFU00<0W9bL0;Fe]@3oool01`3oool005`0oooo0`2UYJD505YJFP<0Hf=S
00<0>CTi0492@P1BDU800P1SHf<00`1[Jf/0Lg=c07]kN`0408B4Q0<0S8b<1@2UYJD208b<S0030:f]
[@2UYJD0YJFU02d0oooo00<0410@0<k>cP3oool05@3oool0102][Jd0<C4a034a<@0a<C420492@P03
04Y:BP1BDU80FUYJ0080Hf=S00T0Jf][07=cL`1cLg<0Lg=c07]kN`24Q8@00000059BDP24Q8@00`2<
S8`50:FUY@030;Fe]@2UYJD0]KFe00<0YJFU0`2<S8`03@24Q8@0S8b<09bLW02LW9`0S8b<0:FUY@2]
[Jd0]KFe0;fm_@3>c/h0g]kN0>OWi`3_knl0303oool01`3gmoL0[Jf]0:FUY@1:BTX0FUYJ06=SH`1[
Jf/00P1cLg<207]kN`80Q8B40`2<S8`30:FUY@050;fm_@2UYJD0_Kfm0:FUY@2m_Kd00`2UYJD01P2<
S8`0Q8B406][J`2<S8`0YJFU0;fm_@80YJFU00<0_Kfm0:FUY@2m_Kd00P2UYJD208b<S00608B4Q01k
Ng/0Ng]k06=SH`1JFUX0DU9B1P0a<C400`0i>CT0@T920492@P050492@PD0BTY:1012@T800`2UYJD0
[Jf]0?ooo`090?ooo`80YJFU0`1JFUX01@1SHf<0Jf][07=cL`1kNg/0Q8B40080S8b<0`2LW9`30:FU
Y@030000002e]KD0]KFe00@0_Kfm00<000000;fm_@36a/H01036a/H40;fm_@030;Fe]@2][Jd0YJFU
0080_Kfm1`3oool005/0oooo0P2UYJD605YJFP0406=SH`1[Jf/0Jf][06][J`80FUYJ00D0@T9204Y:
BP1JFUX0Hf=S06][J`0207=cL`80Ng]k1024Q8@00`2<S8`0Q8B408b<S00208B4Q0030:f][@2UYJD0
YJFU02l0oooo00<0Hf=S08b<S03oool05@3oool0102][Jd0<C4a034a<@0i>CT20492@P0404Y:BP1B
DU80FUYJ06=SH`80Jf][0P1cLg<01@1kNg/0Q8B4059BDP000000Q8B400<0S8b<0`2UYJD00`2m_Kd0
YJFU0;fm_@030;fm_@040;Fe]@2UYJD0YJFU0:FUY@<0S8b<0P24Q8@01P2LW9`0[Jf]0<K6aP3Ng]h0
inOW0>o_ka80oooo00L0[Jf]0:FUY@1BDU80FUYJ06=SH`1[Jf/0Lg=c0080Ng]k0`24Q8@308b<S0L0
YJFU0`2<S8`01P24Q8@0Jf][07]kN`24Q8@0S8b<0:FUY@80_Kfm00<0YJFU0;fm_@2m_Kd00P2m_Kd2
0:FUY@0708b<S024Q8@0Q8B407]kN`1SHf<0FUYJ059BDP04034a<@0303Ti>@12@T80@T9200<0@T92
0`1:BTX7059BDP80BTY:00<0@T920:FUY@2][Jd02@3oool01P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][
J`80Lg=c00<0Ng]k08B4Q02<S8`0102LW9`20:FUY@030;Fe]@000000]KFe00@0_Kfm00<0a/K60000
0036a/H01P36a/H40;fm_@040;Fe]@2][Jd0[Jf]0;fm_@L0oooo001J0?ooo`80YJFU1P1JFUX00`1S
Hf<0Jf][07=cL`0307=cL`0806=SH`2<S8`0DU9B0492@P1BDU80FUYJ06=SH`1[Jf/207=cL`<0Ng]k
0`24Q8@0101kNg/0YJFU0:FUY@2UYJDa0?ooo`0309bLW00a<C40oooo01D0oooo00@0[Jf]034a<@0a
<C40>CTi0P12@T80101:BTX0DU9B05YJFP1SHf<206][J`0607=cL`1kNg/0Ng]k08B4Q00@41000000
0`2<S8`30:FUY@P0_Kfm00D0]KFe0:FUY@2UYJD0YJFU08b<S00208B4Q00408b<S02e]KD0inOW0?Og
maH0oooo00<0[Jf]0:FUY@2UYJD00P1SHf<00`1[Jf/0Lg=c07]kN`0408B4Q0<0S8b<1@2UYJD208b<
S0030:f][@2UYJD0YJFU0080YJFU00H0Jf][07]kN`24Q8@0S8b<0:FUY@2m_Kd20:FUY@@0_Kfm00@0
YJFU08b<S02<S8`0Q8B40P1kNg/0101SHf<0DU9B034a<@0i>CT40492@P<0BTY:0`1BDU8705YJFP<0
DU9B00<0BTY:0:FUY@2][Jd0203oool02P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4
Q02<S8`509bLW0040:FUY@2e]KD0]KFe000000@0_Kfm0P36a/H01P000000a/K60<K6aP3>c/h0a/K6
0<k>cP<0a/K60`2m_Kd0102e]KD0[Jf]0:f][@2m_Kd70?ooo`00F@3oool20:FUY@D0FUYJ00<0Hf=S
06][J`1[Jf/00P1cLg<307]kN`0706][J`2LW9`0DU9B06=SH`1kNg/0@T9205YJFP0206=SH`0706][
J`1cLg<0Lg=c07=cL`1kNg/0Lg=c07]kN`020:FUYC@0oooo00<0410@0=kNgP3oool0503oool0202]
[Jd0<C4a034a<@0i>CT0@T9204Y:BP1BDU80FUYJ0P1SHf<00`1[Jf/0Lg=c07]kN`0207]kN`030492
@P0Q8B4000000080S8b<0`2UYJD50;fm_@030=kNgP2m_Kd0g]kN00<0_Kfm0P2UYJD01`2LW9`0S8b<
08B4Q02<S8`0_Kfm0>o_k`3gmoL0603oool30:FUY@0406=SH`1[Jf/0Lg=c07=cL`80Ng]k1024Q8@0
0`2<S8`0Q8B408b<S00208B4Q0030:f][@2UYJD0YJFU00<0oooo00L0[Jf]0:FUY@2UYJD0Ng]k08B4
Q02<S8`0YJFU0080_Kfm0P2UYJD00`2m_Kd0YJFU0;fm_@020:FUY@0408b<S024Q8@0Q8B407]kN`80
>CTi0`12@T8204Y:BP<0DU9B0`1JFUX906=SH`0305YJFP1BDU80BTY:0080YJFU1`3oool02P2UYJD0
FUYJ05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`409bLW0050:FUY@2e]KD0]KFe0;Fe]@00
00000`2m_Kd30<K6aP0300000036a/H0c/k>00@0c/k>0`36a/H20;fm_@040;Fe]@2][Jd0[Jf]0;fm
_@L0oooo001H0?ooo`80YJFU101JFUX206=SH`0306][J`1cLg<0Lg=c0080Ng]k0`24Q8@04@2<S8`0
W9bL059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<05YJFP2<S8`0Q8B407]kN`1cLg<0
YJFU03D0oooo0P1SHf<E0?ooo`030:f][@0a<C40<C4a0080@T9200D0BTY:059BDP1JFUX0Hf=S06][
J`0207=cL`80Ng]k00D0Lg=c00P8201[Jf/0000008b<S0030:FUY@80_Kfm00<000000=kNgP2m_Kd0
1@3Ng]h20;fm_@080;Fe]@2UYJD0W9bL08b<S024Q8@0S8b<0;fm_@3_knlK0?ooo`<0YJFU00@0Hf=S
06][J`1cLg<0Lg=c0`1kNg/308B4Q00407]kN`2UYJD0YJFU0:FUY@L0oooo0`2UYJD0101kNg/0Q8B4
08b<S02UYJD20;fm_@030:FUY@2m_Kd0_Kfm0080_Kfm00@0YJFU08b<S02<S8`0Q8B40`12@T8204Y:
BP80DU9B0`1JFUX406=SH`L0Jf][0`1SHf<205YJFP040:FUY@2][Jd0oooo0?ooo`80[Jf]0`2UYJD3
05YJFP0606][J`1cLg<0Lg=c07]kN`24Q8@0S8b<0`2LW9`20:FUY@80]KFe00@0_Kfm0000002m_Kd0
_Kfm0`36a/H00`3>c/h000000<k>cP060<k>cP<0a/K60P2m_Kd20;Fe]@030;fm_@3oool0oooo00D0
oooo001G0?ooo`80YJFU101JFUX0101SHf<0Jf][07=cL`1cLg<207]kN`80Q8B40`2<S8`309bLW007
0;Fe]@2m_Kd0a/K60<k>cP3Fe]H0c/k>0<K6aP0409bLW080S8b<00<0[Jf]0:FUY@3oool0<`3oool0
1@3Ng]h0410@0>o_k`3oool000000180oooo0P2][Jd0200a<C40@T920492@P1:BTX0DU9B05YJFP1S
Hf<0Jf][0P1cLg<0101kNg/0Q8B4024Q8@12@T8208b<S0030000002UYJD0YJFU0080_Kfm00<00000
0=kNgP3Ng]h01`3Ng]h0102m_Kd0]KFe0;Fe]@2UYJD208b<S0030:f][@2m_Kd0moOg01d0oooo3@2U
YJD;0?ooo`80YJFU00H0Jf][07]kN`24Q8@0S8b<0:FUY@2m_Kd20:FUY@030;fm_@2UYJD0_Kfm0080
YJFU0`12@T800`1:BTX0DU9B059BDP0205YJFP@0Hf=S0`1[Jf/707=cL`<0Jf][0P1SHf<01@1JFUX0
YJFU0:f][@2][Jd0YJFU0080FUYJ00<0Lg=c05YJFP1JFUX00P1JFUX01@1[Jf/0Lg=c07]kN`24Q8@0
S8b<00<0W9bL0`2UYJD00`2e]KD0_Kfm0;fm_@0800000080c/k>00<0e]KF0<k>cP3Fe]H00`3>c/h3
0<K6aP040;fm_@2e]KD0]KFe0<K6aPL0oooo001F0?ooo`80YJFU101JFUX01@1SHf<0Jf][07=cL`1c
Lg<0Ng]k0080Q8B40P2<S8`709bLW0L0YJFU1@2LW9`00`2<S8`0[Jf]0:FUY@0d0?ooo`0506=SH`1k
Ng/0oooo0?ooo`0000004P3oool0202][Jd0<C4a03Ti>@12@T80BTY:059BDP1JFUX0Hf=S0P1[Jf/0
1@1cLg<0Ng]k0492@P0@4100Ng]k00<0S8b<100000020;fm_@030=kNgP2m_Kd0g]kN0080g]kN00<0
_Kfm0=kNgP2m_Kd00P2m_Kd01P2UYJD0S8b<08B4Q02<S8`0[Jf]0?Ogmb@0oooo00<0YJFU0?ooo`3o
ool0403oool01`2][Jd0YJFU0:FUY@1kNg/0Q8B408b<S02UYJD00P2m_Kd00`2UYJD0_Kfm0;fm_@02
0;fm_@80@T920P1:BTX2059BDP0305YJFP1SHf<0Hf=S0080Hf=S0`1[Jf/907=cL`<0Jf][0P1SHf<0
0`0a<C40@T9205YJFP0307=cL`0:07]kN`1SHf<0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0Q8B408b<
S0<0W9bL0P2UYJD01@2e]KD0_Kfm0;fm_@2m_Kd0000000<0a/K60`3>c/h00`000000c/k>0=KFeP04
0=KFeP<0c/k>0P36a/H0102m_Kd0]KFe0;Fe]@36a/H70?ooo`00EP3oool00`2UYJD0FUYJ05YJFP03
05YJFP0306=SH`1[Jf/0Lg=c0080Ng]k0P24Q8@00`2<S8`0W9bL09bLW00509bLW0T0YJFU1@2LW9`0
0`24Q8@0YJFU0?ooo`0c0?ooo`050=kNgP000000g]kN0?ooo`0000004P3oool0202][Jd0<C4a03Ti
>@12@T80BTY:059BDP1JFUX0Hf=S0P1[Jf/0101cLg<0FUYJ00P8201[Jf/308b<S0<0YJFU0`2m_Kd9
0=kNgP80_Kfm00H0]KFe0:FUY@2<S8`0S8b<0:f][@3gmoLi0?ooo`80YJFU00H0Jf][07]kN`24Q8@0
S8b<0:FUY@2m_Kd20:FUY@050;fm_@12@T80@T9204Y:BP1BDU800`1JFUX206=SH`<0Jf][0`1cLg<5
07]kN`0308B4Q01kNg/0Ng]k00<0Ng]k0P1cLg<01@1[Jf/0@T9204Y:BP1SHf<0Ng]k00@0Lg=c0P1J
FUX01P1SHf<0Lg=c07=cL`1kNg/0Q8B408b<S0<0W9bL00<0YJFU0;Fe]@2e]KD00`2m_Kd00`000000
a/K60<K6aP030<k>cP030=KFeP000000e]KF00H0e]KF0`3>c/h01@36a/H0_Kfm0;fm_@2m_Kd0a/K6
00L0oooo001E0?ooo`80YJFU0`1JFUX01P1SHf<0Jf][07=cL`1cLg<0Ng]k08B4Q0<0S8b<1@2LW9`3
0:FUY@D0]KFe00<0_Kfm0;Fe]@2e]KD00`2e]KD20:FUY@80W9bL00<0[Jf]0:FUY@3oool0<`3oool0
1@1cLg<0@T920?ooo`3oool000000140oooo0P2][Jd20492@P0:059BDP1JFUX0Hf=S06=SH`1[Jf/0
Lg=c06=SH`0820P0DU9B08B4Q080S8b<0`2UYJD30;fm_@/0g]kN0P2m_Kd0102UYJD0S8b<0:f][@2]
[Jdk0?ooo`070:f][@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@020;fm_@050:FUY@12@T80BTY:04Y:
BP1BDU800P1JFUX206=SH`<0Jf][0`1cLg<307]kN`0308B4Q01kNg/0Q8B40080Q8B400<0Ng]k08B4
Q01kNg/00P1kNg/00`1cLg<0Jf][0492@P0207=cL`<0W9bL0P1kNg/205YJFP0506=SH`1cLg<0Ng]k
08B4Q02<S8`00`2LW9`0102UYJD0]KFe0;Fe]@2e]KD20;fm_@030<K6aP000000a/K600<0c/k>0P3F
e]H01P000000e]KF0=KFeP3Ng]h0e]KF0=kNgP<0e]KF0`3>c/h01036a/H0_Kfm0;fm_@36a/H70?oo
o`00E@3oool00`2UYJD0FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B408b<S02<
S8`01@2LW9`30:FUY@<0]KFe00<0_Kfm0;Fe]@2m_Kd00P2m_Kd00`2e]KD0_Kfm0;Fe]@020;Fe]@05
0:FUY@2LW9`0W9bL09bLW02UYJD0<@3oool020000000oooo0?ooo`3_knl08B4Q08b<S03oool00000
4P3oool01P2][Jd0<C4a0492@P1:BTX0DU9B05YJFP<0Hf=S00@0410@034a<@24Q8@0Q8B40`2<S8`3
0:FUY@<0_Kfm1`3Ng]h30;fm_@80YJFU0P2<S8`00`2UYJD0oooo0?ooo`0l0?ooo`070:FUY@1JFUX0
Jf][07]kN`24Q8@0S8b<0:FUY@020492@P80BTY:00@0DU9B05YJFP1SHf<0Hf=S0`1[Jf/307=cL`<0
Ng]k2@24Q8@307]kN`0407=cL`1SHf<0Ng]k07]kN`<0W9bL0P24Q8@205YJFP0506][J`1cLg<0Ng]k
08B4Q02<S8`00P2LW9`20:FUY@80]KFe0P2m_Kd20<K6aP040000003>c/h0c/k>0<k>cP<0e]KF00<0
00000=KFeP3Ng]h0103Ng]h30=KFeP80c/k>00@0a/K60;fm_@2m_Kd0a/K61`3oool005D0oooo00<0
YJFU05YJFP1JFUX00P1JFUX00`1SHf<0Jf][07=cL`0207]kN`0308B4Q02<S8`0W9bL00@0W9bL0`2U
YJD30;Fe]@T0_Kfm0`2e]KD0102UYJD0W9bL09bLW02UYJDb0?ooo`080000003oool0oooo0<k>cP0@
4100_Kfm0?ooo`00000A0?ooo`80[Jf]00T0@T9204Y:BP1BDU80FUYJ06=SH`1JFUX061PH034a<@1k
Ng/00P24Q8@208b<S0<0YJFU0`2m_Kd90=kNgP<0_Kfm00@0YJFU08b<S02][Jd0YJFU?P3oool01P2]
[Jd0<C4a059BDP1SHf<0Ng]k08B4Q080@T9200@0BTY:059BDP1JFUX0FUYJ0P1SHf<0101[Jf/0Lg=c
07=cL`1cLg<307]kN`@0Q8B400<0S8b<08B4Q02<S8`0102<S8`408B4Q00407]kN`1cLg<0Q8B408B4
Q0<0W9bL0P2<S8`205YJFP0506][J`1cLg<0Ng]k08B4Q02<S8`00P2LW9`20:FUY@030;Fe]@2m_Kd0
_Kfm00<0a/K60`3>c/h30=KFePT0g]kN0`3Fe]H01@3>c/h0a/K60;fm_@3>c/h0a/K600L0oooo001D
0?ooo`80YJFU0`1JFUX01@1SHf<0Jf][07=cL`1kNg/0Q8B40080S8b<0`2LW9`30:FUY@<0]KFe102m
_Kd00`36a/H0_Kfm0<K6aP040<K6aP@0_Kfm00D0]KFe0:FUY@2LW9`0]KFe0:f][@0b0?ooo`800000
00D0oooo09bLW00@4100c/k>0000000B0?ooo`0:0:f][@2UYJD0@T9204Y:BP1JFUX0DU9B00P8200Q
8B40Lg=c07]kN`80Q8B40`2<S8`30:FUY@<0_Kfm1`3Ng]h30;fm_@040:FUY@2<S8`0[Jf]0:FUYCl0
oooo00D0[Jf]034a<@0a<C40<C4a03Ti>@030492@P0304Y:BP1BDU80FUYJ0080Hf=S0P1[Jf/207=c
L`<0Ng]k1024Q8@908b<S0@0Q8B400<0Ng]k08b<S02<S8`00`2UYJD209bLW0070;Fe]@1JFUX0Hf=S
07=cL`1kNg/0Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe0080_Kfm0`36a/H30<k>cP<0e]KF00<0
g]kN0=KFeP3Ng]h00P3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP030<k>cP36a/H0_Kfm0080_Kfm203o
ool005@0oooo00H0YJFU05YJFP1JFUX0FUYJ06=SH`1[Jf/207=cL`0307]kN`24Q8@0S8b<00@0W9bL
0P2UYJD30;Fe]@@0_Kfm2@36a/H40;fm_@040;Fe]@2UYJD0W9bL0:f][C@0oooo00H000000?ooo`2L
W9`0410@0<k>cP00000B0?ooo`060:f][@2UYJD0@T92034a<@0820P0>CTi0P1[Jf/0101cLg<0Ng]k
08B4Q024Q8@308b<S0<0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP050;fm_@040:FUY@2<S8`0[Jf]0:FU
YD00oooo00D0[Jf]034a<@0a<C40<C4a03Ti>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S0`1[Jf/0
101cLg<0Ng]k07]kN`1kNg/4000000D0S8b<00<0YJFU08b<S02UYJD00`2<S8`308B4Q00307]kN`2L
W9`0W9bL00<0]KFe00T0_Kfm0<K6aP2UYJD0FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`00`2LW9`0102U
YJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>0<K6aP2m_Kd0_Kfm203o
ool005@0oooo00X0YJFU05YJFP1JFUX0FUYJ06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<1@2LW9`0102U
YJD0]KFe0;Fe]@2e]KD40;fm_@D0a/K600<0c/k>0<K6aP3>c/h00`36a/H30;fm_@040;Fe]@2UYJD0
W9bL0:f][CD0oooo0P0000000`2LW9`000000000000C0?ooo`0809bLW00a<C4020P80492@P1JFUX0
Hf=S06][J`1cLg<207]kN`80Q8B40`2<S8`30:FUY@L0_Kfm0`2UYJD00`2<S8`0[Jf]0:FUY@110?oo
o`050:f][@0a<C40<C4a034a<@0i>CT00P12@T800`1:BTX0DU9B05YJFP0206=SH`80Jf][00D0Lg=c
07]kN`1kNg/0Ng]k0000000308B4Q00508b<S0000000S8b<0:FUY@2<S8`01@2UYJD308b<S080Q8B4
00<0Ng]k08B4Q02<S8`00`2UYJD0202e]KD0W9bL0;Fe]@1JFUX0Jf][07=cL`24Q8@0S8b<0`2LW9`0
0`2UYJD0]KFe0;fm_@020;fm_@80a/K60`3>c/h30=KFeP/0g]kN0P3Fe]H0103>c/h0a/K60<K6aP2m
_Kd80?ooo`00E03oool02P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`409bL
W0040:FUY@2e]KD0]KFe000000@0_Kfm0P36a/H00`000000c/k>0<K6aP050<k>cP<0a/K60P2m_Kd0
102e]KD0YJFU09bLW02][Jdg0?ooo`80000000<08B4Q0492@P3Ng]h0403oool0202<S8`0410@03Ti
>@2LW9`0BTY:05YJFP1SHf<0Jf][0P1cLg<207]kN`80Q8B40`2<S8`30:FUY@050;fm_@2UYJD0_Kfm
0:FUY@2m_Kd00`2UYJD00`2<S8`0[Jf]0:FUY@120?ooo`040:f][@0a<C40<C4a034a<@<0@T9200<0
BTY:059BDP1JFUX00P1SHf<00`1[Jf/0Lg=c07=cL`0207]kN`0400000024Q8@0Q8B408B4Q0<0S8b<
00<000000:FUY@2UYJD01P2UYJD308b<S080Q8B400<0Ng]k09bLW02e]KD00P2e]KD02@2m_Kd0a/K6
0<k>cP3Fe]H0FUYJ06][J`1kNg/0Q8B408b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>
c/h30=KFePL0g]kN0`3Fe]H20<k>cP030<K6aP2m_Kd0]KFe00T0oooo001D0?ooo`050:FUY@1JFUX0
FUYJ05YJFP1[Jf/00P1cLg<00`1kNg/0Q8B408b<S00309bLW080YJFU0P2e]KD010000000_Kfm0;fm
_@2m_Kd30<K6aP030000003>c/h0c/k>00H0c/k>0`36a/H20;fm_@030;Fe]@2UYJD0[Jf]03T0oooo
00D0kno_07=cL`000000Hf=S0=kNgP0;0?ooo`0=0=kNgP1kNg/08B4Q0492@P2m_Kd0oooo0:f][@2U
YJD0DU9B05YJFP1SHf<0Jf][07=cL`0207]kN`<0Q8B40`2<S8`70:FUY@<0S8b<00<0[Jf]0:FUY@3o
ool0@P3oool0102][Jd0<C4a034a<@0a<C420492@P0304Y:BP1BDU80FUYJ0080Hf=S00L0Jf][07=c
L`1cLg<0Lg=c07]kN`24Q8@000000080Q8B40`2<S8`50:FUY@030;fm_@2UYJD0_Kfm00<0YJFU0`2<
S8`208B4Q00308b<S02UYJD0_Kfm0080W9bL00P0]KFe0;fm_@2UYJD0YJFU07=cL`1kNg/0Q8B408b<
S080W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd20<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>0<K6
aP36a/H0]KFe2@3oool005@0oooo00T0YJFU05YJFP1JFUX0FUYJ06][J`1cLg<0Ng]k08B4Q02<S8`0
0`2LW9`30:FUY@030;Fe]@2m_Kd000000080_Kfm0`36a/H00`3>c/h000000<k>cP020<k>cP030=KF
eP3>c/h0e]KF00<0c/k>0`36a/H0102m_Kd0]KFe0:FUY@2][Jdk0?ooo`070=kNgP1SHf<0410@034a
<@1kNg/0_Kfm0=kNgP030?ooo`070=kNgP2m_Kd0Ng]k034a<@000000Hf=S0;fm_@040?ooo`80YJFU
00H0DU9B06=SH`1SHf<0Jf][07=cL`1kNg/408B4Q0<0S8b<1@2UYJD208b<S0030:f][@2UYJD0YJFU
04@0oooo00@0[Jf]034a<@0a<C40>CTi0P12@T80101:BTX0DU9B05YJFP1SHf<206][J`80Lg=c00D0
Ng]k08B4Q024Q8@0000008B4Q00308b<S0<0YJFU00<0_Kfm0:FUY@2m_Kd0102m_Kd30:FUY@80S8b<
00<0Q8B407]kN`1cLg<00P2UYJD30:f][@80oooo0P2UYJD00`1cLg<0Ng]k08b<S00309bLW0040:FU
Y@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e]KD:0?oo
o`00E03oool02@2UYJD0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0Q8B408b<S00309bLW080YJFU00D0
]KFe0;fm_@2m_Kd000000;fm_@030<K6aP80c/k>00<000000=KFeP3>c/h01@3Fe]H30<k>cP80a/K6
00@0_Kfm0;Fe]@2UYJD0[Jf]?P3oool0102][Jd0Lg=c0492@P0@410300000005010@4012@T80Lg=c
0:f][@3_knl01`3oool01P2][Jd0@T9204Y:BP1JFUX0Hf=S06][J`80Lg=c0P1kNg/408B4Q00308b<
S024Q8@0S8b<0080Q8B400<0[Jf]0:FUY@2UYJD0AP3oool0102][Jd0<C4a034a<@0i>CT20492@P04
04Y:BP1BDU80FUYJ06=SH`80Jf][00<0Lg=c07]kN`1kNg/00P24Q8@010000000S8b<08b<S02<S8`3
0:FUY@T0_Kfm0`2UYJD01@2<S8`0Q8B408B4Q01kNg/0YJFU00L0oooo0P2UYJD00`1cLg<0Q8B408b<
S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFeP030=kNgP3Fe]H0g]kN00D0e]KF
00@0c/k>0<K6aP36a/H0]KFe2`3oool005@0oooo00@0YJFU05YJFP1JFUX0Hf=S0P1cLg<00`1kNg/0
Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe0080_Kfm00@000000<K6aP36a/H0a/K60`3>c/h00`00
0000e]KF0=KFeP060=KFeP<0c/k>00D0a/K60;fm_@2m_Kd0]KFe0:f][@1A0?ooo`080:f][@0a<C40
DU9B0492@P1BDU80FUYJ06=SH`1[Jf/207=cL`<0Ng]k0`24Q8@0101kNg/0YJFU0:FUY@2UYJE80?oo
o`080:f][@0a<C40<C4a03Ti>@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Ng]k
0P24Q8@00`000000S8b<08b<S0030:FUY@D0_Kfm00<0g]kN0;fm_@3Ng]h00`2m_Kd30:FUY@0408b<
S024Q8@0Ng]k0:FUY@P0oooo0P2UYJD00`1kNg/0Q8B408b<S00209bLW0030:FUY@2e]KD0]KFe0080
_Kfm0`36a/H30<k>cPL0e]KF0`3>c/h20<K6aP030;Fe]@3oool0oooo00X0oooo001D0?ooo`080:FU
Y@1JFUX0FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`309bLW0040:FUY@2e]KD0]KFe0;Fe]@80_Kfm2000
00030=KFeP030=kNgP3Fe]H0g]kN00<0e]KF0`3>c/h01036a/H0_Kfm0;Fe]@2e]KEA0?ooo`030:f]
[@0i>CT0FUYJ0080Hf=S00D0@T9205YJFP1SHf<0Hf=S06][J`0207=cL`H0YJFUBP3oool00`2][Jd0
<C4a034a<@020492@P0504Y:BP1BDU80FUYJ06=SH`1[Jf/00P1cLg<207]kN`80Q8B400<0S8b<0000
002<S8`00`2UYJD20;fm_@030000003Ng]h0_Kfm00D0g]kN0`2m_Kd20:FUY@0408b<S024Q8@0Ng]k
0:FUY@T0oooo0P2UYJD0101kNg/0S8b<09bLW02LW9`20:FUY@80]KFe0P2m_Kd30<K6aP<0c/k>00D0
e]KF0<k>cP3Fe]H0c/k>0=KFeP030<k>cP80a/K600<0]KFe0?ooo`3oool02`3oool005@0oooo00P0
YJFU05YJFP1JFUX0Jf][07=cL`1kNg/0Q8B408b<S080W9bL0P2UYJD20;Fe]@80_Kfm00<0a/K60000
0036a/H00`3>c/h20=KFeP030000003Ng]h0e]KF00D0g]kN0`3Fe]H20<k>cP040<K6aP2m_Kd0]KFe
0;Fe]E00oooo0P2][Jd00`12@T80Hf=S06=SH`0207]kN`0708B4Q02<S8`0YJFU0;fm_@2UYJD0FUYJ
0:FUY@1?0?ooo`80[Jf]00P0<C4a0492@P12@T80BTY:059BDP1JFUX0Hf=S06][J`80Lg=c00<0Ng]k
08B4Q024Q8@00`2<S8`00`000000YJFU0:FUY@020;fm_@030000003Ng]h0g]kN00L0g]kN0`2m_Kd0
1@2UYJD0S8b<08B4Q02][Jd0YJFU00X0oooo0P2UYJD01@24Q8@0S8b<09bLW02LW9`0YJFU0080]KFe
0`2m_Kd30<K6aPL0c/k>1036a/H00`2e]KD0oooo0?ooo`0<0?ooo`00E03oool20:FUY@0605YJFP1[
Jf/0Lg=c07]kN`24Q8@0S8b<0P2LW9`20:FUY@030;Fe]@2m_Kd0_Kfm0080a/K600@000000<k>cP3>
c/h0c/k>0`3Fe]H00`000000g]kN0=kNgP060=kNgP<0e]KF00D0c/k>0<K6aP2m_Kd0a/K60;Fe]@1@
0?ooo`0>0:f][@0a<C40@T9206=SH`1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S02U
YJE@0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<206][J`0307=cL`1kNg/0Ng]k
0080Q8B40`2<S8`400000080_Kfm00<0g]kN0;fm_@3Ng]h00P3Ng]h00`2m_Kd0g]kN0;fm_@020;fm
_@050:FUY@2<S8`0Q8B408B4Q02UYJD0303oool20:FUY@060:f][@2LW9`0W9bL09bLW02UYJD0]KFe
102m_Kd30<K6aPD0c/k>0`36a/H00`2m_Kd0]KFe0?ooo`0>0?ooo`00E@3oool01`2UYJD0FUYJ06=S
H`1cLg<0Ng]k08B4Q02<S8`00`2LW9`00`2UYJD0]KFe0;Fe]@020;fm_@030<K6aP000000a/K600<0
c/k>0P3Fe]H00`000000g]kN0=KFeP030=kNgP030=KFeP3Ng]h0e]KF0080e]KF00D0c/k>0<K6aP2m
_Kd0_Kfm0;Fe]@1A0?ooo`0>0:f][@0a<C40@T92059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2U
YJD0S8b<08B4Q02UYJE@0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<206][J`04
07=cL`1kNg/0Q8B408B4Q0<0S8b<0`2UYJD30;fm_@T0g]kN0`2m_Kd0102UYJD0S8b<08B4Q02UYJD>
0?ooo`030:FUY@2][Jd0[Jf]0080W9bL0P2UYJD20;Fe]@@0_Kfm00<0a/K60;fm_@36a/H00P2m_Kd0
0`36a/H0_Kfm0;Fe]@0A0?ooo`00E@3oool01`2UYJD0FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`00`2L
W9`0102UYJD0]KFe0;fm_@2m_Kd20<K6aP040000003>c/h0c/k>0<k>cP<0e]KF00<000000=kNgP3N
g]h01P3Ng]h30=KFeP040<k>cP36a/H0_Kfm0;Fe]E40oooo00h0[Jf]03Ti>@1JFUX0DU9B06=SH`1k
Ng/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0[Jf]0:FUYE00oooo0P2][Jd20492@P07059BDP1JFUX0
Hf=S06=SH`1[Jf/0Lg=c07]kN`0308B4Q080S8b<0`2UYJD30;fm_@/0g]kN0P2m_Kd0102UYJD0S8b<
0:f][@2UYJD@0?ooo`030:FUY@2][Jd0[Jf]0080W9bL0P2UYJD30;Fe]@<0_Kfm00@0]KFe0;fm_@2e
]KD0]KFe4`3oool005D0oooo0P2UYJD0101[Jf/0Lg=c08B4Q02<S8`309bLW0030:FUY@2e]KD0_Kfm
0080_Kfm0P36a/H30<k>cP<0e]KF2`3Ng]h20=KFeP040<k>cP36a/H0a/K60;Fe]D`0oooo1P2][Jd0
3012@T80Hf=S059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0:FUYE80oooo00H0[Jf]
034a<@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Q8B40`2<S8`30:FUY@<0_Kfm
1`3Ng]h30;fm_@80YJFU00<0S8b<08B4Q02UYJD04`3oool00`2UYJD0[Jf]0;Fe]@050;Fe]@030;fm
_@2e]KD0_Kfm0080]KFe5@3oool005H0oooo00H0YJFU05YJFP1[Jf/0Ng]k08B4Q02<S8`309bLW004
0:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H20<k>cP030<K6aP2m_Kd0]KFe
04/0oooo0`2][Jd5034a<@0<0492@P1SHf<0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<
S8`0YJFUDP3oool20:f][@070492@P1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`0207]kN`80Q8B40P2<
S8`30:FUY@<0_Kfm2@3Ng]h30;fm_@040:FUY@2<S8`0[Jf]0:FUYAT0oooo00<0[Jf]0?ooo`3oool0
6@3oool005H0oooo0P2UYJD0101cLg<0Ng]k08B4Q02<S8`209bLW0030:FUY@2e]KD0]KFe0080_Kfm
0P36a/H30<k>cP<0e]KF2@3Ng]h30=KFeP040<k>cP36a/H0a/K60;Fe]DT0oooo0`2][Jd7034a<@0<
0492@P1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S024Q8@0YJFUD`3oool01@2][Jd0
YJFU0492@P1:BTX0FUYJ0080Hf=S00<0Jf][07=cL`1kNg/00P24Q8@308b<S0<0YJFU0`2m_Kd70=kN
gP<0_Kfm00@0YJFU08b<S02][Jd0YJFU=P3oool005L0oooo0P2UYJD00`1cLg<0Ng]k08b<S00309bL
W0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e
]KE80?ooo`<0[Jf]1@0a<C4203Ti>@0?034a<@0i>CT0FUYJ059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU
0;fm_@2UYJD0S8b<08B4Q02UYJD0[Jf]05<0oooo00H0[Jf]0:FUY@12@T80DU9B05YJFP1SHf<206][
J`0407=cL`1kNg/0Q8B408B4Q0<0S8b<0`2UYJD30;fm_@030=kNgP2m_Kd0g]kN00D0_Kfm00@0YJFU
08b<S02][Jd0YJFU=`3oool005P0oooo0P2UYJD00`1cLg<0Q8B408b<S00309bLW0040:FUY@2e]KD0
_Kfm0;fm_@<0a/K60`3>c/h30=KFeP030=kNgP3Fe]H0g]kN00D0e]KF00@0c/k>0<K6aP36a/H0]KFe
B03oool20:f][@H0<C4a01<0>CTi0492@P12@T80<C4a0492@P1SHf<0DU9B06=SH`1kNg/0Q8B408b<
S02UYJD0_Kfm0:FUY@2<S8`0Hf=S0492@P2UYJD0[Jf]05<0oooo00P0[Jf]0:FUY@1:BTX0DU9B05YJ
FP1SHf<0Jf][07=cL`80Ng]k0P24Q8@308b<S0<0YJFU1`2m_Kd30:FUY@0308b<S02][Jd0YJFU03P0
oooo001I0?ooo`80YJFU00<0Ng]k08B4Q02<S8`00P2LW9`00`2UYJD0]KFe0;Fe]@020;fm_@<0a/K6
0`3>c/h70=KFeP<0c/k>0P36a/H00`2e]KD0oooo0?ooo`160?ooo`80[Jf]1P0a<C401P0i>CT0@T92
0492@P12@T80<C4a0492@P80Hf=S0P1kNg/02`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S01SHf<0BTY:
0492@P2UYJD0[Jf]05<0oooo00H0[Jf]0:FUY@1:BTX0FUYJ06=SH`1[Jf/207=cL`80Ng]k0P24Q8@3
08b<S0<0YJFU00D0_Kfm0:FUY@2m_Kd0YJFU0;fm_@030:FUY@0308b<S02][Jd0YJFU03T0oooo001J
0?ooo`80YJFU00@0Ng]k08b<S02LW9`0W9bL0P2UYJD20;Fe]@80_Kfm0`36a/H30<k>cP050=KFeP3>
c/h0e]KF0<k>cP3Fe]H00`3>c/h20<K6aP030;Fe]@3oool0oooo04H0oooo0P2][Jd5034a<@0303Ti
>@12@T80@T920080@T920P1:BTX03012@T80Hf=S06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2m
_Kd0Q8B406=SH`80DU9B00<0BTY:0:FUY@2][Jd0D`3oool01`2][Jd0YJFU059BDP1JFUX0Hf=S06][
J`1cLg<00P1kNg/308B4Q0<0S8b<1`2UYJD308b<S0030:f][@2UYJD0oooo03T0oooo001K0?ooo`80
YJFU00D0Q8B408b<S02LW9`0W9bL0:FUY@020;Fe]@<0_Kfm0`36a/H70<k>cP@0a/K600<0]KFe0?oo
o`3oool0AP3oool20:f][@@0<C4a0P0i>CT30492@P80BTY:0P1BDU802`1JFUX0DU9B06=SH`1kNg/0
Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0Q8B40080Hf=S00<0FUYJ059BDP1:BTX00P2UYJEC0?ooo`80
YJFU00H0DU9B06=SH`1SHf<0Jf][07=cL`1kNg/408B4Q0<0S8b<1@2UYJD208b<S0030:f][@2UYJD0
YJFU03/0oooo001L0?ooo`80YJFU00H0[Jf]09bLW02LW9`0W9bL0:FUY@2e]KD40;fm_@<0a/K61@3>
c/h30<K6aP030;fm_@2e]KD0oooo04L0oooo0P2][Jd4034a<@0403Ti>@12@T80@T920492@P80BTY:
0P1BDU8305YJFP80Hf=S00L0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0080Jf][0`1SHf<205YJ
FP80YJFUD`3oool01P2][Jd0@T9204Y:BP1JFUX0Hf=S06][J`80Lg=c0P1kNg/408B4Q00308b<S024
Q8@0S8b<0080Q8B400<0[Jf]0:FUY@2UYJD0?@3oool005h0oooo00<0YJFU0:f][@2][Jd00P2LW9`2
0:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP020;fm_@030<K6aP2m_Kd0]KFe04T0oooo0P2][Jd4
034a<@0503Ti>@12@T80@T920492@P1:BTX00P1BDU8205YJFP@0Hf=S0`1[Jf/207=cL`030;fm_@1c
Lg<0Lg=c0080Lg=c0`1[Jf/206=SH`0305YJFP2UYJD0YJFU0580oooo00P0[Jf]034a<@1BDU80@T92
059BDP1JFUX0Hf=S06][J`80Lg=c0`1kNg/308B4Q00407]kN`2UYJD0YJFU0:FUYCl0oooo001P0?oo
o`030:FUY@2][Jd0[Jf]0080W9bL0P2UYJD30;Fe]@<0_Kfm00@0]KFe0;fm_@2e]KD0]KFe=03oool0
0`2UYJD0oooo0?ooo`0D0?ooo`030:f][@0a<C40<C4a00<0<C4a00<0>CTi0492@P12@T800P1:BTX2
059BDP0305YJFP1SHf<0Hf=S0080Hf=S0`1[Jf/907=cL`<0Jf][0P1SHf<00`1BDU80YJFU0?ooo`1A
0?ooo`030:f][@0i>CT0FUYJ0080Hf=S00D0@T9205YJFP1SHf<0Hf=S06][J`0207=cL`H0YJFU@@3o
ool00680oooo00<0YJFU0:f][@2e]KD01@2e]KD00`2m_Kd0]KFe0;fm_@020;Fe]C00oooo3@2UYJD?
0?ooo`80[Jf]0`0a<C401P0i>CT0@T920492@P12@T80BTY:059BDP<0FUYJ0P1SHf<306][J`<0Lg=c
1@1kNg/00`24Q8@0Ng]k07]kN`0307]kN`80Lg=c00@0Jf][06=SH`2UYJD0YJFUD03oool20:f][@03
0492@P1SHf<0Hf=S0080Ng]k00L0Q8B408b<S02UYJD0_Kfm0:FUY@1JFUX0YJFU04H0oooo001X0?oo
o`030:f][@3oool0oooo0380oooo0`2UYJD;05YJFP<0YJFU3@3oool00`2][Jd0<C4a034a<@02034a
<@0303Ti>@12@T80@T920080BTY:00<0DU9B05YJFP1JFUX00P1SHf<306][J`<0Lg=c0`1kNg/00`24
Q8@0Ng]k08B4Q00208B4Q00307]kN`24Q8@0Ng]k0080Ng]k00D0Lg=c06][J`1SHf<0Hf=S0:FUY@1@
0?ooo`0>0:f][@0a<C40@T9206=SH`1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S02U
YJE60?ooo`00V`3oool30:FUY@P0FUYJ1`1SHf<30:FUY@/0oooo00<0[Jf]034a<@0a<C400P0a<C40
0`0i>CT0@T920492@P0204Y:BP04059BDP1JFUX0Hf=S06=SH`<0Jf][0`1cLg<307]kN`T0Q8B40`1k
Ng/0101cLg<0Jf][06=SH`2UYJE@0?ooo`0>0:f][@0a<C40@T92059BDP1SHf<0Ng]k08B4Q02<S8`0
YJFU0;fm_@2UYJD0S8b<08B4Q02UYJE60?ooo`00V@3oool30:FUY@D0FUYJ0`1SHf<306][J`L0Lg=c
00@0Jf][0:FUY@2UYJD0YJFU203oool20:f][@<0<C4a00D0>CTi0492@P12@T80BTY:059BDP0205YJ
FP80Hf=S00@0Jf][07=cL`1cLg<0Lg=c0`1kNg/408B4Q00308b<S024Q8@0S8b<00@0S8b<1024Q8@0
0`1kNg/0Lg=c06][J`020:FUYDl0oooo00h0[Jf]03Ti>@1JFUX0DU9B06=SH`1kNg/0Q8B408b<S02U
YJD0_Kfm0:FUY@2<S8`0[Jf]0:FUYDH0oooo002H0?ooo`80YJFU1P1JFUX0101SHf<0Jf][06][J`1[
Jf/407=cL`D0Ng]k101cLg<20:FUY@L0oooo00D0[Jf]034a<@0a<C40<C4a03Ti>@030492@P0304Y:
BP1BDU80FUYJ0080Hf=S0P1[Jf/207=cL`<0Ng]k1024Q8@908b<S0@0Q8B400@0Ng]k07=cL`1[Jf/0
YJFUBP3oool60:f][@0<0492@P1SHf<0DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<S8`0
YJFUA`3oool009L0oooo0P2UYJD605YJFP0306=SH`1[Jf/0Lg=c00<0Lg=c0`1kNg/708B4Q080Ng]k
00<0Lg=c0:FUY@2UYJD01P3oool01@2][Jd0<C4a034a<@0a<C40>CTi0080@T9200<0BTY:059BDP1J
FUX00P1SHf<306][J`0407=cL`1kNg/0Ng]k07]kN`@0Q8B41@2<S8`00`2UYJD0S8b<0:FUY@0308b<
S0<0Q8B400@0Ng]k07=cL`1[Jf/0YJFUB03oool30:f][@D0<C4a00`0@T9206=SH`1BDU80Hf=S07]k
N`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S02UYJE70?ooo`00UP3oool20:FUY@D0FUYJ00<0Hf=S06][
J`1[Jf/00P1cLg<307]kN`<0Q8B41`2<S8`308B4Q00307]kN`2UYJD0YJFU00D0oooo00D0[Jf]034a
<@0a<C40<C4a03Ti>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S0P1[Jf/01@1cLg<0Ng]k07]kN`1k
Ng/0Q8B400@000000P2<S8`00`2UYJD0S8b<0:FUY@040:FUY@<0S8b<0P24Q8@0101kNg/0Lg=c06][
J`2UYJE60?ooo`<0[Jf]1`0a<C403012@T80DU9B06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2<
S8`0Q8B40:FUYDL0oooo002E0?ooo`80YJFU101JFUX206=SH`0306][J`1cLg<0Lg=c0080Ng]k0`24
Q8@308b<S0T0W9bL00<0S8b<08B4Q01kNg/00P2UYJD40?ooo`040:f][@0a<C40<C4a034a<@<0@T92
00<0BTY:059BDP1JFUX00P1SHf<00`1[Jf/0Lg=c07=cL`0207]kN`0408B4Q0000000Q8B408B4Q080
S8b<00<000000:FUY@2UYJD01`2UYJD308b<S080Q8B400<0Ng]k07=cL`2UYJD0A03oool30:f][@D0
<C4a0P0i>CT03`0a<C40>CTi05YJFP1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S024
Q8@0YJFU0:f][@160?ooo`00U03oool20:FUY@@0FUYJ00@0Hf=S06][J`1cLg<0Lg=c0P1kNg/208B4
Q0<0S8b<3P2LW9`208b<S080YJFU102][Jd3034a<@80@T9200<0BTY:059BDP1JFUX00P1SHf<01`1[
Jf/0Lg=c07=cL`1cLg<0Ng]k08B4Q00000000P24Q8@308b<S0030:FUY@000000YJFU0080YJFU00<0
_Kfm0:FUY@2m_Kd00`2UYJD308b<S00408B4Q01kNg/0Lg=c0:FUYD<0oooo0P2][Jd6034a<@0C03Ti
>@12@T80@T92034a<@12@T80Hf=S059BDP1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<06=S
H`12@T80YJFU0:f][@150?ooo`00T`3oool20:FUY@@0FUYJ00D0Hf=S06][J`1cLg<0Lg=c07]kN`02
08B4Q080S8b<1`2LW9`70:FUY@D0W9bL00<0S8b<034a<@0a<C400P12@T83034a<@0703Ti>@12@T80
@T9204Y:BP1BDU80FUYJ06=SH`0206][J`80Lg=c00D0Ng]k08B4Q024Q8@0000008B4Q00308b<S0<0
YJFU00<0_Kfm0:FUY@2m_Kd0102m_Kd30:FUY@80S8b<00@0Q8B407]kN`1cLg<0YJFU@P3oool20:f]
[@H0<C4a00H0>CTi0492@P12@T80@T92034a<@12@T8206=SH`80Ng]k00/0Q8B408b<S02UYJD0_Kfm
0:FUY@2<S8`0Hf=S04Y:BP12@T80YJFU0:f][@140?ooo`00T`3oool00`2UYJD0FUYJ05YJFP0305YJ
FP0306=SH`1[Jf/0Lg=c0080Ng]k0P24Q8@00`2<S8`0W9bL09bLW00509bLW0T0YJFU102LW9`207=c
L`0403Ti>@1:BTX0BTY:0492@P80<C4a00L0>CTi0492@P12@T80BTY:059BDP1JFUX0Hf=S0080Jf][
00<0Lg=c07]kN`1kNg/00P24Q8@010000000S8b<08b<S02<S8`30:FUY@T0_Kfm0`2UYJD01@2<S8`0
Q8B408B4Q01kNg/0YJFU0440oooo0P2][Jd5034a<@0303Ti>@12@T80@T920080@T920P1:BTX03012
@T80Hf=S06=SH`1kNg/0Q8B408b<S02UYJD0_Kfm0:FUY@2m_Kd0Q8B406=SH`80DU9B00<0BTY:0:FU
Y@2][Jd0@`3oool00980oooo0P2UYJD305YJFP0606=SH`1[Jf/0Lg=c07=cL`1kNg/0Q8B40`2<S8`5
09bLW0<0YJFU1@2e]KD00`2m_Kd0]KFe0;Fe]@030;Fe]@80YJFU00<0W9bL0492@P12@T800P1SHf<0
201:BTX0<C4a034a<@0i>CT0@T9204Y:BP1BDU80FUYJ0P1SHf<00`1[Jf/0Lg=c07]kN`0207]kN`80
Q8B400<0000008b<S02<S8`00`2UYJD50;fm_@030=kNgP2m_Kd0g]kN00<0_Kfm0`2UYJD0102<S8`0
Q8B407]kN`2UYJE00?ooo`80[Jf]100a<C4203Ti>@<0@T920P1:BTX2059BDP0;05YJFP1BDU80Hf=S
07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<S024Q8@00P1SHf<00`1JFUX0DU9B04Y:BP020:FUYD80
oooo002B0?ooo`030:FUY@1JFUX0FUYJ0080FUYJ00<0Hf=S06][J`1cLg<00P1kNg/00`24Q8@0S8b<
08b<S00509bLW0<0YJFU0`2e]KD00`2m_Kd0]KFe0;fm_@020;fm_@030;Fe]@2m_Kd0]KFe0080]KFe
00@0YJFU09bLW01:BTX0BTY:0P1SHf<00`1BDU80<C4a034a<@020492@P0504Y:BP1BDU80FUYJ06=S
H`1[Jf/00P1cLg<207]kN`80Q8B400<0S8b<0000002<S8`00`2UYJD30;fm_@030=kNgP2m_Kd0g]kN
00@0g]kN0`2m_Kd20:FUY@0408b<S024Q8@0Ng]k0:FUYCl0oooo0P2][Jd4034a<@0403Ti>@12@T80
@T920492@P80BTY:0P1BDU8305YJFP80Hf=S00L0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD0S8b<0080
Jf][0`1SHf<205YJFP80YJFU@@3oool00980oooo00<0YJFU05YJFP1JFUX00P1JFUX00`1SHf<0Jf][
07=cL`0207]kN`0308B4Q02<S8`0W9bL00@0W9bL0`2UYJD30;Fe]@T0_Kfm0`2e]KD00`2LW9`0DU9B
059BDP0206][J`0305YJFP0a<C40<C4a0080@T9200D0BTY:059BDP1JFUX0Hf=S06][J`0207=cL`03
07]kN`24Q8@0Q8B40080S8b<00@000000:FUY@2UYJD0YJFU0`2m_Kd00`000000g]kN0=kNgP060=kN
gP<0_Kfm00D0YJFU08b<S024Q8@0Q8B40:FUY@0n0?ooo`030:FUY@2][Jd0<C4a00<0<C4a00D0>CTi
0492@P12@T80@T9204Y:BP02059BDP80FUYJ101SHf<306][J`80Lg=c00<0_Kfm07=cL`1cLg<00P1c
Lg<306][J`80Hf=S00<0FUYJ0:FUY@2UYJD0@03oool00940oooo0P2UYJD305YJFP0506=SH`1[Jf/0
Lg=c07]kN`24Q8@00P2<S8`309bLW0<0YJFU0`2e]KD40;fm_@030<K6aP2m_Kd0a/K600@0a/K6102m
_Kd00`2e]KD0FUYJ05YJFP0207=cL`80Hf=S00L0<C4a03Ti>@12@T80BTY:059BDP1JFUX0Hf=S0080
Jf][00<0Lg=c07]kN`1kNg/00P24Q8@208b<S0090000002UYJD0YJFU0:FUY@2m_Kd000000;fm_@3N
g]h0_Kfm00<0g]kN00<0_Kfm0=kNgP2m_Kd00P2m_Kd01`2UYJD0S8b<08B4Q024Q8@0Hf=S0:FUY@2]
[Jd0>P3oool30?Ogm`030:FUY@0a<C40<C4a00<0<C4a00<0>CTi0492@P12@T800P1:BTX2059BDP03
05YJFP1SHf<0Hf=S0080Hf=S0`1[Jf/907=cL`<0Jf][0P1SHf<00`1BDU80YJFU0?ooo`0o0?ooo`00
T@3oool01P2UYJD0Hf=S05YJFP1JFUX0Hf=S06][J`80Lg=c00<0Ng]k08B4Q02<S8`0102LW9`00`2U
YJD000000;Fe]@020;Fe]@<0_Kfm00<000000<K6aP36a/H01`36a/H40;fm_@80Hf=S101kNg/01`0a
<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<00P1[Jf/0101cLg<0Ng]k08B4Q024Q8@308b<S0030:FU
Y@00000000000080000000<0_Kfm0=kNgP3Ng]h01`3Ng]h30;fm_@070:FUY@2<S8`0Q8B406=SH`1J
FUX0YJFU0:f][@0i0?ooo`80moOg00<0YJFU09bLW00i>CT00P0a<C401P0i>CT0@T920492@P12@T80
BTY:059BDP<0FUYJ0P1SHf<306][J`<0Lg=c1@1kNg/00`24Q8@0Ng]k07]kN`0307]kN`80Lg=c00@0
Jf][06=SH`2UYJD0YJFU?`3oool00940oooo00X0[Jf]06=SH`1SHf<0FUYJ06=SH`1[Jf/0Lg=c07]k
N`24Q8@0S8b<1@2LW9`0102UYJD000000;Fe]@2e]KD40;fm_@0300000036a/H0a/K60080a/K600<0
c/k>0<K6aP3>c/h00`36a/H30;fm_@030;Fe]@1kNg/0Lg=c0080Lg=c0P0a<C420492@P07059BDP1J
FUX0Hf=S06=SH`1[Jf/0Lg=c07]kN`0308B4Q080S8b<0`2UYJD30;fm_@/0g]kN0P2m_Kd01P2UYJD0
S8b<08B4Q01[Jf/0Ng]k06=SH`80YJFU00<0[Jf]0?ooo`3oool0=@3oool0103gmoL0kno_0:FUY@0i
>CT3034a<@0303Ti>@12@T80@T920080BTY:00<0DU9B05YJFP1JFUX00P1SHf<306][J`<0Lg=c0`1k
Ng/00`24Q8@0Ng]k08B4Q00208B4Q00307]kN`24Q8@0Ng]k0080Ng]k00D0Lg=c06][J`1SHf<0Hf=S
0:FUY@0o0?ooo`00;03ooolG0?Ogm`T0oooo1@3gmoL60?ooo`@0moOg=P3oool02P2][Jd0Hf=S06=S
H`1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`409bLW0040:FUY@2e]KD000000;Fe]@@0_Kfm00D0
a/K600000036a/H0c/k>0<K6aP050<k>cP<0a/K60P2m_Kd00`2e]KD0Hf=S07]kN`0307]kN`80<C4a
00@0@T9204Y:BP1BDU80FUYJ0P1SHf<00`1[Jf/0Lg=c07]kN`0208B4Q0<0S8b<0`2UYJD30;fm_@L0
g]kN0`2m_Kd20:FUY@0308b<S024Q8@0Jf][0080Q8B400D0Ng]k06=SH`1JFUX0YJFU0:f][@0C0?oo
o`030:f][@3oool0oooo01l0oooo00D0moOg0>o_k`3Ng]h0W9bL03Ti>@03034a<@0303Ti>@12@T80
@T920080BTY:00@0DU9B05YJFP1SHf<0Hf=S0`1[Jf/307=cL`<0Ng]k2@24Q8@307]kN`0407=cL`1[
Jf/0Hf=S0:FUYCl0oooo000[0?oooa80moOg00<0kno_0?Ogm`3gmoL00P3gmoL00`3_knl0moOg0?Og
m`0M0?Ogmbl0oooo00D0]KFe06][J`1SHf<0FUYJ06][J`0207=cL`0307]kN`24Q8@0S8b<00<0W9bL
0P2UYJD00`2e]KD000000;fm_@030;fm_@80a/K600<000000<k>cP3>c/h01`3>c/h30<K6aP80_Kfm
00D0Ng]k08B4Q02<S8`0YJFU0;fm_@02034a<@070492@P1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`02
07]kN`80Q8B40P2<S8`30:FUY@<0_Kfm2@3Ng]h30;fm_@040:FUY@2<S8`0Q8B406][J`80S8b<00@0
Q8B407]kN`1kNg/0Hf=S0P2UYJD00`2][Jd0oooo0?ooo`090?ooo`d0[Jf]6P3oool01`3gmoL0kno_
0>OWi`2UYJD0S8b<03Ti>@0a<C400P0i>CT20492@P0404Y:BP1BDU80FUYJ05YJFP80Hf=S00@0Jf][
07=cL`1cLg<0Lg=c0`1kNg/408B4Q00308b<S024Q8@0S8b<00@0S8b<1024Q8@00`1kNg/0Lg=c06][
J`020:FUYCh0oooo000[0?oooa40moOg00<0kno_0?Ogm`3gmoL0103gmoL00`3_knl0moOg0?Ogm`0?
0?Ogm`<0oooo303gmoLG0?ooo`030?Ogm`3oool0oooo01<0oooo00T0]KFe06][J`1SHf<0Hf=S06][
J`1cLg<0Ng]k08B4Q02<S8`00`2LW9`30:FUY@030;Fe]@000000_Kfm0080_Kfm0`36a/H00`000000
c/k>0<k>cP020<k>cP030=KFeP3>c/h0e]KF00<0c/k>0`36a/H00`2m_Kd0e]KF06][J`040:FUY@05
0:f][@2UYJD0@T9204Y:BP1JFUX00P1SHf<00`1[Jf/0Lg=c07]kN`0208B4Q0<0S8b<0`2UYJD30;fm
_@L0g]kN0`2m_Kd01@2UYJD0S8b<08B4Q01[Jf/0_Kfm0080YJFU00@0S8b<08B4Q024Q8@0Ng]k0P1S
Hf<20:FUY@030:f][@3oool0oooo00D0oooo0`2][Jd;034a<@<0[Jf]603oool01P3gmoL0inOW0<k>
cP2<S8`0>CTi034a<@80>CTi0P12@T8204Y:BP04059BDP1JFUX0Hf=S06=SH`80Jf][0P1cLg<307]k
N`@0Q8B42@2<S8`408B4Q00407]kN`1cLg<0Jf][0:FUYCh0oooo000[0?oooa40moOg00<0kno_0?Og
m`3gmoL05@3gmoL40?ooo`X0moOg;`3oool02@2m_Kd0Lg=c06=SH`1SHf<0Jf][07=cL`1kNg/0Q8B4
08b<S00309bLW080YJFU00<0]KFe0;fm_@0000001`0000000`3>c/h0e]KF0<k>cP050=KFeP<0c/k>
0P36a/H0102m_Kd0]KFe0:FUY@2UYJD40?ooo`060:f][@2UYJD0@T92059BDP1JFUX0Hf=S0P1[Jf/0
101cLg<0Ng]k08B4Q024Q8@308b<S0<0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP050;fm_@060:FUY@2<
S8`0Q8B406][J`2m_Kd0YJFU0P2m_Kd0102UYJD0S8b<08b<S024Q8@207]kN`0406=SH`1JFUX0YJFU
0:f][@@0oooo0`2][Jd8034a<@L0>CTi0`2][JdD0?ooo`80moOg00@0kno_0=KFeP2e]KD0Ng]k0P0i
>CT0100a<C40>CTi0492@P12@T82059BDP0305YJFP1SHf<0Hf=S00<0Jf][00@0Lg=c07]kN`1kNg/0
Ng]k1024Q8@508b<S0030:FUY@2<S8`0YJFU00<0S8b<0`24Q8@0101kNg/0Lg=c06][J`2UYJDn0?oo
o`00;03oool?0?Ogm`030?ooo`3gmoL0oooo01<0oooo0P3gmoL80?ooo`030?Ogm`3oool0oooo03<0
oooo00@0_Kfm07=cL`1SHf<0Hf=S0P1cLg<00`1kNg/0Q8B408b<S00309bLW0060:FUY@2e]KD0]KFe
0;fm_@000000_Kfm0`36a/H20<k>cP030000003Fe]H0e]KF00L0e]KF0`3>c/h01@36a/H0_Kfm0;fm
_@2e]KD0[Jf]00D0oooo00P0[Jf]0:FUY@1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`80Ng]k0P24Q8@3
08b<S0<0YJFU1`2m_Kd30:FUY@0408b<S024Q8@0Jf][0;fm_@80YJFU00<0_Kfm0:FUY@2m_Kd00P2U
YJD00`2<S8`0Q8B408B4Q00207]kN`0306=SH`2UYJD0YJFU00@0[Jf]1@0a<C4303Ti>@P0@T920P1:
BTX01@12@T80[Jf]0:f][@2][Jd0moOg0140oooo00H0moOg0>o_k`3WinL0c/k>0:f][@1cLg<403Ti
>@050492@P1:BTX0BTY:059BDP1JFUX00P1SHf<206][J`0407=cL`1kNg/0Ng]k07]kN`80Q8B41000
00000`2<S8`0YJFU08b<S0050:FUY@<0S8b<0P24Q8@0101kNg/0Lg=c06][J`2UYJDn0?ooo`00T@3o
ool0202m_Kd0Lg=c06=SH`1SHf<0Lg=c07]kN`24Q8@0S8b<0`2LW9`01P2UYJD0]KFe0;Fe]@2e]KD0
_Kfm000000<0a/K60`3>c/h00`000000e]KF0=KFeP020=KFeP030=kNgP3Fe]H0g]kN00<0e]KF0`3>
c/h01036a/H0_Kfm0;Fe]@2e]KD60?ooo`060:f][@2UYJD0BTY:05YJFP1SHf<0Jf][0P1cLg<207]k
N`80Q8B40`2<S8`30:FUY@050;fm_@2UYJD0_Kfm0:FUY@2m_Kd00`2UYJD01P2<S8`0Q8B406][J`2<
S8`0YJFU0;fm_@80YJFU102m_Kd00`2UYJD0S8b<08b<S00208B4Q00407]kN`1SHf<0FUYJ059BDPL0
<C4a00<0>CTi0492@P12@T801@12@T8404Y:BP07059BDP1:BTX0BTY:04Y:BP1BDU80[Jf]0;Fe]@02
0?Ogm`h0oooo00/0moOg0>o_k`3Ng]h0a/K609bLW01kNg/0Hf=S03Ti>@0a<C40>CTi0492@P0204Y:
BP80DU9B00@0FUYJ06=SH`1SHf<0Jf][0P1cLg<207]kN`80Q8B400<0000008B4Q02<S8`00P2<S8`0
0`000000YJFU0:FUY@060:FUY@<0S8b<0P24Q8@00`1kNg/0Lg=c0:FUY@0n0?ooo`00T@3oool00`36
a/H0Lg=c06=SH`0207=cL`0307]kN`24Q8@0S8b<0080W9bL0P2UYJD20;Fe]@80_Kfm00<000000<K6
aP36a/H00`3>c/h01@3Fe]H000000=KFeP3Ng]h0e]KF00D0g]kN0`3Fe]H20<k>cP040<K6aP2m_Kd0
]KFe0;Fe]@L0oooo00L0[Jf]0:FUY@1BDU80FUYJ06=SH`1[Jf/0Lg=c0080Ng]k0`24Q8@308b<S0L0
YJFU0`2<S8`02024Q8@0Jf][06][J`1kNg/0Q8B408b<S02UYJD0_Kfm0P2UYJD00`2m_Kd0YJFU0;fm
_@020:FUY@80S8b<00@0Q8B407]kN`1kNg/0Hf=S0P1BDU84034a<@0303Ti>@12@T80@T9200<0@T92
0`1:BTX8059BDP80FUYJ00<0[Jf]0;fm_@3_knl00P3gmoL80?ooo`0:0?Ogm`3_knl0kno_0=kNgP3>
c/h0_Kfm0:FUY@2<S8`0Lg=c04Y:BP@0>CTi00D0@T9204Y:BP1:BTX0DU9B05YJFP0206=SH`0506][
J`1cLg<0Lg=c07=cL`1kNg/00P24Q8@00`000000Q8B408b<S00208b<S080YJFU00H000000:FUY@2U
YJD0_Kfm0:FUY@2m_Kd30:FUY@<0S8b<00@0Q8B407]kN`1cLg<0YJFU?P3oool00940oooo00<0a/K6
0;Fe]@1SHf<00P1cLg<00`1kNg/0Q8B408b<S00209bLW080YJFU00H0]KFe0;fm_@2m_Kd0a/K60000
0036a/H30<k>cP80e]KF00<000000=kNgP3Ng]h01`3Ng]h30=KFeP050<k>cP36a/H0_Kfm0<K6aP2e
]KD0203oool30:FUY@80Hf=S00<0Jf][07=cL`1kNg/01024Q8@308b<S0D0YJFU0P2<S8`0102][Jd0
YJFU0:FUY@2][Jd20:FUY@0407]kN`24Q8@0S8b<0:FUY@80_Kfm00<0YJFU0;fm_@2m_Kd00P2m_Kd2
0:FUY@0608b<S024Q8@0Q8B407]kN`1SHf<0FUYJ0P0a<C400`0i>CT0@T920492@P020492@P<0BTY:
0`1BDU8705YJFP07059BDP1JFUX0Hf=S06][J`2][Jd0a/K60>o_k`020?Ogm`<0oooo0P3gmoL02P3W
inL0g]kN0<k>cP36a/H0]KFe09bLW02<S8`0Lg=c06=SH`1BDU820492@P<0>CTi0P12@T8204Y:BP03
059BDP1JFUX0Hf=S0080Jf][0P1cLg<01@1kNg/0Q8B408B4Q024Q8@0000000<0S8b<0`2UYJD00`2m
_Kd0YJFU0;fm_@040;fm_@<0YJFU0P2<S8`01024Q8@0Ng]k07=cL`2UYJDn0?ooo`00TP3oool01`2e
]KD0Hf=S06=SH`1cLg<0Ng]k08B4Q02<S8`00`2LW9`00`2UYJD0]KFe0;Fe]@020;fm_@<0a/K60`3>
c/h30=KFeP030=kNgP3Fe]H0g]kN0080g]kN00<0e]KF0=kNgP3Fe]H00P3Fe]H01@3>c/h0a/K60;fm
_@2m_Kd0]KFe00/0oooo0`2UYJD0101SHf<0Jf][07=cL`1cLg<207]kN`@0Q8B400<0S8b<08B4Q02<
S8`00P24Q8@00`2][Jd0YJFU0:FUY@040?ooo`80YJFU00H0Jf][07]kN`24Q8@0S8b<0:FUY@2m_Kd2
0:FUY@@0_Kfm00@0YJFU08b<S02<S8`0Q8B40P1kNg/203Ti>@<0@T920P1:BTX3059BDP<0FUYJ2P1S
Hf<01@1[Jf/0Ng]k0;Fe]@3>c/h0inOW0080kno_00/0inOW0=kNgP3>c/h0a/K60;Fe]@2UYJD0S8b<
07]kN`1[Jf/0FUYJ059BDP0204Y:BP<0@T920`0i>CT00`12@T80BTY:04Y:BP02059BDP0505YJFP1S
Hf<0Jf][06][J`1cLg<00P1kNg/308B4Q0030000002<S8`0S8b<00<0YJFU2@2m_Kd30:FUY@0508b<
S024Q8@0Q8B407]kN`2UYJD03@3oool00`2UYJD0oooo0?ooo`0^0?ooo`00TP3oool01`2e]KD0Hf=S
06=SH`1cLg<0Ng]k08B4Q02<S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H9
0=kNgP<0e]KF00@0c/k>0<K6aP2m_Kd0]KFe3@3oool30:FUY@0406=SH`1[Jf/0Lg=c07=cL`<0Ng]k
0`24Q8@0101kNg/0YJFU0:FUY@2UYJD70?ooo`070:f][@2UYJD0YJFU07]kN`24Q8@0S8b<0:FUY@02
0;fm_@80YJFU00<0_Kfm0:FUY@2m_Kd00P2UYJD00`2<S8`0Q8B408B4Q0030492@P80BTY:0P1BDU83
05YJFP@0Hf=S1P1[Jf/306=SH`0406][J`1kNg/0S8b<0;Fe]@80_Kfm00T0]KFe0:FUY@2LW9`0S8b<
07]kN`1[Jf/0Hf=S05YJFP1BDU801`1:BTX20492@P80>CTi00D0@T9204Y:BP1BDU80DU9B05YJFP02
06=SH`0306][J`1cLg<0Ng]k0080Ng]k0P24Q8@00`2<S8`0000008b<S0030:FUY@D0_Kfm00<0g]kN
0;fm_@3Ng]h00`2m_Kd30:FUY@0408b<S024Q8@0Ng]k0:FUY@L0oooo3@2UYJDZ0?ooo`00TP3oool0
1P2e]KD0[Jf]07=cL`1cLg<0Q8B408b<S0<0W9bL00<0YJFU0;Fe]@2m_Kd00P2m_Kd20<K6aP<0c/k>
0`3Fe]H;0=kNgP80e]KF00@0c/k>0<K6aP36a/H0]KFe3`3oool=0:FUY@/0oooo0`2UYJD0101kNg/0
Q8B408b<S02UYJD20;fm_@030:FUY@2m_Kd0_Kfm0080_Kfm00<0YJFU08b<S012@T800P12@T800`1:
BTX0DU9B059BDP0205YJFP@0Hf=S0`1[Jf/407=cL`0306][J`1cLg<0Lg=c00<0Jf][0`1cLg<306][
J`0406=SH`1JFUX0DU9B059BDPH0BTY:101BDU80101:BTX0@T920492@P0i>CT20492@P0604Y:BP1B
DU80FUYJ05YJFP1SHf<0Jf][0P1cLg<207]kN`80Q8B40P2<S8`010000000YJFU0:FUY@2UYJD30;fm
_@030=kNgP2m_Kd0g]kN00@0g]kN0`2m_Kd20:FUY@0408b<S024Q8@0Ng]k0:FUY@D0oooo0`2UYJD;
05YJFP<0YJFU:03oool009<0oooo00H0[Jf]06=SH`1[Jf/0Ng]k08B4Q02<S8`309bLW0040:FUY@2e
]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H20<k>cP030<K6aP2m_Kd0]KFe01H0oooo
00<0YJFU0?ooo`3oool04@3oool20:FUY@0606][J`1kNg/0Q8B408b<S02UYJD0_Kfm0P2UYJD0102m
_Kd0YJFU0;fm_@2UYJD20492@P80BTY:0P1BDU800`1JFUX0Hf=S06=SH`0206=SH`<0Jf][2@1cLg<0
1@1[Jf/0Hf=S06=SH`1JFUX0DU9B00P0BTY:1@1BDU8305YJFP03059BDP1:BTX0@T9200<0@T920P1:
BTX01@1BDU80FUYJ05YJFP1SHf<0Jf][0080Lg=c00<0Ng]k08B4Q024Q8@00`2<S8`00`000000YJFU
0:FUY@030;fm_@030=kNgP000000g]kN00H0g]kN0`2m_Kd01@2UYJD0S8b<08B4Q024Q8@0YJFU00<0
oooo0`2UYJD805YJFPL0Hf=S0`2UYJDV0?ooo`00T`3oool01P2][Jd0YJFU07=cL`1kNg/0Q8B408b<
S080W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd20<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>0<K6
aP36a/H0]KFe:`3oool01`2][Jd0YJFU0:FUY@1kNg/0Q8B408b<S02UYJD00P2m_Kd00`2UYJD0_Kfm
0:FUY@020492@P0304Y:BP1BDU80FUYJ0080FUYJ0P1SHf<306][J`<0Lg=c1@1kNg/00`24Q8@0Ng]k
07]kN`0207=cL`0606][J`1SHf<0Hf=S05YJFP1BDU80BTY:101BDU8705YJFP<0Hf=S00<0FUYJ059B
DP1BDU800P1:BTX20492@P0504Y:BP1BDU80DU9B05YJFP1SHf<00P1[Jf/00`1cLg<0Ng]k07]kN`02
08B4Q0<0S8b<00<000000:FUY@2UYJD00P2m_Kd00`000000g]kN0;fm_@030=kNgP030;fm_@3Ng]h0
_Kfm0080_Kfm00L0YJFU08b<S024Q8@0Q8B406=SH`2UYJD0[Jf]00<0YJFU1@1JFUX306=SH`<0Jf][
1`1cLg<0101[Jf/0YJFU0:FUY@2UYJDT0?ooo`00U03oool20:FUY@0307=cL`1kNg/0S8b<00<0W9bL
00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF1`3Ng]h30=KFeP040<k>cP36a/H0a/K60;Fe
]Bh0oooo0P2UYJD01`1[Jf/0Ng]k08B4Q02<S8`0YJFU0;fm_@2UYJD00P12@T8204Y:BP03059BDP1J
FUX0FUYJ0080Hf=S0`1[Jf/307=cL`<0Ng]k00<0Q8B407]kN`24Q8@00P24Q8@01P1kNg/0Q8B407=c
L`1cLg<0Jf][06=SH`80FUYJ00<0DU9B05YJFP1JFUX00`1JFUX706=SH`80Jf][0P1SHf<205YJFP04
059BDP12@T80@T9204Y:BP80DU9B00H0FUYJ06=SH`1[Jf/0Jf][07=cL`1kNg/208B4Q0<0S8b<0P2U
YJD4000000T0g]kN0`2m_Kd01`2UYJD0S8b<08B4Q01SHf<0FUYJ059BDP0a<C401P1JFUX0101SHf<0
Jf][06][J`1[Jf/407=cL`D0Ng]k101cLg<20:FUYB<0oooo002E0?ooo`80YJFU00<0Lg=c08B4Q02<
S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H00`3Ng]h0e]KF0=kNgP050=KF
eP040<k>cP36a/H0a/K60;Fe]C00oooo00P0[Jf]0:FUY@1SHf<0Ng]k08B4Q02<S8`0YJFU0;fm_@80
@T920P1:BTX0101BDU80FUYJ06=SH`1SHf<306][J`<0Lg=c0`1kNg/908B4Q080Lg=c00@0Jf][06=S
H`1JFUX0FUYJ201SHf<406][J`80Lg=c0P1[Jf/0101SHf<0FUYJ04Y:BP12@T8204Y:BP80FUYJ0P1S
Hf<00`1[Jf/0Lg=c07]kN`0308B4Q080S8b<0`2UYJD30;fm_@/0g]kN0P2m_Kd01P2UYJD0S8b<08B4
Q01[Jf/0Ng]k06=SH`80Q8B4101JFUX00`1SHf<0Jf][07=cL`0307=cL`<0Ng]k1`24Q8@207]kN`03
07=cL`2UYJD0YJFU0280oooo002F0?ooo`80YJFU00<0Ng]k08B4Q02<S8`00P2LW9`00`2UYJD0]KFe
0;Fe]@020;fm_@<0a/K60`3>c/h70=KFeP<0c/k>0P36a/H00`2e]KD0oooo0?ooo`0`0?ooo`060:f]
[@0i>CT0FUYJ06][J`1cLg<0>CTi0P12@T80101:BTX0DU9B05YJFP1JFUX206=SH`0406][J`1cLg<0
Lg=c07=cL`<0Ng]k1024Q8@00`2<S8`0Q8B408b<S00408b<S00408B4Q01kNg/0Ng]k07=cL`80Jf][
0`1SHf<506][J`P0Lg=c0P1[Jf/306=SH`0304Y:BP1BDU80DU9B0080FUYJ0P1SHf<00`1[Jf/0Lg=c
07]kN`0208B4Q0<0S8b<0`2UYJD30;fm_@L0g]kN0`2m_Kd20:FUY@0308b<S024Q8@0Jf][0080Q8B4
00H0Ng]k06=SH`2<S8`0Q8B405YJFP1SHf<206][J`80Lg=c0`1kNg/308B4Q0L0S8b<0`24Q8@00`1k
Ng/0YJFU0:FUY@0Q0?ooo`00U`3oool20:FUY@0407]kN`2<S8`0W9bL09bLW080YJFU0P2e]KD20;fm
_@<0a/K60`3>c/h01@3Fe]H0c/k>0=KFeP3>c/h0e]KF00<0c/k>0P36a/H00`2e]KD0oooo0?ooo`0a
0?ooo`050:f][@0a<C40<C4a059BDP0i>CT00`12@T800`1:BTX0DU9B05YJFP0206=SH`80Jf][0P1c
Lg<307]kN`@0Q8B42@2<S8`208B4Q00307]kN`1cLg<0Jf][0080Jf][0`1cLg<00`1kNg/0Lg=c07=c
L`0307=cL`<0Ng]k1024Q8@0101kNg/0Q8B407]kN`1kNg/3059BDP0405YJFP1SHf<0Jf][07=cL`80
Ng]k0P24Q8@208b<S0<0YJFU0`2m_Kd90=kNgP<0_Kfm00@0YJFU08b<S024Q8@0Jf][0P2<S8`00`24
Q8@0]KFe0;Fe]@0206=SH`0306][J`1cLg<0Lg=c0080Ng]k0`24Q8@308b<S0T0W9bL00<0S8b<08B4
Q01kNg/00P2UYJDP0?ooo`00V03oool20:FUY@0508B4Q02<S8`0W9bL09bLW02UYJD00P2e]KD30;fm
_@<0a/K61`3>c/h40<K6aP030;Fe]@3oool0oooo0380oooo00D0[Jf]034a<@0a<C40<C4a03Ti>@02
0492@P0304Y:BP1BDU80FUYJ0080Hf=S0`1[Jf/00`1cLg<0Ng]k07]kN`040000000308B4Q02<S8`0
S8b<00<0S8b<00<0YJFU08b<S02LW9`00`2<S8`00`24Q8@0Ng]k07]kN`0207=cL`80Ng]k0P24Q8@5
07]kN`0408B4Q02<S8`0S8b<08b<S0@0W9bL0P2UYJD01P2][Jd0S8b<08B4Q01:BTX0DU9B05YJFP80
Hf=S00<0Jf][07=cL`1kNg/00P24Q8@308b<S0<0YJFU0`2m_Kd70=kNgP<0_Kfm00D0YJFU08b<S024
Q8@0Jf][0;fm_@020:FUY@0408b<S02m_Kd0_Kfm06][J`80Lg=c0P1kNg/208B4Q0<0S8b<3P2LW9`2
08b<S0030:f][@2UYJD0oooo01h0oooo002I0?ooo`80YJFU00H0[Jf]09bLW02LW9`0W9bL0:FUY@2e
]KD40;fm_@<0a/K61@3>c/h30<K6aP030;fm_@2e]KD0oooo03@0oooo00D0[Jf]034a<@0a<C40<C4a
03Ti>@020492@P0304Y:BP1BDU80FUYJ0080Hf=S0P1[Jf/0101cLg<0Ng]k07]kN`00000408B4Q005
0000002<S8`0S8b<0:FUY@2<S8`0102UYJD0102LW9`0S8b<08b<S02<S8`:08B4Q080S8b<0`2LW9`0
1P2UYJD0[Jf]0;Fe]@2m_Kd0c/k>0=KFeP80g]kN00D0c/k>0<K6aP2LW9`0S8b<059BDP0205YJFP05
06=SH`1[Jf/0Jf][07=cL`1kNg/00P24Q8@308b<S0<0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP050;fm
_@060:FUY@2<S8`0Q8B406][J`2m_Kd0YJFU0P2m_Kd00`2UYJD0a/K606][J`0207=cL`0307]kN`24
Q8@0Q8B40080S8b<1`2LW9`70:FUY@D0W9bL00<0S8b<0:f][@2UYJD07P3oool009/0oooo00<0YJFU
0:f][@2][Jd00P2LW9`20:FUY@80]KFe102m_Kd00`36a/H0_Kfm0<K6aP020;fm_@030<K6aP2m_Kd0
]KFe03L0oooo00@0[Jf]034a<@0a<C40<C4a0`12@T800`1:BTX0DU9B05YJFP0206=SH`0506][J`1c
Lg<0Lg=c07]kN`0000001024Q8@208b<S0030000002UYJD0YJFU00H0YJFU00@0W9bL08b<S02<S8`0
S8b<0P24Q8@0101kNg/0Q8B408b<S02<S8`309bLW0090:FUY@2][Jd0]KFe0;fm_@36a/H0c/k>0=kN
gP3WinL0kno_0080moOg0P3_knl00`3WinL0g]kN0=KFeP0209bLW080DU9B00@0FUYJ06=SH`1[Jf/0
Lg=c0P1kNg/208B4Q0<0S8b<0`2UYJD70;fm_@<0YJFU00@0S8b<08B4Q01[Jf/0_Kfm0P2UYJD01P2m
_Kd0YJFU0;fm_@3>c/h0Jf][07=cL`80Ng]k0P24Q8@00`2<S8`0W9bL09bLW00509bLW0T0YJFU1@2L
W9`00`24Q8@0YJFU0?ooo`0M0?ooo`00W@3oool00`2UYJD0[Jf]0:f][@0209bLW080YJFU0`2e]KD3
0;fm_@040;Fe]@2m_Kd0]KFe0;Fe]CT0oooo00@0[Jf]034a<@0a<C40<C4a0P12@T800`1:BTX0DU9B
05YJFP0206=SH`0606][J`1cLg<0Lg=c07=cL`1kNg/000000`24Q8@308b<S0D0YJFU00<0_Kfm0:FU
Y@2e]KD00P2UYJD00`2LW9`0S8b<08b<S00308b<S00709bLW02<S8`0W9bL0:f][@2m_Kd0e]KF0>OW
i`020>o_k`<0moOg1@3oool30?Ogm`090>o_k`3WinL0inOW0:FUY@2LW9`0DU9B05YJFP1SHf<0Jf][
0080Lg=c0P1kNg/208B4Q0<0S8b<0`2UYJD01@2m_Kd0YJFU0;fm_@2UYJD0_Kfm00<0YJFU00H0S8b<
08B4Q01[Jf/0S8b<0:FUY@2m_Kd20:FUY@060=KFeP3>c/h0Lg=c07=cL`1kNg/0Q8B40`2<S8`509bL
W0<0YJFU1@2e]KD00`2m_Kd0]KFe0;Fe]@030;Fe]@80YJFU0P2LW9`00`2][Jd0YJFU0?ooo`0L0?oo
o`00W`3oool00`2UYJD0[Jf]0;Fe]@050;Fe]@030;fm_@2e]KD0_Kfm0080]KFe>`3oool0102][Jd0
<C4a034a<@0i>CT20492@P0404Y:BP1BDU80FUYJ06=SH`80Jf][0P1cLg<00`1kNg/0Q8B400000002
08B4Q0<0S8b<0`2UYJD00`2m_Kd0YJFU0;fm_@020;fm_@80]KFe0`2UYJD508b<S0040:FUY@36a/H0
inOW0?Ogm``0oooo00<0moOg0?ooo`3gmoL00P3gmoL20>o_k`80YJFU00D0DU9B05YJFP1SHf<0Jf][
07=cL`0207]kN`<0Q8B40`2<S8`70:FUY@<0S8b<00/0Q8B406][J`1[Jf/0Ng]k08B4Q02<S8`0YJFU
0;fm_@2UYJD0c/k>07=cL`0207]kN`0308B4Q02<S8`0S8b<00D0W9bL0`2UYJD30;Fe]@030;fm_@2e
]KD0_Kfm0080_Kfm00<0]KFe0;fm_@2e]KD00P2e]KD01@2UYJD0W9bL09bLW02LW9`0YJFU01d0oooo
002U0?ooo`030:f][@3oool0oooo03l0oooo00@0[Jf]034a<@0a<C40>CTi0P12@T80101:BTX0DU9B
05YJFP1SHf<206][J`0607=cL`1kNg/0Ng]k08B4Q0000000Q8B40`2<S8`30:FUY@L0_Kfm0P2e]KD0
0`2UYJD0W9bL09bLW00308b<S0030:FUY@36a/H0moOg0180oooo103gmoL30:FUY@80Hf=S00<0Jf][
07=cL`1kNg/01024Q8@308b<S0D0YJFU0P2<S8`03@2][Jd0YJFU0:FUY@2UYJD0[Jf]09bLW02e]KD0
_Kfm0<K6aP3>c/h0e]KF06][J`1cLg<00P1kNg/00`24Q8@0S8b<09bLW00409bLW0<0YJFU0`2e]KD9
0;fm_@<0]KFe00@0YJFU09bLW02LW9`0YJFU7@3oool00>L0oooo00P0[Jf]034a<@0a<C40>CTi0492
@P1:BTX0DU9B05YJFP80Hf=S00<0Jf][07=cL`1kNg/00P1kNg/00`24Q8@0000008b<S00208b<S0<0
YJFU1@2m_Kd0103Ng]h0_Kfm0=KFeP2m_Kd20;Fe]@80YJFU0`2LW9`00`2UYJD0g]kN0?ooo`0D0?oo
o`80moOg00<0oooo0?Ogm`2UYJD00P2UYJD0101SHf<0Jf][07=cL`1cLg<207]kN`@0Q8B400<0S8b<
08B4Q02<S8`00P24Q8@00`2][Jd0YJFU0:FUY@030?ooo`0:0:FUY@1SHf<0S8b<09bLW02e]KD0_Kfm
06][J`1cLg<0Ng]k08B4Q080S8b<0`2LW9`30:FUY@<0]KFe102m_Kd00`36a/H0_Kfm0<K6aP040<K6
aP@0_Kfm00D0]KFe0:FUY@2LW9`0]KFe0:f][@0L0?ooo`00TP3oool00`3gmoL0oooo0?ooo`1B0?oo
o`030:f][@0a<C40<C4a0080@T9200D0BTY:059BDP1JFUX0Hf=S06][J`0207=cL`80Ng]k0P24Q8@0
0`000000S8b<08b<S0030:FUY@050;fm_@000000_Kfm0=kNgP2m_Kd01@3Ng]h00`2m_Kd0]KFe0;Fe
]@020:FUY@80W9bL00<0]KFe0?Ogm`3oool06P3oool30:FUY@0406=SH`1[Jf/0Lg=c07=cL`<0Ng]k
0`24Q8@0101kNg/0YJFU0:FUY@2UYJD50?ooo`060:FUY@1JFUX0FUYJ08B4Q01SHf<0Jf][0P1cLg<0
0`1kNg/0Q8B408b<S00409bLW080YJFU00<0]KFe0000002e]KD0102m_Kd00`36a/H000000<K6aP06
0<K6aP@0_Kfm00@0]KFe0:FUY@2LW9`0[Jf]703oool00980oooo00<0moOg0?ooo`3oool0DP3oool2
0:f][@08034a<@12@T80@T9204Y:BP1BDU80FUYJ06=SH`1[Jf/207=cL`0307]kN`24Q8@0Q8B40080
S8b<00L000000:FUY@2UYJD0YJFU0;fm_@000000_Kfm00T0g]kN00@0_Kfm0;Fe]@2e]KD0YJFU0P2L
W9`00`3Fe]H0moOg0?ooo`0L0?ooo`d0YJFU1`3oool02P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`1c
Lg<0Ng]k08B4Q02<S8`509bLW0040:FUY@2e]KD0]KFe000000@0_Kfm0P36a/H01P000000a/K60<K6
aP3>c/h0a/K60<k>cP<0a/K60`2m_Kd0102e]KD0YJFU09bLW02][JdL0?ooo`00TP3oool00`3gmoL0
oooo0?ooo`1C0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<206][J`0307=cL`1k
Ng/0Ng]k0080Q8B40P2<S8`4000000<0_Kfm00<0g]kN0;fm_@3Ng]h00P3Ng]h00`2m_Kd0g]kN0;fm
_@020;Fe]@050:FUY@2<S8`0S8b<09bLW03Ng]h0903oool00`2UYJD0oooo0?ooo`0;0?ooo`0:0:FU
Y@1JFUX0FUYJ05YJFP1SHf<0Jf][07=cL`1kNg/0Q8B408b<S0@0W9bL00D0YJFU0;Fe]@2e]KD0]KFe
000000030;fm_@<0a/K600<000000<K6aP3>c/h0103>c/h30<K6aP80_Kfm00@0]KFe0:FUY@2LW9`0
[Jf]703oool00940oooo0P3gmoME0?ooo`080:f][@0a<C40>CTi0492@P1:BTX0DU9B05YJFP1SHf<2
06][J`0407=cL`1kNg/0Q8B408B4Q0<0S8b<0`2UYJD30;fm_@T0g]kN0P2m_Kd01@2e]KD0YJFU08b<
S02LW9`0inOW0380oooo00D0YJFU05YJFP1JFUX0FUYJ06][J`0207=cL`0307]kN`24Q8@0S8b<00<0
W9bL0P2UYJD20;Fe]@040;fm_@000000_Kfm0;fm_@<0a/K600<0c/k>0000003>c/h01P3>c/h30<K6
aP80_Kfm00<0]KFe0:FUY@2][Jd0703oool00940oooo0P3gmoME0?ooo`80[Jf]0P12@T801`1BDU80
FUYJ06=SH`1SHf<0Jf][07=cL`1kNg/00`24Q8@208b<S0<0YJFU0`2m_Kd:0=kNgP070=KFeP2m_Kd0
]KFe0:FUY@2LW9`0_Kfm0>o_k`0b0?ooo`090:FUY@1JFUX0FUYJ05YJFP1[Jf/0Lg=c07]kN`24Q8@0
S8b<00<0W9bL0`2UYJD01@2e]KD0_Kfm0;fm_@000000_Kfm00<0a/K60P3>c/h01P000000c/k>0<k>
cP3Fe]H0c/k>0=KFeP<0c/k>0`36a/H0102m_Kd0]KFe0:FUY@2][JdL0?ooo`00T@3oool20?OgmeH0
oooo00H0[Jf]034a<@12@T80BTY:059BDP1JFUX206=SH`0306][J`1cLg<0Ng]k0080Q8B40`2<S8`3
0:FUY@<0_Kfm1`3Ng]h30;fm_@80YJFU0P2<S8`00`3>c/h0oooo0?ooo`0a0?ooo`090:FUY@1JFUX0
FUYJ06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<00<0W9bL0P2UYJD0102e]KD0_Kfm0;fm_@2m_Kd80000
00030<k>cP3Fe]H0e]KF00<0e]KF0`3>c/h20<K6aP040;fm_@2e]KD0YJFU0:f][A`0oooo002A0?oo
o`80moOgEP3oool20:f][@070492@P1:BTX0DU9B05YJFP1SHf<0Jf][07=cL`0207]kN`80Q8B40P2<
S8`30:FUY@<0_Kfm2@3Ng]h30;fm_@040:FUY@2<S8`0_Kfm0>o_kc<0oooo00@0YJFU05YJFP1JFUX0
Hf=S0P1cLg<00`1kNg/0Q8B408b<S00309bLW0030:FUY@2e]KD0]KFe00<0_Kfm00<000000<K6aP36
a/H00`3>c/h00`3Fe]H000000=KFeP060=KFeP<0c/k>00D0a/K60;fm_@2m_Kd0]KFe0:f][@0L0?oo
o`00T@3oool20?OgmeL0oooo00D0[Jf]0:FUY@12@T80BTY:05YJFP0206=SH`0306][J`1cLg<0Ng]k
0080Q8B40`2<S8`30:FUY@<0_Kfm1`3Ng]h30;fm_@040:FUY@2<S8`0[Jf]0<k>cS@0oooo00P0YJFU
05YJFP1JFUX0Hf=S07=cL`1kNg/0Q8B408b<S0<0W9bL00@0YJFU0;Fe]@2e]KD0]KFe0P2m_Kd00`36
a/H000000<K6aP030<k>cP80e]KF00H000000=KFeP3Fe]H0g]kN0=KFeP3Ng]h30=KFeP<0c/k>00@0
a/K60;fm_@2e]KD0]KFe703oool00940oooo0P3gmoMH0?ooo`060:f][@2UYJD0@T92059BDP1JFUX0
Hf=S0P1[Jf/0101cLg<0Ng]k08B4Q024Q8@308b<S0<0YJFU0`2m_Kd00`3Ng]h0_Kfm0=kNgP050;fm
_@040:FUY@2<S8`0[Jf]0:f][CD0oooo00P0YJFU05YJFP1JFUX0Jf][07=cL`1kNg/0Q8B408b<S080
W9bL0P2UYJD20;Fe]@80_Kfm0P36a/H010000000c/k>0<k>cP3>c/h30=KFeP030000003Fe]H0g]kN
00@0g]kN0`3Fe]H20<k>cP040<K6aP2m_Kd0]KFe0;Fe]A`0oooo002A0?ooo`80moOgF@3oool0202]
[Jd0@T9204Y:BP1BDU80FUYJ06=SH`1[Jf/0Lg=c0P1kNg/208B4Q0<0S8b<0`2UYJD70;fm_@<0YJFU
00<0S8b<0:f][@2UYJD0=P3oool20:FUY@0605YJFP1[Jf/0Lg=c07]kN`24Q8@0S8b<0P2LW9`20:FU
Y@030;Fe]@2m_Kd0_Kfm00<0a/K600<000000<k>cP3>c/h00`3Fe]H00`3Ng]h000000=kNgP060=kN
gP<0e]KF00D0c/k>0<K6aP2m_Kd0a/K60;Fe]@0L0?ooo`00T@3oool20?OgmeT0oooo00L0YJFU034a
<@12@T80BTY:05YJFP1SHf<0Jf][0080Lg=c0P1kNg/208B4Q0<0S8b<0`2UYJD01@2m_Kd0YJFU0;fm
_@2UYJD0_Kfm00<0YJFU00<0S8b<0:f][@2UYJD0>03oool01`2UYJD0FUYJ06=SH`1cLg<0Ng]k08B4
Q02<S8`00`2LW9`00`2UYJD0]KFe0;Fe]@020;fm_@<0a/K60`3>c/h30=KFeP030=kNgP3Fe]H0g]kN
0080g]kN00<0e]KF0=kNgP3Fe]H00P3Fe]H01@3>c/h0a/K60;fm_@2m_Kd0]KFe01d0oooo002A0?oo
o`80moOgE`3oool30:FUY@0805YJFP0a<C40@T92059BDP1JFUX0Hf=S06][J`1cLg<207]kN`<0Q8B4
0`2<S8`70:FUY@<0S8b<00<0[Jf]0:FUY@3oool0>03oool01`2UYJD0FUYJ06=SH`1cLg<0Ng]k08B4
Q02<S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H90=kNgP<0e]KF00@0c/k>
0<K6aP2m_Kd0]KFe7@3oool00940oooo0P3gmoME0?ooo`<0YJFU101JFUX00`0i>CT0@T92059BDP02
06=SH`0306][J`1cLg<0Ng]k00@0Q8B40`2<S8`50:FUY@80S8b<00<0[Jf]0:FUY@2UYJD0>P3oool2
0:FUY@0406][J`1cLg<0Q8B408b<S0<0W9bL00<0YJFU0;Fe]@2m_Kd00P2m_Kd20<K6aP<0c/k>0`3F
e]H;0=kNgP80e]KF00@0c/k>0<K6aP36a/H0]KFe7@3oool00940oooo00<0moOg0?ooo`3oool0DP3o
ool30:FUY@D0FUYJ0P1SHf<01P0a<C40@T9204Y:BP1JFUX0Hf=S06][J`80Lg=c0P1kNg/408B4Q003
08b<S024Q8@0S8b<0080Q8B400<0[Jf]0:FUY@2UYJD0?@3oool01P2UYJD0FUYJ06][J`1kNg/0Q8B4
08b<S0<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF1`3Ng]h30=KFeP80c/k>00<0
a/K60;fm_@2e]KD07P3oool00>D0oooo0P2UYJD605YJFP0;06=SH`1[Jf/0Jf][034a<@0i>CT0FUYJ
0492@P1BDU80FUYJ06=SH`1[Jf/00P1cLg<307]kN`<0Q8B400@0Ng]k0:FUY@2UYJD0YJFU?`3oool2
0:FUY@0407=cL`1kNg/0Q8B408b<S080W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd20<K6aP<0c/k>0`3F
e]H90=kNgP<0e]KF00@0c/k>0<K6aP36a/H0]KFe7P3oool00>@0oooo0P2UYJD605YJFP0606=SH`1[
Jf/0Lg=c07=cL`0a<C40@T920P1SHf<00`1kNg/0@T9205YJFP0206=SH`0906][J`1cLg<0Lg=c07=c
L`1kNg/0Lg=c07]kN`1cLg<0YJFU0480oooo0P2UYJD00`1cLg<0Ng]k08b<S00309bLW0040:FUY@2e
]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFePL0g]kN0`3Fe]H0103>c/h0a/K60<K6aP2e]KDO0?ooo`00
h`3oool20:FUY@D0FUYJ00<0Hf=S06][J`1[Jf/00P1cLg<207]kN`0<06][J`2LW9`0Hf=S07=cL`1k
Ng/0Q8B408b<S02UYJD0_Kfm0:FUY@1JFUX0Hf=S0P24Q8@00`1kNg/0Lg=c0:FUY@130?ooo`80YJFU
00<0Lg=c08B4Q02<S8`00`2LW9`0102UYJD0]KFe0;fm_@2m_Kd30<K6aP<0c/k>0`3Fe]H00`3Ng]h0
e]KF0=kNgP050=KFeP040<k>cP36a/H0a/K60;Fe]B00oooo003R0?ooo`80YJFU101JFUX206=SH`03
06][J`1cLg<0Lg=c0080Ng]k0`24Q8@02P1BDU80Hf=S07]kN`24Q8@0S8b<0:FUY@2m_Kd0YJFU08b<
S02m_Kd209bLW00308b<S024Q8@0Ng]k0080YJFU@`3oool20:FUY@0307]kN`24Q8@0S8b<0080W9bL
00<0YJFU0;Fe]@2e]KD00P2m_Kd30<K6aP<0c/k>1`3Fe]H30<k>cP80a/K600<0]KFe0?ooo`3oool0
7`3oool00>40oooo0P2UYJD405YJFP0406=SH`1[Jf/0Lg=c07=cL`80Ng]k0P24Q8@308b<S080W9bL
00L0]KFe0;fm_@36a/H0c/k>0=KFeP3>c/h0a/K600D0W9bL0P2<S8`00`2][Jd0YJFU0?ooo`120?oo
o`80YJFU00@0Ng]k08b<S02LW9`0W9bL0P2UYJD20;Fe]@80_Kfm0`36a/H30<k>cP050=KFeP3>c/h0
e]KF0<k>cP3Fe]H00`3>c/h20<K6aP030;Fe]@3oool0oooo0200oooo003P0?ooo`80YJFU101JFUX0
1@1SHf<0Jf][07=cL`1cLg<0Ng]k0080Q8B40P2<S8`709bLW080YJFU00<0e]KF0:FUY@2UYJD00P2U
YJD509bLW00308b<S02][Jd0YJFU04<0oooo0P2UYJD01@24Q8@0S8b<09bLW02LW9`0YJFU0080]KFe
0`2m_Kd30<K6aPL0c/k>1036a/H00`2e]KD0oooo0?ooo`0Q0?ooo`00h03oool00`2UYJD0FUYJ05YJ
FP0305YJFP0306=SH`1[Jf/0Lg=c0080Ng]k0P24Q8@00`2<S8`0W9bL09bLW00509bLW0T0YJFU1@2L
W9`00`24Q8@0YJFU0?ooo`130?ooo`80YJFU00H0[Jf]09bLW02LW9`0W9bL0:FUY@2e]KD40;fm_@<0
a/K61@3>c/h30<K6aP030;fm_@2e]KD0oooo02<0oooo003O0?ooo`80YJFU0`1JFUX01P1SHf<0Jf][
07=cL`1cLg<0Ng]k08B4Q0<0S8b<1@2LW9`30:FUY@D0]KFe00<0_Kfm0;Fe]@2e]KD00`2e]KD20:FU
Y@80W9bL00<0[Jf]0:FUY@3oool0A03oool01@2UYJD0[Jf]0:f][@2LW9`0YJFU0080[Jf]0P2e]KD4
0;fm_@030<K6aP2m_Kd0a/K60080_Kfm00<0a/K60;fm_@2e]KD09P3oool00=l0oooo00<0YJFU05YJ
FP1JFUX00P1JFUX00`1SHf<0Jf][07=cL`0207]kN`0308B4Q02<S8`0S8b<00D0W9bL0`2UYJD30;Fe
]@030;fm_@2e]KD0_Kfm0080_Kfm00<0]KFe0;fm_@2e]KD00P2e]KD01@2UYJD0W9bL09bLW02LW9`0
YJFU04L0oooo0P2][Jd00`2e]KD0W9bL0:FUY@020:f][@<0]KFe0`2m_Kd0102e]KD0_Kfm0;fm_@2e
]KDX0?ooo`00g`3oool00`2UYJD0FUYJ05YJFP0205YJFP0306=SH`1[Jf/0Lg=c0080Ng]k00<0Q8B4
08b<S02LW9`0102LW9`30:FUY@<0]KFe2@2m_Kd30;Fe]@040:FUY@2LW9`0W9bL0:FUYDT0oooo0P2e
]KD60;fm_@030<K6aP2m_Kd0a/K60080_Kfm:P3oool00=h0oooo0P2UYJD305YJFP0506=SH`1[Jf/0
Lg=c07]kN`24Q8@00P2<S8`309bLW0<0YJFU0`2e]KD40;fm_@030<K6aP2m_Kd0a/K600@0a/K6102m
_Kd01@2e]KD0YJFU09bLW02e]KD0[Jf]04h0oooo00<0a/K60?ooo`3oool0;P3oool00=h0oooo00H0
YJFU05YJFP1JFUX0FUYJ06=SH`1[Jf/207=cL`0307]kN`24Q8@0S8b<00@0W9bL0P2UYJD30;Fe]@@0
_Kfm2@36a/H40;fm_@040;Fe]@2UYJD0W9bL0:f][Gl0oooo003N0?ooo`0:0:FUY@1JFUX0FUYJ05YJ
FP1SHf<0Jf][07=cL`1kNg/0Q8B408b<S0D0W9bL00@0YJFU0;Fe]@000000]KFe102m_Kd00`36a/H0
00000<K6aP020<K6aP030<k>cP36a/H0c/k>00<0a/K60`2m_Kd0102e]KD0YJFU09bLW02][Jeo0?oo
o`00gP3oool02P2UYJD0FUYJ05YJFP1JFUX0Hf=S06][J`1cLg<0Ng]k08B4Q02<S8`409bLW0040:FU
Y@2e]KD0]KFe000000@0_Kfm0P36a/H00`000000c/k>0<K6aP050<k>cP<0a/K60P2m_Kd0102e]KD0
YJFU09bLW02][Jeo0?ooo`00gP3oool01@2UYJD0FUYJ05YJFP1JFUX0Jf][0080Lg=c00<0Ng]k08B4
Q02<S8`00`2LW9`20:FUY@80]KFe00@000000;fm_@2m_Kd0_Kfm0`36a/H00`000000c/k>0<k>cP06
0<k>cP<0a/K60P2m_Kd00`2e]KD0YJFU0:f][@1o0?ooo`00gP3oool02@2UYJD0FUYJ05YJFP1JFUX0
Jf][07=cL`1kNg/0Q8B408b<S00309bLW0<0YJFU00<0]KFe0;fm_@0000000P2m_Kd30<K6aP030<k>
cP000000c/k>0080c/k>00<0e]KF0<k>cP3Fe]H00`3>c/h30<K6aP040;fm_@2e]KD0YJFU0:f][Gl0
oooo003N0?ooo`090:FUY@1JFUX0FUYJ06=SH`1[Jf/0Lg=c07]kN`24Q8@0S8b<00<0W9bL0P2UYJD0
1@2e]KD0_Kfm0;fm_@000000_Kfm00<0a/K60P3>c/h00`000000e]KF0<k>cP050=KFeP<0c/k>0P36
a/H0102m_Kd0]KFe0:FUY@2][Jeo0?ooo`00gP3oool0102UYJD0FUYJ05YJFP1SHf<207=cL`0307]k
N`24Q8@0S8b<00<0W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd8000000P0e]KF0`3>c/h01@36a/H0_Kfm
0;fm_@2e]KD0[Jf]07l0oooo003N0?ooo`080:FUY@1JFUX0FUYJ06=SH`1cLg<0Ng]k08B4Q02<S8`3
09bLW0040:FUY@2e]KD0]KFe0;Fe]@80_Kfm00<000000<K6aP36a/H00`3>c/h00`3Fe]H000000=KF
eP020=KFeP030=kNgP3Fe]H0g]kN00<0e]KF0`3>c/h01036a/H0_Kfm0;Fe]@2e]KEo0?ooo`00gP3o
ool0202UYJD0FUYJ05YJFP1[Jf/0Lg=c07]kN`24Q8@0S8b<0P2LW9`20:FUY@80]KFe0P2m_Kd00`36
a/H000000<K6aP030<k>cP80e]KF00<000000=kNgP3Fe]H01@3Ng]h30=KFeP80c/k>00@0a/K60;fm
_@2e]KD0]KFeO`3oool00=h0oooo0P2UYJD01P1JFUX0Jf][07=cL`1kNg/0Q8B408b<S080W9bL0P2U
YJD00`2e]KD0_Kfm0;fm_@020<K6aP040000003>c/h0c/k>0<k>cP<0e]KF00<000000=kNgP3Ng]h0
1P3Ng]h30=KFeP050<k>cP36a/H0_Kfm0<K6aP2e]KD0O`3oool00=l0oooo00L0YJFU05YJFP1SHf<0
Lg=c07]kN`24Q8@0S8b<00<0W9bL00<0YJFU0;Fe]@2e]KD00P2m_Kd00`36a/H000000<K6aP030<k>
cP80e]KF00<000000=kNgP3Fe]H00`3Ng]h00`3Fe]H0g]kN0=KFeP020=KFeP050<k>cP36a/H0_Kfm
0;fm_@2e]KD0P03oool00=l0oooo00L0YJFU05YJFP1SHf<0Lg=c07]kN`24Q8@0S8b<00<0W9bL00@0
YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF2@3Ng]h30=KFeP040<k>cP36a/H0_Kfm0;Fe]H00
oooo003O0?ooo`80YJFU00@0Jf][07=cL`24Q8@0S8b<0`2LW9`00`2UYJD0]KFe0;fm_@020;fm_@80
a/K60`3>c/h30=KFeP/0g]kN0P3Fe]H0103>c/h0a/K60<K6aP2e]KF00?ooo`00h03oool01P2UYJD0
FUYJ06][J`1kNg/0Q8B408b<S0<0W9bL00@0YJFU0;Fe]@2m_Kd0_Kfm0`36a/H30<k>cP<0e]KF1`3N
g]h30=KFeP80c/k>00<0a/K60;fm_@2e]KD0P@3oool00>00oooo0P2UYJD0101cLg<0Ng]k08B4Q02<
S8`209bLW0030:FUY@2e]KD0]KFe0080_Kfm0P36a/H30<k>cP<0e]KF2@3Ng]h30=KFeP040<k>cP36
a/H0a/K60;Fe]H40oooo003Q0?ooo`80YJFU00<0Lg=c07]kN`2<S8`00`2LW9`0102UYJD0]KFe0;fm
_@2m_Kd30<K6aP<0c/k>0`3Fe]H70=kNgP<0e]KF00@0c/k>0<K6aP36a/H0]KFePP3oool00>80oooo
0P2UYJD00`1cLg<0Q8B408b<S00309bLW0040:FUY@2e]KD0_Kfm0;fm_@<0a/K60`3>c/h30=KFeP03
0=kNgP3Fe]H0g]kN00D0e]KF00@0c/k>0<K6aP36a/H0]KFeP`3oool00><0oooo0P2UYJD00`1kNg/0
Q8B408b<S00209bLW0030:FUY@2e]KD0]KFe0080_Kfm0`36a/H30<k>cPL0e]KF0`3>c/h20<K6aP03
0;Fe]@3oool0oooo0880oooo003T0?ooo`80YJFU00@0Ng]k08b<S02LW9`0W9bL0P2UYJD20;Fe]@80
_Kfm0`36a/H30<k>cP050=KFeP3>c/h0e]KF0<k>cP3Fe]H00`3>c/h20<K6aP030;Fe]@3oool0oooo
08<0oooo003U0?ooo`80YJFU00D0Q8B408b<S02LW9`0W9bL0:FUY@020;Fe]@<0_Kfm0`36a/H70<k>
cP@0a/K600<0]KFe0?ooo`3oool0Q03oool00>H0oooo00<0YJFU0:f][@2][Jd00P2LW9`00`2UYJD0
[Jf]0;Fe]@040;fm_@<0a/K61@3>c/h30<K6aP030;fm_@2e]KD0oooo08H0oooo003X0?ooo`80[Jf]
00<0]KFe09bLW02UYJD00P2][Jd20;Fe]@@0_Kfm00<0a/K60;fm_@36a/H00P2m_Kd00`36a/H0_Kfm
0;Fe]@290?ooo`00jP3oool30;Fe]@040:FUY@2][Jd0]KFe0;Fe]@<0_Kfm0`36a/H0102m_Kd0a/K6
0;fm_@2m_Kf;0?ooo`00k03oool00`2m_Kd0a/K60<K6aP050<K6aP030<k>cP36a/H0c/k>0080a/K6
S@3oool00?80oooo00<0c/k>0?ooo`3oool0T@3oool00?l0ooooQ`3oool00?l0ooooQ`3oool00?l0
ooooQ`3oool00?l0ooooQ`3oool00?l0ooooQ`3oool00?l0ooooQ`3oool00001\
\>"], "Graphics",
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{Inherited, Inherited}, {8, Inherited}},
  Evaluatable->False,
  Copyable->False,
  ImageSize->{390, 293},
  ImageMargins->{{16, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"ImageCacheDepth"->8}],

Cell["\<\
If your parent compound allows for conformational transformations, \
take a complete set of conformational generators and enter the resulting \
substituent site permutations below. Please, distinguish between \
conformations containing reflections or inversions, and those being \
reflection- and inversion-free.\
\>", NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, 12}, {7, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(To\ enter\ a\ conformational\ rotation\ generator, \ 
        press\ \(here!\)\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(Isomers`Isomers`Private`InsertConformation&),
      ButtonEvaluator->Automatic,
      Active->True]], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(To\ enter\ a\ conformational\ reflection\ generator, \ 
        press\ \(here!\)\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(Isomers`Isomers`Private`InsertConformationReflection&),
      
      ButtonEvaluator->Automatic,
      Active->True]], NotebookDefault,
  Editable->False,
  Selectable->True,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[""], "Input",
  Editable->True,
  Selectable->True,
  CellFrame->True,
  CellMargins->{{24, 24}, {20, 1}},
  Active->False,
  Evaluatable->False,
  CellFrameMargins->6,
  CellFrameLabels->{{
    Inherited, Inherited}, {
      StyleBox[ 
        "Confirmational Transformation Generators", FontWeight -> "Plain", 
          FontFamily -> "Helvetica", FontSize -> 9], Inherited}},
  CellFrameLabelMargins->2,
  CellTags->"ConfirmationGenerators"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "To store the new parent compound in the database and to complete the input \
procedure click here. ",
  StyleBox["(Do not forget to save your parent compound permanently, using \
the ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["SaveParentCompounds", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["-command on the 'Isomers Control Panel'.)",
    FontColor->RGBColor[1, 0, 0]]
}], NotebookDefault,
  Editable->False,
  Selectable->False,
  Deletable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
  Copyable->False,
  FontFamily->"Times",
  FontSize->12],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(Paste\ parent\ compound\ definition\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(NotebookApply[ Isomers`Isomers`Private`snb, #]&),
      ButtonEvaluator->Automatic,
      ButtonData:>Isomers`Isomers`Private`PasteParentCompoundDefinition,
      Active->True]], NotebookDefault,
  Editable->False,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}],

Cell["To terminate the input procedure click here.", NotebookDefault,
  Editable->False,
  Selectable->False,
  Deletable->False,
  CellMargins->{{Inherited, 5}, {7, Inherited}},
  Copyable->False,
  PageBreakAbove->True,
  LineSpacing->{1, 3},
  ScriptMinSize->9,
  CounterIncrements->"Text"],

Cell[BoxData[
    ButtonBox[
      StyleBox[\(Discard\ parent\ compound\ panel\),
        FontFamily->"Times",
        FontSize->12,
        FontWeight->"Plain"],
      ButtonFunction:>(Isomers`Isomers`Private`DiscardIsomersInputPanel&),
      ButtonEvaluator->Automatic]], NotebookDefault,
  Editable->False,
  Deletable->False,
  CellMargins->{{24, Inherited}, {5, Inherited}},
  Evaluatable->True,
  Copyable->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
Editable->True,
WindowToolbars->{},
CellGrouping->Manual,
PageWidth->420,
WindowSize->{440, 600},
WindowMargins->{{Automatic, 6}, {Automatic, 3}},
WindowFrame->"Palette",
WindowElements->{"HorizontalScrollBar", "VerticalScrollBar"},
WindowFrameElements->"CloseBox",
WindowClickSelect->True,
WindowTitle->"Parent Compound Input Panel",
PageFooters->{{
  Inherited, Inherited, Inherited}, {Inherited, None, Inherited}},
ShowCellBracket->False,
ShowGroupOpenCloseIcon->True,
CellMargins->{{5, 0}, {0, 3}},
Active->True,
CellOpen->True,
ShowCellLabel->False,
ShowCellTags->False,
ImageMargins->{{0, Inherited}, {Inherited, 0}},
Magnification->1,
MacintoshSystemPageSetup->"\<\
01h0001804P000000aP2@_ogooP3@09:8085N`?P0000005X0FP000003gP;BP5/
038;BTLH05000@4100000BL?00400@000000000000000000000000000040I000
00000000000@X@X04@000000001C=S0`\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ParentCompoundSymbol"->{
    Cell[66980, 922, 434, 14, 70, "Input",
      Evaluatable->False,
      CellTags->"ParentCompoundSymbol"]},
  "NumberOfSubstituentSites"->{
    Cell[68702, 982, 467, 15, 70, "Input",
      Evaluatable->False,
      CellTags->"NumberOfSubstituentSites"]},
  "RotationGenerators"->{
    Cell[702718, 15712, 432, 14, 70, "Input",
      Evaluatable->False,
      CellTags->"RotationGenerators"]},
  "RotationReflectionGenerators"->{
    Cell[817191, 20483, 453, 14, 70, "Input",
      Evaluatable->False,
      CellTags->"RotationReflectionGenerators"]},
  "ConfirmationGenerators"->{
    Cell[950884, 22228, 457, 14, 70, "Input",
      Evaluatable->False,
      CellTags->"ConfirmationGenerators"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ParentCompoundSymbol", 954741, 22349},
  {"NumberOfSubstituentSites", 954884, 22353},
  {"RotationGenerators", 955025, 22357},
  {"RotationReflectionGenerators", 955173, 22361},
  {"ConfirmationGenerators", 955325, 22365}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1718, 49, 337, 11, 49, NotebookDefault],
Cell[2058, 62, 390, 12, 46, NotebookDefault],

Cell[CellGroupData[{
Cell[2473, 78, 280, 9, 30, NotebookDefault],
Cell[2756, 89, 790, 20, 70, NotebookDefault],
Cell[3549, 111, 405, 13, 70, NotebookDefault,
  CellOpen->True],
Cell[3957, 126, 62736, 782, 70, 62442, 772, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[66696, 910, 281, 10, 70, NotebookDefault],
Cell[66980, 922, 434, 14, 70, "Input",
  Evaluatable->False,
  CellTags->"ParentCompoundSymbol"]
}, Closed]],

Cell[CellGroupData[{
Cell[67451, 941, 275, 9, 31, NotebookDefault],
Cell[67729, 952, 673, 16, 70, NotebookDefault],
Cell[68405, 970, 294, 10, 70, NotebookDefault],
Cell[68702, 982, 467, 15, 70, "Input",
  Evaluatable->False,
  CellTags->"NumberOfSubstituentSites"]
}, Closed]],

Cell[CellGroupData[{
Cell[69206, 1002, 272, 9, 31, NotebookDefault],
Cell[69481, 1013, 982, 27, 70, NotebookDefault],
Cell[70466, 1042, 961, 23, 70, NotebookDefault],
Cell[71430, 1067, 445, 12, 70, NotebookDefault],

Cell[CellGroupData[{
Cell[71900, 1083, 400, 13, 70, NotebookDefault,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[72303, 1098, 763, 16, 70, NotebookDefault],
Cell[73069, 1116, 451, 15, 70, NotebookDefault],

Cell[CellGroupData[{
Cell[73545, 1135, 24670, 433, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[98218, 1570, 24722, 434, 70, 3346, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[122943, 2006, 24547, 432, 70, 3349, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[147493, 2440, 24125, 426, 70, 3349, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[171621, 2868, 21953, 400, 70, 3351, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[193577, 3270, 22928, 412, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[216508, 3684, 24297, 429, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[240808, 4115, 24612, 432, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[265423, 4549, 24727, 434, 70, 3347, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[290153, 4985, 24172, 427, 70, 3339, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[314328, 5414, 20093, 377, 70, 3346, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[334424, 5793, 23262, 416, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[357689, 6211, 24224, 428, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[381916, 6641, 23864, 423, 70, 3347, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[405783, 7066, 22341, 405, 70, 3338, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[428127, 7473, 22957, 412, 70, 3343, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[451087, 7887, 24033, 425, 70, 3346, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[475123, 8314, 24164, 427, 70, 3343, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[499290, 8743, 20837, 386, 70, 3345, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[520130, 9131, 22824, 410, 70, 3344, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[542957, 9543, 24661, 433, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[567633, 9979, 387, 15, 70, NotebookDefault],
Cell[568023, 9996, 488, 13, 70, NotebookDefault],
Cell[568514, 10011, 576, 14, 70, NotebookDefault],
Cell[569093, 10027, 456, 15, 70, NotebookDefault],

Cell[CellGroupData[{
Cell[569574, 10046, 21332, 392, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics"],
Cell[590909, 10440, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[594588, 10614, 3675, 172, 70, 3351, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[598266, 10788, 3666, 172, 70, 3342, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[601935, 10962, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[605610, 11136, 3663, 172, 70, 3339, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[609276, 11310, 3666, 172, 70, 3342, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[612945, 11484, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[616620, 11658, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[620299, 11832, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[623974, 12006, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[627649, 12180, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[631328, 12354, 3670, 172, 70, 3346, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[635001, 12528, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[638676, 12702, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[642355, 12876, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[646034, 13050, 3675, 172, 70, 3351, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[649712, 13224, 3667, 172, 70, 3343, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[653382, 13398, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[657057, 13572, 3663, 172, 70, 3339, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[660723, 13746, 3674, 172, 70, 3350, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[664400, 13920, 3677, 172, 70, 3353, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[668080, 14094, 3677, 172, 70, 3353, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[671760, 14268, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[675435, 14442, 3669, 172, 70, 3345, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[679107, 14616, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[682782, 14790, 3672, 172, 70, 3348, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[686457, 14964, 3673, 172, 70, 3349, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[690133, 15138, 3677, 172, 70, 3353, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[693813, 15312, 3676, 172, 70, 3352, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[697492, 15486, 3685, 172, 70, 3353, 160, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],
Cell[701192, 15661, 388, 15, 70, NotebookDefault],
Cell[701583, 15678, 596, 15, 70, NotebookDefault],
Cell[702182, 15695, 533, 15, 70, NotebookDefault,
  Evaluatable->True],
Cell[702718, 15712, 432, 14, 70, "Input",
  Evaluatable->False,
  CellTags->"RotationGenerators"]
}, Open  ]],

Cell[CellGroupData[{
Cell[703187, 15731, 411, 13, 70, NotebookDefault,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[703601, 15746, 577, 14, 70, NotebookDefault],
Cell[704181, 15762, 420, 12, 70, NotebookDefault],
Cell[704604, 15776, 477, 14, 70, NotebookDefault],
Cell[705084, 15792, 387, 12, 70, NotebookDefault],

Cell[CellGroupData[{
Cell[705496, 15808, 29120, 516, 70, 3750, 193, "GraphicsData", "PostScript", \
"Graphics"],
Cell[734619, 16326, 4073, 205, 70, 3748, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[738695, 16533, 4070, 205, 70, 3745, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[742768, 16740, 4074, 205, 70, 3749, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[746845, 16947, 4074, 205, 70, 3749, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[750922, 17154, 4032, 202, 70, 3707, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[754957, 17358, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[758993, 17562, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[763029, 17766, 4032, 202, 70, 3707, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[767064, 17970, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[771100, 18174, 4048, 203, 70, 3723, 191, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[775151, 18379, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[779187, 18583, 4032, 202, 70, 3707, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[783222, 18787, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[787258, 18991, 4033, 202, 70, 3708, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[791294, 19195, 4032, 202, 70, 3707, 190, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[795329, 19399, 4074, 205, 70, 3749, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[799406, 19606, 4074, 205, 70, 3749, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[803483, 19813, 4070, 205, 70, 3745, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[807556, 20020, 4073, 205, 70, 3748, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[811632, 20227, 4061, 203, 70, 3728, 191, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],
Cell[815708, 20433, 468, 16, 70, NotebookDefault],
Cell[816179, 20451, 437, 12, 70, NotebookDefault],
Cell[816619, 20465, 569, 16, 70, NotebookDefault,
  Evaluatable->True],
Cell[817191, 20483, 453, 14, 70, "Input",
  Evaluatable->False,
  CellTags->"RotationReflectionGenerators"]
}, Closed]],

Cell[CellGroupData[{
Cell[817681, 20502, 404, 13, 70, NotebookDefault,
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakAbove->True,
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[818088, 20517, 697, 16, 70, NotebookDefault],
Cell[818788, 20535, 673, 19, 70, NotebookDefault],
Cell[819464, 20556, 476, 13, 70, NotebookDefault],
Cell[819943, 20571, 129281, 1603, 70, 128987, 1593, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[949227, 22176, 505, 13, 70, NotebookDefault],
Cell[949735, 22191, 562, 16, 70, NotebookDefault,
  Evaluatable->True],
Cell[950300, 22209, 581, 17, 70, NotebookDefault,
  Evaluatable->True],
Cell[950884, 22228, 457, 14, 70, "Input",
  Evaluatable->False,
  CellTags->"ConfirmationGenerators"]
}, Closed]]
}, Closed]],
Cell[951368, 22246, 636, 18, 56, NotebookDefault],
Cell[952007, 22266, 576, 15, 28, NotebookDefault,
  Evaluatable->True],
Cell[952586, 22283, 293, 9, 26, NotebookDefault,
  PageBreakAbove->True,
  CounterIncrements->"Text"],
Cell[952882, 22294, 482, 13, 28, NotebookDefault,
  Evaluatable->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

